-------------------------------------------------------------------------------
-- Title      : ErrorCounter
-- Project    : Chip-Module for first submission on 28.04.2000
-------------------------------------------------------------------------------
-- File       : ErrorCounter.vhd
-- Author     : Rolf Schneider  <rolf.schneider@kip.uni-heidelberg.de>
-- Company    : University Heidelberg - KIP
-- Last update: 2000/04/06
-- Platform   : Synopsys - 1999.10
-------------------------------------------------------------------------------
-- This is a first Chip-Module design test for the submission on 28.02.2000
-- to get experience with the AMS-0.35u technologie
-------------------------------------------------------------------------------
-- Description: Counter for Hamming decoder errors
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2000/04/05  1.0      schneide	Created
-------------------------------------------------------------------------------

library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_signed.all;
use WORK.Global.all;

-------------------------------------------------------------------------------
-- ENTITY
-------------------------------------------------------------------------------
entity ErrorCounter is
  port(clk:                     in  STD_LOGIC;
       reset:                   in  STD_LOGIC;
       enable:                  in  STD_LOGIC;
       clear:                   in  STD_LOGIC;
       hamm_st:                 in  Hamming_Status;
       data_out:                out Error_Counter_Word);
end ErrorCounter;

-------------------------------------------------------------------------------
-- ARCHITECTURE
-------------------------------------------------------------------------------
architecture v of ErrorCounter is

  -- SIGNALS ------------------------------------------------------------------
  signal count:                 Error_Counter_Word;

  -- STRUCTURE ----------------------------------------------------------------
begin

  data_out                      <= count;
  
  counter_proc: process(clk, reset, clear, hamm_st)
    begin
      if clk'event and clk='1' then
        if clear='0' then
          count <= (others => '0');
        elsif (hamm_st/="00" and enable='0') then
          count <= count + 1;
        end if;
      end if;
      if reset='0' then
        count <= (others => '0');
      end if;
    end process;

end v;
