-------------------------------------------------------------------------------
-- Title      : Global
-- Project    : Chip-Module for first submission on 28.04.2000
-------------------------------------------------------------------------------
-- File       : Global.vhd
-- Author     : Rolf Schneider  <rolf.schneider@kip.uni-heidelberg.de>
-- Company    : University Heidelberg - KIP
-- Last update: 2000/04/21
-- Platform   : Synopsys - 1999.10
-------------------------------------------------------------------------------
-- This is a first Chip-Module design test for the submission on 28.04.2000
-- to get experience with the AMS-0.35u technologie
-------------------------------------------------------------------------------
-- Description: some global used constants and types of signals
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author    Description
-- 2000/02/26  1.0      schneide  Created
-- 2000/03/28  1.1      schneide  Reduced to Low Latency Design
-------------------------------------------------------------------------------

library IEEE;
use IEEE.std_logic_1164.all;

package Global is
  
  -- CONSTANT BUS WIDTHS ------------------------------------------------------
  constant external_bus_width           : integer := 13;
  constant event_data_width             : integer := 32;
  constant hamming_code_width           : integer := external_bus_width;
  constant event_data_word_width        : integer := (event_data_width / 4);
  constant hamming_status_width         : integer := 2;
  constant error_counter_width          : integer := 6;

  -- SIGNAL TYPES -------------------------------------------------------------
  subtype External_Bus
    is STD_LOGIC_VECTOR((external_bus_width - 1) downto 0);
  
  subtype Event_Data
    is STD_LOGIC_VECTOR((event_data_width - 1) downto 0);
  
  subtype Hamming_Code
    is STD_LOGIC_VECTOR((hamming_code_width - 1) downto 0);
  
  subtype Event_Data_Word
    is STD_LOGIC_VECTOR((event_data_word_width - 1) downto 0);

  subtype Hamming_Status
    is STD_LOGIC_VECTOR((hamming_status_width - 1) downto 0);

  subtype Error_Counter_Word
    is STD_LOGIC_VECTOR((error_counter_width - 1) downto 0);

  -- CONSTANT SIGNALS ---------------------------------------------------------
  constant end_signature_code   : External_Bus    := "0000000000001";
  constant start_signature_word : Event_Data_Word := "11111111";
  
end Global;

