-------------------------------------------------------------------------------
-- Title      : Hamming_Decoder
-- Project    : Chip-Module for first submission on 28.04.2000
-------------------------------------------------------------------------------
-- File       : Hamming_Decoder.vhd
-- Author     : Rolf Schneider  <rolf.schneider@kip.uni-heidelberg.de>
-- Company    : University Heidelberg - KIP
-- Last update: 2000/04/21
-- Platform   : Synopsys - 1999.10
-------------------------------------------------------------------------------
-- This is a first Chip-Module design test for the submission on 28.02.2000
-- to get experience with the AMS-0.35u technologie
-------------------------------------------------------------------------------
-- Description: hamming decider (12,8) with parity and status output
--              generated with cmd: ~/src/c/hamming_vhdl/hamm 8
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author    Description
-- 2000/03/28  1.0      schneide  Created
-- 2000/03/30  1.1      schneide  Reduced to Low Latency Design
-------------------------------------------------------------------------------

library IEEE;
use IEEE.std_logic_1164.all;
use WORK.Global.all;

entity Hamming_Decoder is
  port (
    code:               in  Hamming_Code;
    data:               out Event_Data_Word;
    status:             out Hamming_Status);
end Hamming_Decoder;

architecture v of Hamming_Decoder is
  signal syndrom:       STD_LOGIC_VECTOR(3 downto 0);
  signal syndrom_nez:   STD_LOGIC;
  signal parity:        STD_LOGIC;
  signal parity_ok:     STD_LOGIC;
  
begin

  -- PARITY -------------------------------------------------------------------
  parity <=     code( 0) xor code( 1) xor code( 2) xor code( 3)
            xor code( 4) xor code( 5) xor code( 6) xor code( 7)
            xor code( 8) xor code( 9) xor code(10) xor code(11) ;

  parity_ok <= parity xor code(12);
  
  -- SYNDROM ------------------------------------------------------------------
  syndrom(0) <=     code( 0) xor code( 2) xor code( 4) xor code( 6) 
                xor code( 8) xor code(10) ;
  syndrom(1) <=     code( 1) xor code( 2) xor code( 5) xor code( 6) 
                xor code( 9) xor code(10) ;
  syndrom(2) <=     code( 3) xor code( 4) xor code( 5) xor code( 6) 
                xor code(11) ;
  syndrom(3) <=     code( 7) xor code( 8) xor code( 9) xor code(10) 
                xor code(11) ;

  syndrom_nez <=    syndrom(0) or syndrom(1) or syndrom(2) or syndrom(3);

  -- CORRECTED DATA -----------------------------------------------------------
  data( 0) <= code( 2) xor 
              (syndrom(0) and syndrom(1) and (not syndrom(2)) and (not syndrom(3)));
  data( 1) <= code( 4) xor 
              (syndrom(0) and (not syndrom(1)) and syndrom(2) and (not syndrom(3)));
  data( 2) <= code( 5) xor 
              ((not syndrom(0)) and syndrom(1) and syndrom(2) and (not syndrom(3)));
  data( 3) <= code( 6) xor 
              (syndrom(0) and syndrom(1) and syndrom(2) and (not syndrom(3)));
  data( 4) <= code( 8) xor 
              (syndrom(0) and (not syndrom(1)) and (not syndrom(2)) and syndrom(3));
  data( 5) <= code( 9) xor 
              ((not syndrom(0)) and syndrom(1) and (not syndrom(2)) and syndrom(3));
  data( 6) <= code(10) xor 
              (syndrom(0) and syndrom(1) and (not syndrom(2)) and syndrom(3));
  data( 7) <= code(11) xor 
              ((not syndrom(0)) and (not syndrom(1)) and syndrom(2) and syndrom(3));

  -- STATUS -------------------------------------------------------------------
  status <= syndrom_nez & parity_ok;    -- "00" : everything ok
                                        -- "01" : data ok, parity wrong
                                        -- "11" : data corrected
                                        -- "10" : data wrong, two bit error
  
end v;
