-------------------------------------------------------------------------------
-- Title      : Hamming_Encoder
-- Project    : Chip-Module for first submission on 28.04.2000
-------------------------------------------------------------------------------
-- File       : Hamming_Encoder.vhd
-- Author     : Rolf Schneider  <rolf.schneider@kip.uni-heidelberg.de>
-- Company    : University Heidelberg - KIP
-- Last update: 2000/04/04
-- Platform   : Synopsys - 1999.10
-------------------------------------------------------------------------------
-- This is a first Chip-Module design test for the submission on 28.02.2000
-- to get experience with the AMS-0.35u technologie
-------------------------------------------------------------------------------
-- Description: hamming encoder (12,8) with parity
--              generated with cmd: ~/src/c/hamming_vhdl/hamm 8
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author    Description
-- 2000/03/28  1.0      schneide  Created
-- 2000/03/30  1.1      schneide  Reduced to Low Latency Design
-------------------------------------------------------------------------------

library IEEE;
use IEEE.std_logic_1164.all;
use WORK.Global.all;

entity Hamming_Encoder is
  port (
    data:               in  Event_Data_Word;
    code:               out Hamming_Code);
end Hamming_Encoder;

architecture v of Hamming_Encoder is
  signal hamming:       STD_LOGIC_VECTOR(3 downto 0);
  signal parity:        STD_LOGIC;
  
begin

  -- HAMMING BITS -------------------------------------------------------------
  hamming(0) <=     data( 0) xor data( 1) xor data( 3) xor data( 4) 
                xor data( 6) ;
  hamming(1) <=     data( 0) xor data( 2) xor data( 3) xor data( 5) 
                xor data( 6) ;
  hamming(2) <=     data( 1) xor data( 2) xor data( 3) xor data( 7) ;
  hamming(3) <=     data( 4) xor data( 5) xor data( 6) xor data( 7) ;

  -- PARITY -------------------------------------------------------------------
  parity <=     data( 7) xor data( 6) xor data( 5) xor data( 4)
            xor hamming(3) xor data( 3) xor data( 2) xor data( 1)
            xor hamming(2) xor data( 0) xor hamming(1) xor hamming(0) ;
  
  -- OUTPUT CODE --------------------------------------------------------------
                                        -- hamming code positions are 2^x
  code       <= parity & data( 7) & data( 6) & data( 5) & data( 4) & hamming(3)
                & data( 3) & data( 2) & data( 1) & hamming(2) & data( 0)
                & hamming(1) & hamming(0) ;

end v;
