/**************************************************************************
 * Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 *                                                                        *
 * Author: The ALICE Off-line Project.                                    *
 * Contributors are mentioned in the code where appropriate.              *
 *                                                                        *
 * Permission to use, copy, modify and distribute this software and its   *
 * documentation strictly for non-commercial purposes is hereby granted   *
 * without fee, provided that the above copyright notice appears in all   *
 * copies and that both the copyright notice and this permission notice   * 
 * appear in the supporting documentation. The authors make no claims     *
 * about the suitability of this software for any purpose. It is          *
 * provided "as is" without express or implied warranty.                  *
 **************************************************************************/

/*
$Log$
*/

#include "AliTRDfitPadrow.h"
#include <AliTRDgtuGlobal.h>
#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include <time.h>
#include <AliTRDfitTracklet.h>
#include <AliTRDfitType.h>

ClassImp(AliTRDfitPadrow)

//_________________________________________________________________________
AliTRDfitPadrow::AliTRDfitPadrow():TObject()
{
  //
  //  AliTRDfitPadrow default constructor
  //

  SetHitsMin(kHitsMin);

//  for (Int_t lPad = 0; lPad < 128; lPad++)		// kPads durch 128 ersetzt
//    fCand[lPad] = new AliTRDgtuCandidate();

  for (Int_t lChip = 0; lChip < kChips; lChip++) {
    for (Int_t lChannel = 0; lChannel < kChannels; lChannel++) { 
      SetThreshold(lChip,lChannel,kThreshold);
      SetPed(lChip,lChannel,kPedestal);
    }
  }	

  fPlane   = -1;
  fSector  = -1;
  fChamber = -1;
  fPadrow  = -1;
  
  for (Int_t track= 0; track < 128; track++) {
     Tracklet[track] = new AliTRDfitTracklet(fPlane, fSector, fChamber, fPadrow);
     for(Int_t time=0; time < kTimebins; time++) {
       Tracklet[track]->SetfHitPos(time, -1);
      } 
  
     
     //for(Int_t time=0; time < kTimebins; time++) { 
     //  for(Int_t cluster=0; cluster < kCluster; cluster++) {
     //    Tracklet[track]->SetfDigitHit(time, cluster, NULL);	// initialisiere mit NULL-Pointer
     //  }
     // }
  }
  
  ari_1 = new  AliTRDfitType();
  ari_2 = new  AliTRDfitType();
  ari_3 = new  AliTRDfitType();	
  ari_4 = new  AliTRDfitType();   
  ari_5 = new  AliTRDfitType();
  ari_6 = new  AliTRDfitType();
}

//_________________________________________________________________________
AliTRDfitPadrow::AliTRDfitPadrow(Int_t iPlane, Int_t iSector, Int_t iChamber, Int_t iPadrow):TObject()
{
  //
  //  AliTRDfitPadrow default constructor
  //

  SetHitsMin(kHitsMin);

//  for (Int_t lPad = 0; lPad < 128; lPad++)
//    fCand[lPad] = new AliTRDgtuCandidate();

  for (Int_t lChip = 0; lChip < kChips; lChip++) {
    for (Int_t lChannel = 0; lChannel < kChannels; lChannel++) { 
      SetThreshold(lChip,lChannel,kThreshold);
      SetPed(lChip,lChannel,kPedestal);
    }
  }	

  fPlane   = iPlane;
  fSector  = iSector;
  fChamber = iChamber;
  fPadrow  = iPadrow;
  
  Cut_off_chi = 500;
  Cut_off_m = 255;
  Cut_off_b = 16384;
  
  for (Int_t track= 0; track < 128; track++) {
     Tracklet[track] = new AliTRDfitTracklet(fPlane, fSector, fChamber, fPadrow);
     for(Int_t time=0; time < kTimebins; time++) {
       Tracklet[track]->SetfHitPos(time, -1);
      } 
  
     // for(Int_t time=0; time < kTimebins; time++) {
     //    for(Int_t cluster=0; cluster < kCluster; cluster++) {
     //      Tracklet[track]->SetfDigitHit(time, cluster, NULL);   // initialisiere mit NULL-Pointer
     //    }
     // }
  } 
  
  ari_1 = new  AliTRDfitType();
  ari_2 = new  AliTRDfitType();
  ari_3 = new  AliTRDfitType();	
  ari_4 = new  AliTRDfitType();   
  ari_5 = new  AliTRDfitType();
  ari_6 = new  AliTRDfitType();
  
}


//_________________________________________________________________________
AliTRDfitPadrow::~AliTRDfitPadrow()
{
  //
  //  AliTRDfitPadrow default destructor
  //

//  for (Int_t lPad = 0; lPad < 128; lPad++)
//    delete fCand[lPad];
    
  for (Int_t track= 0; track < 128; track++) {
   delete Tracklet[track];
     }
   delete ari_1; delete ari_2; delete ari_3; delete ari_4; delete ari_5;
}

//_________________________________________________________________________
void AliTRDfitPadrow::OutputAmplitudes()
{
  //
  //  Output amplitudes of current padrow
  //  ab die post

  AliTRDdigit *lDigit;

  Int_t lDet    = fTRDgeometry->GetDetector(fPlane, fChamber, fSector); 
  Int_t colMax  = fTRDgeometry->GetColMax(fPlane);
  Int_t timeMax = fTRDgeometry->GetTimeMax();

  printf("\n*** AliTRDfitPadrow : digit amplitudes for plane %d, chamber %d, sector %2d, padrow %2d\n\n",
      fPlane, fChamber, fSector, fPadrow);
  for(Int_t col = 0; col < colMax; col++) {
    printf("ch %3d : ", col);
    for(Int_t time = 0; time < timeMax; time++) {
      lDigit = fDigitsManager->GetDigit(fPadrow,col,time,lDet);
      if(lDigit) printf("%3d ", lDigit->GetAmp());
      delete lDigit;
    }
    printf("\n");
  } 
}


//_________________________________________________________________________
void  AliTRDfitPadrow::fit_in_echt(Int_t sumXi, Int_t sumYi, Int_t sumXiYi, Int_t sumXi2, Int_t sumhit, Double_t *m, Double_t *b)
{
  //
  // To calculate the real fit we need:
  // a12 = a21 = sum xi, r1 = sumyi, r2 = sumxiyi,
  // a22 = sumxi2, a11 = n(hitcount).
  // Then we solve the set of equations (Kramerregel).
  //
  // y = m*x + b; r1 = a11*b+a12*m; r2 = a21*b+a22*m;
  // b = (r1*a22 - a12*r2)/det; m = (a11*r2 - r1*a21)/det;
  // det = a11*a22 - a12*a21
  //

  double a[2][3] = {{0},{0}} ; /* Matrix fuer die Summen  */
  double det ;
 
  a[1][1] = sumXi2;		  
  a[0][1] = sumXi;
  a[0][2] = sumYi;
  a[1][2] = sumXiYi;
    
  a[1][0] = a[0][1];  a[0][0] =  sumhit;
  det = a[0][0]*a[1][1]-a[0][1]*a[1][0];
  *b = ( a[0][2]*a[1][1]-a[0][1]*a[1][2] ) / det ;
  *m = ( a[0][0]*a[1][2]-a[0][2]*a[1][0] ) / det ;
}

//_________________________________________________________________________
void  AliTRDfitPadrow::hardwarefit(Int_t sumXi, Int_t sumYi, Int_t sumXiYi, Int_t sumXi2, Int_t sumhit, Int_t *tmp_m, Int_t *tmp_b)
{
  //
  // Calculate the fit with hardware arithmetik
  //

  Int_t nenner   = 0;
  Int_t mz       = 0;
  Int_t bz       = 0;
  Int_t op1, op2 = 0;

  const int mask_24	= 0x00ffffff;	  // 24 Bit WE IMPLEMENT 24 BIT ARITHMETIC
//  const int mask_32	= 0xffffffff;	  // 32 Bit
//  const int mask_16	= 0x0000ffff;	  // 16 Bit
//  const int mask_18	= 0x0003ffff;	  // 18 Bit
  const int mask_xi	= 0x000001ff;	  //  9 Bit
//  const int mask_xiyi = 0x00007fff;	  // 15 Bit
//  const int mask_yi	= 0xffffffff;	  // 11 Bit
  const int mask_xi2  = 0x00003fff;	  // 14 Bit
//  const int mask_yi2  = 0x00007fff;	  // 15 Bit
  const int mask_hc	= 0x0000001f;	  //  5 Bit
//  const int mask_msb  = 0x10000000;	// MSB Maske
  
  sumXi   = sumXi   & mask_xi;	// ok falk
  // sumYi   = sumYi   & mask_yi;  // vorsicht
  // sumXiYi = sumXiYi & mask_xiyi;// vorsicht
  sumXi2  = sumXi2  & mask_xi2;	// ok falk
  sumhit  = sumhit  & mask_hc;	// ok falk
  
  // Calculate denominator (nenner)
  // In this version we implement 24 Bit arithmetic
  nenner = ((sumhit * sumXi2) & mask_24) - ((sumXi * sumXi) & mask_24);
  op1 = sumhit * sumXi2;
  if (ari_check(op1)) {SetAriError();}
  op2 = sumXi * sumXi;
  if (ari_check(op2)) {SetAriError();}
  nenner = op1 - op2;
  if (ari_check(nenner)) {SetAriError();}
  
  // Calculate numerator  (zaehler) and results
  
  op1 = sumhit * sumXiYi;
  if (ari_check(op1)) {SetAriError();}
  op2 = sumXi * sumYi;
  if (ari_check(op2)) {SetAriError();}
  mz = op1 - op2;
  mz = mz << 5;
  if (ari_check(mz)) {SetAriError();}
  op1 = sumYi * sumXi2;
  if (ari_check(op1)) {SetAriError();}
  op2 = sumXiYi * sumXi;
  if (ari_check(op2)) {SetAriError();}
  bz = op1 - op2;
  if (ari_check(bz)) {SetAriError();}
  
  //ari_1->ari = sumhit * sumXiYi; ari_2->ari = sumXi * sumYi; ari_3->ari = ari_1 - ari_2;
  //ari_4->ari = sumYi * sumXi2; ari_5->ari = sumXiYi * sumXi; ari_6->ari = ari_4 - ari_5;
  //ari_1->ari = ari_3->ari / nenner;
  //ari_2->ari = ari_6->ari / nenner;
  
  // cout << "Nenner: " << (int)nenner << endl << endl;
  // cout << "mz: " << (int)mz << endl;
  // cout << "bz: " << (int)bz << endl;
  
  *tmp_m = mz / nenner;
  *tmp_b = bz / nenner;
  
  //*m = mz / nenner;
  //*b = bz / nenner;
}

//_________________________________________________________________________
void AliTRDfitPadrow::merge_2ch_rc(Int_t  *sumXi_c, Int_t *sumXi_r, Int_t *sumYi_c, 
Int_t *sumYi_r, Int_t *sumXiYi_c, Int_t *sumXiYi_r, Int_t *sumXi2_c, Int_t *sumXi2_r, Int_t *sumhit_c, Int_t *sumhit_r)
{
  //
  //  move data from the RIGHT channel TO the CENTER channel
  //
 
  *sumXi_c = (*sumXi_c) + (*sumXi_r);
  *sumYi_c = (*sumYi_c) + (*sumYi_r) + (*sumhit_r) * 127;
  *sumhit_c = (*sumhit_c) + (*sumhit_r);
  *sumXiYi_c = (*sumXiYi_c) + (*sumXiYi_r) + 127 * (*sumXi_r);
  *sumXi2_c = (*sumXi2_c) + (*sumXi2_r);
  *sumXi_r = 0;
  *sumYi_r = 0;
  *sumhit_r = 0;
  *sumXiYi_r = 0;
  *sumXi2_r = 0;
}

//_________________________________________________________________________
void AliTRDfitPadrow::chi(Double_t m, Double_t b, Int_t hitcount, Int_t yi[kTimebins], Int_t *chi2)
{
  //
  //  calculate chi
  //  

  Double_t tmp_sum = 0;
  Double_t tmp_yi = 0.0;

  for (Int_t l=0; l<kTimebins; l++) {
    if (yi[l] != -5000) {
      tmp_yi = yi[l];
      tmp_sum += (tmp_yi - (m*l+b)) * (tmp_yi - (m*l+b));
    }
  }
  *chi2 = ((int)tmp_sum)/(hitcount);
}

//_________________________________________________________________________
void AliTRDfitPadrow::movedata_rc(Int_t matrix[kChannels][kTimebins], Int_t center, Int_t right, Int_t chip )
{
  //
  //  move data from right channel to center channel
  //

  for (Int_t k=0; k<kTimebins; k++) {
    if (matrix[right][k] != -5000)  {
      // move data from right to center channel
      matrix[center][k]= (matrix[right][k]) + 127;
      // delete all data in right channel
      matrix[right][k]= -5000;
    }
  }
}

//_________________________________________________________________________
void AliTRDfitPadrow::moveptr_rc( Int_t center, Int_t right)

{
  //
  //  move ptr from the RIGHT channel to CENTER channel
  //
  
  // AliTRDdigit *tmp;
  Int_t tmp;
  Int_t size = 0;
  Int_t trackid = 0;
  Int_t trackcount = 0;
  Int_t Pos = -2000;
    

  for (Int_t k=0; k<kTimebins; k++) {	// loop over all timebins
    // for (Int_t j=0; j<kCluster; j++) {
    //  if (Tracklet[right]->GetfDigitHit(k,j) != NULL)  {
      if (Tracklet[right]->GetfHitPos(k) != -1)  {
      // move data from center to right channel
      // tmp = Tracklet[right]->GetfDigitHit(k,j);
      tmp = Tracklet[right]->GetfHitPos(k);
      // Tracklet[center]->SetfDigitHit(k,j,tmp);
      Tracklet[center]->SetfHitPos(k,tmp);
      // delete all data in center channel
      // Tracklet[right]->SetfDigitHit(k,j,NULL);
      Tracklet[right]->SetfHitPos(k,-1);
     }
   }
// }
 
  
  size = Tracklet[right]->GetASize();
  for (Int_t p = 0; p < size; p++) {				// loop over all tracklets
    trackid = Tracklet[right]->GetTrackAt(p);			// get Track ID right
    trackcount = Tracklet[right]->GetTrackCountAt(p);		// Get Trackcount right
  	if (trackid != -1) {					// IMPORTANT, only valid trackids are shiftet
	    // cout << "Shift Track ID and Count from right to center , right: " << right << " center: " << center << endl;
	    // cout << "ID Right: " << trackid << endl;
            Tracklet[center]->AddTrackandCount(trackid, trackcount);
	    Tracklet[right]->SetTrackAt( -1 ,p);
	}
   } 
 
// Move all entries in yi-array from Right to Center channel
 for (Int_t i = 0; i < kTimebins; i++) { 
   Pos = Tracklet[right]->GetYi(i);
   if (Pos != -2000) {
     Pos = Pos + 126;
     Tracklet[center]->SetYi(i,Pos);
     Tracklet[right]->SetYi(i,-2000);
   }
  } // end for
 
} // end moveptr_rc

//_________________________________________________________________________
void AliTRDfitPadrow::Fit()
{
  //
  //  main routine for candidate calculation within single padrow
  //

  Double_t m[8][kChannels];               // Steigung 32 Bit
  Double_t b[8][kChannels];               // Achsenabschnitt 32 Bit
  
  Int_t tmp_m[8][kChannels];		  // Steigung 32 Bit mit Check
  Int_t tmp_b[8][kChannels];  		  // Achsenabschnitt 32 Bit mit Check
  

  // Here the results 8 chips, 17 channels
  Int_t sum_Xi[8][kChannels], sum_Yi[8][kChannels];
  Int_t sum_XiYi[8][kChannels], sum_Xi2[8][kChannels]; 
  Int_t sum_Yi2[8][kChannels];
  Int_t sum_hit[8][kChannels], sum_trd[8][kChannels];
  Int_t channel[8][kChannels+2], ch_sum[8][kChannels], ch_diff[8][kChannels], ch_trd[8][kChannels];
  Int_t ch_hit[8][kChannels];
  
  
  Int_t YI[8][kChannels][kTimebins];
  Int_t i, j, h;
  Int_t diff_abs, diff_neg, Yi;
  Int_t ilogd, ilogs;
  Int_t tmp1, pad =0;
  Int_t Trackcount = -1;
  Int_t amplitude = -1;
  Int_t position = -2000;
  
  // Clear all arrays
  for (i= 0; i<8; i++) {
   for (j= 0; j<kChannels; j++) {
    sum_Xi[i][j]= sum_Yi[i][j]= sum_XiYi[i][j]= sum_Xi2[i][j]= 0;
    sum_Yi2[i][j]= sum_hit[i][j]= sum_trd[i][j]= 0; 
    ch_hit[i][j] = ch_sum[i][j]= ch_diff[i][j]= ch_trd[i][j] = 0;
    for (Int_t k= 0; k<kTimebins; k++) {
     YI[i][j][k] = -5000;
    }
   }
  }

  // Dump data to internal used channel array and sub. pedestal
  AliTRDdigit *lDigit;
  Int_t lDet    = fTRDgeometry->GetDetector(fPlane, fChamber, fSector); 
  Int_t  colMax = fTRDgeometry->GetColMax(fPlane);
  Int_t timeMax = fTRDgeometry->GetTimeMax();

  for (i = 0; i < timeMax; i++) { 	// for each valid timebin, use rolfs max timebin number
    for (Int_t k = 0; k < 8; k++) { 	// for each chip 0..7
      for (j = 0; j<19; j++) {		// each chip have 19 inputs, becuse we have 17 channels
        Int_t digcol = j+k*16;		// to get the digits
	if((digcol-1 >= 0) && (digcol-1 < colMax)) {
          lDigit = fDigitsManager->GetDigit(fPadrow,digcol-1,i,lDet);
          
	  amplitude= lDigit->GetAmp();  // Get the Amplitude
	  delete lDigit;		// delete the pointer
	  if (amplitude > (pow(2,kADCBitwidth)-1))		// cut amplitudes and set 
	  amplitude = int(pow(2,kADCBitwidth)-1);	
	  channel[k][j] = amplitude - fPed[k][j]; // negativ numbers are not possible
	}
        else {
          channel[k][j]= 0; 		// invalid channels set Amplitude = 0
	}  
      }					// end loop channel
    
    
    
  // calculate faro-sums for each channel and store in Mems
  // calculate hit flags for each chip ans all channels
  for (j= 0; j<kChannels; j++) {	// loop over all channels
   //                left             center          right
   ch_sum[k][j]= channel[k][j] + channel[k][j+1] + channel[k][j+2]; // calculate sum(l,c,r)
   ch_diff[k][j]= channel[k][j+2] - channel[k][j];                  // calculate diff(l,r)
   ch_hit[k][j]= ((channel[k][j]<channel[k][j+1]) && (channel[k][j+1]>=channel[k][j+2]))
   && ch_sum[k][j]>=fThreshold[k][j];   // find hits
        // ch_trd[k][j]= channel[k][j+1] >> 8; // gain signatur, not used yet
   ch_trd[k][j]= 0;	// TR Bit is not used in FaRo 1, set to 0 ! 
      }

  // no hits are deleted in FaRo 2 Design
  // calculate Positions (Yi)
  // split into two sectors
  
  for (h= 0; h<8; h++) {		// lopp over all pads (first section) from the chip 0..7
   if (ch_hit[k][h] != 0) {		// for all valid hits
    pad = h+k*16;			// to get the track ID
    					// 16 because one channel is twice

    if (pad < 0) pad = 0;		// only valid pads
    
    if (k != 0) {
     if ((pad >= 0) && (pad < colMax) && (h != 0)) { // Track ID's from channel 0 are not saved
      Tracklet[pad]->SetfHitPos(i, pad); // save hit position (timebin, pad) 
      tmp1 = fDigitsManager->GetTrack(0, fPadrow, pad, i, lDet); // Get Track (0, fPadrow, temp+k*16, i, lDet); 
      //cout << "AddTrack; k!=0; Teil 1; pad=" << h+k*16 << " Timebin " << i << endl;
      Tracklet[pad]->AddTrack(tmp1);				 // Add Track ID to ftracks !!!!! OK THATS WORK FINE !!!!!!!
     }
    }
    else {
     if ((pad >= 0) && (pad < colMax)) { // the first chip, to avoid shadow track id's
      Tracklet[pad]->SetfHitPos(i, pad); // save hit position (timebin, pad)
      tmp1 = fDigitsManager->GetTrack(0, fPadrow, pad, i, lDet); // get track id
      //cout << "AddTrack; k=0; Teil 2; pad=" << h+k*16 << " Timebin " << i << endl;
      Tracklet[pad]->AddTrack(tmp1);			 // add track ID to ftracks !!!!! OK THATS WORK FINE !!!!!!!
     }
    }
   }
  }
         
  // The last channal is also included in the next chip 
  // Track ID from the last channel are saved in this section 
  for (h= 8; h < 17; h++) {
   if (ch_hit[k][h] != 0) {		// for all valid hits
    pad = h+k*16;							
    if (pad < 0) pad = 0;
    if ((pad >= 0) && (pad < colMax)) {
     Tracklet[pad]->SetfHitPos(i, pad);	
     tmp1 = fDigitsManager->GetTrack(0, fPadrow, pad, i, lDet);
     //cout << "AddTrack; k=0; Teil 3; pad=" << h+k*16 << " Timebin " << i << endl; 
     Tracklet[pad]->AddTrack(tmp1);
    }
   } 
  }

  // for each channel with hit ...
  for (j= 0; j<kChannels; j++) { 	// loop over all channels
   if (ch_hit[k][j]) {			// search for hit  
   diff_abs= ch_diff[k][j];	// the divider use only pos. numbers
   diff_neg= 0; 		// '1' if divisor or divident is negativ
   if (diff_abs<0) { diff_abs= - diff_abs; diff_neg= 1; }
   if (diff_abs>=2) {          
    // the special log divider
    ilogd= (Int_t)((log((double)diff_abs)-log(2.0)) * 42.88 + 0.5) ;
    ilogs= (Int_t)((log((double)ch_sum[k][j])-log(2.0)) * 42.88 + 0.5) ;
    Yi= (unsigned char)(((exp(-1.0*((double)(ilogs - ilogd))/42.88)) * 128.0) + 0.5);
    // Yi = (unsigned char)((((double)diff_abs * 127.0) / (double)ch_sum[k][j]) + 0.5);
   }
   else 				// the divident is less than 2
   Yi= 0;				// set the position to 0
   
   

  // update all sum memories
  // here we produce shadow tracklets
  // be careful
  
  sum_Xi[k][j]+= i;			// Xi (timebin)
  sum_Yi[k][j]+= diff_neg? -Yi : Yi;	// Yi (position)
  sum_XiYi[k][j]+= diff_neg? i*(-Yi) : i*Yi; // Xi * Yi
  sum_Xi2[k][j]+= i*i;			// Xi * Xi
  sum_Yi2[k][j]+= Yi*Yi;		// Yi * Yi
  sum_hit[k][j]+= 1;			// hitcounter
  sum_trd[k][j]+= ch_trd[k][j];		// TR signatur, not used yet
  YI[k][j][i]= diff_neg? -Yi : Yi;	// position
  position = diff_neg? -Yi : Yi;	// position
  if ((k != 0) && (j != 0)) { 
   Tracklet[k*(kChannels-1)+j]->SetYi(i, position); // because one channel is twice
   						    // we don't look at channel 0
  }
  if (k == 0) { Tracklet[j]->SetYi(i, position); } // In the first chip we also look to channel 0
  position = 0xdeadface;		// inpossible number
	  
   }	// end search for hits
  }     // end loop over all channels in one chip	
 }      // end loop over all chips    
     
  for(Int_t a=0; a<8;a++) {			// clear channel-hit-array	
   for(Int_t b=0; b<kChannels;b++) {
    ch_hit[a][b] = 0;
   }
  }
  
 } 	// end loop over timebins
 	
	// end of Faro 1 simulation
	//**********************************************************************************************************************
	

 // initialization of result arrays
  for(Int_t x=0; x<8; x++) {		
    for(Int_t y=0; y<kChannels; y++) {
      m[x][y] = b[x][y] = -1.0;		// -1.0
      tmp_m[x][y] = tmp_b[x][y] = -1;
      fChi[x][y]= -2000;
    }
  }
  
  
  // The linear fit; powered by MIMD CPU
  // be careful; exclude shadow tracklets
  
 
  for(Int_t x=0; x<8;x++) { 		// loop over all chips
   for(Int_t y=0; y<kChannels;y++) { 	// loop over all channels
    
    
    // A single Track inside one channel 
    // condition for a stiff track
    if ((sum_hit[x][y] > fHitsMin) && (sum_hit[x][y+1] < fHitsMin/2) && (y!= 16)) {
     fit_in_echt(sum_Xi[x][y], sum_Yi[x][y], sum_XiYi[x][y], sum_Xi2[x][y], sum_hit[x][y], &m[x][y], &b[x][y]);
     hardwarefit(sum_Xi[x][y], sum_Yi[x][y], sum_XiYi[x][y], sum_Xi2[x][y], sum_hit[x][y], &tmp_m[x][y], &tmp_b[x][y]);
    
     if ((x != 0) && (y != 0)) {     
      Tracklet[x*(kChannels-1)+y]->SetfMerge (0); // tracklet is not merged	  
     }
     if (x == 0) { Tracklet[y]->SetfMerge (0);}
     continue; // next channel
   }      
  
    // Single track over two channels
    // shift data from the RIGHT channel TO the CENTER channel
    // and calculate the fit parameter
    if ((sum_hit[x][y] > fHitsMin/2) && (sum_hit[x][y+1] > fHitsMin/2) && (y!= 16)) {
     // shift data
     merge_2ch_rc( &sum_Xi[x][y], &sum_Xi[x][y+1], &sum_Yi[x][y], &sum_Yi[x][y+1], &sum_XiYi[x][y], &sum_XiYi[x][y+1], 
     &sum_Xi2[x][y], &sum_Xi2[x][y+1], &sum_hit[x][y], &sum_hit[x][y+1]);
     // calculate fit parameter 
     fit_in_echt(sum_Xi[x][y], sum_Yi[x][y], sum_XiYi[x][y], sum_Xi2[x][y], sum_hit[x][y], &m[x][y], &b[x][y]);
     hardwarefit(sum_Xi[x][y], sum_Yi[x][y], sum_XiYi[x][y], sum_Xi2[x][y], sum_hit[x][y], &tmp_m[x][y], &tmp_b[x][y]);    
     moveptr_rc( x*(kChannels-1)+y, x*(kChannels-1)+y+1); // move pointer from right to center channel
     
     if ((x != 0) && (y != 0)) { 
      Tracklet[x*(kChannels-1)+y]->SetfMerge (1); //tracklet is merged
     }
     if (x == 0) { Tracklet[y]->SetfMerge (1);}
     movedata_rc(YI[x], y, y+1, x); 		//Move Pos data from right to center
     // reset hitcounter from right channel
     sum_hit[x][y+1]= 0;
     // reset pos and m from right channel
     b[x][y+1]= -1;
     
     y++;    
     continue;
    } // end merge
   }  // end loop over all channels
  }   // end loop over all chips
  

//  for(Int_t x=0; x<8;x++) {
//   for(Int_t y=0; y<kChannels;y++) {
//    if(tmp_b[x][y] != b[x][y]) cout << "Fehler im B-Array Channel: " << "b= " << b[x][y] << " tmp_b= " << tmp_b[x][y] << endl;
//     if(tmp_m[x][y] != m[x][y]) cout << "Fehler im M-Array m= " << m[x][y] << " tmp_m= " << tmp_m[x][y]  << endl;
//   }
//  }

  // calculate chi**2
  for(Int_t x=0; x<8;x++) {
   for(Int_t y=0; y<kChannels;y++) {
    if((x*(kChannels-1)+y >= 0) && (x*(kChannels-1)+y < colMax)) {
     if (b[x][y]!= -1) {
      chi(m[x][y], b[x][y], sum_hit[x][y], YI[x][y], &fChi[x][y]);
     }
    }
   }
  }

  Int_t ex1 = 0; Int_t ex2 = 0; Int_t ex3 = 0;
  
  
  for(Int_t x=0; x<8;x++) { 		// loop over all chips	
   for(Int_t y=0; y<kChannels;y++) { 	// loop over all channels
    if((x*(kChannels-1)+y >= 0) && (x*(kChannels-1)+y < colMax)) {
     if (b[x][y]!= -1) {			
       // hier habe ich trotz langem denken viel MIst gebaut !!!
       b[x][y]= b[x][y] + 64 + y * 127 + x * (kChannels-1) * 127;
	
       if (b[x][y] > Cut_off_b)  { 
        //b[x][y]= -1;
        //m[x][y]= -1;
	ex1 = 1;
       }
      
       // Die Multiplikation wurde geaendert, m wird geshiftet !!!!!!!
       m[x][y]= m[x][y] * 15.059 + 128;
       if (m[x][y] < 0 || m[x][y] > Cut_off_m) {
        //m[x][y]= -1;
        //b[x][y]= -1;
        ex2 = 3;
       }
      
       if (fChi[x][y] > Cut_off_chi) {
        //m[x][y]= -1;
        //b[x][y]= -1;
        //fChi[x][y]= -2000;
        ex3 = 5;
       }
      
       if (tmp_b[x][y]!= -1) {
        if (x == 0) {						
	 Tracklet[y]->SetfEject(ex1+ex2+ex3);
	 Tracklet[y]->SetfRPos((Int_t)b[x][y]);
	 Tracklet[y]->SetfAngle((Int_t)m[x][y]);
	 Tracklet[y]->SetfChi2((Int_t)fChi[x][y]);
	 Trackcount = Tracklet[y]->TrackCount();
	 Tracklet[y]->SetfNTracks(Trackcount);
	 Tracklet[y]->MainTrack();
	}
	if (x != 0) {
	 Tracklet[x*(kChannels-1)+y]->SetfEject(ex1+ex2+ex3);
	 Tracklet[x*(kChannels-1)+y]->SetfRPos((Int_t)b[x][y]);
	 Tracklet[x*(kChannels-1)+y]->SetfAngle((Int_t)m[x][y]);
	 Tracklet[x*(kChannels-1)+y]->SetfChi2((Int_t)fChi[x][y]);
	 Trackcount = Tracklet[x*(kChannels-1)+y]->TrackCount();
	 Tracklet[x*(kChannels-1)+y]->SetfNTracks(Trackcount);
	 Tracklet[x*(kChannels-1)+y]->MainTrack();
	}
	ex1 = ex2 = ex3 = 0;
       }
      } 
     } // end if colmax
    }  // end loop pads
   }   // end loop chips
  }    // the end my friend
