#ifndef ALITRDFITPADROW_H
#define ALITRDFITPADROW_H
/* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               */

/* $Id$ */

#include <TObject.h>
#include <AliTRDdigit.h>
#include <AliTRDdigitsManager.h>
#include <AliTRDgeometry.h>
#include <AliTRDgtuCandidate.h>
#include "AliTRDfitConst.h"
#include <AliTRDfitTracklet.h>
#include <AliTRDfitType.h>
#include <math.h>


class AliTRDfitPadrow : public TObject {

  public:

    AliTRDfitPadrow();
    AliTRDfitPadrow(Int_t iPlane, Int_t iSector, Int_t iChamber, Int_t iPadrow);
    virtual ~AliTRDfitPadrow();


    void         Fit();
    AliTRDgtuCandidate *GetCandidate(Int_t iPad);
    Int_t        GetChi(Int_t col) { return fChi[col/16][col%16]; }
    AliTRDdigitsManager *GetDigitsManager() { return fDigitsManager; }
    Int_t        GetHitsMin() const { return fHitsMin; }
    Int_t        GetPed(Int_t chip_nr, Int_t channel_nr) { return fPed[chip_nr][channel_nr]; }
    Int_t        GetThreshold(Int_t chip_nr, Int_t channel_nr) { return fThreshold[chip_nr][channel_nr]; }
    AliTRDgeometry *GetTRDgeometry() { return fTRDgeometry; }
    AliTRDfitTracklet *GetTracklet(Int_t pad) {return Tracklet[pad];}
    Int_t	 GetCut_off_chi(){return Cut_off_chi;}
    Int_t	 GetCut_off_m(){return Cut_off_m;}
    Int_t	 GetCut_off_b(){return Cut_off_b;}
    Int_t	 GetBitwidth(){return kADCBitwidth;}
//    Int_t	 Posdivider(Int_t divident Int_t divisor);
    Int_t	 ari_check(Int_t value) {
    		 Double_t tmp = 0.0;
    		 if ((value > -8388608) && (value < 8388607)) {return 0;}
		 else {
		 // cout << "Fehler: Operand cannot fit into 24 Bit" << endl;
		 tmp = log(value) / log(2);
		 tmp = int(tmp+2);
		 // cout << "You need " << tmp << " Bits (TC)" << endl;
		 return 1;
		 } }
    Int_t	 GetAriError(){return AriErrorCount;}
		 
		 
    
    void         OutputAmplitudes();
    void	 SetCut_off_chi(Int_t chi){Cut_off_chi = chi;}
    void	 SetAriError(){AriErrorCount += 1;}
    void	 SetCut_off_m(Int_t m){Cut_off_m = m;}
    void	 SetCut_off_b(Int_t b){Cut_off_b = b;}
    void         SetCandidate(Int_t iPad, Int_t iOffset, Int_t iAngle);
    void         SetChi(Int_t chi, Int_t chip, Int_t pad) { fChi[chip][pad] = chi; }
    void         SetDigitsManager(AliTRDdigitsManager *iDigitsManager) { fDigitsManager = iDigitsManager; }
    void         SetHitsMin(Int_t iHitsMin) { fHitsMin = iHitsMin; }
    void         SetPed(Int_t chip_nr, Int_t channel_nr, Int_t Ped) { fPed[chip_nr][channel_nr] = Ped; }
    void         SetThreshold(Int_t chip_nr, Int_t channel_nr, Int_t TH) { fThreshold[chip_nr][channel_nr] = TH; }
    void	 SetThreshold(Int_t TH){
    		   for (Int_t lChip = 0; lChip < kChips; lChip++) {
    			for (Int_t lChannel = 0; lChannel < kChannels; lChannel++) { 
      				fThreshold[lChip][lChannel] = TH; }}}

    void         SetTRDgeometry(AliTRDgeometry *iTRDgeometry) { fTRDgeometry = iTRDgeometry; }
    
    

  private:

    void         fit_in_echt(Int_t sumXi, Int_t sumYi, Int_t sumXiYi, Int_t sumXi2, Int_t sumhit, Double_t *m, Double_t *b);
    void         hardwarefit(Int_t sumXi, Int_t sumYi, Int_t sumXiYi, Int_t sumXi2, Int_t sumhit, Int_t *tmp_m, Int_t *tmp_b);

    void         merge_2ch_rc(Int_t  *sumXi_c, Int_t *sumXi_r, Int_t *sumYi_c, Int_t *sumYi_r, Int_t *sumXiYi_c, 
                     Int_t *sumXiYi_r, Int_t *sumXi2_c, Int_t *sumXi2_r, Int_t *sumhit_c, Int_t *sumhit_r);
    void         movedata_rc(Int_t matix[16][kTimebins], Int_t center, Int_t right, Int_t chip);
    void	 moveptr_rc(Int_t center, Int_t right);
    void         chi(Double_t m, Double_t b, Int_t hitcount, Int_t yi[kTimebins], Int_t *chi2);
    void 	 addTrack(Int_t col, Int_t time);



    AliTRDfitType *ari_1;
    AliTRDfitType *ari_2;
    AliTRDfitType *ari_3;
    AliTRDfitType *ari_4;
    AliTRDfitType *ari_5;
    AliTRDfitType *ari_6;
    
    AliTRDfitTracklet *Tracklet[128];
    AliTRDdigitsManager *fDigitsManager;
    AliTRDgeometry *fTRDgeometry;
    Int_t   fPed[kChips][kChannels];
    Int_t   fHitsMin;
    Int_t   fThreshold[kChips][kChannels];
    Int_t   fChi[kChips][kChannels];
   
    Int_t   fPlane;   // current plane identifier
    Int_t   fSector;  // current sector identifier
    Int_t   fChamber; // current chamber identifier
    Int_t   fPadrow;  // current padrow identifier

    Int_t   Cut_off_chi;       // cutt off for chi2 eject
    Int_t   Cut_off_m;         // cutt off for m eject
    Int_t   Cut_off_b;         // cutt off for b eject
    
    Int_t   AriErrorCount;     // Count of Arithmetic Bit width violations
    




  protected:

    ClassDef(AliTRDfitPadrow,1) 			// Data container for one TRD GTU Candidate

};


    

#endif
