#ifndef ALITRDFITTRACKLET_H
#define ALITRDFITTRACKLET_H
/* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               */

/* $Id$ */

#include <TObject.h>
#include <TArrayI.h>
#include <AliTRDdigit.h>
#include "AliTRDfitConst.h"


class AliTRDfitTracklet: public TObject {

  public:

   AliTRDfitTracklet();									// Default Construktor
   AliTRDfitTracklet(Int_t iPlane, Int_t iSector, Int_t iChamber, Int_t iPadrow);	// Construktor
   ~AliTRDfitTracklet();								// Destruktor
   
   Int_t	GetfRPos() { return fRPos;}						// Offset
   Int_t	GetfAngle() { return fAngle;}						// Angle
   Int_t	GetfRPosProj() { return fRPosProj;}
   Int_t	GetfTrQuality() { return fTrQuality;}					// 
   Int_t	GetfChi2() { return fChi2;}						//
   Int_t	GetfNTracks() { return fNTracks;}					// 1 or 2 
   Float_t	GetfDefl() { return fDefl;}						// ??
   Int_t	GetfMainTrack() { return fMainTrack;}					
   TArrayI	*GetfTracks() { return fTracks;}
   Int_t	GetfHitPos(Int_t timebin) {return fHitPos[timebin];}
   Int_t	GetTrackAt(Int_t c) {return fTracks->At(c);}
   Int_t	GetFEject() {return fEject;}
   Int_t	GetfMerge() {return fMerge;}
   Int_t	GetTrackCountAt(Int_t c) {return fTracksCount->At(c);}
   Int_t	GetASize(){return fTracks->GetSize();}
   Int_t	GetYi(Int_t pos){return fArray_yi[pos];}				// Get Yi at position pos
   Int_t	TrackCount();
   void		MainTrack();

   
   void		SetfRPos(Int_t iRPos) {fRPos = iRPos;}
   void		SetfAngle(Int_t iAngle) {fAngle = iAngle;}
   void		SetfRPosProj(Int_t iRPosProj) {fRPosProj = iRPosProj;}
   void		SetfTrQuality(Int_t iTrQuality) {fTrQuality = iTrQuality;}
   void		SetfChi2(Int_t iChi2) {fChi2 = iChi2;}
   void		SetfNTracks(Int_t iNTracks) {fNTracks = iNTracks;}
   void		SetfTracks(TArrayI *iTracks) {*fTracks = *iTracks;} 
   void		SetfHitPos(Int_t timebin, Int_t pad) {fHitPos[timebin] = pad;}		// save hit position (center pad)
   void		AddTrack(Int_t TrackID);
   void		AddTrackandCount(Int_t TrackID, Int_t count);
   
   void		SetTrackCountAdd(Int_t count, Int_t pos) {fTracksCount->AddAt(count, pos);}
   void		SetTrackAt(Int_t TrackID, Int_t c) {return fTracks->AddAt(TrackID,c);}
   void		SetfEject(Int_t Ejectnr) {fEject = Ejectnr;}
   void 	SetfMerge(Int_t Mergenr) {fMerge = Mergenr;}
   void 	SetYi(Int_t pos, Int_t yi) {fArray_yi[pos] = yi;}
   void		Dump();
   
   
   	


  private:

    // all information about a hit
    
    Int_t		fHitPos[kTimebins];			// Array for Pad No. of the center pad
    Int_t		fMainTrack;				// Track with 
    Int_t		fMainTrackCount;			// Hitcount of the Main Track
    Int_t		fRPos;
    Int_t		fAngle;
    Int_t		fRPosProj;
    Int_t		fTrQuality;
    Int_t		fChi2;
    Int_t		fNTracks;				// involved tracks
    Float_t		fDefl;
    TArrayI	        *fTracks;				// all involved tracks
    TArrayI		*fTracksCount;				// Hitcount of each involved track
    
    Int_t   		fPlane;   
    Int_t   		fSector;  
    Int_t   		fChamber; 
    Int_t   		fPadrow;
    
    Int_t		fEject;					// Tracklet is not fine
    								// 0 = Tracklet is ok
    								// 1 = Eject Steigung
								// 3 = Eject Achse
								// 5 = Eject chi2  
								// 4,6,8 Kombinationen

    Int_t		fMerge;					// Tracklet was merged
    								// 0 = not merged
								// 1 = move data from right to center
								

    Int_t		fArray_yi[kTimebins];			// Array for calculated yi
								

protected:

ClassDef(AliTRDfitTracklet,1)

   };
   
#endif   
