
void AliTRDfitPadrow() 
{

/////////////////////////////////////////////////////////////////////////
//
//  Demo of using AliTRDfitPadrow
//
/////////////////////////////////////////////////////////////////////////

  Char_t *alifile = "~schneide/data/galice_bv.root";

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfit");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");

  // Event number
  Int_t   nEvent  = 0;

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(alifile);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << alifile << endl;
    gafl = new TFile(alifile);
  }
  else {
    cout << alifile << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nparticles = gAlice->GetEvent(nEvent);
   cout << "EventNo:" << nEvent << endl;
  if (nparticles <= 0) break;

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Init AliTRDfitPadrow evironment
  Int_t lPlane   = 0;
  Int_t lSector  = 0;
  Int_t lChamber = 0;
  Int_t lPadrow  = 0;

  for (lPlane = 0; lPlane < 6; lPlane++) {
    AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(lPlane, lSector, lChamber, lPadrow);
    fitPadrow->SetDigitsManager(DigitsManager);
    fitPadrow->SetTRDgeometry(TRDgeometry);
    fitPadrow->OutputAmplitudes();
    fitPadrow->Fit();
    for (Int_t i=0; i<128;i++) {
      if (fitPadrow->GetTracklet(i)->GetfMainTrack() != -1) {
	cout << "--------------------------------------------------------" << endl;
	cout << "CHANNEL-NR: " << i << endl;
	fitPadrow->GetTracklet(i)->Dump();
	cout << "MAIN TRACK: " << fitPadrow->GetTracklet(i)->GetfMainTrack() << endl;
      }  
    }
    //cout << "You have " <<  fitPadrow->GetAriError() << " arithmetic bit width violations" << endl << endl;    
  }  

  // Do some statistics

  // end
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  gafl->Close();
  cout << endl;
  delete gafl;
  delete fitPadrow;
  cout << "BYE." << endl << endl;
}











