/**************************************************************************
 * Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 *                                                                        *
 * Author: The ALICE Off-line Project.                                    *
 * Contributors are mentioned in the code where appropriate.              *
 *                                                                        *
 * Permission to use, copy, modify and distribute this software and its   *
 * documentation strictly for non-commercial purposes is hereby granted   *
 * without fee, provided that the above copyright notice appears in all   *
 * copies and that both the copyright notice and this permission notice   *
 * appear in the supporting documentation. The authors make no claims     *
 * about the suitability of this software for any purpose. It is          *
 * provided "as is" without express or implied warranty.                  *
 **************************************************************************/

/*
$Log: AliTRDgtu.cxx,v $
Revision 1.1.1.1  2001/01/16 18:02:33  schneide
Import of TRDgtu

*/

/**************************************************************************
 *                                                                        *
 *  TRD Global Tracking Unit Class                                        *
 *                                                                        *
 *  Author : Rolf Schneider                                               *
 *                                                                        *
 **************************************************************************/

#include "TObject.h"
#include "AliTRDgtuConst.h"
#include "AliTRDgtuGlobal.h"
#include "AliTRDgtu.h"

ClassImp(AliTRDgtu)

//_________________________________________________________________________
AliTRDgtu::AliTRDgtu():TObject()
{
  //
  //  AliTRDgtu default constructor
  //

  DBG_N ( printf("**** Initialize Global Tracking Unit\n"); )

  for(Int_t lSector=0; lSector<kSectors; lSector++)
    for(Int_t lChamber=0; lChamber<kChambers; lChamber++)
      fBlock[lSector][lChamber] = new AliTRDgtuBlock(lSector, lChamber);
}

//_________________________________________________________________________
AliTRDgtu::AliTRDgtu(Int_t iSector, Int_t iChamber):TObject()
{
  //
  //  AliTRDgtu default constructor
  //
  //  initializes only one Block
  //

  DBG_N ( printf("**** Initialize Global Tracking Unit Block (-, %d, %d, -)\n", iSector, iChamber); )

  for(Int_t lSector=0; lSector<kSectors; lSector++)
    for(Int_t lChamber=0; lChamber<kChambers; lChamber++)
      fBlock[lSector][lChamber] = NULL;

  fBlock[iSector][iChamber] = new AliTRDgtuBlock(iSector, iChamber);
}

//_________________________________________________________________________
AliTRDgtu::~AliTRDgtu()
{
  //
  //  AliTRDgtu default destructor
  //

  for(Int_t lSector=0; lSector<kSectors; lSector++)
    for(Int_t lChamber=0; lChamber<kChambers; lChamber++)
      if(fBlock[lSector][lChamber]) delete fBlock[lSector][lChamber];

  DBG_N ( printf("**** Leave Global Tracking Unit, bye.\n"); )
}

//_________________________________________________________________________
AliTRDgtuBlock *AliTRDgtu::GetBlock(Int_t iSector, Int_t iChamber)
{
  //
  //  return block specified by sector and chamber number
  //

  return(fBlock[iSector][iChamber]);
}

//_________________________________________________________________________
Int_t AliTRDgtu::Global2Local(Int_t iSector, Int_t iChamber)
{
  //
  //  convert global block identifier into local array index
  //

  return((iSector * kChambers) + iChamber);
}

//_________________________________________________________________________
void AliTRDgtu::Local2Global(Int_t iLocal, Int_t *iSector, Int_t *iChamber)
{
  //
  //  convert local array index into global block identifier
  //

  *iChamber = iLocal % kChambers;
  *iSector  = iLocal / kChambers;
}

//_________________________________________________________________________
void AliTRDgtu::SetWarningLevel(Int_t mode)
{
  //
  //  Sets the warning output level
  //
  //    mode = 0   : output only errors and requested outputs
  //    mode = 1   : output warnings, errors and requested outputs
  //    mode = 2   : output info, warnings, errors and requested outputs
  //

  if((mode < WL_NONE) || (mode > WL_ALL))
    DBG_N ( printf("WARNING: valid debug modes are %d..%d\n", WL_NONE, WL_ALL); )
  else
    AliTRDgtuGlobal::TMUwl = mode;

  DBG_I ( printf("current warning level is %d\n", AliTRDgtuGlobal::TMUwl); )
}

//_________________________________________________________________________
void AliTRDgtu::Info()
{
  //
  //  banner and version info of TRDgtu
  //

  DBG_N ( printf("\n"); )
  DBG_N ( printf("  *********************************************\n"); )
  DBG_N ( printf("  *                                           *\n"); )
  DBG_N ( printf("  *     Global Tracking Unit - Simulation     *\n"); )
  DBG_N ( printf("  *                                           *\n"); )
  DBG_N ( printf("  *  Version      : %s                   *\n", VERSION); )
  DBG_N ( printf("  *  Author       : Rolf Schneider            *\n"); )
  DBG_N ( printf("  *  Module       : %s                 *\n", MODULE); )
  DBG_N ( printf("  *  Library      : %s                    *\n", LIBRARY); )
  DBG_N ( printf("  *  Warning Level: %d                         *\n", AliTRDgtuGlobal::TMUwl); )
  DBG_N ( printf("  *                                           *\n"); )
  DBG_N ( printf("  *********************************************\n"); )
  DBG_N ( printf("\n"); )
}
