#ifndef ALITRDGTUCANDIDATE_H
#define ALITRDGTUCANDIDATE_H
/* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               */

/* $Id: AliTRDgtuCandidate.h,v 1.1.1.1 2001/01/16 18:02:33 schneide Exp $ */

#include <TObject.h>
#include <AliTRDgtuConst.h>

class AliTRDgtuCandidate : public TObject {

  public:

    AliTRDgtuCandidate();
    virtual ~AliTRDgtuCandidate();

    void     AddParticle(Int_t iParticle);
    void     AddParticle(Int_t iParticle, Float_t iX1, Float_t iY1, Float_t iX2, Float_t iY2);
    void     CalcMidlayer(Int_t iLayer);
    Int_t    GetAmplitude() const { return fAmplitude; }
    Int_t    GetAngle() const { return fAngle; }
    Int_t    GetParticle(Int_t iParticleNo) const { return fParticle[iParticleNo]; }
    void     GetParticlePos(Int_t iParticleNo, Float_t &iX1, Float_t &iY1, Float_t &iX2, Float_t &iY2);
    Int_t    GetRPos() const { return fRPos; }
    Int_t    GetRPosMidlayer() const { return fRPosMidlayer; }
    Int_t    GetTrQuality() const { return fTrQuality; }
    Int_t    GetZPos() const { return fZPos; }
    Bool_t   IsValid();
    Int_t    NumberOfParticles();
    void     Output();
    void     SetAmplitude(Int_t iAmplitude);
    void     SetAngle(Int_t iAngle);
    void     SetParticlePos(Int_t iParticleNo, Float_t iX1, Float_t iY1, Float_t iX2, Float_t iY2);
    void     SetRPos(Int_t iRPos);
    void     SetRPosMidlayer(Int_t iRPosMidlayer);
    void     SetTrQuality(Int_t iTrQuality);
    void     SetZPos(Int_t iZPos);

  private:

    Int_t    fAmplitude;     // ave. amplitude of candidate
    Int_t    fAngle;         // angle of candidate
    Int_t    fParticle[kParticlesPerCandidate];      // particles involved in Candidate
    Float_t  fParticlePos[kParticlesPerCandidate*8]; // particles start and end position
    Int_t    fRPos;          // position in rphi direction
    Int_t    fRPosMidlayer;  // position in rphi direction of middle layer
    Int_t    fTrQuality;     // number for quality of transition radiation
    Int_t    fZPos;          // position in z direction (equiv. to padrow)

    Int_t    RangeTest(char *iVarName, Int_t iValue, Int_t iMin, Int_t iMax);

  protected:

    ClassDef(AliTRDgtuCandidate,1) // Data container for one TRD GTU Candidate

};

#endif
