#ifndef ALITRDGTUCONST_H
#define ALITRDGTUCONST_H
/* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               */

/* $Id: AliTRDgtuConst.h,v 1.2 2001/02/06 17:38:16 schneide Exp $ */

#include "Rtypes.h"

///////////////////////////////////////////////////////////////////////////
//  DEFINES                                                              //
///////////////////////////////////////////////////////////////////////////
#define VERSION            "V000717"             // current version
#define MODULE             "AliTRDgtu"
#define LIBRARY            "TRDgtu"
#define TRUE               1
#define FALSE              0
#define XXX                -1                    // not defined
#define WL_NONE            0                     // warning level: none
#define WL_WARNING         1                     //                warnings
#define WL_INFO            2                     //                info
#define WL_ALL             3                     //                all

///////////////////////////////////////////////////////////////////////////
//  CONSTANTS                                                            //
///////////////////////////////////////////////////////////////////////////

// IMPLEMENTATION
const Int_t   kCandsPerChamberMax     = 20;
const Int_t   kCandsPerPadrowMax      = 10;
const Int_t   kCandsPerTrackMax       = 6;
const Int_t   kTracksPerDetectorMax   = 10;
const Int_t   kTracksPerPadrowMax     = 5;
const Int_t   kTracksPerTrackMax      = 3;
const Int_t   kParticlesPerCandidate  = 3;

const Int_t   kRPosMax                = 16383;   // == 14 Bits
const Int_t   kAngleMax               = 255;     // ==  8 Bits
const Int_t   kZPosMax                = 31;      // ==  5 Bits
const Int_t   kAmplitudeMax           = 255;     // ==  8 Bits
const Int_t   kTrQualityMax           = 3;       // ==  1 Bits
const Int_t   kRPosMidlayerMax        = 16383;   // == 14 Bits

// BIT WIDTHS
const Int_t   kRPosBits               = 14;      // == 16384d
const Int_t   kAngleBits              = 8;       // ==   256d
const Int_t   kZPosBits               = 5;       // ==    32d
const Int_t   kAmplitudeBits          = 8;       // ==   256d
const Int_t   kTrQualityBits          = 2;       // ==     4d
const Int_t   kRPosMidlayerBits       = 14;      // == 16384d
const Int_t   kEndSignatureBits       = 1;       // ==     2d

// HIT CONDITIONS
const Int_t   kHitsToFitMin           = 4;
const Int_t   kAngleDiff              = 2;
const Int_t   kAmplitudeDiff          = 3;
const Int_t   kRPosMidlayerDiff       = 5;

// GEOMETRY
const Int_t   kLayers                 = 6;
const Int_t   kSectors                = 18;
const Int_t   kChambers               = 5;
const Int_t   kPadrowsPerChamber      = 23;
const Int_t   kCompareLayers          = (kLayers - kHitsToFitMin + 1);
const Float_t kAngleMaxRad            = 0.32;    // max. angle in rad
                                                 // res = cAngleMax/(2^cAngleBits)
const Float_t kAngleMaxRes            = (kAngleMaxRad / kAngleMax);

///////////////////////////////////////////////////////////////////////////
//  MACROS                                                               //
///////////////////////////////////////////////////////////////////////////
#define DBG_A(CMD)   { if(AliTRDgtuGlobal::TMUwl >= WL_ALL) { printf("%s: ", MODULE); CMD }}
#define DBG_I(CMD)   { if(AliTRDgtuGlobal::TMUwl >= WL_INFO) { printf("%s: ", MODULE); CMD }}
#define DBG_W(CMD)   { if(AliTRDgtuGlobal::TMUwl >= WL_WARNING) { printf("%s: ", MODULE); CMD }}
#define DBG_N(CMD)   { if(AliTRDgtuGlobal::TMUwl >= WL_NONE) { printf("%s: ", MODULE); CMD }}
#define HEAD(CMD)    { DBG_N ( printf("\n"); ) DBG_N ( printf("************************************************************\n"); ) DBG_N ( printf("**** "); ) CMD DBG_N ( printf("************************************************************\n"); ) DBG_N ( printf("\n"); ) }
#endif
