/**************************************************************************
 * Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 *                                                                        *
 * Author: The ALICE Off-line Project.                                    *
 * Contributors are mentioned in the code where appropriate.              *
 *                                                                        *
 * Permission to use, copy, modify and distribute this software and its   *
 * documentation strictly for non-commercial purposes is hereby granted   *
 * without fee, provided that the above copyright notice appears in all   *
 * copies and that both the copyright notice and this permission notice   *
 * appear in the supporting documentation. The authors make no claims     *
 * about the suitability of this software for any purpose. It is          *
 * provided "as is" without express or implied warranty.                  *
 **************************************************************************/

/*
$Log: AliTRDgtuGlobal.cxx,v $
Revision 1.2  2001/01/30 18:48:27  schneide
Changes for AliRoot 3.04, Visualisation of Tracklets, FindNextTrack added

Revision 1.1.1.1  2001/01/16 18:02:33  schneide
Import of TRDgtu

*/

///////////////////////////////////////////////////////////////////////////
//                                                                       //
//  Global Tracking Unit - Global class                                  //
//  This class holds the global used variables and its instances         //
//                                                                       //
//  module: (TRDgtu) Global Tracking Unit        author: Rolf Schneider  //
//                                                                       //
///////////////////////////////////////////////////////////////////////////

#include "AliTRDgtuConst.h"
#include "AliTRDgtuGlobal.h"

ClassImp(AliTRDgtuGlobal)

Int_t AliTRDgtuGlobal::TMUwl = WL_WARNING;

//_________________________________________________________________________
Float_t AliTRDgtuGlobal::FindNextTrack(AliTRDgeometry *TRDgeometry, AliTRDgtuReal *Real, Int_t trackno, Int_t det, Int_t padrow, Int_t nParticles)
{
  //
  //  return the distance to the track which is nearest to the track trackno
  //

  Float_t minDistance = 1000000.0;
  Float_t minTrack = -1;

  Int_t plane = TRDgeometry->GetPlane(det);
  Float_t trackpos = Real->GetRealTrack(trackno)->GetExStartColumn(plane);

  for(Int_t track=0; track<nParticles; track++) {
    if(track == trackno) continue;
    AliTRDgtuRealTrack *RT = Real->GetRealTrack(track);
    Int_t lDet = TRDgeometry->GetDetector(plane, RT->GetChamber(), RT->GetSector());
    if(lDet != det) continue;
    Int_t comp_padrow = (Int_t)RT->GetExStartPadrow(plane);
    if((comp_padrow != padrow) || (comp_padrow == -1)) continue;
    Float_t comp_pos = RT->GetExStartColumn(plane);
    Float_t distance = TMath::Abs(trackpos-comp_pos);
    if(distance < minDistance) {
      minDistance = distance;
      minTrack = track;
    }
  }

  Float_t lColPadSize = TRDgeometry->GetColPadSize(plane);

  return(10.0 * lColPadSize * minDistance);
}
