#ifndef ALITRDGTUREAL_H
#define ALITRDGTUREAL_H
/* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               */

/* $Id: AliTRDgtuReal.h,v 1.3 2001/02/06 17:38:17 schneide Exp $ */

#include <TObject.h>
#include <TTree.h>
#include <TClonesArray.h>
#include <AliRun.h>
#include <AliTRDv1.h>
#include <AliTRDgeometry.h>
#include <AliTRDdigitsManager.h>
#include "AliTRDgtuRealTrack.h"

class AliTRDgtuReal : public TObject {

  public:

    AliTRDgtuReal();
    AliTRDgtuReal(Int_t iParticles, Int_t iPrimaryParticles);
    virtual ~AliTRDgtuReal();

    void  Dump();
    void  FillRealTracks(AliTRDgeometry *TRDgeometry, AliTRDdigitsManager *DigitsManager, TClonesArray *ParticleArray, Bool_t info);
    void  GetExactPositions(AliTRDgeometry *TRDgeometry, AliRun *gAlice, AliTRDv1 *TRD, TTree *hitTree);
    Int_t GetParticles() { return fParticles; }
    Int_t GetPrimaryParticles() { return fPrimaryParticles; }
    AliTRDgtuRealTrack *GetRealTrack(Int_t iTrackID) { return (AliTRDgtuRealTrack *)fRealTrack->At(iTrackID); }
    Int_t GetTRDparticles();
    Int_t GetTRDprimaryParticles();
    void  SetChamberRange(Int_t iMin, Int_t iMax) { fChamberMin = iMin; fChamberMax = iMax; }
    void  SetParticles(Int_t iParticles) { fParticles = iParticles; }
    void  SetPlaneRange(Int_t iMin, Int_t iMax) { fPlaneMin = iMin; fPlaneMax = iMax; }
    void  SetPrimaryParticles(Int_t iPrimaryParticles) { fPrimaryParticles = iPrimaryParticles; }
    void  SetSectorRange(Int_t iMin, Int_t iMax) { fSectorMin = iMin; fSectorMax = iMax; }

  private:

    Int_t  Local2Global(Int_t iPlane, Int_t iSector, Int_t iChamber);
    Bool_t CheckEnv();
    Bool_t CheckRange();

    TClonesArray *fRealTrack;

    Int_t  fParticles;           // number of particles
    Int_t  fPrimaryParticles;    // number of primary particles
    Int_t  fPlaneMin;
    Int_t  fPlaneMax;
    Int_t  fSectorMin;
    Int_t  fSectorMax;
    Int_t  fChamberMin;
    Int_t  fChamberMax;

  protected:

    ClassDef(AliTRDgtuReal,1)   // container class for ordered RealTracks

};

#endif
