#ifndef ALITRDGTUREALTRACK_H
#define ALITRDGTUREALTRACK_H
/* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               */

/* $Id: AliTRDgtuRealTrack.h,v 1.3 2001/02/06 17:38:17 schneide Exp $ */

#include <TObject.h>
#include <AliTRDgeometry.h>
#include <AliTRDgtuConst.h>

class AliTRDgtuRealTrack : public TObject {

  public:

    AliTRDgtuRealTrack();
    AliTRDgtuRealTrack(Int_t iTrackID, Int_t iSector, Int_t iChamber);
    virtual ~AliTRDgtuRealTrack();

    void       Dump();
    Int_t      GetAmplitudeSum();
    Int_t      GetAmplitudeSum(Int_t iPlane) { return fAmplitudeSum[iPlane]; }
    Int_t      GetChamber() const { return fChamber; }
    Int_t      GetDigitsSum();
    Int_t      GetDigitsSum(Int_t iPlane) { return fDigitsSum[iPlane]; }
    Int_t      GetEndColumn(Int_t iPlane) { return fEndColumn[iPlane]; }
    Int_t      GetEndPadrow(Int_t iPlane) { return fEndPadrow[iPlane]; }
    Float_t    GetExEndColumn(Int_t iPlane) { return fExEndColumn[iPlane]; }
    Float_t    GetExEndPadrow(Int_t iPlane) { return fExEndPadrow[iPlane]; }
    Float_t    GetExEndTimebin(Int_t iPlane) { return fExEndTimebin[iPlane]; }
    Float_t    GetExStartColumn(Int_t iPlane) { return fExStartColumn[iPlane]; }
    Float_t    GetExStartPadrow(Int_t iPlane) { return fExStartPadrow[iPlane]; }
    Float_t    GetExStartTimebin(Int_t iPlane) { return fExStartTimebin[iPlane]; }
    Int_t      GetSector() const { return fSector; }
    Int_t      GetStartColumn(Int_t iPlane) { return fStartColumn[iPlane]; }
    Int_t      GetStartPadrow(Int_t iPlane) { return fStartPadrow[iPlane]; }
    Int_t      GetTrackID() { return fTrackID; }
    void       IncAmplitudeSum(Int_t iPlane, Int_t iAmp) { fAmplitudeSum[iPlane] += iAmp; }
    void       IncDigitsSum(Int_t iPlane, Int_t iDig) { fDigitsSum[iPlane] += iDig; }
    void       SetAmplitudeSum(Int_t iPlane, Int_t iAmp) { fAmplitudeSum[iPlane] = iAmp; }
    void       SetChamber(Int_t iChamber) { fChamber = iChamber; }
    void       SetDigitsSum(Int_t iPlane, Int_t iDig) { fDigitsSum[iPlane] = iDig; }
    void       SetEndColumn(Int_t iPlane, Int_t iColumn) { fEndColumn[iPlane] = iColumn; }
    void       SetEndPadrow(Int_t iPlane, Int_t iPadrow) { fEndPadrow[iPlane] = iPadrow; }
    void       SetExEndTimebin(Int_t iPlane, Float_t iTimebin) { fExEndTimebin[iPlane] = iTimebin; }
    void       SetExEndColumn(Int_t iPlane, Float_t iColumn) { fExEndColumn[iPlane] = iColumn; }
    void       SetExEndPadrow(Int_t iPlane, Float_t iPadrow) { fExEndPadrow[iPlane] = iPadrow; }
    void       SetExStartColumn(Int_t iPlane, Float_t iColumn) { fExStartColumn[iPlane] = iColumn; }
    void       SetExStartPadrow(Int_t iPlane, Float_t iPadrow) { fExStartPadrow[iPlane] = iPadrow; }
    void       SetExStartTimebin(Int_t iPlane, Float_t iTimebin) { fExStartTimebin[iPlane] = iTimebin; }
    void       SetSector(Int_t iSector) { fSector = iSector; }
    void       SetStartColumn(Int_t iPlane, Int_t iColumn) { fStartColumn[iPlane] = iColumn; }
    void       SetStartPadrow(Int_t iPlane, Int_t iPadrow) { fStartPadrow[iPlane] = iPadrow; }
    void       SetTrackID(Int_t iTrackID) { fTrackID = iTrackID; }

  private:

    Int_t      fTrackID;                // Monte-Carlo Track number
    Int_t      fSector;                 // current sector identifier
    Int_t      fChamber;                // current chamber identifier

    Int_t      fAmplitudeSum[kLayers];  // sum of amplitude for each layer
    Int_t      fDigitsSum[kLayers];     // number of digits for each layer
    Float_t    fExStartPadrow[kLayers]; // exact innermost padrow position
    Float_t    fExEndPadrow[kLayers];   // exact outermost padrow position
    Float_t    fExStartColumn[kLayers]; // exact innermost column position
    Float_t    fExEndColumn[kLayers];   // exact outermost column position
    Float_t    fExStartTimebin[kLayers];// exact innermost timebin
    Float_t    fExEndTimebin[kLayers];  // exact outermost timebin
    Int_t      fStartPadrow[kLayers];   // number of padrow for innermost timebin
    Int_t      fEndPadrow[kLayers];     // number of padrow for outermost timebin
    Int_t      fStartColumn[kLayers];   // number of column for innermost timebin
    Int_t      fEndColumn[kLayers];     // number of column for outermost timebin

  protected:

    ClassDef(AliTRDgtuRealTrack,1) // Data container for one TRD real track

};

#endif
