#ifndef ALITRDGTUSTATISTIC_H
#define ALITRDGTUSTATISTIC_H
/* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               */

/* $Id: AliTRDgtuStatistic.h,v 1.1.1.1 2001/01/16 18:02:33 schneide Exp $ */

#include <TH1.h>
#include <TH2.h>
#include <AliRun.h>
#include <AliTRDv1.h>
#include <AliTRDgeometry.h>
#include <AliTRDdigitsManager.h>
#include "AliTRDgtuReal.h"

class AliTRDgtuStatistic : public TObject {

  public:

    AliTRDgtuStatistic(AliRun *gAlice);
    virtual ~AliTRDgtuStatistic();

    TH1F                *GenH1(Float_t iPtMin, Bool_t iPrimary);
    TH1F                *GenH2(Float_t iPtMin, Bool_t iPrimary);
    TH1F                *GenH3(Float_t iPtMin, Bool_t iPrimary);
    TH2F                *GenH4(Float_t iPtMin, Bool_t iPrimary);
    TH2F                *GenH5(Float_t iPtMin, Bool_t iPrimary);
    AliTRDdigitsManager *GetDigitsManager() const { return fDigitsManager; }
    Int_t                GetParticles() { return fParticles; }
    Int_t                GetPrimaryParticles() { return fPrimaryParticles; }
    AliTRDv1            *GetTRD() const { return fTRD; }
    AliTRDgeometry      *GetTRDgeometry() const { return fTRDgeometry; }
    Float_t              Pos2Defl(Float_t xinner, Float_t xouter, Float_t tinner, Float_t touter, Int_t plane, Int_t column);
    Float_t              Pt2Defl(Float_t pt, Float_t charge, Int_t plane, Int_t column);
    void                 SetChamberRange(Int_t iMin, Int_t iMax);
    void                 GetParticlePos(Int_t iParticle, Int_t iDetector, Float_t *iGPos1, Float_t *iGPos2, Float_t *iLPos1, Float_t *iLPos2); 
    void                 SetPlaneRange(Int_t iMin, Int_t iMax);
    void                 SetReal(AliTRDgtuReal *iReal);
    void                 SetSectorRange(Int_t iMin, Int_t iMax);

    TH1F                *h1;  // real energy loss vs pt (ptmin, primary)
    TH1F                *h2;  // digits vs pt (ptmin, primary)
    TH1F                *h3;  // pt distribution (ptmin, primary)
    TH2F                *h4;  // mean deflection vs. pt (ptmin, primary)
    TH2F                *h5;  // real deflection vs. pt (ptmin, primary)

  private:

    AliTRDgtuReal       *fReal;
    AliRun              *fgAlice;
    AliTRDv1            *fTRD;
    AliTRDgeometry      *fTRDgeometry;
    AliTRDdigitsManager *fDigitsManager;
    TTree               *fHitTree;
    TClonesArray        *fParticleArray;
    Int_t                fParticles;
    Int_t                fPrimaryParticles;

    Int_t                fPlaneMin;
    Int_t                fPlaneMax;
    Int_t                fSectorMin;
    Int_t                fSectorMax;
    Int_t                fChamberMin;
    Int_t                fChamberMax;

  protected:

    ClassDef(AliTRDgtuStatistic,1) // TRD GTU statistic class

};

#endif
