#ifndef ALITRDGTUTMU_H
#define ALITRDGTUTMU_H
/* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               */

/* $Id: AliTRDgtuTMU.h,v 1.1.1.1 2001/01/16 18:02:33 schneide Exp $ */

#include <TObjArray.h>
#include "AliTRDgtuConst.h"
#include "AliTRDgtuTrack.h"
#include "AliTRDgtuCandidate.h"
#include "AliTRDgtuVisual.h"

class AliTRDgtuTMU : public TObject {

  public:

    AliTRDgtuTMU();
    AliTRDgtuTMU(Int_t iSector, Int_t iChamber, Int_t iPadrow);
    virtual ~AliTRDgtuTMU();

    void    AddCandidate(AliTRDgtuCandidate *iCandidate, Int_t iLayer);
    void    AddTrack(AliTRDgtuTrack *iTrack);
    Int_t   NumberOfCandidates();
    void    FindTracksV0();
    void    OutputCandidates();
    void    OutputTracks();
    void    VisualCandidates2D(AliTRDgtuVisual *iVisual);
    void    VisualTracks2D(AliTRDgtuVisual *iVisual);

    void    SetSector(Int_t iSector) { fSector = iSector; }
    void    SetChamber(Int_t iChamber) { fChamber = iChamber; }
    void    SetPadrow(Int_t iPadrow) { fPadrow = iPadrow; }
    Int_t   GetSector() const { return fSector; }
    Int_t   GetChamber() const { return fChamber; }
    Int_t   GetPadrow() const { return fPadrow; }

  private:

    TObjArray *fCandidate[kLayers];  // candidates for current TMU
    Bool_t     fUsedForFit[kLayers][kCandsPerPadrowMax]; // internal used flags
    TObjArray *fTrack;              // array of hopefully found tracks

    Bool_t     RangeCheck(Int_t iValue, Int_t iRef, Int_t iRange);
    Bool_t     HitConditionCheck(AliTRDgtuCandidate *iCmpCandidate, AliTRDgtuCandidate *iCandidate);

    Int_t      fSector;  // current sector identifier
    Int_t      fChamber; // current chamber identifier
    Int_t      fPadrow;  // current padrow identifier

  protected:

    ClassDef(AliTRDgtuTMU,1)         // TRD GTU Track Matching Unit class

};

#endif
