#ifndef ALITRDGTUVISUAL_H
#define ALITRDGTUVISUAL_H
/* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               */

/* $Id: AliTRDgtuVisual.h,v 1.2 2001/01/30 18:48:27 schneide Exp $ */

#include <TCanvas.h>
#include <AliTRDgeometry.h>
#include "../AliTRDsim/AliTRDfitTracklet.h"
#include "AliTRDgtuCandidate.h"
#include "AliTRDgtuTrack.h"

class AliTRDgtuVisual : public TObject {

  public:

    AliTRDgtuVisual();
    virtual ~AliTRDgtuVisual();
    TPad  *Init2D();
    TPad  *Init3D();
    TPad  *GetPad2D() { return fPad2D; }
    TPad  *GetPad3D() { return fPad3D; }
    void   DrawBlock2D();
    void   DrawBlock3D();
    void   DrawCandidate2D(AliTRDgtuCandidate *iCandidate, Int_t iLayer);
    void   DrawTracklet2D(AliTRDfitTracklet *iTracklet, Int_t iLayer);
    void   DrawCandidate3D(AliTRDgtuCandidate *iCandidate, Int_t iLayer);
    void   DrawTracklet3D(AliTRDgeometry *TRDgeometry, AliTRDfitTracklet *iTracklet, Int_t iPlane, Int_t iChamber, Int_t iSector, Int_t iPadrow);
    void   DrawTrack2D(AliTRDgtuTrack *iTrack);
    void   DrawTrackCandProj2D(AliTRDgtuTrack *iTrack);
    void   DrawStats2D(Int_t iPlane, Int_t iSector, Int_t iChamber, Int_t iPadrow);

  private:

    Float_t  fLayer_r[kLayers]; // position of chamber in r direction
    Float_t  fLayer_w[kLayers]; // width of chamber
    Float_t  fLayer_h[kLayers]; // height of chamber
    Float_t  fLayer_z[kLayers]; // depth of chamber
    TCanvas *fCanvas2D;         // canvas for 2D visualization
    TCanvas *fCanvas3D;         // canvas for 3D visualization
    TPad    *fPad2D;            // pad for 2D visualization
    TPad    *fPad3D;            // pad for 2D visualization

    Char_t *NumberString(Char_t *iStr, Int_t iNumber);

  protected:

    ClassDef(AliTRDgtuVisual,1) // TRD GTU visualization class

};

#endif
