void AliTRDfit()
{
  gROOT->LoadMacro("/home/schneide/src/c/AliTRDmacros/getDigitsManager.C");
  gROOT->LoadMacro("/home/schneide/src/c/AliTRDmacros/dialogs.C");

  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfittmp");

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDfitPadrow SIMULATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  // CONSTANTS //
  const Char_t *alifile     = "~schneide/data/galice_nh.root";
  const Int_t   iSec        = 0;
  const Int_t   iCha        = 2;
  const Int_t   iPla        = 3;
  const Int_t   iDefaultRow = 10;

  // READ ALIROOT FILE //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  GET DIGITS FROM ALIROOT EVENT FILE                --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;

  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }

  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(alifile);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << alifile << endl;
    gafl = new TFile(alifile);
  }
  else {
    cout << alifile << " is already open" << endl;
  }

  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  AliTRDgtuStatistic *stat = new AliTRDgtuStatistic(gAlice);

  AliTRDdigitsManager *DigitsManager = stat->GetDigitsManager();
  AliTRDv1 *TRD = stat->GetTRD();
  AliTRDgeometry *TRDgeometry = stat->GetTRDgeometry();
  TClonesArray *ParticleArray = gAlice->Particles();

  // INITIALIZE ENVIRONMENT //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  INITIALIZE LEVEL-0 TRIGGER SIMULATION ENVIRONMENT --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow();
  cout << "Current Detector : Sector " << iSec << "; Chamber " << iCha
       << "; Plane " << iPla << endl;
  Int_t iRow = GetIntegerDialog("Give ROW number:", iDefaultRow);
  cout << "Current Padrow   : " << iRow << endl;
  Int_t rowMax  = TRDgeometry->GetRowMax(iPla,iCha,iSec);
  Int_t colMax  = TRDgeometry->GetColMax(iPla);
  Int_t timeMax = TRDgeometry->GetTimeMax();
  cout << "Geometry         : Rows " << rowMax << "; Cols " << colMax << "; Bins " << timeMax << endl << endl;

  // FALKS SIMULATION //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  STARTING FALKS SIMULATION                         --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDdigit *Digit;
  AliTRDmatrix *TRDmatrix = new AliTRDmatrix(rowMax,colMax,timeMax,iSec,iCha,iPla);

  Int_t iDet = TRDgeometry->GetDetector(iPla,iCha,iSec);
  for (Int_t col = 0;  col < colMax ;  col++) {
    for (Int_t time = 0; time < timeMax; time++) {
      Digit = DigitsManager->GetDigit(iRow,col,time,iDet);
      Int_t iAmp = Digit->GetAmp();
      if (iAmp > 255) iAmp = 255;
      //if(col == 60) iAmp = 7*time;
      //if(col == 61) iAmp = 210-(7*time);
      fitPadrow->SetDigit(col, time,iAmp);
      TRDmatrix->SetSignal(iRow,col,time,iAmp);
      delete Digit;
    }
  }

  cout << endl << "*** Starting Fitting Simulation ***" << endl << endl;
  fitPadrow->thefit();

  // HISTOGRAMM OUTPUTS //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  STARTING HISTOGRAMM OUTPUTS                       --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;

  cout << "*** Draw digits data" << endl << endl;
  TRDmatrix->DrawRow(iRow);

  Float_t mom = 1.5;
  cout << endl << "*** Mark stiff particles (>" << mom << "GeV/c)" << endl << endl;
  Int_t   lTrack = 0;
  TParticle *Particle;
  TLine *stiffbox = new TLine();
  stiffbox->SetLineWidth(1);
  stiffbox->SetLineColor(4);
  Int_t iDet = TRDgeometry->GetDetector(iPla,iCha,iSec);
  for (Int_t col = 0;  col < colMax ;  col++) {
    for (Int_t time = 0; time < timeMax; time++) {
      lTrack = DigitsManager->GetTrack(0,iRow,col,time,iDet);
      if(lTrack > -1) {
        Particle = (TParticle *) ParticleArray->At(lTrack);
        if(Particle->Pt() >= mom) {
          Float_t x1 = col - 0.2;
          Float_t x2 = col + 0.2;
          Float_t y1 = time - 0.2;
          Float_t y2 = time + 0.2;
          stiffbox->DrawLine(x1, y1, x2, y2);
//printf("Stiff Track: %5d\n", lTrack);
        }
      }
    }
  }

  /*
  cout << endl << "*** Draw selected track" << endl << endl;
  Int_t CurrParticle = 358;
  TLine *particleline = new TLine();
  particleline->SetLineWidth(2);
  particleline->SetLineColor(4);
  AliTRDgeometry *fGeo = stat->GetTRDgeometry();
  Int_t cDet = fGeo->GetDetector(iPla, iCha, iSec);
  Float_t gpos1[3], gpos2[3];
  Float_t lpos1[3], lpos2[3];
  stat->GetParticlePos(CurrParticle, cDet, gpos1, gpos2, lpos1, lpos2);
  printf("Track Number    : %d\n", CurrParticle);
  printf("Global Position : (%5.2f, %5.2f, %5.2f) -> (%5.2f, %5.2f, %5.2f)\n", gpos1[0], gpos1[1], gpos1[2], gpos2[0], gpos2[1], gpos2[2]);
  printf("Local Position  : (%5.2f, %5.2f, %5.2f) -> (%5.2f, %5.2f, %5.2f)\n", lpos1[0], lpos1[1], lpos1[2], lpos2[0], lpos2[1], lpos2[2]);
  particleline->DrawLine(lpos1[1]-0.5, lpos1[2]-0.5, lpos2[1]-0.5, lpos2[2]-0.5);
  */

  cout << endl << "*** Draw candidate fits" << endl << endl;
  TLine *trackline = new TLine();
  trackline->SetLineWidth(2);
  trackline->SetLineColor(2);
  AliTRDgtuCandidate *lCandidate;
  for(Int_t col = 0; col < colMax ;  col++) {
    lCandidate = fitPadrow->GetCandidate(col);
    if(lCandidate->GetRPos() != -1) {
      Int_t lOffset = lCandidate->GetRPos();
      Int_t lAngle  = lCandidate->GetAngle();
      Float_t x1 = (Float_t)(lOffset-64)/128;
      Float_t x2 = x1 + (((Float_t)lAngle-128)/128);
      Float_t y1 = 0;
      Float_t y2 = timeMax-1;
      printf("fit: Col %3d; Off %5d; Ang %3d  ->  Line (%6.2f,%6.3f),(%6.2f,%6.3f)\n", col, lOffset, lAngle, x1, y1, x2, y2);
      trackline->DrawLine(x1, y1, x2, y2);
    }
  }

  // FINISHED //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
