void AliTRDfitAll2()
{
  gROOT->LoadMacro("/home/schneide/src/c/AliTRDmacros/getDigitsManager.C");
  gROOT->LoadMacro("/home/schneide/src/c/AliTRDmacros/dialogs.C");

  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfit");

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDfitPadrow SIMULATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  // CONSTANTS //
  const Char_t *alifile     = "/home/schneide/data/galice_nh.root";
  const Int_t   iSec        = 0;
  const Int_t   iCha        = 2;
  const Int_t   iDefaultRow = 16;
  const Int_t   iOffMax     = 128;
  const Int_t   iAngMax     = 256;

  // READ ALIROOT FILE //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  GET DIGITS FROM ALIROOT EVENT FILE                --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDdigitsManager *DigitsManager;
  AliTRDv1 *TRD;
  TClonesArray *ParticleArray;
  AliTRDgeometry *TRDgeometry;
  if(!(getDigitsManager(alifile, &DigitsManager, &TRD, &ParticleArray))) {
    cout << "ERROR: cannot get DigitsManager" << endl;
    break;
  }
  TRDgeometry = TRD->GetGeometry();

  // INITIALIZE ENVIRONMENT //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  INITIALIZE LEVEL-0 TRIGGER SIMULATION ENVIRONMENT --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDfitPadrow *fitPadrow[6];
  for(Int_t plane = 0; plane < 6; plane++)
    fitPadrow[plane] = new AliTRDfitPadrow();
  cout << "Current Detector : Sector " << iSec << "; Chamber " << iCha << endl;
  Int_t iRow = GetIntegerDialog("Give ROW number:", iDefaultRow);
  cout << "Current Padrow   : " << iRow << endl << endl;
  Int_t rowMax  = TRDgeometry->GetRowMax(0,iCha,iSec);
  Int_t timeMax = TRDgeometry->GetTimeMax();

  // FALKS SIMULATION //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  STARTING FALKS SIMULATION                         --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDdigit *Digit;

  for(Int_t plane = 0; plane < 6; plane++) {
    Int_t colMax = TRDgeometry->GetColMax(plane);
    Int_t iDet = TRDgeometry->GetDetector(plane,iCha,iSec);
    for (Int_t col = 0;  col < colMax ;  col++) {
      for (Int_t time = 0; time < timeMax; time++) {
        Digit = DigitsManager->GetDigit(iRow,col,time,iDet);
        Int_t iAmp = Digit->GetAmp();
        if (iAmp > 255) iAmp = 255;
        fitPadrow[plane]->SetDigit(col, time,iAmp);
        delete Digit;
      }
    }
    cout << endl << "*** Starting Simulation for Layer " << plane << endl << endl;
    fitPadrow[plane]->thefit();
  }

  // HISTOGRAMM OUTPUTS //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  STARTING HISTOGRAMM OUTPUTS                       --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;

  Char_t   ctitle[120];
  Float_t  keil = 1.80;
  Float_t  lDistance = 123.0;
  TH2F    *hSliceRow[6];
  TPad    *fPad[6];

  fCanvas2D = new TCanvas("Canvas2D", "GTU -- 2D-Visualisation", 100, 100, 1400, 800);
  fCanvas2D->Draw();
  sprintf(ctitle, "Padrow %d (Sector: %d Chamber: %d)", iRow, iSec, iCha);
  fTitle = new TPaveLabel(0.10, 0.95, 0.90, 0.99, ctitle); fTitle->Draw();
  fPad[0] = new TPad("PadL0", "PadL0", 0.06F*keil, 0.01F, 1.00F-0.06F*keil, 0.10F, 18, 2, 1);
  fPad[1] = new TPad("PadL1", "PadL1", 0.05F*keil, 0.16F, 1.00F-0.05F*keil, 0.25F, 18, 2, 1);
  fPad[2] = new TPad("PadL2", "PadL2", 0.04F*keil, 0.31F, 1.00F-0.04F*keil, 0.40F, 18, 2, 1);
  fPad[3] = new TPad("PadL3", "PadL3", 0.03F*keil, 0.46F, 1.00F-0.03F*keil, 0.55F, 18, 2, 1);
  fPad[4] = new TPad("PadL4", "PadL4", 0.02F*keil, 0.61F, 1.00F-0.02F*keil, 0.70F, 18, 2, 1);
  fPad[5] = new TPad("PadL5", "PadL5", 0.01F*keil, 0.76F, 1.00F-0.01F*keil, 0.85F, 18, 2, 1);

  for (Int_t plane = 0; plane < 6; plane++) fPad[plane]->Draw();

  // digits
  for (Int_t plane = 0; plane < 6; plane++) {
    cout << "*** Drawing Digits in Plane " << plane << " ..." << endl;
    Int_t colMax = TRDgeometry->GetColMax(plane);
    fPad[plane]->cd();
    sprintf(ctitle, "Plane: %d", plane);
    hSliceRow[plane] = new TH2F(ctitle,ctitle,colMax ,-0.5,colMax +0.5,timeMax,-0.5,timeMax+0.5);  
    for (Int_t col = 0;  col < colMax ;  col++) {
      for (Int_t time = 0; time < timeMax; time++) {
        Int_t iDet  = TRDgeometry->GetDetector(plane,iCha,iSec); 
        Digit = DigitsManager->GetDigit(iRow,col,time,iDet);
        Int_t iAmp = Digit->GetAmp();
        if (iAmp > 255) iAmp = 255;
        hSliceRow[plane]->Fill(col,time,iAmp);
        delete Digit;
      }
    }
    hSliceRow[plane]->Draw("COLZ");
  }

  cout << endl << "--------------------------------------------------------" << endl;

  // stiff particles
  Float_t mom = 1.5;
  Int_t   lTrack = 0;
  TLine *stiffline = new TLine();
  stiffline->SetLineWidth(2);
  stiffline->SetLineColor(4);
  AliTRDgtuCandidate *lCandidate;
  for (Int_t plane = 0; plane < 6; plane++) {
    fPad[plane]->cd();
    Int_t colMax = TRDgeometry->GetColMax(plane);
    cout << endl << "*** Marking stiff particle digits in Plane " << plane << endl << endl;
    for (Int_t col = 0;  col < colMax ;  col++) {
      for (Int_t time = 0; time < timeMax; time++) {
        Int_t iDet  = TRDgeometry->GetDetector(plane,iCha,iSec); 
        Digit = DigitsManager->GetDigit(iRow,col,time,iDet);
        lTrack = DigitsManager->GetTrack(0,iRow,col,time,iDet);
        if(lTrack > -1) {
          Particle = (TParticle *) ParticleArray->At(lTrack);
          if(Particle->Pt() >= mom) {
            printf("Col %4d; Bin %2d  ->  Track %5d; Pt %4.2f\n", col, time, lTrack, Particle->Pt());
            Float_t x1 = col - 0.2;
            Float_t x2 = col + 0.2;
            Float_t y1 = time;
            Float_t y2 = time;
            stiffline->DrawLine(x1, y1, x2, y2);
	  }
	}
        delete Digit;
      }
    }
  }

  cout << endl << "--------------------------------------------------------" << endl;

  // fits
  TLine *trackline = new TLine();
  trackline->SetLineWidth(2);
  trackline->SetLineColor(2);
  AliTRDgtuCandidate *lCandidate;
  for (Int_t plane = 0; plane < 6; plane++) {
    fPad[plane]->cd();
    Int_t colMax = TRDgeometry->GetColMax(plane);
    cout << endl << "*** Drawing Fits in Plane " << plane << endl << endl;
    for(Int_t col = 0; col < colMax ;  col++) {
      lCandidate = fitPadrow[plane]->GetCandidate(col);
      if(lCandidate->GetRPos() != -1) {
        Int_t lOffset = lCandidate->GetRPos();
        Int_t lAngle  = lCandidate->GetAngle();
        Float_t x1 = (Float_t)(lOffset-64)/128;
        Float_t x2 = x1 + (((Float_t)lAngle-128)/128);
        Float_t y1 = 0;
        Float_t y2 = timeMax - 1;
        printf("fit: Off %4d; Ang %3d  ->  Line (%6.2f,%6.3f),(%6.2f,%6.3f)\n", lOffset, lAngle, x1, y1, x2, y2);
        trackline->DrawLine(x1, y1, x2, y2);
      }
    }
  }

  // FINISHED //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  //for(Int_t plane = 0; plane < 6; plane++)
  //  delete fitPadrow[plane];
  cout << "BYE." << endl << endl;
}
