void AliTRDfitAngle()
{
  gROOT->LoadMacro("~schneide/src/c/AliTRDmacros/getDigitsManager.C");

  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfit");

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDfitPadrow SIMULATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  // CONSTANTS //
  const Char_t *alifile     = "~schneide/data/galice.root";
  const Int_t   iSec        = 13;
  const Int_t   iCha        = 2;
  const Int_t   iPla        = 3;
  const Int_t   iDefaultRow = 1;

  // READ ALIROOT FILE //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  GET DIGITS FROM ALIROOT EVENT FILE                --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDdigitsManager *DigitsManager;
  AliTRDv1 *TRD;
  TClonesArray *ParticleArray;
  AliTRDgeometry *TRDgeometry;
  if(!(getDigitsManager("~schneide/data/galice.root", &DigitsManager, &TRD, &ParticleArray))) {
    cout << "ERROR: cannot get DigitsManager" << endl;
    break;
  }
  TRDgeometry = TRD->GetGeometry();

  // INITIALIZE ENVIRONMENT //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  INITIALIZE LEVEL-0 TRIGGER SIMULATION ENVIRONMENT --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  cout << "Current Detector : Sector " << iSec << "; Chamber " << iCha
       << "; Plane " << iPla << endl;
  Int_t iRow = iDefaultRow; //GetIntegerDialog("Give ROW number:", iDefaultRow);
  cout << "Current Padrow   : " << iRow << endl;
  Int_t rowMax  = TRDgeometry->GetRowMax(iPla,iCha,iSec);
  Int_t colMax  = TRDgeometry->GetColMax(iPla);
  Int_t timeMax = TRDgeometry->GetTimeMax();
  cout << "Geometry         : Rows " << rowMax << "; Cols " << colMax << "; Bins " << timeMax << endl << endl;

  // FALKS SIMULATION //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  STARTING FALKS SIMULATION                         --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDdigit *Digit;
  TCanvas *c1 = new TCanvas("c1", "Angles", 200, 200, 600, 600);
  c1->Draw();
  TH1F *h1 = new TH1F("h1", "Angles", 20, -0.5, 255.5);
  AliTRDgtuCandidate *lCandidate;

  for(Int_t plane = 0; plane < 6; plane++) {
    for(Int_t row = 0; row < rowMax; row++) {
      AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow();
      Int_t iDet = TRDgeometry->GetDetector(plane,iCha,iSec);
      Int_t colMax  = TRDgeometry->GetColMax(plane);
      for (Int_t col = 0;  col < colMax ;  col++) {
        for (Int_t time = 0; time < timeMax; time++) {
          Digit = DigitsManager->GetDigit(row,col,time,iDet);
          Int_t iAmp = Digit->GetAmp();
          if (iAmp > 255) iAmp = 255;
          fitPadrow->SetDigit(col, time,iAmp);
          delete Digit;
        }
      }
      cout << endl << "*** Starting Fitting Simulation Plane " << plane << " Row " << row << endl << endl;
      fitPadrow->thefit();
      for(Int_t col = 0; col < colMax ;  col++) {
        lCandidate = fitPadrow->GetCandidate(col);
        if(lCandidate->GetRPos() != -1) {
          h1->Fill(lCandidate->GetAngle(), 1);
        }
      }
      delete fitPadrow;
    }
  }

  h1->Draw();


  // FINISHED //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
