void AliTRDfitStatistic()
{
  gROOT->LoadMacro("/home/schneide/src/c/AliTRDmacros/getDigitsManager.C");
  gROOT->LoadMacro("/home/schneide/src/c/AliTRDmacros/dialogs.C");

  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfit");

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDfitPadrow SIMULATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  // CONSTANTS //
  const Char_t *alifile     = "/home/schneide/data/galice_nh.root";

  const Bool_t  iSaveAs = 1; // what to do

  const Int_t   iSecMin = 0; // working range
  const Int_t   iSecMax = 17;
  const Int_t   iChaMin = 2;
  const Int_t   iChaMax = 2;
  const Int_t   iPlaMin = 0;
  const Int_t   iPlaMax = 5;

  // READ ALIROOT FILE //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  GET DIGITS FROM ALIROOT EVENT FILE                --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDdigitsManager *DigitsManager;
  AliTRDv1 *TRD;
  TClonesArray *ParticleArray;
  AliTRDgeometry *TRDgeometry;
  if(!(getDigitsManager(alifile, &DigitsManager, &TRD, &ParticleArray))) {
    cout << "ERROR: cannot get DigitsManager" << endl;
    break;
  }
  TRDgeometry = TRD->GetGeometry();

  // INITIALIZE ENVIRONMENT //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  INITIALIZE LEVEL-0 TRIGGER SIMULATION ENVIRONMENT --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;

  AliTRDfitPadrow *fitPadrow;
  AliTRDgtuCandidate *lCandidate;

  Int_t timeMax = TRDgeometry->GetTimeMax();
  printf("Sector Range   : %2d - %2d\n", iSecMin, iSecMax);
  printf("Chamber Range  : %2d - %2d\n", iChaMin, iChaMax);
  printf("Plane Range    : %2d - %2d\n", iPlaMin, iPlaMax);
  printf("Timebins       : %2d\n", timeMax);

  // HISTO INIT //
  TCanvas *c1 = new TCanvas("c1", "Hits per Track", 100, 10, 800, 600);
  c1->Draw();
  TH1F *h1 = new TH1F("h1", "Hits per Track", 30, 0, 30);
  h1->SetXTitle("Timebins"); h1->SetYTitle("Hits");

  TCanvas *c2 = new TCanvas("c2", "Gradient Distribution", 120, 30, 800, 600);
  c2->Draw();
  TH1F *h2 = new TH1F("h2", "Gradient Distribution", 256, 0, 256);
  h2->SetXTitle("Gradient"); h2->SetYTitle("Hits");

  TCanvas *c3 = new TCanvas("c3", "High Pt Digits Amplitude", 140, 50, 800, 600);
  c3->Draw();
  TH1F *h3 = new TH1F("h3", "High Pt Digits Amplitude", 256, 0, 256);
  h3->SetXTitle("Amplitude"); h2->SetYTitle("Digits");

  // FALKS SIMULATION //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  STARTING FALKS SIMULATION                         --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDdigit *Digit;
  TParticle *Particle;
  Int_t lTrack1, lTrack2, lTrack3;

  for(Int_t sector = iSecMin; sector <= iSecMax; sector++) {
    for(Int_t chamber = iChaMin; chamber <= iChaMax; chamber++) {
      for(Int_t plane = iPlaMin; plane <= iPlaMax; plane++) {
        Int_t rowMax  = TRDgeometry->GetRowMax(0,chamber,sector);
        for(Int_t row = 0; row < rowMax; row++) {
          fitPadrow = new AliTRDfitPadrow();
          Int_t colMax = TRDgeometry->GetColMax(plane);
          for (Int_t col = 0;  col < colMax ;  col++) {
            for (Int_t time = 0; time < timeMax; time++) {
              Int_t iDet = TRDgeometry->GetDetector(plane,chamber,sector);
              Digit = DigitsManager->GetDigit(row,col,time,iDet);
              lTrack1 = DigitsManager->GetTrack(0,row,col,time,iDet);
              Int_t iAmp = Digit->GetAmp();
              if (iAmp > 255) iAmp = 255;
              if(lTrack1 > -1) {
                Particle = (TParticle *) ParticleArray->At(lTrack1);
                if(Particle->Pt() > 1.0) {
                  h3->Fill(iAmp, 1);
		}
	      }
              fitPadrow->SetDigit(col, time,iAmp);
              delete Digit;
            }
          }
          printf("*** starting simulation for sector %2d, chamber %d, plane %d\r", sector, chamber, plane);
          fitPadrow->thefit();
          for(Int_t fcol = 0; fcol < colMax ;  fcol++) {
            lCandidate = fitPadrow->GetCandidate(fcol);
            if(lCandidate->GetRPos() != -1) {
              h1->Fill(lCandidate->GetAmplitude(), 1);
              h2->Fill(lCandidate->GetAngle(), 1);
            }
          }
          delete fitPadrow;
	}
      }
    }
  }
  cout << endl;

  // HISTOGRAMM OUTPUTS //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  STARTING HISTOGRAMM OUTPUTS                       --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;

  cout << "*** Hits per Track" << endl;
  c1->cd();
  h1->Draw();
  if(iSaveAs) c1->SaveAs("sim_res2_1.gif");

  cout << "*** Gradient Distribution" << endl;
  c2->cd();
  h2->Fit("gaus");
  h2->Draw();
  if(iSaveAs) c2->SaveAs("sim_res2_2.gif");

  cout << "*** High Pt Digits Amplitude" << endl;
  c3->cd();
  h3->Draw();
  if(iSaveAs) c3->SaveAs("sim_res2_4.gif");

  // FINISHED //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
