void AliTRDtrigger()
{
  gROOT->LoadMacro("/home/schneide/src/c/AliTRDmacros/getDigitsManager.C");
  gROOT->LoadMacro("/home/schneide/src/c/AliTRDmacros/dialogs.C");

  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfit");

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT LEVEL-0 TRIGGER SIMULATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  // CONSTANTS //
  const Char_t *alifile     = "/home/schneide/data/galice.root";
  const Int_t   iSec        = 13;
  const Int_t   iCha        = 2;
  const Int_t   iDefaultRow = 1;
  const Int_t   kPlanes     = 6;

  // READ ALIROOT FILE //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  GET DIGITS FROM ALIROOT EVENT FILE                --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDdigitsManager *DigitsManager;
  AliTRDv1 *TRD;
  TClonesArray *ParticleArray;
  AliTRDgeometry *TRDgeometry;
  if(!(getDigitsManager("/home/schneide/data/galice.root", &DigitsManager, &TRD, &ParticleArray))) {
    cout << "ERROR: cannot get DigitsManager" << endl;
    break;
  }
  TRDgeometry = TRD->GetGeometry();

  // INITIALIZE ENVIRONMENT //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  INITIALIZE LEVEL-0 TRIGGER SIMULATION ENVIRONMENT --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDfitPadrow *fitPadrow[kPlanes];
  for(Int_t plane = 0; plane < kPlanes; plane ++)
    fitPadrow[plane] = new AliTRDfitPadrow();
  AliTRDgtu *GTU = new AliTRDgtu(iSec, iCha);
  GTU->SetWarningLevel(0);

  // FALKS SIMULATION //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  STARTING FALKS SIMULATION                         --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDdigit *Digit;
  cout << "Current Detector : Sector " << iSec << "; Chamber " << iCha << endl;
  Int_t iRow = GetIntegerDialog("Give ROW number:", iDefaultRow);
  cout << "Current Padrow   : " << iRow << endl << endl;

printf("*** %d ***\n", fitPadrow[0]->GetCandidate(0)->GetRPos());

  for(Int_t plane = 0; plane < kPlanes; plane ++) {
    cout << "Dumping digits to AliTRDfit of Layer " << plane << endl;
    Int_t iDet = TRDgeometry->GetDetector(plane,iCha,iSec);
    for (Int_t col = 0;  col < TRDgeometry->GetColMax(plane) ;  col++) {
      for (Int_t time = 0; time < TRDgeometry->GetTimeMax(); time++) {
        Digit = DigitsManager->GetDigit(iRow,col,time,iDet);
        Int_t iAmp = Digit->GetAmp();
        if (iAmp > 255) iAmp = 255;
        fitPadrow[plane]->SetDigit(col, time,iAmp);
        delete Digit;
      }
    }
    cout << "Starting simulation for Layer " << plane << endl;
    fitPadrow[plane]->thefit();
  }

  // ROLFS SIMULATION //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  STARTING ROLFS SIMULATION                         --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;;
  AliTRDgtuBlock *Block = GTU->GetBlock(iSec, iCha);
  AliTRDgtuCandidate *lCandidate;

  for(Int_t plane = 0; plane < kPlanes; plane ++) {
    cout << "Copy fit-results to AliTRDgtu of Layer " << plane << endl;
    for(Int_t col = 0; col < TRDgeometry->GetColMax(plane) ;  col++) {
      lCandidate = fitPadrow[plane]->GetCandidate(col);
      if(lCandidate->GetRPos() != -1) {
//printf("Pla %d ; Col %3d -> Off %5d ; Ang %5d\n", plane, col, lCandidate->GetRPos(), lCandidate->GetAngle());
        lCandidate->SetZPos(iRow);
        lCandidate->SetAmplitude(0); // dummy data
        lCandidate->SetTrQuality(0); // dummy data
        Block->AddCandidate(plane, lCandidate);
      }
    }
  }

  Block->CalcMidlayer();
  //Block->OutputBlockData();
  Block->InitTMUs();
  //Block->OutputTMUs();
  Block->FindTracks(iRow);
  Block->OutputTracks(iRow);

  // FINISHED //
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
