//__________________________________________________________________
Float_t sumi(Int_t b, Int_t e, Int_t s)
{
  Float_t sumi = 0.0;

  for(Int_t i=b; i<=e; i+=s)
    sumi += i;

  return(sumi);
}

//__________________________________________________________________
Float_t sqrsumi(Int_t b, Int_t e, Int_t s)
{
  Int_t i;
  Float_t sqrsumi = 0.0;

  sqrsumi = sumi(b, e, s);
  sqrsumi = sqrsumi * sqrsumi;

  return(sqrsumi);
}

//__________________________________________________________________
Float_t sumsqri(Int_t b, Int_t e, Int_t s)
{
  Int_t i;
  Float_t sumsqri = 0.0;

  for(Int_t i=b; i<=e; i+=s)
    sumsqri += i * i;

  return(sumsqri);
}

//__________________________________________________________________
void fit_error()
{
  const Int_t   TIMEBINS   = 32;
  const Float_t DELTA_Y    = 200;
  const Int_t   start_time = 15;

  Float_t rad, radh, b;

  printf("sumi(32) = %f\nsumsqri(32) = %f\nsqrsumi(32) = %f\n", sumi(1, 32, 1), sumsqri(1, 32, 1), sqrsumi(1, 32, 1));

  //////////////////////////////////////////////////////////////////////
  // MITTLERER WINKELFEHLER UEBER TIMEBINS
  // 15-32 timebins, 200um resolution, timebins measurements
  //////////////////////////////////////////////////////////////////////
  c_ae = new TCanvas("c_ae","Error Estimation",200,10,700,500);
  c_ae->SetGrid();
  TH1F *Histo_ae = new TH1F("Histo_ae", "mittlerer Winkelfehler (dy = 200um)", TIMEBINS-start_time+1, start_time, TIMEBINS+1);
  Histo_ae->SetXTitle("timebins");
  Histo_ae->SetYTitle("um/timebin");

  for(Int_t timebins = start_time; timebins <= TIMEBINS+1; timebins++) {
    rad = 0.0;
    for(Int_t i=1; i<=timebins; i++) {
      radh = (((timebins * i) - sumi(1, timebins, 1)) * DELTA_Y) /
             ((timebins * sumsqri(1, timebins, 1)) - sqrsumi(1, timebins, 1));
      rad += radh * radh;
    }
    b = sqrt(rad);
    Histo_ae->Fill(timebins, b);
  }
  Histo_ae->Draw();

  //////////////////////////////////////////////////////////////////////
  // MITTLERER POSITIONSFEHLER UEBER TIMEBINS IN MITTELEBENE
  // 15-32 timebins, 200um resolution, timebins measurements
  //////////////////////////////////////////////////////////////////////
  c_pe = new TCanvas("c_pe","Error Estimation",300,20,700,500);
  c_pe->SetGrid();
  TH1F *Histo_pe = new TH1F("Histo_pe", "mittlerer Positionsfehler in Mittelebene (dy = 200um)", TIMEBINS-start_time, start_time, TIMEBINS);
  Histo_pe->SetXTitle("timebins");
  Histo_pe->SetYTitle("mm");

  for(Int_t timebins = start_time; timebins <= TIMEBINS; timebins++) {
    rad = 0.0;
    for(Int_t i=1; i<=timebins; i++) {
      radh = (((timebins * i) - sumi(1, timebins, 1)) * DELTA_Y) /
             ((timebins * sumsqri(1, timebins, 1)) - sqrsumi(1, timebins, 1));
      rad += radh * radh;
    }
    b = sqrt(rad);
    Histo_pe->Fill(timebins, (b*308)/1000);
  }
  Histo_pe->Draw();

  //////////////////////////////////////////////////////////////////////
  // MITTLERER WINKELFEHLER UEBER AUFLOESGUNG
  // 32 timebins, 0-500um resolution, timebins measurements
  //////////////////////////////////////////////////////////////////////
  Float_t dy;
  c_ae2 = new TCanvas("c_ae2","Error Estimation",400,30,700,500);
  c_ae2->SetGrid();
  TH1F *Histo_ae2 = new TH1F("Histo_ae2", "mittlerer Winkelfehler (32 timebins)", 500, 0, 500);
  Histo_ae2->SetXTitle("dy [um]");
  Histo_ae2->SetYTitle("um/timebin");

  for(Int_t dyi = 0; dyi <= 500; dyi++) {
    rad = 0.0;
    dy = (Float_t)dyi;
    for(Int_t i=1; i<=TIMEBINS; i++) {
      radh = (((TIMEBINS * i) - sumi(1, TIMEBINS, 1)) * dy) /
             ((TIMEBINS * sumsqri(1, TIMEBINS, 1)) - sqrsumi(1, TIMEBINS, 1));
      rad += radh * radh;
    }
    b = sqrt(rad);
    Histo_ae2->Fill(dyi, b);
  }
  Histo_ae2->Draw();

  //////////////////////////////////////////////////////////////////////
  // MITTLERER WINKELFEHLER UEBER MESSUNGEN
  // 32 timebins, 200um resolution, 15-32 measurements
  //////////////////////////////////////////////////////////////////////
  /*
  c_ae3 = new TCanvas("c_ae3","Error Estimation",500,40,700,500);
  c_ae3->SetGrid();
  TH1F *Histo_ae3 = new TH1F("Histo_ae2", "mittlerer Winkelfehler (32 timebins, dy=200um)", TIMEBINS-start_time+1, start_time, TIMEBINS+1);
  Histo_ae3->SetXTitle("Messwerte");
  Histo_ae3->SetYTitle("um/timebin");

  for(Int_t mw = start_time; mw <= TIMEBINS+1; mw++) {
    rad = 0.0;
    for(Int_t i=1; i<=mw; i++) {
      radh = (((mw * i) - sumi(1, mw, 1)) * DELTA_Y) /
             ((mw * sumsqri(1, mw, 1)) - sqrsumi(1, mw, 1));
      rad += radh * radh;
    }
    b = sqrt(rad);
    Histo_ae3->Fill(mw, b);
  }
  Histo_ae3->Draw();

  /*
  TH1F *Histo_ae3_2 = new TH1F("Histo_ae3_2", "", TIMEBINS-start_time+1, start_time, TIMEBINS+1);

  for(Int_t mw = start_time; mw <= TIMEBINS+1; mw++) {
    rad = 0.0;
    for(Int_t i=1; i<=mw; i++) {
      radh = (((mw * (i)) - sumi(1, mw, 1)) * DELTA_Y) /
             ((mw * sumsqri(1, mw, 1)) - sqrsumi(1, mw, 1));
      rad += radh * radh;
    }
    b = sqrt(rad);
    Histo_ae3_2->Fill(mw, b+1);
  }
  Histo_ae3_2->Draw("same");
  */
}
