#define HEAD(title) printf("\n--------------------------------------------------------\n--  %s\n--------------------------------------------------------\n\n", title)

void getDigitNew() {

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDfitPadrow Eventdisplay              //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
  ////// SET CONSTANTS AND WORKING RANGE
  /////////////////////////////////////////////////////////////////

  HEAD("SET CONSTANTS AND WORKING RANGE");
  const Char_t *alifile = "~schneide/data/galice_nh.root";

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  3; Int_t lPlaneMax   =  3; // Plane
  Int_t lSectorMin  =  3; Int_t lSectorMax  =  3; // Sector
  Int_t lChamberMin =  2; Int_t lChamberMax =  2; // Chamber
  Int_t lPadrowMin  = 7; Int_t lPadrowMax  = 7; // Padrow

  printf("AliRoot file  : %s\n\n", alifile);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Padrow range  : %3d .. %3d\n", lPadrowMin,  lPadrowMax);

  /////////////////////////////////////////////////////////////////
  ////// INITIALIZE ALIROOT ENVIRONMENT
  /////////////////////////////////////////////////////////////////

  HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfittmp");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(alifile);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << alifile << endl;
    gafl = new TFile(alifile);
  }
  else {
    cout << alifile << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
  ////// GET NEXT EVENT
  /////////////////////////////////////////////////////////////////

  HEAD("GET NEXT EVENT");
  printf("Current event number: %d\n", event);
  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// SIMULATION
  /////////////////////////////////////////////////////////////////

  HEAD("SIMULATION");

  for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
    for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
      for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	printf("working on event %d, chamber %d, sector %2d, plane %d ...\n", event, chamber, sector, plane);
        Int_t    lDet = TRDgeometry->GetDetector(plane, chamber, sector);
        Int_t  rowMax = TRDgeometry->GetRowMax(plane,chamber,sector);
        Int_t  colMax = TRDgeometry->GetColMax(plane);
        Int_t timeMax = TRDgeometry->GetTimeMax();
        AliTRDmatrix *TRDmatrix = new AliTRDmatrix(rowMax,colMax,timeMax,sector,chamber,plane);

	if(lPadrowMax == -1) Int_t lPadrowMMax = TRDgeometry->GetRowMax(plane, chamber, sector) - 1;
          else Int_t lPadrowMMax = lPadrowMax;
	for(Int_t padrow=lPadrowMin; padrow<=lPadrowMMax; padrow++) {
          Int_t lAmp;
          Int_t lTrack;
          // Loop through the detector pixel
          for (Int_t  col = 0;  col < colMax ;  col++) {
            for (Int_t time = 0; time < timeMax; time++) {
              AliTRDdigit *Digit = DigitsManager->GetDigit(padrow,col,time,lDet);
              Int_t lAmp = Digit->GetAmp();
              if(lAmp > 255) lAmp = 255;
              TRDmatrix->SetSignal(padrow,col,time,lAmp);
              delete Digit;
            }
          }
          TRDmatrix->DrawRow(padrow);

	  AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	  fitPadrow->SetDigitsManager(DigitsManager);
	  fitPadrow->SetTRDgeometry(TRDgeometry);
	  fitPadrow->Fit();
	  for(Int_t column=0; column<128; column++) {
	    AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	    Int_t MainTrack = fitTracklet->GetfMainTrack();

	    if (MainTrack != -1) { // found tracklet
	      Int_t MainTrackPos = 0;
	      for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
	      TParticle *Particle = (TParticle *)ParticleArray->At(MainTrack);
              // fit output
              TLine *trackline = new TLine();
              trackline->SetLineWidth(2);
              trackline->SetLineColor(2);
              Int_t lOffset = fitTracklet->GetfRPos();
              Int_t lAngle  = fitTracklet->GetfAngle();
              Float_t x1 = (Float_t)(lOffset-64)/128;
              Float_t x2 = x1 + (((Float_t)lAngle-128)/128);
              Float_t y1 = 0;
              Float_t y2 = timeMax-1;
              printf("fit: Col %3d; Off %5d; Ang %3d  ->  Line (%6.2f,%6.3f),(%6.2f,%6.3f)\n", col, lOffset, lAngle, x1, y1, x2, y2);
              trackline->DrawLine(x1, y1, x2, y2);

	    } // end found tracklet

	  } // end column
	  delete fitPadrow;
	} // end padrow
      } // end plane
    } // end sector
  } // end chamber
  //delete DigitsManager;
  } // end event

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;

}
