#define HEAD(title) printf("\n--------------------------------------------------------\n--  %s\n--------------------------------------------------------\n\n", title)

void AliTRDgtuStatistic() 
{

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDgtuStatistic GENERATION             //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  // set beauty colormap for 3d histograms
  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  // filenames
  const Char_t *alifile = "~schneide/data/galice_nh_tmp.root";
  const Char_t *realfile = "~schneide/src/c/AliTRDmacros/ROOTFILES/real.root";
  const Char_t *TitleString = "Config_nh.C (gain: 8000)";

  // set working ranges
  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event
  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  2; Int_t lChamberMax =  2; // Chamber

  Float_t lPtMin = 0.0; // minimal transvers momentum

  // output settings
  printf("AliRoot file  : %s\n\n", alifile);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt       : %f\n", lPtMin);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE CANVAS");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 1000); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(2,5);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(alifile);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << alifile << endl;
    gafl = new TFile(alifile);
  }
  else {
    cout << alifile << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  /////////////////////////////////////////////////////////////////
    HEAD("INIT ALITRDGTU ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // init AliTRDgtuStatistic enviroment
  AliTRDgtuGlobal::TMUwl = 2;
  AliTRDgtuStatistic *stat = new AliTRDgtuStatistic(gAlice);
  stat->SetSectorRange(lPlaneMin, lPlaneMax);
  stat->SetChamberRange(lSectorMin, lSectorMax);
  stat->SetPlaneRange(lChamberMin, lChamberMax);
  Int_t nParticles = stat->GetParticles();
  Int_t nPrimaryParticles = stat->GetPrimaryParticles();

  // read AliTRDgtuReal class
  AliTRDgtuReal *lReal = new AliTRDgtuReal();
  TFile *fp = new TFile(realfile);
  lReal->Read("Real");
  fp->Close();
  delete fp;
  stat->SetReal(lReal);

  /////////////////////////////////////////////////////////////////
    HEAD("DO SOME STATISTICS");
  /////////////////////////////////////////////////////////////////

  phisto1->cd(1);  stat->GenH1(lPtMin, FALSE)->Draw();
  phisto1->cd(2);  stat->GenH1(lPtMin, TRUE)->Draw();
  phisto1->cd(3);  stat->GenH2(lPtMin, FALSE)->Draw();
  phisto1->cd(4);  stat->GenH2(lPtMin, TRUE)->Draw();
  phisto1->cd(5);  stat->GenH3(lPtMin, FALSE)->Draw();
  phisto1->cd(6);  stat->GenH3(lPtMin, TRUE)->Draw();
  phisto1->cd(7);  stat->GenH4(lPtMin, FALSE)->Draw("colz");
  phisto1->cd(8);  stat->GenH4(lPtMin, TRUE)->Draw("colz");
  phisto1->cd(9);  stat->GenH5(lPtMin, FALSE)->Draw("colz");
  phisto1->cd(10); stat->GenH5(lPtMin, TRUE)->Draw("colz");

  // end
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  delete stat;
  delete lReal;
  gafl->Close();
  delete gafl;
  cout << "BYE." << endl << endl;
}
