/*
$Log: AliTRDnh_chi2.C,v $
Revision 1.7  2001/04/02 14:51:34  schneide
Use of global header file for fit settings

Revision 1.6  2001/02/18 17:56:42  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.5  2001/02/14 17:42:43  schneide
Update to new root file for full multiplicity

Revision 1.4  2001/01/26 13:17:40  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "chi2"

void AliTRDnh_chi2()
{
  const Int_t     kChips                  = 8;
  const Int_t     kChannels               = 16;

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  Float_t SigmaPos = 0.6; // sigma of position error in [mm]
  Float_t DeflCut = 4; // in [mm] over drifttime

  printf("AliRoot file  : %s\n\n", ALIFILE);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt       : %f\n", LPTMIN);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 800); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(1,2);

  // init histogramms
  TH1F *h1_1 = new TH1F("h1_1", "fit: #chi^{2} distribution (#sigma_{pos}=600#mum)", 500, 0.5, 50.5);
  h1_1->SetXTitle("#chi^{2}");
  TH1F *h1_1_2 = new TH1F("h1_1_2", "fit: #chi^{2} distribution (#sigma_{pos}=600#mum)", 500, 0.5, 50.5);
  TH1F *h1_1_3 = new TH1F("h1_1_3", "fit: #chi^{2} distribution (#sigma_{pos}=600#mum)", 500, 0.5, 50.5);

  Double_t xbins[100];
  for(Int_t xbin=0; xbin<50; xbin++)
    xbins[xbin] = 0.5;
  for(Int_t xbin=50; xbin<100; xbin++)
    xbins[xbin] = 2.0;

  TH2F *h2_1 = new TH2F("h2_1", "fit: #chi^{2}vs. detector distribution (#sigma_{pos}=600#mum, defl.cut 4mm)", 100, xbins, 540, 0.0, 540.0);
  h2_1->SetXTitle("#chi^{2}"); h2_1->SetYTitle("#detector");

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

  for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
    for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
      for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	printf("working on ev %d, cha %d, sec %2d, pla %d ...\n", event, chamber, sector, plane);
	Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector);
	Int_t lColumnMax  = TRDgeometry->GetColMax(plane);
	Int_t lTimeMax = TRDgeometry->GetTimeMax();
	for(Int_t padrow=0; padrow<lPadrowMax; padrow++) {
	  AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	  fitPadrow->SetDigitsManager(DigitsManager);
	  fitPadrow->SetTRDgeometry(TRDgeometry);
	  fitPadrow->SetThreshold(LTH);
	  fitPadrow->SetHitsMin(LSP);
	  fitPadrow->Fit();
	  for(Int_t column=0; column<128; column++) {
	    AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	    Int_t MainTrack = fitTracklet->GetfMainTrack();
	    if(MainTrack != -1) { // found tracklet
	      if(fitTracklet->GetFEject() >= 0) { // ==
		TParticle *Particle = (TParticle *)ParticleArray->At(MainTrack);
		Int_t MainTrackPos = 0;
		for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
		Float_t fitx1   = offset2mm(TRDgeometry, fitTracklet->GetfRPos(), plane);
		Float_t fitx2   = fitx1 + (10.0*TRDgeometry->GetColPadSize(plane)*(((Float_t)fitTracklet->GetfAngle()-128.0)/128.0));
		Float_t fitdiff = fitx2-fitx1;
		Float_t fitstep = fitdiff/(Float_t)lTimeMax;

		Float_t Chi2 = 0.0;

		for(Int_t timebin=0; timebin<lTimeMax; timebin++) {
		  Int_t hitpos = fitTracklet->GetfHitPos(timebin);
		  Int_t yi = fitTracklet->GetYi(timebin);
		  if(hitpos != -1) {
		    // residuae
		    Float_t yif  = column2mm(TRDgeometry, column, yi, plane);
		    Float_t yiff = fitx1 + (timebin*fitstep);
		    Float_t res = yiff-yif;
		    Chi2 += (res*res)/(SigmaPos*SigmaPos);
		  }
		}

		h1_1->Fill(Chi2, 1);
		
		if(MainTrack < nPrimaryParticles) {
		  h1_1_2->Fill(Chi2, 1);
		  if(Particle->Pt() > LPTMIN)
		    h1_1_3->Fill(Chi2, 1);
		}

                Float_t fitdefl = Angle2Defl(TRDgeometry, fitTracklet->GetfAngle(), plane, column);
		if(TMath::Abs(fitdefl) <= 4.0) {
		  h2_1->Fill(Chi2, lDet, 1);
		}
	      }
	    } // end found tracklet
	    
	  } // end column
	  delete fitPadrow;
	} // end padrow
      } // end plane
    } // end sector
  } // end chamber
  //delete DigitsManager;

  } // end event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  phisto1->cd(1); gPad->SetLogx();
  h1_1->SetLineWidth(3); h1_1->SetLineColor(2); h1_1->Draw();
  h1_1_2->SetLineWidth(3); h1_1_2->SetLineColor(4); h1_1_2->Draw("same");
  h1_1_3->SetLineWidth(3); h1_1_3->SetLineColor(6); h1_1_3->Draw("same");

  phisto1->cd(2); //gPad->SetLogx();
  h2_1->Draw("colz");

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE OUTPUT FILES");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_chi2.root", "CREATE", "Simulation");
    h1_1->Write("h1_1");
    h1_1_2->Write("h1_1_2");
    h1_1_3->Write("h1_1_3");

    h2_1->Write("h2_1");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
