/*
$Log: AliTRDnh_debug.C,v $
Revision 1.6  2001/04/02 14:51:35  schneide
Use of global header file for fit settings

Revision 1.5  2001/02/14 17:42:44  schneide
Update to new root file for full multiplicity

Revision 1.4  2001/02/08 09:30:12  schneide
Remove of static array size for RealTracks

Revision 1.3  2001/01/26 13:17:40  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#define HEAD(title) printf("\n----------------------------------------------------------\n--  %s\n----------------------------------------------------------\n\n", title)
#define STEPLINE() printf("----------------------------------------------------------\n")

void AliTRDnh_debug()
{
  cout << endl;
  cout << "//////////////////////////////////////////////////////////" << endl;
  cout << "//                                                      //" << endl;
  cout << "//  ALIROOT FIT DEBUGGER                                //" << endl;
  cout << "//                                                      //" << endl;
  cout << "//////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  const Char_t *alifile = "~schneide/data/galice.root";
  const Char_t *realfile = "~schneide/src/c/AliTRDmacros/ROOTFILES/real.root";
  const Char_t *TitleString = "Config.C, timebins 15, gain 8000";

  Int_t lEvent    =  0;
  Float_t lPtMin  = 0.0; // minimal transvers momentum

  Int_t lPlane    =   0; // set plane in any case
  Int_t lTrackID  =   8; // set track number or -1 for 

  Int_t lSector   =  3; // given chamber
  Int_t lChamber  =   2;
  Int_t lPadrow   =   2;

  printf("  alifile    : %s\n", alifile);
  printf("  realfile   : %s\n", realfile);
  printf("  event      : %d\n", lEvent);
  printf("  plane      : %d\n", lPlane);
  printf("  min. pt    : %4.2f\n", lPtMin);
  if(lTrackID > -1)
    printf("  track ID   : %d\n", lTrackID);
  else {
    printf("  sector     : %d\n", lSector);
    printf("  chamber    : %d\n", lChamber);
    printf("  padrow     : %d\n", lPadrow);
  }

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfit");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(alifile);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << alifile << endl;
    gafl = new TFile(alifile);
  }
  else {
    cout << alifile << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", lEvent);
  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(lEvent);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  //TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  // READ REAL ROOT FILE

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(realfile);
  Char_t treename[10];
  sprintf(treename, "Real%d", lEvent);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  printf("\n");
  lReal->Dump();
  printf("  particles in TRD         : %d\n", lReal->GetTRDparticles());
  printf("  primary particles in TRD : %d\n", lReal->GetTRDprimaryParticles());

  /////////////////////////////////////////////////////////////////
    HEAD("DEBUGGING");
  /////////////////////////////////////////////////////////////////

  if(lTrackID > -1) {
    AliTRDgtuRealTrack *RT = lReal->GetRealTrack(lTrackID);
    if(!RT->GetDigitsSum(lPlane)) {
      printf("*** ERROR: sorry, there is no track %d in plane %d\n\n", lTrackID, lPlane);
      lTrackID = -1;
    }
    else {
      lSector = RT->GetSector();
      lChamber = RT->GetChamber();
      lPadrow = RT->GetStartPadrow(lPlane);
    }
  }

  printf("  track ID           : %5d\n", lTrackID);
  printf("  plane              : %5d\n", lPlane);
  printf("  sector             : %5d\n", lSector);
  printf("  chamber            : %5d\n", lChamber);
  printf("  padrow             : %5d\n\n", lPadrow);
  printf("  exact lines        : red\n");
  printf("  fit lines          : blue\n");
  printf("  rejected fit lines : green\n\n");

  /////////////////////////////////////////////////////////////////
  ////// HISTOGRAMMS
  /////////////////////////////////////////////////////////////////

  Int_t lRowMax  = TRDgeometry->GetRowMax(lPlane, lChamber, lSector);
  Int_t lColMax  = TRDgeometry->GetColMax(lPlane);
  Int_t lTimeMax = TRDgeometry->GetTimeMax();
  Int_t lDet     = TRDgeometry->GetDetector(lPlane, lChamber, lSector);

  TCanvas *c1 = new TCanvas("c1", "Test", 100, 10, 1000, 400);  c1->ToggleEventStatus(); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, "Padrow Debugging"); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(1,1);

  // init histogramms
  Char_t title1_1[120];
  sprintf(title1_1, "ev %d, pla %d, sec %d, cha %d, row %d", lEvent, lPlane, lSector, lChamber, lPadrow);
  gStyle->SetOptStat(0);
  TH2F *h1_1 = new TH2F("h1_1", title1_1, lColMax, -0.5, lColMax-0.5, lTimeMax, -lTimeMax+0.5, 0.5);
  h1_1->SetXTitle("col"); h1_1->SetYTitle("time");

  AliTRDmatrix *TRDmatrix = new AliTRDmatrix(lRowMax, lColMax, lTimeMax, lSector, lChamber, lPlane);
  for(Int_t col=0; col<lColMax; col++) {
    for(Int_t time=0; time<lTimeMax; time++) {
      AliTRDdigit *Digit = DigitsManager->GetDigit(lPadrow, col, time, lDet);
      Int_t lAmp = Digit->GetAmp();
      if(lAmp > 1023) lAmp = 1023;
      h1_1->Fill(col, -time, lAmp);
      //TRDmatrix->SetSignal(lPadrow, col, time, lAmp);
      delete Digit;
    }
  }

  c1->cd();
  phisto1->cd(1);  h1_1->Draw("colz");

  /////////////////////////////////////////////////////////////////
  ////// DATA GENERATION
  /////////////////////////////////////////////////////////////////

  // Falk's fit
  TArrayI *id2col = new TArrayI(nParticles);
  for(Int_t id=0; id<nParticles; id++) id2col->AddAt(-1, id);
  AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(lPlane, lSector, lChamber, lPadrow);
  fitPadrow->SetDigitsManager(DigitsManager);
  fitPadrow->SetTRDgeometry(TRDgeometry);
  fitPadrow->Fit();
  for(Int_t fitcol=0; fitcol<128; fitcol++) {
    AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(fitcol);
    Int_t MainTrack = fitTracklet->GetfMainTrack();
    if ((MainTrack != -1)/* && (fitTracklet->GetFEject() == 0)*/) { // found tracklet
      id2col->AddAt(fitcol, MainTrack);
    }
  }

  //TRDmatrix->DrawRow(lPadrow);
  Float_t fitx1, fity1, fitx2, fity2;

  for(Int_t parno=0; parno<nParticles; parno++) {
    AliTRDgtuRealTrack *RT = lReal->GetRealTrack(parno);
    if((RT->GetSector() == lSector) && (RT->GetChamber() == lChamber) && (RT->GetDigitsSum(lPlane))
          && ((Int_t)((RT->GetExStartPadrow(lPlane) + RT->GetExEndPadrow(lPlane))/2.0) == lPadrow)) {
      TParticle *Particle = (TParticle *)gAlice->Particle(parno);
      // stdout output
      printf("- TrackID %4d, Pt %4.2f", parno, Particle->Pt());
      if(parno<nPrimaryParticles) printf(", primary -------------------------------------\n");
      else printf(" ----------------------------------------------\n");

      // position
      printf("**Position:\n");
      printf("    mean : (col %6.2f, row %5.2f, time %5.2f) - (col %6.2f, row %5.2f, time %5.2f)\n",
          (Float_t)RT->GetStartColumn(lPlane), (Float_t)RT->GetStartPadrow(lPlane), 0,
          (Float_t)RT->GetEndColumn(lPlane), (Float_t)RT->GetEndPadrow(lPlane), lTimeMax);
      printf("    exact: (col %6.2f, row %5.2f, time %5.2f) - (col %6.2f, row %5.2f, time %5.2f)\n",
          RT->GetExStartColumn(lPlane)-0.5, RT->GetExStartPadrow(lPlane), RT->GetExStartTimebin(lPlane),
          RT->GetExEndColumn(lPlane)-0.5, RT->GetExEndPadrow(lPlane), RT->GetExEndTimebin(lPlane));
      printf("    fit  : ");
      if (id2col->At(parno)>-1) {
        AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(id2col->At(parno));
        fitx1 = offset2mm(TRDgeometry, fitTracklet->GetfRPos(), lPlane) / (10.0*TRDgeometry->GetColPadSize(lPlane));
        fity1 = 0.0;
        fitx2 = fitx1 + (((Float_t)fitTracklet->GetfAngle()-128)/128); // 128/64
        fity2 = -lTimeMax+1;
        printf("(col %6.2f, row %5.2f, time %5.2f) - (col %6.2f, row %5.2f, time %5.2f)\n",
            fitx1, (Float_t)lPadrow, 0, fitx2, (Float_t)lPadrow, lTimeMax);
      }
      else
        printf("-\n");

      // deflection
      if(parno < nPrimaryParticles) {
	printf("**Deflection:\n");
	printf("    mean : %8.4f mm\n", Pt2Defl(TRDgeometry, Particle->Pt(),
            Particle->GetPDG()->Charge(), lPlane, (Int_t)RT->GetExStartColumn(lPlane)));
	printf("    exact: %8.4f mm\n", Pos2Defl(TRDgeometry, RT->GetExStartColumn(lPlane),
            RT->GetExEndColumn(lPlane), RT->GetExStartTimebin(lPlane), RT->GetExEndTimebin(lPlane),
            lPlane, (Int_t)RT->GetExStartColumn(lPlane)));
	printf("    fit  : ");
	if (id2col->At(parno)>-1) {
	  AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(id2col->At(parno));
	  printf("%8.4f mm\n", Angle2Defl(TRDgeometry, fitTracklet->GetfAngle(),
              lPlane, (Int_t)RT->GetExStartColumn(lPlane)));
	}
	else
	  printf("-\n");
      }

      // digits
      printf("**Digits:\n");
      printf("    exact: %3d\n", RT->GetDigitsSum(lPlane));
      printf("    fit  : ");
      if (id2col->At(parno)>-1) {
	AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(id2col->At(parno));
        Int_t MainTrack = fitTracklet->GetfMainTrack();
        Int_t MainTrackPos = 0;
        for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
        printf("%3d\n", fitTracklet->GetTrackCountAt(MainTrackPos));
      }
      else
        printf("-\n");

      printf("\n");

      // draw exact line
      TLine *trackline = new TLine();
      trackline->SetLineWidth(3);
      trackline->SetLineColor(2);
      Float_t realover = 1.0;
      Float_t realangle = (RT->GetExEndColumn(lPlane)-RT->GetExStartColumn(lPlane))/(RT->GetExEndTimebin(lPlane)-RT->GetExStartTimebin(lPlane));
      Float_t realx1 = -0.5 + RT->GetExStartColumn(lPlane) - (realover*realangle);
      Float_t realy1 = -lTimeMax + 0.5 - realover;
      Float_t realx2 = -0.5 + RT->GetExEndColumn(lPlane) + (realover*realangle);
      Float_t realy2 = 0.5 + realover;
      trackline->DrawLine(realx1, realy1, realx2, realy2);

      // draw fit line
      TLine *fitline = new TLine();
      fitline->SetLineWidth(3);
      if(fitTracklet->GetFEject() == 0)
        fitline->SetLineColor(3);
      else
        fitline->SetLineColor(1);
      fitline->DrawLine(fitx1, fity1, fitx2, fity2);
    }
  }

  delete fitPadrow;
  delete lReal;

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  STEPLINE();
  cout << "BYE." << endl << endl;
}
