/*
$Log: AliTRDnh_defl.C,v $
Revision 1.7  2001/04/02 14:51:35  schneide
Use of global header file for fit settings

Revision 1.6  2001/02/18 17:56:42  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.5  2001/02/14 17:42:44  schneide
Update to new root file for full multiplicity

Revision 1.4  2001/01/26 13:17:40  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "defl"

#define DETS 540
#define PRIMPAR 20000

void AliTRDnh_defl()
{
  const Int_t     kChips                  = 8;
  const Int_t     kChannels               = 16;

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  Float_t NormFac = 1./6.; // normalization to one full event

  printf("AliRoot file     : %s\n\n", ALIFILE);
  printf("Event range      : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range      : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range     : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range    : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt          : %f\n", LPTMIN);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 800); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(2,3);

  // init histogramms
  TH1F *h1_1_1 = new TH1F("h1_1_1", "number of found tracklets for single layer vs. pt (defl: <oo,<8mm,<6mm,<4mm,<2mm,<1.5mm)", 50, 0.0, 5.0); // defl < 8mm
  h1_1_1->SetXTitle("pt");
  TH1F *h1_1_2 = new TH1F("h1_1_2", "number of found tracklets", 50, 0.0, 5.0); // defl < 6mm
  TH1F *h1_1_3 = new TH1F("h1_1_3", "number of found tracklets", 50, 0.0, 5.0); // defl < 4mm
  TH1F *h1_1_4 = new TH1F("h1_1_4", "number of found tracklets", 50, 0.0, 5.0); // defl < 2mm
  TH1F *h1_1_5 = new TH1F("h1_1_5", "number of found tracklets", 50, 0.0, 5.0); // defl < 1.5mm

  TH1F *h2_1_1 = new TH1F("h2_1_1", "rel. number of found tracklets for single layer vs. pt (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 50, 0.0, 5.0); // defl < 8mm
  h2_1_1->SetXTitle("pt");
  TH1F *h2_1_2 = new TH1F("h2_1_2", "rel. number of found tracklets", 50, 0.0, 5.0); // defl < 6mm
  TH1F *h2_1_3 = new TH1F("h2_1_3", "rel. number of found tracklets", 50, 0.0, 5.0); // defl < 4mm
  TH1F *h2_1_4 = new TH1F("h2_1_4", "rel. number of found tracklets", 50, 0.0, 5.0); // defl < 2mm
  TH1F *h2_1_5 = new TH1F("h2_1_5", "rel. number of found tracklets", 50, 0.0, 5.0); // defl < 1.5mm

  TH1F *h0_1_1 = new TH1F("h0_1_1", "number of found tracklets (oo,8mm,6mm,4mm,2mm)", 50, 0.0, 5.0); // defl < oo

  TH1F *h3_1_1 = new TH1F("h3_1_1", "#tracklets vs. detector (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 540, 0.0, 540.0);
  h3_1_1->SetXTitle("detector"); h3_1_1->SetYTitle("#tracklets");
  TH1F *h3_1_2 = new TH1F("h3_1_2", "#tracklets vs. detector (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 540, 0.0, 540.0);
  TH1F *h3_1_3 = new TH1F("h3_1_3", "#tracklets vs. detector (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 540, 0.0, 540.0);
  TH1F *h3_1_4 = new TH1F("h3_1_4", "#tracklets vs. detector (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 540, 0.0, 540.0);
  TH1F *h3_1_5 = new TH1F("h3_1_5", "#tracklets vs. detector (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 540, 0.0, 540.0);
  TH1F *h3_1_6 = new TH1F("h3_1_6", "#tracklets vs. detector (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 540, 0.0, 540.0); // MC

  TH1F *h4_1_1 = new TH1F("h4_1_1", "#tracklets per chamber distribution (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 40, 0.0, 100.0);
  h4_1_1->SetXTitle("#tracklets/chamber");
  TH1F *h4_1_2 = new TH1F("h4_1_2", "#tracklets per chamber distribution (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 40, 0.0, 100.0);
  TH1F *h4_1_3 = new TH1F("h4_1_3", "#tracklets per chamber distribution (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 40, 0.0, 100.0);
  TH1F *h4_1_4 = new TH1F("h4_1_4", "#tracklets per chamber distribution (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 40, 0.0, 100.0);
  TH1F *h4_1_5 = new TH1F("h4_1_5", "#tracklets per chamber distribution (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 40, 0.0, 100.0);

  TH1F *h5_1_1 = new TH1F("h5_1_1", "#high pt MC not found vs. detector (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 540, 0.0, 540.0);
  h5_1_1->SetXTitle("#segments");
  TH1F *h5_1_2 = new TH1F("h5_1_2", "#high pt MC not found vs. detector (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 540, 0.0, 540.0);
  TH1F *h5_1_3 = new TH1F("h5_1_3", "#high pt MC not found vs. detector (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 540, 0.0, 540.0);
  TH1F *h5_1_4 = new TH1F("h5_1_4", "#high pt MC not found vs. detector (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 540, 0.0, 540.0);
  TH1F *h5_1_5 = new TH1F("h5_1_5", "#high pt MC not found vs. detector (defl: <8mm,<6mm,<4mm,<2mm,<1.5mm)", 540, 0.0, 540.0);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  //TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

    Bool_t fitfound8[DETS*PRIMPAR];
    Bool_t fitfound6[DETS*PRIMPAR];
    Bool_t fitfound4[DETS*PRIMPAR];
    Bool_t fitfound2[DETS*PRIMPAR];
    Bool_t fitfound15[DETS*PRIMPAR];
    for(Int_t i=0; i<DETS*PRIMPAR; i++) {
      fitfound8[i] = FALSE;
      fitfound6[i] = FALSE;
      fitfound4[i] = FALSE;
      fitfound2[i] = FALSE;
      fitfound15[i] = FALSE;
    }

    for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
      for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
	for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	  printf("working on ev %d, cha %d, sec %2d, pla %d ...\n", event, chamber, sector, plane);
	  Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	  Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector);
	  for(Int_t padrow=0; padrow<lPadrowMax; padrow++) {
	    AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	    fitPadrow->SetDigitsManager(DigitsManager);
	    fitPadrow->SetTRDgeometry(TRDgeometry);
            fitPadrow->SetHitsMin(LSP);
            fitPadrow->SetThreshold(LTH);
	    fitPadrow->Fit();
	    for(Int_t column=0; column<128; column++) {
	      AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	      Int_t MainTrack = fitTracklet->GetfMainTrack();

	      if (MainTrack != -1) { // found tracklet
		Int_t MainTrackPos = 0;
		for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
		TParticle *Particle = (TParticle *)gAlice->Particle(MainTrack);
		Float_t lPt = Particle->Pt();
		Float_t fitdefl = Angle2Defl(TRDgeometry, fitTracklet->GetfAngle(), plane, column);
		h0_1_1->Fill(lPt, NormFac);
		if(TMath::Abs(fitdefl) <= 8.0) {
		  h1_1_1->Fill(lPt, NormFac);
		  h2_1_1->Fill(lPt, NormFac);
		  h3_1_1->Fill(lDet, 1);
		  fitfound8[(DETS*lDet)+MainTrack] = TRUE;
		}
		if(TMath::Abs(fitdefl) <= 6.0) {
		  h1_1_2->Fill(lPt, NormFac);
		  h2_1_2->Fill(lPt, NormFac);
		  h3_1_2->Fill(lDet, 1);
		  fitfound6[(DETS*lDet)+MainTrack] = TRUE;
		}
		if(TMath::Abs(fitdefl) <= 4.0) {
		  h1_1_3->Fill(lPt, NormFac);
		  h2_1_3->Fill(lPt, NormFac);
		  h3_1_3->Fill(lDet, 1);
		  fitfound4[(DETS*lDet)+MainTrack] = TRUE;
		}
		if(TMath::Abs(fitdefl) <= 2.0) {
		  h1_1_4->Fill(lPt, NormFac);
		  h2_1_4->Fill(lPt, NormFac);
		  h3_1_4->Fill(lDet, 1);
		  fitfound2[(DETS*lDet)+MainTrack] = TRUE;
		}
		if(TMath::Abs(fitdefl) <= 1.5) {
		  h1_1_5->Fill(lPt, NormFac);
		  h2_1_5->Fill(lPt, NormFac);
		  h3_1_5->Fill(lDet, 1);
		  fitfound15[(DETS*lDet)+MainTrack] = TRUE;
		}
	      } // end found tracklet

	    } // end column
	    delete fitPadrow;
	  } // end padrow
	} // end plane
      } // end sector
    } // end chamber

  } // end event

  for(Int_t chamber=0; chamber<540; chamber++) {
    h4_1_1->Fill(h3_1_1->GetBinContent(chamber), 1);
    h4_1_2->Fill(h3_1_2->GetBinContent(chamber), 1);
    h4_1_3->Fill(h3_1_3->GetBinContent(chamber), 1);
    h4_1_4->Fill(h3_1_4->GetBinContent(chamber), 1);
    h4_1_5->Fill(h3_1_5->GetBinContent(chamber), 1);
  }

  for(Int_t parno=0; parno<nPrimaryParticles; parno++) {
    TParticle *Particle = (TParticle *)gAlice->Particle(parno);
    Float_t lPt = Particle->Pt();
    if(lPt>LPTMIN) {
      AliTRDgtuRealTrack *RT = lReal->GetRealTrack(parno);
      for(Int_t plane=0; plane<=lPlaneMax; plane++) {
	if(RT->GetAmplitudeSum(plane)) {
	  Int_t lDet = TRDgeometry->GetDetector(plane, RT->GetChamber(), RT->GetSector());
	  h3_1_6->Fill(lDet, 1);
	  if(!fitfound8[(DETS*lDet)+parno]) h5_1_1->Fill(lDet, 1);
	  if(!fitfound6[(DETS*lDet)+parno]) h5_1_2->Fill(lDet, 1);
	  if(!fitfound4[(DETS*lDet)+parno]) h5_1_3->Fill(lDet, 1);
	  if(!fitfound2[(DETS*lDet)+parno]) h5_1_4->Fill(lDet, 1);
	  if(!fitfound15[(DETS*lDet)+parno]) h5_1_5->Fill(lDet, 1);
	}
      }
    }
  }

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  phisto1->cd(1); gPad->SetLogy(); h0_1_1->SetLineWidth(5); h0_1_1->SetLineColor(1); h0_1_1->SetStats(TRUE); h0_1_1->Draw();
  phisto1->cd(1); gPad->SetLogy(); h1_1_1->SetLineWidth(5); h1_1_1->SetLineColor(2); h1_1_1->SetStats(FALSE); h1_1_1->Draw("same");
  phisto1->cd(1); gPad->SetLogy(); h1_1_2->SetLineWidth(5); h1_1_2->SetLineColor(4); h1_1_2->SetStats(FALSE); h1_1_2->Draw("same");
  phisto1->cd(1); gPad->SetLogy(); h1_1_3->SetLineWidth(5); h1_1_3->SetLineColor(6); h1_1_3->SetStats(FALSE); h1_1_3->Draw("same");
  phisto1->cd(1); gPad->SetLogy(); h1_1_4->SetLineWidth(5); h1_1_4->SetLineColor(8); h1_1_4->SetStats(FALSE); h1_1_4->Draw("same");
  phisto1->cd(1); gPad->SetLogy(); h1_1_5->SetLineWidth(5); h1_1_5->SetLineColor(7); h1_1_5->SetStats(FALSE); h1_1_5->Draw("same");

  printf("number of tracklets per layer:\n");
  printf("defl < oo mm: %d\n", h0_1_1->Integral());
  printf("defl <  8 mm: %d\n", h1_1_1->Integral());
  printf("defl <  6 mm: %d\n", h1_1_2->Integral());
  printf("defl <  4 mm: %d\n", h1_1_3->Integral());
  printf("defl <  2 mm: %d\n", h1_1_4->Integral());
  printf("defl <1.5 mm: %d\n", h1_1_5->Integral());

  phisto1->cd(2); h2_1_1->Divide(h0_1_1); h2_1_1->SetLineWidth(5); h2_1_1->SetLineColor(2); h2_1_1->SetStats(FALSE); h2_1_1->Draw();
  phisto1->cd(2); h2_1_2->Divide(h0_1_1); h2_1_2->SetLineWidth(5); h2_1_2->SetLineColor(4); h2_1_2->SetStats(FALSE); h2_1_2->Draw("same");
  phisto1->cd(2); h2_1_3->Divide(h0_1_1); h2_1_3->SetLineWidth(5); h2_1_3->SetLineColor(6); h2_1_3->SetStats(FALSE); h2_1_3->Draw("same");
  phisto1->cd(2); h2_1_4->Divide(h0_1_1); h2_1_4->SetLineWidth(5); h2_1_4->SetLineColor(8); h2_1_4->SetStats(FALSE); h2_1_4->Draw("same");
  phisto1->cd(2); h2_1_5->Divide(h0_1_1); h2_1_5->SetLineWidth(5); h2_1_5->SetLineColor(7); h2_1_5->SetStats(FALSE); h2_1_5->Draw("same");

  phisto1->cd(3); h3_1_1->SetLineWidth(1); h3_1_1->SetLineColor(2); h3_1_1->SetStats(FALSE); h3_1_1->Draw();
  phisto1->cd(3); h3_1_2->SetLineWidth(1); h3_1_2->SetLineColor(4); h3_1_2->SetStats(FALSE); h3_1_2->Draw("same");
  phisto1->cd(3); h3_1_3->SetLineWidth(1); h3_1_3->SetLineColor(6); h3_1_3->SetStats(FALSE); h3_1_3->Draw("same");
  phisto1->cd(3); h3_1_4->SetLineWidth(1); h3_1_4->SetLineColor(8); h3_1_4->SetStats(FALSE); h3_1_4->Draw("same");
  phisto1->cd(3); h3_1_5->SetLineWidth(1); h3_1_5->SetLineColor(7); h3_1_5->SetStats(FALSE); h3_1_5->Draw("same");
  phisto1->cd(3); h3_1_6->SetLineWidth(1); h3_1_6->SetLineColor(1); h3_1_6->SetStats(FALSE); h3_1_6->Draw("same");

  phisto1->cd(4); h4_1_5->SetLineWidth(3); h4_1_5->SetLineColor(7); h4_1_5->SetStats(FALSE); h4_1_5->Draw();
  phisto1->cd(4); h4_1_4->SetLineWidth(3); h4_1_4->SetLineColor(8); h4_1_4->SetStats(FALSE); h4_1_4->Draw("same");
  phisto1->cd(4); h4_1_3->SetLineWidth(3); h4_1_3->SetLineColor(6); h4_1_3->SetStats(FALSE); h4_1_3->Draw("same");
  phisto1->cd(4); h4_1_2->SetLineWidth(3); h4_1_2->SetLineColor(4); h4_1_2->SetStats(FALSE); h4_1_2->Draw("same");
  phisto1->cd(4); h4_1_1->SetLineWidth(3); h4_1_1->SetLineColor(2); h4_1_1->SetStats(FALSE); h4_1_1->Draw("same");

  phisto1->cd(5); h5_1_5->SetLineWidth(1); h5_1_5->SetLineColor(7); h5_1_5->SetStats(FALSE); h5_1_5->Draw();
  phisto1->cd(5); h5_1_4->SetLineWidth(1); h5_1_4->SetLineColor(8); h5_1_4->SetStats(FALSE); h5_1_4->Draw("same");
  phisto1->cd(5); h5_1_3->SetLineWidth(1); h5_1_3->SetLineColor(6); h5_1_3->SetStats(FALSE); h5_1_3->Draw("same");
  phisto1->cd(5); h5_1_2->SetLineWidth(1); h5_1_2->SetLineColor(4); h5_1_2->SetStats(FALSE); h5_1_2->Draw("same");
  phisto1->cd(5); h5_1_1->SetLineWidth(1); h5_1_1->SetLineColor(2); h5_1_1->SetStats(FALSE); h5_1_1->Draw("same");

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE OUTPUT FILES");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_defl.root", "CREATE", "Simulation");
    h0_1_1->Write("h0_1_1");

    h1_1_1->Write("h1_1_1");
    h1_1_2->Write("h1_1_2");
    h1_1_3->Write("h1_1_3");
    h1_1_4->Write("h1_1_4");
    h1_1_5->Write("h1_1_5");

    h2_1_1->Write("h2_1_1");
    h2_1_2->Write("h2_1_2");
    h2_1_3->Write("h2_1_3");
    h2_1_4->Write("h2_1_4");
    h2_1_5->Write("h2_1_5");

    h3_1_1->Write("h3_1_1");
    h3_1_2->Write("h3_1_2");
    h3_1_3->Write("h3_1_3");
    h3_1_4->Write("h3_1_4");
    h3_1_5->Write("h3_1_5");
    h3_1_6->Write("h3_1_6");

    h4_1_1->Write("h4_1_1");
    h4_1_2->Write("h4_1_2");
    h4_1_3->Write("h4_1_3");
    h4_1_4->Write("h4_1_4");
    h4_1_5->Write("h4_1_5");

    h5_1_1->Write("h5_1_1");
    h5_1_2->Write("h5_1_2");
    h5_1_3->Write("h5_1_3");
    h5_1_4->Write("h5_1_4");
    h5_1_5->Write("h5_1_5");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
