/*
$Log: AliTRDnh_digit.C,v $
Revision 1.7  2001/04/02 14:51:35  schneide
Use of global header file for fit settings

Revision 1.6  2001/02/18 17:56:42  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.5  2001/02/14 17:42:44  schneide
Update to new root file for full multiplicity

Revision 1.4  2001/01/26 13:17:40  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "digit"

void AliTRDnh_digit()
{
  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
  ////// SET CONSTANTS AND WORKING RANGE
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  HEAD("SET CONSTANTS AND WORKING RANGE");

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  printf("AliRoot file  : %s\n\n", ALIFILE);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt       : %f\n", LPTMIN);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 400); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(1,1);

  // init histogramms
  TH1F *h1_1 = new TH1F("h1_1", "digit amplitude value", 1050.0, 0.0, 1050.0);
  h1_1->SetXTitle("amplitude");
  TH1F *h1_2 = new TH1F("h1_2", "digit amplitude value (prim)", 1050.0, 0.0, 1050.0);
  h1_2->SetXTitle("amplitude");

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

  for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
    for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
      for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	printf("working on ev %d, cha %d, sec %2d, pla %d ...\n", event, chamber, sector, plane);
        Int_t lDet     = TRDgeometry->GetDetector(plane, chamber, sector);
	Int_t lRowMax  = TRDgeometry->GetRowMax(plane, chamber, sector);
	Int_t lColMax  = TRDgeometry->GetColMax(plane);
	Int_t lTimeMax = TRDgeometry->GetTimeMax();
	for(Int_t padrow=0; padrow<lRowMax; padrow++) {
	  for(Int_t column=0; column<lColMax; column++) {
	    for(Int_t timebin=0; timebin<lTimeMax; timebin++) {
	      Int_t trackno = DigitsManager->GetTrack(0, padrow, column, timebin, lDet);
	      if(trackno <= -1) continue;
	      AliTRDdigit *Digit = DigitsManager->GetDigit(padrow, column, timebin, lDet);
	      Int_t lAmp = Digit->GetAmp();
	      h1_1->Fill(lAmp, 1);
	      if(trackno < nPrimaryParticles) h1_2->Fill(lAmp, 1);
	      delete Digit;
	    } // end timebin
	  } // end column
	} // end padrow
      } // end plane
    } // end sector
  } // end chamber
  } // end event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  phisto1->cd(1); gPad->SetLogy();
  h1_1->SetLineWidth(3); h1_1->SetLineColor(2); h1_1->Draw();
  h1_2->SetLineWidth(3); h1_2->SetLineColor(4); h1_2->Draw("same");

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE OUTPUT FILES");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_digit.root", "CREATE", "Simulation");
    h1_1->Write("h1_1");
    h1_2->Write("h1_2");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
