/*
$Log: AliTRDnh_eff2.C,v $
Revision 1.7  2001/04/02 14:51:35  schneide
Use of global header file for fit settings

Revision 1.6  2001/02/18 17:56:42  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.5  2001/02/14 17:42:44  schneide
Update to new root file for full multiplicity

Revision 1.4  2001/01/26 13:17:40  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "eff2"

void AliTRDnh_eff2()
{
  const Int_t     kChips                  = 8;
  const Int_t     kChannels               = 16;

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  // loop variables for fit constants
  Int_t lSpMin  =  2; // minimal threshold
  Int_t lSpMax  = 10; // maximal threshold
  Int_t lSpStep =  2;

  printf("AliRoot file     : %s\n\n", ALIFILE);
  printf("Event range      : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range      : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range     : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range    : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt          : %f\n", LPTMIN);
  printf("Min. spacepoints : %d .. %d step %d\n", lSpMin, lSpMax, lSpStep);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 400); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(2,1);

  // init histogramms
  TH2F *h1_1 = new TH2F("h1_1", "efficiency vs. HitsMin,pt", 10.0, 0.0, 5.0, 5, lSpMin-((Float_t)lSpStep/2), lSpMax+((Float_t)lSpStep)/2);
  TH2F *h1_1_1 = new TH2F("h1_1_1", "efficiency vs. HitsMin,pt", 10.0, 0.0, 5.0, 5, lSpMin-((Float_t)lSpStep/2), lSpMax+((Float_t)lSpStep)/2);
  h1_1_1->SetXTitle("pt"); h1_1_1->SetYTitle("th"); 
  TH2F *h1_2 = new TH2F("h1_2", "efficiency vs. HitsMin,pt (prim)", 10.0, 0.0, 5.0, 5, lSpMin-((Float_t)lSpStep/2), lSpMax+((Float_t)lSpStep)/2);
  TH2F *h1_2_1 = new TH2F("h1_2_1", "efficiency vs. HitsMin,pt (prim)", 10.0, 0.0, 5.0, 5, lSpMin-((Float_t)lSpStep/2), lSpMax+((Float_t)lSpStep)/2);
  h1_2_1->SetXTitle("pt"); h1_2_1->SetYTitle("th"); 
  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticl
es))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

  TArrayI *lTrackVsPlane = new TArrayI(6*nParticles); // array for fit: tracklets in planes
  TArrayI *lEffFound = new TArrayI(6*nParticles);
  TArrayI *lEffRPos = new TArrayI(6*nParticles);
  TArrayI *lEffAngle = new TArrayI(6*nParticles);
  TArrayI *lEffChi2 = new TArrayI(6*nParticles);
  TArrayI *lEffCol = new TArrayI(6*nParticles);

  for(Int_t lSp=lSpMin; lSp<=lSpMax; lSp+=lSpStep) {

    for(Int_t index=0; index<6*nParticles; index++) lEffFound->AddAt(-1, index);
    lEffRPos->Reset();
    lEffAngle->Reset();
    lEffChi2->Reset();
    lEffCol->Reset();

    for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
      for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
	lTrackVsPlane->Reset();
	for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	  printf("working on sp %d, ev %d, cha %d, sec %2d, pla %d ...\n", lSp, event, chamber, sector, plane);
	  Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	  Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector);
	  for(Int_t padrow=0; padrow<lPadrowMax; padrow++) {
	    AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	    fitPadrow->SetDigitsManager(DigitsManager);
	    fitPadrow->SetTRDgeometry(TRDgeometry);
	    fitPadrow->SetThreshold(LTH);
            fitPadrow->SetHitsMin(lSp);
	    fitPadrow->Fit();
	    for(Int_t column=0; column<128; column++) {
	      AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	      Int_t MainTrack = fitTracklet->GetfMainTrack();

	      if (MainTrack != -1) { // found tracklet
		Int_t MainTrackPos = 0;
		for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
		TParticle *Particle = (TParticle *)ParticleArray->At(MainTrack);
		if((Particle->Pt() >= LPTMIN)) { // Pt > LPTMIN
		  // eff found
		  lEffFound->AddAt(fitTracklet->GetFEject(), (plane*nParticles)+MainTrack);
		  lEffRPos->AddAt(fitTracklet->GetfRPos(), (plane*nParticles)+MainTrack);
		  lEffAngle->AddAt(fitTracklet->GetfAngle(), (plane*nParticles)+MainTrack);
		  lEffChi2->AddAt(fitTracklet->GetfChi2(), (plane*nParticles)+MainTrack);
		  lEffCol->AddAt(column, (plane*nParticles)+MainTrack);
		} // end LPTMIN
	      } // end found tracklet

	    } // end column
	    delete fitPadrow;
	  } // end padrow
	} // end plane


      } // end sector
    } // end chamber
    //delete DigitsManager;

    for(Int_t parno=0; parno<nParticles; parno++) {
      AliTRDgtuRealTrack *RT = lReal->GetRealTrack(parno);
      Float_t lPt = ((TParticle *)ParticleArray->At(parno))->Pt();
      if(lPt >= LPTMIN) {
	for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	  if(RT->GetDigitsSum(plane)) {
	    h1_1->Fill(lPt, lSp, 1);
	    if(parno<nPrimaryParticles) h1_2->Fill(lPt, lSp, 1);
	    if(lEffFound->At((plane*nParticles)+parno) >= 0) { // ==
	      h1_1_1->Fill(lPt, lSp, 100);
	      if(parno<nPrimaryParticles) h1_2_1->Fill(lPt, lSp, 100);
	    }
	  }
	}
      }
    }

  } // end threshold

  delete lEffFound;
  delete lEffRPos;
  delete lEffAngle;
  delete lEffChi2;
  delete lEffCol;
  delete lReal;
  } // end event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  h1_1_1->Divide(h1_1); phisto1->cd(1); h1_1_1->Draw("colz");
  h1_2_1->Divide(h1_2); phisto1->cd(2); h1_2_1->Draw("colz");

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE OUTPUT FILES");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_eff2.root", "CREATE", "Simulation");
    h1_1->Write("h1_1");
    h1_2->Write("h1_2");
    h1_1_1->Write("h1_1_1");
    h1_2_1->Write("h1_2_1");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
