/*
$Log: AliTRDnh_eff3.C,v $
Revision 1.7  2001/04/02 14:51:35  schneide
Use of global header file for fit settings

Revision 1.6  2001/02/18 17:56:42  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.5  2001/02/14 17:42:44  schneide
Update to new root file for full multiplicity

Revision 1.4  2001/01/26 13:17:41  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "eff3"

void AliTRDnh_eff3()
{
  const Int_t     kChips                  = 8;
  const Int_t     kChannels               = 16;

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  printf("AliRoot file     : %s\n\n", ALIFILE);
  printf("Event range      : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range      : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range     : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range    : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt          : %f\n", LPTMIN);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 800); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(1,2);

  // init histogramms
  TH1F *h1_1_1 = new TH1F("h1_1_1", "efficiency vs. pt", 10, 0.0, 5.0); // all particles
  h1_1_1->SetXTitle("pt"); h1_1_1->SetYTitle("%");
  TH1F *h1_1_2 = new TH1F("h1_1_2", "efficiency vs. pt", 10, 0.0, 5.0); // primary particles
  h1_1_2->SetXTitle("pt"); h1_1_2->SetYTitle("%");

  TH1F *h1_2_1 = new TH1F("h1_2_1", "efficiency vs. theta", 50, 40.0, 140.0); // all
  h1_2_1->SetXTitle("theta"); h1_2_1->SetYTitle("%");
  TH1F *h1_2_2 = new TH1F("h1_2_2", "efficiency vs. theta", 50, 40.0, 140.0); // primaries
  h1_2_2->SetXTitle("theta"); h1_2_2->SetYTitle("%");
  TH1F *h1_2_3 = new TH1F("h1_2_3", "efficiency vs. theta", 50, 40.0, 140.0); // high pt primaries
  h1_2_3->SetXTitle("theta"); h1_2_3->SetYTitle("%");

  TH1F *h0_1_1 = new TH1F("h0_1_1", "number of tracks vs. pt", 10, 0.0, 5.0); // all
  TH1F *h0_1_2 = new TH1F("h0_1_2", "number of tracks vs. pt", 10, 0.0, 5.0); // primaries
  TH1F *h0_2_1 = new TH1F("h0_2_1", "number of tracks vs. theta", 50, 40.0, 140.0); // all
  TH1F *h0_2_2 = new TH1F("h0_2_2", "number of tracks vs. theta", 50, 40.0, 140.0); // primaries
  TH1F *h0_2_3 = new TH1F("h0_2_3", "number of tracks vs. theta", 50, 40.0, 140.0); // high pt primaries

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  //TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

    TArrayI *lTrackVsPlane = new TArrayI(6*nParticles); // array for fit: tracklets in planes
    TArrayI *lEffFound = new TArrayI(6*nParticles);
    TArrayI *lEffRPos = new TArrayI(6*nParticles);
    TArrayI *lEffAngle = new TArrayI(6*nParticles);
    TArrayI *lEffChi2 = new TArrayI(6*nParticles);
    TArrayI *lEffCol = new TArrayI(6*nParticles);

    for(Int_t index=0; index<6*nParticles; index++) lEffFound->AddAt(-1, index);
    lEffRPos->Reset();
    lEffAngle->Reset();
    lEffChi2->Reset();
    lEffCol->Reset();

    for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
      for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
	lTrackVsPlane->Reset();
	for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	  printf("working on ev %d, cha %d, sec %2d, pla %d ...\n", event, chamber, sector, plane);
	  Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	  Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector);
	  for(Int_t padrow=0; padrow<lPadrowMax; padrow++) {
	    AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	    fitPadrow->SetDigitsManager(DigitsManager);
	    fitPadrow->SetTRDgeometry(TRDgeometry);
            // set threshold
            fitPadrow->SetHitsMin(LSP);
            fitPadrow->SetThreshold(LTH);
	    fitPadrow->Fit();
	    for(Int_t column=0; column<128; column++) {
	      AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	      Int_t MainTrack = fitTracklet->GetfMainTrack();

	      if (MainTrack != -1) { // found tracklet
		Int_t MainTrackPos = 0;
		for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
		TParticle *Particle = (TParticle *)gAlice->Particle(MainTrack);
		// eff found
		lEffFound->AddAt(fitTracklet->GetFEject(), (plane*nParticles)+MainTrack);
		lEffRPos->AddAt(fitTracklet->GetfRPos(), (plane*nParticles)+MainTrack);
		lEffAngle->AddAt(fitTracklet->GetfAngle(), (plane*nParticles)+MainTrack);
		lEffChi2->AddAt(fitTracklet->GetfChi2(), (plane*nParticles)+MainTrack);
		lEffCol->AddAt(column, (plane*nParticles)+MainTrack);
	      } // end found tracklet

	    } // end column
	    delete fitPadrow;
	  } // end padrow
	} // end plane


      } // end sector
    } // end chamber
    //delete DigitsManager;

    for(Int_t parno=0; parno<nParticles; parno++) {
      //if(parno>=nPrimaryParticles) continue;
      AliTRDgtuRealTrack *RT = lReal->GetRealTrack(parno);
      Float_t lPt = ((TParticle *)gAlice->Particle(parno))->Pt();
      for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	if(RT->GetDigitsSum(plane)) {
	  Int_t rtDet = TRDgeometry->GetDetector(plane, RT->GetChamber(), RT->GetSector());
	  Float_t rttheta = padrow2angle(TRDgeometry, rtDet, RT->GetExStartPadrow(plane));
	  h0_1_1->Fill(lPt, 1);
	  h0_2_1->Fill(rttheta, 1);
	  if(parno<nPrimaryParticles) {
	    h0_1_2->Fill(lPt, 1);
	    h0_2_2->Fill(rttheta, 1);
	    if(lPt>LPTMIN) h0_2_3->Fill(rttheta, 1);
	  }
	  if(lEffFound->At((plane*nParticles)+parno) >= 0) { // ==
	    h1_1_1->Fill(lPt, 100);	  
	    h1_2_1->Fill(rttheta, 100);
	    if(parno<nPrimaryParticles) {
	      h1_1_2->Fill(lPt, 100);
	      h1_2_2->Fill(rttheta, 100);
	      if(lPt>LPTMIN) h1_2_3->Fill(rttheta, 100);
	    }
	  }
	}
      }
    }

  delete lEffFound;
  delete lEffRPos;
  delete lEffAngle;
  delete lEffChi2;
  delete lEffCol;
  delete lReal;

  } // end event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  h1_1_1->SetMaximum(100.0);
  phisto1->cd(1); h1_1_1->Divide(h0_1_1); h1_1_1->SetLineWidth(5); h1_1_1->SetLineColor(2); h1_1_1->SetStats(FALSE); h1_1_1->Draw();
  phisto1->cd(1); h1_1_2->Divide(h0_1_2); h1_1_2->SetLineWidth(5); h1_1_2->SetLineColor(4); h1_1_2->SetStats(FALSE); h1_1_2->Draw("same");
  TPaveText *tt1_1 = new TPaveText(0.5, 20, 1.5, 30); tt1_1->SetTextColor(2); tt1_1->AddText("all particles"); tt1_1->Draw();
  TPaveText *tt1_2 = new TPaveText(0.5, 10, 1.5, 20); tt1_2->SetTextColor(4); tt1_2->AddText("prim. particles"); tt1_2->Draw();

  h1_2_1->SetMaximum(100.0);
  phisto1->cd(2); h1_2_1->Divide(h0_2_1); h1_2_1->SetLineWidth(5); h1_2_1->SetLineColor(2); h1_2_1->SetStats(FALSE); h1_2_1->Draw();
  phisto1->cd(2); h1_2_2->Divide(h0_2_2); h1_2_2->SetLineWidth(5); h1_2_2->SetLineColor(4); h1_2_2->SetStats(FALSE); h1_2_2->Draw("same");
  phisto1->cd(2); h1_2_3->Divide(h0_2_3); h1_2_3->SetLineWidth(5); h1_2_3->SetLineColor(8); h1_2_3->SetStats(FALSE); h1_2_3->Draw("same");
  TPaveText *tt2_1 = new TPaveText(50, 30, 70, 40); tt2_1->SetTextColor(2); tt2_1->AddText("all particles"); tt2_1->Draw();
  TPaveText *tt2_2 = new TPaveText(50, 20, 70, 30); tt2_2->SetTextColor(4); tt2_2->AddText("prim. particles"); tt2_2->Draw();
  TPaveText *tt2_3 = new TPaveText(50, 10, 70, 20); tt2_3->SetTextColor(8); tt2_3->AddText("high pt prim. particles"); tt2_3->Draw();

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE OUTPUT FILES");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_eff3.root", "CREATE", "Simulation");
    h0_1_1->Write("h0_1_1");
    h0_1_2->Write("h0_1_2");
    h1_1_1->Write("h1_1_1");
    h1_1_2->Write("h1_1_2");

    h0_2_1->Write("h0_2_1");
    h0_2_2->Write("h0_2_2");
    h0_2_3->Write("h0_2_3");
    h1_2_1->Write("h1_2_1");
    h1_2_2->Write("h1_2_2");
    h1_2_3->Write("h1_2_3");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
