/*
$Log: AliTRDnh_eff4.C,v $
Revision 1.7  2001/04/02 14:51:35  schneide
Use of global header file for fit settings

Revision 1.6  2001/02/18 17:56:43  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.5  2001/02/14 17:42:44  schneide
Update to new root file for full multiplicity

Revision 1.4  2001/01/26 13:17:41  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "eff4"

void AliTRDnh_eff4()
{
  const Int_t     kChips                  = 8;
  const Int_t     kChannels               = 16;

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  printf("AliRoot file     : %s\n\n", ALIFILE);
  printf("Event range      : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range      : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range     : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range    : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt          : %f\n", LPTMIN);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 400); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(1,1);

  // init histogramms
  TH1F *h1_1_1 = new TH1F("h1_1_1", "pretrigger efficiency vs. pt", 10, 0.0, 5.0); // 1mm
  h1_1_1->SetXTitle("pt"); h1_1_1->SetYTitle("%");
  TH1F *h1_1_2 = new TH1F("h1_1_2", "pretrigger efficiency vs. pt", 10, 0.0, 5.0); // 2mm
  h1_1_2->SetXTitle("pt"); h1_1_2->SetYTitle("%");
  TH1F *h1_1_3 = new TH1F("h1_1_3", "pretrigger efficiency vs. pt", 10, 0.0, 5.0); // 3mm
  h1_1_3->SetXTitle("pt"); h1_1_3->SetYTitle("%");
  TH1F *h1_1_4 = new TH1F("h1_1_4", "pretrigger efficiency vs. pt", 10, 0.0, 5.0); // 4mm
  h1_1_4->SetXTitle("pt"); h1_1_4->SetYTitle("%");

  TH1F *h0_1_1 = new TH1F("h0_1_1", "number of tracks vs. pt", 10, 0.0, 5.0); // 1mm
  TH1F *h0_1_2 = new TH1F("h0_1_2", "number of tracks vs. pt", 10, 0.0, 5.0); // 2mm
  TH1F *h0_1_3 = new TH1F("h0_1_3", "number of tracks vs. pt", 10, 0.0, 5.0); // 3mm
  TH1F *h0_1_4 = new TH1F("h0_1_4", "number of tracks vs. pt", 10, 0.0, 5.0); // 4mm

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

    TArrayI *lTrackVsPlane = new TArrayI(6*nParticles); // array for fit: tracklets in planes
    TArrayI *lEffFound = new TArrayI(6*nParticles);
    TArrayI *lEffRPos = new TArrayI(6*nParticles);
    TArrayI *lEffAngle = new TArrayI(6*nParticles);
    TArrayI *lEffChi2 = new TArrayI(6*nParticles);
    TArrayI *lEffCol = new TArrayI(6*nParticles);

    for(Int_t index=0; index<6*nParticles; index++) lEffFound->AddAt(-1, index);
    lEffRPos->Reset();
    lEffAngle->Reset();
    lEffChi2->Reset();
    lEffCol->Reset();

    for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
      for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
	lTrackVsPlane->Reset();
	for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	  printf("working on ev %d, cha %d, sec %2d, pla %d ...\n", event, chamber, sector, plane);
	  Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	  Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector);
	  for(Int_t padrow=0; padrow<lPadrowMax; padrow++) {
	    AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	    fitPadrow->SetDigitsManager(DigitsManager);
	    fitPadrow->SetTRDgeometry(TRDgeometry);
            // set threshold
            fitPadrow->SetHitsMin(LSP);
            fitPadrow->SetThreshold(LTH);
	    fitPadrow->Fit();
	    for(Int_t column=0; column<128; column++) {
	      AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	      Int_t MainTrack = fitTracklet->GetfMainTrack();

	      if (MainTrack != -1) { // found tracklet
		Int_t MainTrackPos = 0;
		for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
		TParticle *Particle = (TParticle *)ParticleArray->At(MainTrack);
		// eff found
		lEffFound->AddAt(fitTracklet->GetFEject(), (plane*nParticles)+MainTrack);
		lEffRPos->AddAt(fitTracklet->GetfRPos(), (plane*nParticles)+MainTrack);
		lEffAngle->AddAt(fitTracklet->GetfAngle(), (plane*nParticles)+MainTrack);
		lEffChi2->AddAt(fitTracklet->GetfChi2(), (plane*nParticles)+MainTrack);
		lEffCol->AddAt(column, (plane*nParticles)+MainTrack);
	      } // end found tracklet

	    } // end column
	    delete fitPadrow;
	  } // end padrow
	} // end plane


      } // end sector
    } // end chamber
    //delete DigitsManager;

    for(Int_t parno=0; parno<nParticles; parno++) {
      //if(parno>=nPrimaryParticles) continue;
      AliTRDgtuRealTrack *RT = lReal->GetRealTrack(parno);
      Float_t lPt = ((TParticle *)ParticleArray->At(parno))->Pt();
      for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	if(RT->GetDigitsSum(plane)) {
	  Float_t realdefl = Pos2Defl(TRDgeometry, RT->GetExStartColumn(plane),
				      RT->GetExEndColumn(plane), RT->GetExStartTimebin(plane),
				      RT->GetExEndTimebin(plane), plane,
				      (Int_t)RT->GetExStartColumn(plane));
	  Bool_t found = (lEffFound->At((plane*nParticles)+parno) >= 0); // ==
	  Float_t fitdefl = 0.0;
	  if(found) fitdefl = Angle2Defl(TRDgeometry, lEffAngle->At((plane*nParticles)+parno), plane, lEffCol->At((plane*nParticles)+parno));
	  if(TMath::Abs(realdefl) <= 1.0) {
	    h0_1_1->Fill(lPt, 1);
	    if((found) && (TMath::Abs(fitdefl) <= 1.0)) h1_1_1->Fill(lPt, 100);
	  }
	  if(TMath::Abs(realdefl) <= 2.0) {
	    h0_1_2->Fill(lPt, 1);
	    if((found) && (TMath::Abs(fitdefl) <= 2.0)) h1_1_2->Fill(lPt, 100);
	  }
	  if(TMath::Abs(realdefl) <= 3.0) {
	    h0_1_3->Fill(lPt, 1);
	    if((found) && (TMath::Abs(fitdefl) <= 3.0)) h1_1_3->Fill(lPt, 100);
	  }
	  if(TMath::Abs(realdefl) <= 4.0) {
	    h0_1_4->Fill(lPt, 1);
	    if((found) && (TMath::Abs(fitdefl) <= 4.0)) h1_1_4->Fill(lPt, 100);
	  }
	}
      }
    }

  delete lEffFound;
  delete lEffRPos;
  delete lEffAngle;
  delete lEffChi2;
  delete lEffCol;
  delete lReal;

  } // end event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  h1_1_1->SetMaximum(100.0);
  phisto1->cd(1); h1_1_1->Divide(h0_1_1); h1_1_1->SetLineWidth(5); h1_1_1->SetLineColor(2); h1_1_1->SetStats(FALSE); h1_1_1->Draw();
  phisto1->cd(1); h1_1_2->Divide(h0_1_2); h1_1_2->SetLineWidth(5); h1_1_2->SetLineColor(4); h1_1_2->SetStats(FALSE); h1_1_2->Draw("same");
  phisto1->cd(1); h1_1_3->Divide(h0_1_3); h1_1_3->SetLineWidth(5); h1_1_3->SetLineColor(6); h1_1_3->SetStats(FALSE); h1_1_3->Draw("same");
  phisto1->cd(1); h1_1_4->Divide(h0_1_4); h1_1_4->SetLineWidth(5); h1_1_4->SetLineColor(8); h1_1_4->SetStats(FALSE); h1_1_4->Draw("same");
  TPaveText *tt1_0 = new TPaveText(0.5, 25, 1.5, 30); tt1_0->SetTextColor(1); tt1_0->AddText("max. deflection"); tt1_0->Draw();
  TPaveText *tt1_1 = new TPaveText(0.5, 20, 1.5, 25); tt1_1->SetTextColor(2); tt1_1->AddText("1mm"); tt1_1->Draw();
  TPaveText *tt1_2 = new TPaveText(0.5, 15, 1.5, 20); tt1_2->SetTextColor(4); tt1_2->AddText("2mm"); tt1_2->Draw();
  TPaveText *tt1_3 = new TPaveText(0.5, 10, 1.5, 15); tt1_3->SetTextColor(6); tt1_3->AddText("3mm"); tt1_3->Draw();
  TPaveText *tt1_4 = new TPaveText(0.5,  5, 1.5, 10); tt1_4->SetTextColor(8); tt1_4->AddText("4mm"); tt1_4->Draw();

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE OUTPUT FILES");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_eff4.root", "CREATE", "Simulation");
    h0_1_1->Write("h0_1_1");
    h0_1_2->Write("h0_1_2");
    h0_1_3->Write("h0_1_3");
    h0_1_4->Write("h0_1_4");
    h1_1_1->Write("h1_1_1");
    h1_1_2->Write("h1_1_2");
    h1_1_3->Write("h1_1_3");
    h1_1_4->Write("h1_1_4");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
