/*
$Log: AliTRDnh_lay.C,v $
Revision 1.2  2001/04/02 14:51:36  schneide
Use of global header file for fit settings

Revision 1.1  2001/03/20 14:07:56  schneide
update for siemens1 installation

*/

#include "global.h"

#define MODULE "lay"

void AliTRDnh_lay()
{
  const Int_t kChips    = 8;
  const Int_t kChannels = 16;

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  =  0; // Sector
  Int_t lChamberMin =  2; Int_t lChamberMax =  2; // Chamber

  printf("AliRoot file     : %s\n\n", ALIFILE);
  printf("Event range      : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range      : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range     : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range    : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt          : %f\n", LPTMIN);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 800); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(1,2);

  // init histogramms
  TH2F *h1_1 = new TH2F("h1_1", "fit: projected tracklet vs. padrow and column", 18, 0.0, 18.0, 96, 0.0, 96.0); // defl < 8mm
  h1_1->SetXTitle("padrow"); h1_1->SetYTitle("column");

  TH2F *h1_2 = new TH2F("h1_2", "real: projected tracklet vs. padrow and column", 18, 0.0, 18.0, 96, 0.0, 96.0); // defl < 8mm
  h1_2->SetXTitle("padrow"); h1_2->SetYTitle("column");

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

    for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
      for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
	for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	  printf("working on ev %d, cha %d, sec %2d, pla %d ...\n", event, chamber, sector, plane);
	  Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	  Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector);
	  for(Int_t padrow=0; padrow<lPadrowMax; padrow++) {
	    AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	    fitPadrow->SetDigitsManager(DigitsManager);
	    fitPadrow->SetTRDgeometry(TRDgeometry);
            fitPadrow->SetHitsMin(LSP);
            fitPadrow->SetThreshold(LTH);
	    fitPadrow->Fit();
	    for(Int_t column=0; column<128; column++) {
	      AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	      Int_t MainTrack = fitTracklet->GetfMainTrack();

	      if (MainTrack != -1) { // found tracklet
		AliTRDgtuRealTrack *RT = lReal->GetRealTrack(MainTrack);
		Int_t MainTrackPos = 0;
		for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
		TParticle *Particle = (TParticle *)ParticleArray->At(MainTrack);
		Float_t lPt = Particle->Pt();
		Float_t fitdefl = Angle2Defl(TRDgeometry, fitTracklet->GetfAngle(), plane, column);
		Float_t fitpt = Defl2Pt(TRDgeometry, fitdefl, plane, column);
		if(fitpt > LPTMIN) {
		  h1_1->Fill(padrow, column, 1);
		}
		if(lPt > LPTMIN) {
		  h1_2->Fill(RT->GetExStartPadrow(plane), RT->GetExStartColumn(plane), 1);
		}
	      } // end found tracklet

	    } // end column
	    delete fitPadrow;
	  } // end padrow
	} // end plane
      } // end sector
    } // end chamber

  } // end event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  phisto1->cd(1); h1_1->SetStats(FALSE); h1_1->Draw("colz");
  phisto1->cd(2); h1_2->SetStats(FALSE); h1_2->Draw("colz");

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE OUTPUT FILES");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_lay.root", "CREATE", "Simulation");
    h1_1->Write("h1_1");
    h1_2->Write("h1_2");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
