#define HEAD(title) printf("\n--------------------------------------------------------\n--  %s\n--------------------------------------------------------\n\n", title)

void AliTRDnh_new()
{
  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
  ////// SET CONSTANTS AND WORKING RANGE
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  HEAD("SET CONSTANTS AND WORKING RANGE");
  const Char_t *alifile = "~schneide/data/galice_nh_z15.root";
  const Char_t *TitleString = "AliTRDnh (Config_nh_z15.C, hijingParam, gain 8000, threshold 15, HitsMin 5, pt>=0.5, 2001-01-15)";

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  = 12; Int_t lSectorMax  = 12; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  0; // Chamber
  Int_t lPadrowMin  =  0; Int_t lPadrowMax  = -1; // Padrow

  Float_t lPtMin = 0.5; // minimal transvers momentum
  Int_t   lHitsMin = 5; // min. number of clusters
  Int_t   lTh = 15;     // min. threshold

  printf("AliRoot file  : %s\n\n", alifile);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Padrow range  : %3d .. %3d\n", lPadrowMin,  lPadrowMax);
  printf("Min. Pt       : %f\n", lPtMin);

  /////////////////////////////////////////////////////////////////
  ////// INITIALIZE SIMULATION ENVIRONMENT
  /////////////////////////////////////////////////////////////////

  HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 800); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(2,3);

  // init histogramms
  TH1F *h1_1 = new TH1F("h1_1", "fit: hits for tracklets", 16, 0.0, 16.0);
  h1_1->SetXTitle("hits");
  TH1F *h1_2 = new TH1F("h1_2", "fit: hits for tracklets (prim)", 16, 0.0, 16.0);
  TH1F *h1_3 = new TH1F("h1_3", "fit: hits for tracklets (prim, pt)", 16, 0.0, 16.0);

  TH1F *h1_4 = new TH1F("h1_4", "fit: tracklets in planes", 6.0, 0.5, 6.5);
  h1_4->SetXTitle("number of planes");
  TH1F *h1_5 = new TH1F("h1_5", "fit: tracklets in planes (prim)", 6.0, 0.5, 6.5);
  TH1F *h1_6 = new TH1F("h1_6", "fit: tracklets in planes (prim, pt)", 6.0, 0.5, 6.5);

  TH2F *h1_7 = new TH2F("h1_7", "fit: planes vs Pt", 50, 0.0, 5.0, 6.0, 0.5, 6.5);
  h1_7->SetXTitle("Pt (GeV/c)"); h1_7->SetYTitle("number of planes"); 
  TH2F *h1_8 = new TH2F("h1_8", "fit: planes vs Pt (primaries)", 50, 0.0, 5.0, 6.0, 0.5, 6.5);
  h1_8->SetXTitle("Pt (GeV/c)"); h1_8->SetYTitle("number of planes"); 

  TH1F *h1_10 = new TH1F("h1_10", "fit: tracks vs. tracklet", 5.0, 0.5, 5.5);
  h1_10->SetXTitle("number of tracks");
  TH1F *h1_11 = new TH1F("h1_11", "fit: tracks vs. tracklet (prim)", 5.0, 0.5, 5.5);
  TH1F *h1_12 = new TH1F("h1_12", "fit: tracks vs. tracklet (prim, pt)", 5.0, 0.5, 5.5);

  TH1F *h1_13 = new TH1F("h1_13", "fit: columns for tracklet", 3.0, 0.5, 3.5);
  h1_13->SetXTitle("number of padrows");
  TH1F *h1_14 = new TH1F("h1_14", "fit: columns for tracklet (prim)", 3.0, 0.5, 3.5);
  TH1F *h1_15 = new TH1F("h1_15", "fit: columns for tracklet (prim, pt)", 3.0, 0.5, 3.5);

  TCanvas *c2 = new TCanvas("c2", "Config_nh.C", 400, 10, 600, 800); c2->Draw();
  TPad *ptitle2 = new TPad("ptitle2", "ptitle2", 0.01, 0.95, 0.99, 0.99); ptitle2->Draw();
  ptitle2->cd(); TPaveLabel *pltitle2 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle2->Draw();
  c2->cd(); TPad *phisto2 = new TPad("phisto2", "phisto2", 0.01, 0.01, 0.99, 0.94);
  phisto2->Draw(); phisto2->Divide(2,4);

  TH2F *h2_1 = new TH2F("h2_1", "fit: defl. vs Pt", 50, 0.0, 5.0, 50, -10.0, 10.0);
  h2_1->SetXTitle("Pt (GeV/c)"); h2_1->SetYTitle("deflection to pt->oo [mm]"); 
  TH2F *h2_2 = new TH2F("h2_2", "fit: defl. vs Pt (prim)", 50, 0.0, 5.0, 50, -10.0, 10.0);
  h2_2->SetXTitle("Pt (GeV/c)"); h2_2->SetYTitle("deflection to pt->oo [mm]"); 
  TH2F *h2_3 = new TH2F("h2_3", "mean: defl. vs Pt", 50, 0.0, 5.0, 50, -10.0, 10.0);
  h2_3->SetXTitle("Pt (GeV/c)"); h2_3->SetYTitle("deflection to pt->oo [mm]"); 
  TH2F *h2_4 = new TH2F("h2_4", "mean: defl. vs Pt (prim)", 50, 0.0, 5.0, 50, -10.0, 10.0);
  h2_4->SetXTitle("Pt (GeV/c)"); h2_4->SetYTitle("deflection to pt->oo [mm]"); 
  TH2F *h2_5 = new TH2F("h2_5", "difference of deflection vs Pt", 50, 0.0, 5.0, 50, -10.0, 10.0);
  h2_5->SetXTitle("Pt (GeV/c)"); h2_5->SetYTitle("diff. of defl. [mm]"); 
  TH2F *h2_6 = new TH2F("h2_6", "difference of deflection vs Pt (prim)", 50, 0.0, 5.0, 50, -10.0, 10.0);
  h2_6->SetXTitle("Pt (GeV/c)"); h2_6->SetYTitle("diff. of defl. [mm]"); 
  
  TH1F *h2_9 = new TH1F("h2_9", "chi2", 40.0, 0.0, 10.0);
  h2_9->SetXTitle("chi2 [mm]");
  TH1F *h2_10 = new TH1F("h2_10", "chi2 (prim)", 40.0, 0.0, 10.0);

  TH1F *h2_11 = new TH1F("h2_11", "variance of difference of deflection vs. pt", 50, 0.0, 5.0);
  h2_11->SetXTitle("pt"); h2_11->SetYTitle("[mm**2]");
  TH1F *h2_12 = new TH1F("h2_12", "variance of difference of deflection vs. pt (prim)", 50, 0.0, 5.0);


  // for statistics
  TH1F *h0_1 = new TH1F("h0_1", "number of tracklets vs. pt", 50, 0.0, 5.0);
  h0_1->SetXTitle("pt");
  TH1F *h0_2 = new TH1F("h0_2", "number of tracklets vs. pt (prim)", 50, 0.0, 5.0);
  h0_2->SetXTitle("pt");

  /////////////////////////////////////////////////////////////////
  ////// INITIALIZE ALIROOT ENVIRONMENT
  /////////////////////////////////////////////////////////////////

  HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfit");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(alifile);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << alifile << endl;
    gafl = new TFile(alifile);
  }
  else {
    cout << alifile << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
  ////// GET NEXT EVENT
  /////////////////////////////////////////////////////////////////

  HEAD("GET NEXT EVENT");
  printf("Current event number: %d\n", event);
  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// SIMULATION
  /////////////////////////////////////////////////////////////////

  HEAD("SIMULATION");
  TArrayI *lTrackVsPlane = new TArrayI(6*nParticles); // array for fit: tracklets in planes

  for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
    for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
      lTrackVsPlane->Reset();
      for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	printf("working on event %d, chamber %d, sector %2d, plane %d ...\n", event, chamber, sector, plane);
        Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	if(lPadrowMax == -1) Int_t lPadrowMMax = TRDgeometry->GetRowMax(plane, chamber, sector) - 1;
          else Int_t lPadrowMMax = lPadrowMax;
	for(Int_t padrow=lPadrowMin; padrow<=lPadrowMMax; padrow++) {
	  AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	  fitPadrow->SetDigitsManager(DigitsManager);
	  fitPadrow->SetTRDgeometry(TRDgeometry);
          fitPadrow->SetHitsMin(lHitsMin);
          fitPadrow->SetThreshold(lTh);
	  fitPadrow->Fit();
	  for(Int_t column=0; column<128; column++) {
	    AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	    Int_t MainTrack = fitTracklet->GetfMainTrack();

	    if (MainTrack != -1) { // found tracklet
	      Int_t MainTrackPos = 0;
	      for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
	      TParticle *Particle = (TParticle *)ParticleArray->At(MainTrack);
              if(fitTracklet->GetFEject() >= 0) { // (>=) Tracklet is found, (==) Tracklet is ok
		Float_t lPt = Particle->Pt();
	        // fit: defletion vs Pt
                Float_t fitDeflection = Angle2Defl(TRDgeometry, fitTracklet->GetfAngle(), plane, column);
                h2_1->Fill(lPt, fitDeflection);
	        if(MainTrack < nPrimaryParticles) h2_2->Fill(lPt, fitDeflection);
                // mean: defletion vs Pt
                Float_t realCharge = Particle->GetPDG()->Charge();
                Float_t realDeflection = Pt2Defl(TRDgeometry, lPt, realCharge, plane, column);
                h2_3->Fill(lPt, realDeflection);
                if(MainTrack < nPrimaryParticles) h2_4->Fill(lPt, realDeflection);
                // difference of deflection
                Float_t diffDeflection = realDeflection - fitDeflection;
                h2_5->Fill(lPt, diffDeflection);
                if(MainTrack < nPrimaryParticles) h2_6->Fill(lPt, diffDeflection);
		// variance of difference of deflection
		//if(*((UInt_t *)(&realDeflection)) != 0xffc00000) {
		if((realDeflection>-10000) && (realDeflection<10000)) {
		  if(TMath::Abs(diffDeflection) < 20) {
		    h0_1->Fill(lPt, 1);
		    if(MainTrack < nPrimaryParticles) h0_2->Fill(lPt, 1);
		    h2_11->Fill(lPt, (diffDeflection*diffDeflection));
		    if(MainTrack < nPrimaryParticles) h2_12->Fill(lPt, (diffDeflection*diffDeflection));
		  }
		}
	        // fit: hits for tracklets
		Int_t trackcount = 0;
		Int_t trackcountsum = 0;
		for(Int_t trcntno=0; (trcntno<10) && ((trackcount=fitTracklet->GetTrackCountAt(trcntno)) > 0); trcntno++)
		  trackcountsum += trackcount;
	        h1_1->Fill((Float_t)trackcountsum);
	        if(MainTrack < nPrimaryParticles) {
		  h1_2->Fill((Float_t)trackcountsum);
		  if(lPt >= lPtMin) h1_3->Fill((Float_t)trackcountsum);
		}
	        // fit: tracklets in planes / fit: planes vs Pt
                lTrackVsPlane->AddAt(1+lTrackVsPlane->At((plane*nParticles)+MainTrack), (plane*nParticles)+MainTrack);
	        // fit: tracks vs. tracklet
	        h1_10->Fill(fitTracklet->TrackCount());
	        if(MainTrack < nPrimaryParticles) {
		  h1_11->Fill(fitTracklet->TrackCount());
		  if(lPt >= lPtMin) h1_12->Fill(fitTracklet->TrackCount());
		}
	        // fit: chi2
                h2_9->Fill((Float_t)fitTracklet->GetfChi2()/12.7);
		if(MainTrack < nPrimaryParticles) h2_10->Fill((Float_t)fitTracklet->GetfChi2()/12.7);
	      } // end track ok
	    } // end found tracklet

	  } // end column
	  delete fitPadrow;
	} // end padrow
      } // end plane

      for(Int_t tvpparticle=0; tvpparticle<nParticles; tvpparticle++) {
	Float_t tvppt = ((TParticle *)(ParticleArray->At(tvpparticle)))->Pt();
	Int_t tvpPlanes = 0;
	for(Int_t tvpplane=lPlaneMin; tvpplane<=lPlaneMax; tvpplane++) {
	  Int_t tvpPos = (tvpplane*nParticles)+tvpparticle;
	  if(lTrackVsPlane->At(tvpPos)) {
	    tvpPlanes++;
	    h1_13->Fill(lTrackVsPlane->At(tvpPos));
	    if(tvpparticle < nPrimaryParticles) {
	      h1_14->Fill(lTrackVsPlane->At(tvpPos));
	      if(tvppt >= lPtMin) h1_15->Fill(lTrackVsPlane->At(tvpPos));
	    }
	  }
	}
	if(tvpPlanes) {
	  h1_4->Fill(tvpPlanes);
	  if(tvpparticle < nPrimaryParticles) {
	    h1_5->Fill(tvpPlanes);
	    if(tvppt >= lPtMin) h1_6->Fill(tvpPlanes);
	  }
	  h1_7->Fill(tvppt, tvpPlanes, 1);
	  if(tvpparticle<nPrimaryParticles)
	    h1_8->Fill(tvppt, tvpPlanes, 1);
	}
      }

    } // end sector
  } // end chamber
  //delete DigitsManager;
  } // end event

  /////////////////////////////////////////////////////////////////
  ////// DRAW HISTOGRAMS
  /////////////////////////////////////////////////////////////////

  HEAD("DRAW HISTOGRAMS");
  c1->cd();

  phisto1->cd(1);
  h1_1->SetLineColor(2); h1_1->Draw();
  h1_2->SetLineColor(4); h1_2->Draw("same");
  h1_3->SetLineColor(8); h1_3->Draw("same");

  phisto1->cd(2);
  h1_4->SetLineColor(2); h1_4->Draw();
  h1_5->SetLineColor(4); h1_5->Draw("same");
  h1_6->SetLineColor(8); h1_6->Draw("same");

  phisto1->cd(5);
  h1_7->Draw("colz");
  phisto1->cd(6);
  h1_8->Draw("colz");

  phisto1->cd(3); gPad->SetLogy();
  h1_10->SetLineColor(2); h1_10->Draw();
  h1_11->SetLineColor(4); h1_11->Draw("same");
  h1_12->SetLineColor(8); h1_12->Draw("same");

  phisto1->cd(4); gPad->SetLogy();
  h1_13->SetLineColor(2); h1_13->Draw();
  h1_14->SetLineColor(4); h1_14->Draw("same");
  h1_15->SetLineColor(8); h1_15->Draw("same");

  c2->cd();
  phisto2->cd(1);  h2_1->Draw("colz");
  phisto2->cd(2);  h2_2->Draw("colz");
  phisto2->cd(3);  h2_3->Draw("colz");
  phisto2->cd(4);  h2_4->Draw("colz");
  phisto2->cd(5);  h2_5->Draw("colz");
  phisto2->cd(6);  h2_6->Draw("colz");

  phisto2->cd(7);
  h2_9->SetLineColor(2); h2_9->Draw();
  h2_10->SetLineColor(4); h2_10->Draw("same");

  phisto2->cd(8);
  h2_11->SetLineColor(2); h2_11->Divide(h0_1); h2_11->Draw();
  h2_12->SetLineColor(4); h2_12->Divide(h0_2); h2_12->Draw("same");

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
