/*
$Log: AliTRDnh_pt.C,v $
Revision 1.4  2001/04/02 14:51:36  schneide
Use of global header file for fit settings

Revision 1.3  2001/02/18 17:56:43  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.2  2001/02/14 17:42:44  schneide
Update to new root file for full multiplicity

Revision 1.1  2001/02/12 15:32:13  schneide
Adding of AliTRDnh_pt.C

Revision 1.1  2001/01/26 13:27:56  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "pt"

void AliTRDnh_pt()
{
  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
  ////// SET CONSTANTS AND WORKING RANGE
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  HEAD("SET CONSTANTS AND WORKING RANGE");

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  printf("AliRoot file  : %s\n\n", ALIFILE);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt       : %f\n", LPTMIN);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 800); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(2,4);

  // init histogramms
  TH1F *h1_1 = new TH1F("h1_1", "fit: pt distribution", 50, 0.0, 5.0);
  h1_1->SetXTitle("pt [GeV/c]");

  TH1F *h1_2 = new TH1F("h1_2", "MC: pt distribution", 50, 0.0, 5.0);
  h1_2->SetXTitle("pt [GeV/c]");

  TH1F *h1_3 = new TH1F("h1_3", "#Deltapt", 50, -2.5, 2.5);
  h1_3->SetXTitle("pt [GeV/c]");

  TH2F *h1_4 = new TH2F("h1_4", "#Deltapt/pt vs. pt", 50, 0.0, 5.0, 50, -2.5, 2.5);
  h1_4->SetXTitle("pt [GeV/c]"); h1_4->SetYTitle("[GeV/c]");

  TH2F *h1_5 = new TH2F("h1_5", "#Deltadeflection vs. pt", 50, 0.0, 5.0, 50, -5.0, 5.0);
  h1_5->SetXTitle("pt [GeV/c]"); h1_5->SetYTitle("[mm]");

  TH2F *h1_6 = new TH2F("h1_6", "#Deltadeflection/deflection vs. #Deltapt/pt", 50, -2.5, 2.5, 100, -15.0, 15.0);
  h1_6->SetXTitle("[GeV/c]"); h1_6->SetYTitle("[mm]");

  TH1D *h1_7 = new TH1D("h1_7", "#sigma(#Deltadeflection/deflection) vs. pt", 50, 0.0, 5.0);
  h1_7->SetXTitle("pt [GeV/c]");

  TH1D *h1_8 = new TH1D("h1_8", "#sigma^{2}(#Deltadeflection/defletion) vs. pt", 50, 0.0, 5.0);
  h1_8->SetXTitle("pt [GeV/c]");
  TH1D *h1_8_1 = new TH1D("h1_8_1", "number of entries vs. pt", 50, 0.0, 5.0);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }
  cout << "opened" << endl;

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

  for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
    for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
      for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	printf("working on event %d, chamber %d, sector %2d, plane %d ...\n", event, chamber, sector, plane);
        Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector) - 1;
	for(Int_t padrow=0; padrow<=lPadrowMax; padrow++) {
	  AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	  fitPadrow->SetDigitsManager(DigitsManager);
	  fitPadrow->SetTRDgeometry(TRDgeometry);
          fitPadrow->SetHitsMin(LSP);
          fitPadrow->SetThreshold(LTH);
	  fitPadrow->Fit();
	  for(Int_t column=0; column<128; column++) {
	    AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	    Int_t MainTrack = fitTracklet->GetfMainTrack();
	    if(MainTrack >= nPrimaryParticles) continue;

	    if (MainTrack != -1) { // found tracklet
	      Int_t MainTrackPos = 0;
	      for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
	      TParticle *Particle = (TParticle *)ParticleArray->At(MainTrack);
              if(fitTracklet->GetFEject() >= 0) { // (>=) Tracklet is found, (==) Tracklet is ok
		Float_t lPt = Particle->Pt();

                TParticlePDG *ParticlePDG = Particle->GetPDG();
                if(ParticlePDG)
                  Float_t realCharge = ParticlePDG->Charge();
                else {
                  Float_t realCharge = 1.0;
                  printf("WARNING - ParticlePDG not found, set charge to 1.0\n");
                }
                Float_t realDeflection = Pt2Defl(TRDgeometry, lPt, realCharge, plane, column);
		Float_t realPt = Defl2Pt(TRDgeometry, realDeflection, plane, column);

	        // fit: pt distribution
		Float_t fitDefl = Angle2Defl(TRDgeometry, fitTracklet->GetfAngle(), plane, column);
		Float_t fitPt = Defl2Pt(TRDgeometry, fitDefl, plane, column);

		Float_t relptdiff = (lPt-fitPt)/lPt;
		h1_1->Fill(fitPt, 1);
	        // real: pt distribution
		h1_2->Fill(lPt, 1);
		// difference of pt
		h1_3->Fill(relptdiff, 1);
		// difference of pt vs pt
		h1_4->Fill(lPt, relptdiff, 1);
		// difference of deflection vs pt
		h1_5->Fill(lPt, realDeflection-fitDefl, 1);
		// difference of deflection vs difference of pt
		h1_6->Fill(relptdiff, (realDeflection-fitDefl)/realDeflection, 1);
		// variance of rel. difference of deflection vs pt
		if(TMath::Abs(relptdiff)<10) {
		  h1_7->Fill(lPt, relptdiff*relptdiff);
		  h1_8->Fill(lPt, relptdiff*relptdiff);
		  h1_8_1->Fill(lPt, 1);
		}

	      } // end track ok
	    } // end found tracklet

	  } // end column
	  delete fitPadrow;
	} // end padrow
      } // end plane
    } // end sector
  } // end chamber
  //delete DigitsManager;
  } // end event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();

  phisto1->cd(1);
  gPad->SetLogy(); h1_1->SetLineWidth(3); h1_1->SetLineColor(2); h1_1->Draw();

  phisto1->cd(2);
  gPad->SetLogy(); h1_2->SetLineWidth(3); h1_2->SetLineColor(2); h1_2->Draw();

  phisto1->cd(3);
  gPad->SetLogy(); h1_3->SetLineWidth(3); h1_3->SetLineColor(2); h1_3->Draw();

  phisto1->cd(4);
  h1_4->Draw("colz");

  phisto1->cd(5);
  h1_5->Draw("colz");

  phisto1->cd(6);
  h1_6->Draw("colz");

  phisto1->cd(8);
  gPad->SetLogy(); h1_8->Divide(h1_8_1); h1_8->SetLineWidth(3); h1_8->SetLineColor(2); h1_8->Draw();

  
  phisto1->cd(7);
  for(Int_t bin=1; bin<=h1_7->GetNbinsX(); bin++)
    h1_7->SetBinContent(bin, TMath::Sqrt(h1_7->GetBinContent(bin)));
  gPad->SetLogy(); h1_7->SetLineWidth(3); h1_7->SetLineColor(2); h1_7->Draw();

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE OUTPUT FILES");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_pt.root", "CREATE", "Simulation");
    phisto1->cd(1);
    h1_1->Write("h1_1");
    h1_2->Write("h1_2");
    h1_3->Write("h1_3");
    h1_4->Write("h1_4");
    h1_5->Write("h1_5");
    h1_6->Write("h1_6");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
