/*
$Log: AliTRDnh_real.C,v $
Revision 1.6  2001/04/02 14:51:36  schneide
Use of global header file for fit settings

Revision 1.5  2001/02/14 17:42:45  schneide
Update to new root file for full multiplicity

Revision 1.4  2001/02/08 09:30:12  schneide
Remove of static array size for RealTracks

Revision 1.3  2001/01/26 13:17:41  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "real"

void AliTRDnh_real()
{
  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT EVENT STATISTIC                           //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax =  17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  printf("AliRoot file   : %s\n\n", ALIFILE);
  printf("Event range    : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range    : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range   : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range  : %3d .. %3d\n", lChamberMin, lChamberMax);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  //gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfit");
  gSystem->Load(TRDGTULIB);
  //gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
    HEAD("DATA GENERATION");
  /////////////////////////////////////////////////////////////////

  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);
  lReal->SetPlaneRange(lPlaneMin, lPlaneMax);
  lReal->SetSectorRange(lSectorMin, lSectorMax);
  lReal->SetChamberRange(lChamberMin, lChamberMax);
  lReal->Dump();
  lReal->FillRealTracks(TRDgeometry, DigitsManager, ParticleArray, 1);

  lReal->GetExactPositions(TRDgeometry, gAlice, TRD, hitTree);

  /////////////////////////////////////////////////////////////////
    HEAD ("WRITE ROOT FILE");
  /////////////////////////////////////////////////////////////////

  TFile *fp = new TFile(REALFILE, "UPDATE", "AliTRDgtuRealTrack");
  fp->SetCompressionLevel(0); 
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Write(treename);
  delete lReal;
  fp->Close();
  delete fp;

  } // end event

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
