/*
$Log: AliTRDnh_realhist.C,v $
Revision 1.8  2001/04/02 14:51:36  schneide
Use of global header file for fit settings

Revision 1.7  2001/02/18 17:56:43  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.6  2001/02/14 17:42:45  schneide
Update to new root file for full multiplicity

Revision 1.5  2001/02/08 09:30:13  schneide
Remove of static array size for RealTracks

Revision 1.4  2001/01/26 13:17:41  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "realhist"

void AliTRDnh_realhist()
{
  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT EVENT STATISTIC                           //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  printf("AliRoot file   : %s\n\n", ALIFILE);
  printf("Event range    : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range    : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range   : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range  : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt        : %f\n", LPTMIN);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "c1", 100, 10, 600, 800); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(2,3);

  // init histogramms
  TH1F *h1_1 = new TH1F("h1_1", "real: ave. energy loss for pt", 50.0, 0.0, 5.0);
  h1_1->SetXTitle("pt"); h1_1->SetYTitle("amplitude sum");
  TH1F *h1_2 = new TH1F("h1_2", "real: ave. energy loss for pt (prim)", 50.0, 0.0, 5.0);
  h1_2->SetXTitle("pt"); h1_2->SetYTitle("amplitude sum");
  TH1F *h1_5 = new TH1F("h1_5", "real: pt distribution", 50.0, 0.0, 5.0);
  h1_5->SetXTitle("pt");
  TH1F *h1_6 = new TH1F("h1_6", "real: pt distribution (prim)", 50.0, 0.0, 5.0);
  h1_6->SetXTitle("pt");
  TH2F *h1_7 = new TH2F("h1_7", "mean: deflection vs pt (prim)", 50.0, 0.0, 5.0, 20, -10, 10);
  h1_7->SetXTitle("pt"); h1_7->SetYTitle("deflection");
  TH2F *h1_8 = new TH2F("h1_8", "real: deflection vs pt (prim)", 50.0, 0.0, 5.0, 20, -10, 10);
  h1_8->SetXTitle("pt"); h1_8->SetYTitle("deflection");

  TCanvas *c2 = new TCanvas("c2", "c2", 200, 10, 600, 400); c2->Draw();
  TPad *ptitle2 = new TPad("ptitle2", "ptitle2", 0.01, 0.95, 0.99, 0.99); ptitle2->Draw();
  ptitle2->cd(); TPaveLabel *pltitle2 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle2->Draw();
  c2->cd(); TPad *phisto2 = new TPad("phisto2", "phisto2", 0.01, 0.01, 0.99, 0.94);
  phisto2->Draw(); phisto2->Divide(2,1);

  TH1F *h2_1 = new TH1F("h2_1", "real: number of track segments vs. theta", 50.0, 40.0, 140.0);
  h2_1->SetXTitle("theta");

  TH1F *h2_2 = new TH1F("h2_2", "real: number of planes for track", 6, 0.5, 6.5);
  h2_2->SetXTitle("number of planes");
  TH1F *h2_3 = new TH1F("h2_3", "real: number of planes for track (prim)", 6, 0.5, 6.5);
  TH1F *h2_4 = new TH1F("h2_4", "real: number of planes for track (prim, pt>1.0)", 6, 0.5, 6.5);

  TH1F *h0_1 = new TH1F("h0_1", "real: tracks vs. pt", 50.0, 0.0, 5.0);
  TH1F *h0_2 = new TH1F("h0_2", "real: tracks vs. pt (prim)", 50.0, 0.0, 5.0);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  //TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  printf("Read AliTRDgtuReal root file \n");
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

  lReal->Dump();
  printf("  particles in TRD         : %d\n", lReal->GetTRDparticles());
  printf("  primary particles in TRD : %d\n\n", lReal->GetTRDprimaryParticles());

  for(Int_t parno=0; parno<nParticles; parno++) {
    if(!(parno%100)) printf("no. %6d\r", parno);
    TParticle *Particle = (TParticle *)gAlice->Particle(parno);
    Float_t lPt = Particle->Pt();
    if(lPt >= LPTMIN) {
      AliTRDgtuRealTrack *RT = lReal->GetRealTrack(parno);
      if(RT->GetTrackID() != -1) {
	h0_1->Fill(lPt, 1);
	h1_1->Fill(lPt, RT->GetAmplitudeSum());
	h1_5->Fill(lPt);

	Int_t planes=0;
	for(Int_t nop=0; nop<6; nop++)
	  if(RT->GetDigitsSum(nop)) planes++;
	h2_2->Fill(planes, 1);

	if(parno<nPrimaryParticles) {
	  h0_2->Fill(lPt, 1);
	  h1_2->Fill(lPt, RT->GetAmplitudeSum());
	  h1_6->Fill(lPt);
	  h2_3->Fill(planes, 1);
	  if(lPt>=1.0) h2_4->Fill(planes, 1);

	  for(Int_t plane=0; plane<6; plane++) {
	    if(RT->GetExStartColumn(plane) != -1.0) {
	      Float_t meandefl = Pt2Defl(TRDgeometry, lPt, Particle->GetPDG()->Charge(),
					 plane, (Int_t)RT->GetExStartColumn(plane));
	      Float_t realdefl = Pos2Defl(TRDgeometry, RT->GetExStartColumn(plane),
					  RT->GetExEndColumn(plane), RT->GetExStartTimebin(plane),
					  RT->GetExEndTimebin(plane), plane,
					  (Int_t)RT->GetExStartColumn(plane));
	      h1_7->Fill(lPt, meandefl);
	      h1_8->Fill(lPt, realdefl);

	      // track segments vs theta
	      Int_t rtDet = TRDgeometry->GetDetector(plane, RT->GetChamber(), RT->GetSector());
	      Float_t rttheta = padrow2angle(TRDgeometry, rtDet, RT->GetExStartPadrow(plane));
	      h2_1->Fill(rttheta, 1);
	      // ---
	    }
	  }
	}

      }
    }
  }

  printf("\n\n");
  delete lReal;

  } //event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  phisto1->cd(1);  h1_1->Divide(h0_1) ; h1_1->Draw();
  phisto1->cd(2);  h1_2->Divide(h0_2) ; h1_2->Draw();
  phisto1->cd(3);  h1_5->Draw();
  phisto1->cd(4);  h1_6->Draw();
  phisto1->cd(5);  h1_7->Draw("colz");
  phisto1->cd(6);  h1_8->Draw("colz");

  c2->cd();
  phisto2->cd(1);  h2_1->Draw();
  phisto2->cd(2);
  h2_2->SetLineColor(2); h2_2->SetStats(FALSE); h2_2->Draw();
  h2_3->SetLineColor(3); h2_3->SetStats(FALSE); h2_3->Draw("same");
  h2_4->SetLineColor(4); h2_4->SetStats(FALSE); h2_4->Draw("same");

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE OUTPUT FILES");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_realhist.root", "CREATE", "Simulation");
    h0_1->Write("h0_1");
    h0_2->Write("h0_2");

    h1_1->Write("h1_1");
    h1_2->Write("h1_2");
    h1_5->Write("h1_5");
    h1_6->Write("h1_6");
    h1_7->Write("h1_7");
    h1_8->Write("h1_8");

    h2_1->Write("h2_1");
    h2_2->Write("h2_2");
    h2_3->Write("h2_3");
    h2_4->Write("h2_4");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
