/*
$Log: AliTRDnh_res.C,v $
Revision 1.7  2001/04/02 14:51:36  schneide
Use of global header file for fit settings

Revision 1.6  2001/02/18 17:56:43  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.5  2001/02/14 17:42:45  schneide
Update to new root file for full multiplicity

Revision 1.4  2001/01/26 13:17:41  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "res"

void AliTRDnh_res()
{
  const Int_t     kChips                  = 8;
  const Int_t     kChannels               = 16;

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  // loop variables for fit constants
  Int_t lThMin  =  0; // minimal threshold
  Int_t lThMax  = 20; // maximal threshold
  Int_t lThStep =  5;

  printf("AliRoot file  : %s\n\n", ALIFILE);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt       : %f\n", LPTMIN);
  printf("Threshold     : %d .. %d step %d\n", lThMin, lThMax, lThStep);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 800); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(1,2);

  // init histogramms
  TH2F *h1_1 = new TH2F("h1_1", "fit: residuae", 100.0, -3000.0, 3000.0, 5, lThMin-((Float_t)lThStep/2), lThMax+((Float_t)lThStep)/2);
  h1_1->SetXTitle("diff [um]"); h1_1->SetYTitle("threshold");

  TH1F *h2_1 = new TH1F("h2_1", "fit: residuae", 100.0, -3000.0, 3000.0);
  h2_1->SetXTitle("diff [um]");
  TH1F *h2_2 = new TH1F("h2_2", "fit: residuae", 100.0, -3000.0, 3000.0);
  TH1F *h2_3 = new TH1F("h2_3", "fit: residuae", 100.0, -3000.0, 3000.0);
  TH1F *h2_4 = new TH1F("h2_4", "fit: residuae", 100.0, -3000.0, 3000.0);
  TH1F *h2_5 = new TH1F("h2_5", "fit: residuae", 100.0, -3000.0, 3000.0);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);
  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  //TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  Int_t lParCut = nPrimaryParticles;

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticl
es))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

  for(Int_t lTh=lThMin; lTh<=lThMax; lTh+=lThStep) {
    for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
      for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
	for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	  printf("working on th %2d, ev %d, cha %d, sec %2d, pla %d ...\n", lTh, event, chamber, sector, plane);
	  Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	  Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector);
	  Int_t lTimeMax = TRDgeometry->GetTimeMax();
	  for(Int_t padrow=0; padrow<lPadrowMax; padrow++) {
	    AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	    fitPadrow->SetDigitsManager(DigitsManager);
	    fitPadrow->SetTRDgeometry(TRDgeometry);
	    fitPadrow->SetHitsMin(LSP);
	    fitPadrow->SetThreshold(lTh);
	    fitPadrow->Fit();
	    for(Int_t column=0; column<128; column++) {
	      AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	      Int_t MainTrack = fitTracklet->GetfMainTrack();

	      if(MainTrack != -1) { // found tracklet
		TParticle *Particle = (TParticle *)gAlice->Particle(MainTrack);
		if(MainTrack>=lParCut) continue; // primary particles
		if(Particle->Pt() < LPTMIN) continue; // transversal momentum
                if(fitTracklet->GetFEject() >= 0) { // ==
		  Int_t MainTrackPos = 0;
		  for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
		  AliTRDgtuRealTrack *RT = lReal->GetRealTrack(MainTrack);
		  Float_t fitx1   = offset2mm(TRDgeometry, fitTracklet->GetfRPos(), plane);
		  Float_t fitx2   = fitx1 + (10.0*TRDgeometry->GetColPadSize(plane)*(((Float_t)fitTracklet->GetfAngle()-128.0)/128.0));
		  Float_t fitstep = (fitx2-fitx1)/(Float_t)lTimeMax;
		  for(Int_t timebin=0; timebin<lTimeMax; timebin++) {
		    Int_t yi = fitTracklet->GetYi(timebin);
		    if(yi > -2000) {
		      Float_t yif  = column2mm(TRDgeometry, column, yi, plane);
		      Float_t yiff = fitx1 + (timebin*fitstep);
		      Float_t res = 1000.0 * (yiff-yif); // conv to [um]
		      //Float_t yir  = realx1 + (timebin*realstep);
		      h1_1->Fill(res, lTh, 1);
		      if(lTh==0) h2_1->Fill(res, 1);
		      if(lTh==5) h2_2->Fill(res, 1);
		      if(lTh==10) h2_3->Fill(res, 1);
		      if(lTh==15) h2_4->Fill(res, 1);
		      if(lTh==20) h2_5->Fill(res, 1);
		    }
		  }
		}
	      } // end found tracklet

	    } // end column
	    delete fitPadrow;
	  } // end padrow
	} // end plane
      } // end sector
    } // end chamber
  } // end threshold
  //delete DigitsManager;

  } // end event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  phisto1->cd(1); h1_1->Draw("colz");

  phisto1->cd(2); 
  h2_1->SetLineColor(2); h2_1->SetLineWidth(2); h2_1->SetStats(FALSE); h2_1->Draw();
  h2_2->SetLineColor(3); h2_2->SetLineWidth(2); h2_2->SetStats(FALSE); h2_2->Draw("same");
  h2_3->SetLineColor(4); h2_3->SetLineWidth(2); h2_3->SetStats(FALSE); h2_3->Draw("same");
  h2_4->SetLineColor(6); h2_4->SetLineWidth(2); h2_4->SetStats(FALSE); h2_4->Draw("same");
  h2_5->SetLineColor(8); h2_5->SetLineWidth(2); h2_5->SetStats(FALSE); h2_5->Draw("same");

  Float_t max = h2_5->GetMaximum();
  Char_t text[80];
  TPaveText *tt0 = new TPaveText(1000, 0.9*max, 2500, 0.95*max); tt0->SetTextColor(2); sprintf(text, "TH = %d, RMS = %d", 0, (Int_t)h2_1->GetRMS()); tt0->AddText(text); tt0->Draw();
  TPaveText *tt1 = new TPaveText(1000, 0.85*max, 2500, 0.9*max); tt1->SetTextColor(3); sprintf(text, "TH = %d, RMS = %d", 5, (Int_t)h2_2->GetRMS()); tt1->AddText(text); tt1->Draw();
  TPaveText *tt2 = new TPaveText(1000, 0.8*max, 2500, 0.85*max); tt2->SetTextColor(4); sprintf(text, "TH = %d, RMS = %d", 10, (Int_t)h2_3->GetRMS()); tt2->AddText(text); tt2->Draw();
  TPaveText *tt3 = new TPaveText(1000, 0.75*max, 2500, 0.8*max); tt3->SetTextColor(6); sprintf(text, "TH = %d, RMS = %d", 15, (Int_t)h2_4->GetRMS()); tt3->AddText(text); tt3->Draw();
  TPaveText *tt4 = new TPaveText(1000, 0.7*max, 2500, 0.75*max); tt4->SetTextColor(8); sprintf(text, "TH = %d, RMS = %d", 20, (Int_t)h2_5->GetRMS()); tt4->AddText(text); tt4->Draw();

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE OUTPUT FILES");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_res.root", "CREATE", "Simulation");
    h1_1->Write("h1_1");
    h2_1->Write("h2_1");
    h2_2->Write("h2_2");
    h2_3->Write("h2_3");
    h2_4->Write("h2_4");
    h2_5->Write("h2_5");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
