/*
$Log: AliTRDnh_res2.C,v $
Revision 1.3  2001/01/26 13:17:41  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#define HEAD(title) printf("\n--------------------------------------------------------\n--  %s\n--------------------------------------------------------\n\n", title)

void AliTRDnh_res2()
{
  const Int_t     kChips                  = 8;
  const Int_t     kChannels               = 16;

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  const Char_t *alifile = "~schneide/data/galice_nh_tmp.root";
  const Char_t *realfile = "~schneide/src/c/AliTRDmacros/ROOTFILES/real.root";
  const Char_t *TitleString = "AliTRDnh_res2 (Config_nh.C, gain 8000, threshold 5, HitsMin 8, primary particles, 2000-12-11)";

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  2; Int_t lChamberMax =  2; // Chamber

  Float_t lPtMin = 0.0; // minimal transvers momentum

  // loop variables for fit constants
  Int_t lThMin  =  5; // minimal threshold
  Int_t lThMax  =  5; // maximal threshold
  Int_t lThStep =  5;

  printf("AliRoot file  : %s\n\n", alifile);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt       : %f\n", lPtMin);
  printf("Threshold     : %d .. %d step %d\n", lThMin, lThMax, lThStep);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 400); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(1,1);

  // init histogramms
  TH2F *h1_1 = new TH2F("h1_1", "fit: variance of regression", 50.0, 0.0, 5.0, 50, 0.0, 10.0);
  h1_1->SetXTitle("pt [GeV]"); h1_1->SetYTitle("[mm**2]");

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfit");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(alifile);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << alifile << endl;
    gafl = new TFile(alifile);
  }
  else {
    cout << alifile << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  Int_t lParCut = nPrimaryParticles;

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal();

  TFile *fp = new TFile(realfile);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

  for(Int_t lTh=lThMin; lTh<=lThMax; lTh+=lThStep) {
    for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
      for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
	for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	  printf("working on th %2d, ev %d, cha %d, sec %2d, pla %d ...\n", lTh, event, chamber, sector, plane);
	  Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	  Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector);
	  Int_t lTimeMax = TRDgeometry->GetTimeMax();
	  for(Int_t padrow=0; padrow<lPadrowMax; padrow++) {
	    AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	    fitPadrow->SetDigitsManager(DigitsManager);
	    fitPadrow->SetTRDgeometry(TRDgeometry);
	    // set threshold
            for(Int_t chip=0; chip<kChips; chip++)
	      for(Int_t channel=0; channel<kChannels; channel++)
		fitPadrow->SetThreshold(chip, channel, lTh);
	    fitPadrow->Fit();
	    for(Int_t column=0; column<128; column++) {
	      AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	      Int_t MainTrack = fitTracklet->GetfMainTrack();

	      if(MainTrack != -1) { // found tracklet
		if(MainTrack >= lParCut) continue; // primary particles
                if(fitTracklet->GetFEject() >= 0) { // ==
		  Int_t MainTrackPos = 0;
		  for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
		  TParticle *Particle = (TParticle *)ParticleArray->At(MainTrack);
		  AliTRDgtuRealTrack *RT = lReal->GetRealTrack(MainTrack);
		  Float_t realangle = (RT->GetExEndColumn(plane)-RT->GetExStartColumn(plane))/(RT->GetExEndTimebin(plane)-RT->GetExStartTimebin(plane));
		  Float_t realx1 = 10.0 * (-0.5 + RT->GetExStartColumn(plane));
		  Float_t realx2 = 10.0 * (-0.5 + RT->GetExEndColumn(plane));
		  Float_t realstep = (realx2-realx1)/lTimeMax;
		  Float_t ressum2 = 0.0;
		  Float_t resanz = 0.0;
		  for(Int_t timebin=0; timebin<lTimeMax; timebin++) {
		    Int_t yi = fitTracklet->GetYi(timebin);
		    if(yi > -2000) {
		      Float_t yif = column2mm(column, yi);
		      Float_t yir = realx1 + (timebin*realstep);
		      Float_t res = yir-yif;
		      ressum2 += res*res;
		      resanz += 1.0;
		    }
		  } // end timebin
		  Float_t sigma = ressum2/resanz;
		  h1_1->Fill(Particle->Pt(), sigma, 1);
if((Particle->Pt()>2.1) && (Particle->Pt() < 2.5) && (sigma > 7)) printf("id %5d, plane %d, pt %6.3f, sigma %f\n", MainTrack, plane, Particle->Pt(), sigma);
		}
	      } // end found tracklet

	    } // end column
	    delete fitPadrow;
	  } // end padrow
	} // end plane
      } // end sector
    } // end chamber
  } // end threshold
  //delete DigitsManager;

  } // end event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  phisto1->cd(1); h1_1->Draw("colz");
 
  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
