/*
$Log: AliTRDnh_res3.C,v $
Revision 1.10  2001/04/02 14:51:36  schneide
Use of global header file for fit settings

Revision 1.9  2001/03/20 14:07:56  schneide
update for siemens1 installation

Revision 1.8  2001/02/18 17:56:43  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.7  2001/02/14 17:42:45  schneide
Update to new root file for full multiplicity

Revision 1.6  2001/02/12 14:14:10  schneide
Review of error calculations and adding of res5

Revision 1.5  2001/02/08 09:30:13  schneide
Remove of static array size for RealTracks

Revision 1.4  2001/01/26 13:17:41  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "res3"

#define PARTICLES_MAX 70000

void AliTRDnh_res3()
{
  const Int_t     kChips                  = 8;
  const Int_t     kChannels               = 16;

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event !! change foundtracks array !!

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   = 5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  Float_t lMinDist = 30.0;// min. distance (slope error)

  Bool_t WriteHisto = FALSE; // write histograms into root file in HISTOGRAMS directory

  Short_t foundtracks[1][6][PARTICLES_MAX];
  for(Int_t ev=0; ev<1; ev++)
    for(Int_t pl=0; pl<6; pl++)
      for(Int_t tr=0; tr<PARTICLES_MAX; tr++)
	foundtracks[ev][pl][tr] = 0;

  Float_t res_sum2_all = 0.0;
  Float_t res_anz_all = 0.0;
  Float_t res_sum2_prim = 0.0;
  Float_t res_anz_prim = 0.0;
  Float_t res_sum2_primpt = 0.0;
  Float_t res_anz_primpt = 0.0;
  Int_t clusters[101];

  printf("AliRoot file  : %s\n\n", ALIFILE);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt       : %f\n", LPTMIN);
  printf("Threshold     : %d\n", LTH);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 1000); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(2,6);

  // init histogramms
  TH1F *h1_1 = new TH1F("h1_1", "fit: residuae to fit (all, primaries, high pt primaries)", 100.0, -3.0, 3.0);
  h1_1->SetXTitle("distance [mm]");
  TH1F *h1_1_2 = new TH1F("h1_1_2", "fit: residuae, primary", 100.0, -3.0, 3.0);
  TH1F *h1_1_3 = new TH1F("h1_1_3", "fit: residuae, primary, high pt", 100.0, -3.0, 3.0);

  TH1F *h1_2 = new TH1F("h1_2", "th: cluster position error by quantisation", 80, 0.0, 400.0);
  h1_2->SetXTitle("[#mum]");
  TH1F *h1_3 = new TH1F("h1_3", "ampR - ampL", 100.0, -50.0, 50.0);
  h1_3->SetXTitle("difference");
  TH1F *h1_4 = new TH1F("h1_4", "ampL + ampC + ampR", 100.0, 0, 200.0);
  h1_4->SetXTitle("sum");
  TH1F *h1_5 = new TH1F("h1_5", "fit: clusters per tracklet vs. threshold", 18, 2.5, 102.5);
  h1_5->SetXTitle("threshold");
  TH1F *h1_5_2 = new TH1F("h1_5", "tracklets vs. threshold", 18, 2.5, 102.5);
  TH1F *h1_6 = new TH1F("h1_6", "ampC", 80.0, 0, 160.0);
  h1_6->SetXTitle("amplitude");
  TH1F *h1_7 = new TH1F("h1_7", "(ampR + ampL) / (ampL + ampC + ampR)", 100.0, -0.2, 0.8);

  TH1F *h1_8 = new TH1F("h1_8", "th: slope error by lin. reg. using residuae", 100, 0.0, 1.0);
  h1_8->SetXTitle("[mm]");
  TH1F *h1_8_2 = new TH1F("h1_8_2", "th: slope error by lin. reg. using residuae, prim", 100, 0.0, 1.0);
  TH1F *h1_8_3 = new TH1F("h1_8_3", "th: slope error by lin. reg. using residuae, high pt prim", 100, 0.0, 1.0);
  TH1F *h1_8_4 = new TH1F("h1_8_4", "th: slope error by lin. reg. using residuae, free high pt prim", 100, 0.0, 1.0);

  TH1F *h1_9 = new TH1F("h1_9", "th: #sigma_{slope} over driftlength using fit residuae", 100, 0.0, 1000.0);
  h1_9->SetXTitle("[#mum]");
  TH1F *h1_9_2 = new TH1F("h1_9_2", "th: #sigma_{slope} by lin. reg. using residuae, prim", 100, 0.0, 1000.0);
  TH1F *h1_9_3 = new TH1F("h1_9_3", "th: #sigma_{slope} by lin. reg. using residuae, high pt prim", 100, 0.0, 1000.0);

  TH2F *h1_10 = new TH2F("h1_10", "th: cluster position error by quantisation vs. cluster sum", 100.0, 0.0, 600.0, 100, 0.0, 100.0);
  h1_10->SetXTitle("[#mum]");
  TH1F *h1_11 = new TH1F("h1_11", "number of ghost tracks vs. theta", 50, 40.0, 140.0);
  h1_11->SetXTitle("theta");
  TH1F *h1_11_2 = new TH1F("h1_11_2", "number of tracks vs. theta", 50, 40.0, 140.0);

  TH1F *h1_12 = new TH1F("h1_12", "#sigma of fit residuae", 160, 0.0, 800.0);
  h1_12->SetXTitle("sigma [#mum]");
  TH1F *h1_12_2 = new TH1F("h1_12_2", "sigma by using residuae", 160, 0.0, 800.0);
  TH1F *h1_12_3 = new TH1F("h1_12_3", "sigma by using residuae", 160, 0.0, 800.0);

  /////////////////////////////////////////////////////////////////
  ////// INITIALIZE ALIROOT ENVIRONMENT
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  printf("Current event number: %d\n", event);
  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  //TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  Int_t lParCut = nPrimaryParticles;

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

    res_sum2_all = 0.0;
    res_anz_all = 0.0;
    res_sum2_prim = 0.0;
    res_anz_prim = 0.0;
    res_sum2_primpt = 0.0;
    res_anz_primpt = 0.0;

    for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
      for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
	for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	  printf("working on ev %d, cha %d, sec %2d, pla %d ...\n", event, chamber, sector, plane);
	  Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	  Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector);
	  Int_t lColumnMax  = TRDgeometry->GetColMax(plane);
	  Int_t lTimeMax = TRDgeometry->GetTimeMax();
	  for(Int_t padrow=0; padrow<lPadrowMax; padrow++) {
	    AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	    fitPadrow->SetDigitsManager(DigitsManager);
	    fitPadrow->SetTRDgeometry(TRDgeometry);
	    fitPadrow->SetThreshold(LTH);
	    fitPadrow->SetHitsMin(LSP);
	    fitPadrow->Fit();
	    for(Int_t column=0; column<128; column++) {
	      AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	      Int_t MainTrack = fitTracklet->GetfMainTrack();

	      if(MainTrack > -1) { // found tracklet
		TParticle *Particle = (TParticle *)gAlice->Particle(MainTrack);
		//if(MainTrack >= lParCut) continue; // primary particles
		//if(Particle->Pt() < LPTMIN) continue; // min. transverse momentum
                if(fitTracklet->GetFEject() >= 0) { // ==
		  if((MainTrack < lParCut) && (Particle->Pt() >= LPTMIN)) foundtracks[event][plane][MainTrack]++;
		  Int_t MainTrackPos = 0;
		  for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
		  AliTRDgtuRealTrack *RT = lReal->GetRealTrack(MainTrack);
                  Float_t fitx1   = offset2mm(TRDgeometry, fitTracklet->GetfRPos(), plane);
                  Float_t fitx2   = fitx1 + (10.0*TRDgeometry->GetColPadSize(plane)*(((Float_t)fitTracklet->GetfAngle()-128.0)/128.0));
                  Float_t fitstep = (fitx2-fitx1)/(Float_t)lTimeMax;
		  Float_t realx1  = RT->GetExStartColumn(plane) * 10 * TRDgeometry->GetColPadSize(plane) - 5;
		  Float_t realx2  = RT->GetExEndColumn(plane) * 10 * TRDgeometry->GetColPadSize(plane) - 5;
		  Float_t realstep= (realx2-realx1)/(Float_t)lTimeMax;
		  Float_t ressum2 = 0.0;
		  Float_t resanz  = 0.0;

		  // for slope error
		  Int_t sumxi = 0;
		  Int_t sumxi2 = 0;
		  Int_t nn = 0;
		  //Float_t db_ave_error = 0.0;
		  Float_t db_ave_error_res = 0.0;
		  for(Int_t timebin=0; timebin<lTimeMax; timebin++) {
		    Int_t hitpos = fitTracklet->GetfHitPos(timebin);
		    if(hitpos != -1) {
		      nn++;
		      sumxi += timebin;
		      sumxi2 += timebin*timebin;
		    }
		  }

		  // for number of clusters vs. threshold
		  for(Int_t th=LTH; th<=100; th+=5) {
		    clusters[th] = 0;
		    h1_5_2->Fill(th, 1);
		  }

		  for(Int_t timebin=0; timebin<lTimeMax; timebin++) {
		    Int_t hitpos = fitTracklet->GetfHitPos(timebin);
		    Int_t yi = fitTracklet->GetYi(timebin);
		    if(hitpos != -1) {
		      Float_t yif  = column2mm(TRDgeometry, column, yi, plane);
		      Float_t yiff = fitx1 + (timebin*fitstep);
		      Float_t res = yiff-yif;
		      ressum2 += res*res;
		      resanz += 1.0;
		    }
		  }
		  Float_t sigma2 = ressum2/(resanz-2.0); // 2 degrees of freedom
		  Float_t sigma = TMath::Sqrt(sigma2);
		  h1_12->Fill(1000.0*sigma, 1);
		  if(MainTrack < lParCut) {
		    h1_12_2->Fill(1000.0*sigma, 1);
		    if(Particle->Pt() >= LPTMIN) {
		      h1_12_3->Fill(1000.0*sigma, 1);
		    }
		  }

		  if(TMath::Abs(sigma) < 3.0) {
		    res_sum2_all += ressum2;
		    res_anz_all += resanz;
		    if(MainTrack < lParCut) {
		      res_sum2_prim += ressum2;
		      res_anz_prim += resanz;
		      if(Particle->Pt() >= LPTMIN) {
			res_sum2_primpt += ressum2;
			res_anz_primpt += resanz;
		      }
		    }
		  }

		  for(Int_t timebin=0; timebin<lTimeMax; timebin++) {
		    Int_t hitpos = fitTracklet->GetfHitPos(timebin);
		    Int_t yi = fitTracklet->GetYi(timebin);
		    if(hitpos != -1) {
		      Float_t yif  = column2mm(TRDgeometry, column, yi, plane);
		      Float_t yiff = fitx1 + (timebin*fitstep);
		      Float_t realyiff = realx1 + (timebin*realstep);
		      Float_t res = yiff-yif;
		      Float_t realres = realyiff-yif;

		      Int_t ampC, ampL, ampR;
		      AliTRDdigit *DigitC = DigitsManager->GetDigit(padrow, hitpos, timebin, lDet);
		      ampC = DigitC->GetAmp();
		      delete DigitC;

		      if((hitpos-1) < 0)
			ampL = 0;
		      else {
			AliTRDdigit *DigitL = DigitsManager->GetDigit(padrow, hitpos-1, timebin, lDet);
			ampL = DigitL->GetAmp();
			delete DigitL;
		      }

		      if((hitpos+1) >= lColumnMax)
			ampR = 0;
		      else {
			AliTRDdigit *DigitR = DigitsManager->GetDigit(padrow, hitpos+1, timebin, lDet);
			ampR = DigitR->GetAmp();
			delete DigitR;
		      }

		      Float_t dy_ave_err = amps2error(TRDgeometry, ampL, ampC, ampR, plane);

		      for(Int_t th=LTH; th<=100; th+=5)
			if(ampL+ampC+ampR >= th) clusters[th]++;

		      h1_1->Fill(res, 1);
		      if(MainTrack < lParCut) h1_1_2->Fill(res, 1);
		      if((MainTrack < lParCut) && (Particle->Pt() >= LPTMIN)) {
			h1_1_3->Fill(res, 1);
			h1_2->Fill(1000.0*dy_ave_err, 1);
			h1_10->Fill(1000.0*dy_ave_err, ampL+ampC+ampR, 1);
			h1_3->Fill(ampR-ampL, 1);
			h1_4->Fill(ampL+ampC+ampR, 1);
			h1_6->Fill(ampC, 1);
			h1_7->Fill((Float_t)(ampR+ampL)/(Float_t)(ampL+ampC+ampR), 1);
		      }
		      //Float_t db = (nn*sigma2) / ((nn*sumxi2) - (sumxi*sumxi));
		      Float_t db_res = (sigma * ((nn*timebin) - sumxi)) / ((nn*sumxi2) - (sumxi*sumxi));
		      //db_ave_error += db*db;
		      db_ave_error_res += db_res*db_res;
		    }
		  } // end timebin

		  for(th=LTH; th<=100; th+=5) {
		    h1_5->Fill(th, clusters[th]);
		  }

		  Float_t db_ave_error = (nn*sigma2) / ((nn*sumxi2) - (sumxi*sumxi));
		  db_ave_error = 1000.0 * TMath::Sqrt(db_ave_error); // conversion to [um]
		  db_ave_error_res = TMath::Sqrt(db_ave_error_res);
		  h1_9->Fill(lTimeMax*db_ave_error, 1);
		  h1_8->Fill(lTimeMax*db_ave_error_res, 1);
		  if(MainTrack < lParCut) {
		    h1_9_2->Fill(lTimeMax*db_ave_error, 1);
		    h1_8_2->Fill(lTimeMax*db_ave_error_res, 1);
		    if(Particle->Pt() >= LPTMIN) {
		      h1_9_3->Fill(lTimeMax*db_ave_error, 1);
		      h1_8_3->Fill(lTimeMax*db_ave_error_res, 1);
		      Float_t dist = AliTRDgtuGlobal::FindNextTrack(TRDgeometry, lReal, MainTrack, lDet, padrow, nParticles);
		      if(dist > lMinDist) h1_8_4->Fill(30*db_ave_error_res, 1);
		    }
		  }
		}
	      } // end found tracklet

	    } // end column
	    delete fitPadrow;
	  } // end padrow
	} // end plane
      } // end sector
    } // end chamber
  //delete DigitsManager;

  Float_t res_sigma2_all = res_sum2_all/(res_anz_all-2.0);
  Float_t res_sigma_all = TMath::Sqrt(res_sigma2_all);
  Float_t res_sigma2_prim = res_sum2_prim/(res_anz_prim-2.0);
  Float_t res_sigma_prim = TMath::Sqrt(res_sigma2_prim);
  Float_t res_sigma2_primpt = res_sum2_primpt/(res_anz_primpt-2.0);
  Float_t res_sigma_primpt = TMath::Sqrt(res_sigma2_primpt);
  printf("sigma_all    %fum\n", 1000.0*res_sigma_all);
  printf("sigma_prim   %fum\n", 1000.0*res_sigma_prim);
  printf("sigma_primpt %fum\n", 1000.0*res_sigma_primpt);

  } // end event

  for(Int_t event=lEventMin; event<=lEventMax; event++) {
    for(Int_t plane=0; plane<6; plane++) {
      for(Int_t track=0; track<10000; track++) {
	if(foundtracks[event][plane][track] > 1) {
	  AliTRDgtuRealTrack *RT = lReal->GetRealTrack(track);
	  Int_t rtDet = TRDgeometry->GetDetector(plane, RT->GetChamber(), RT->GetSector());
	  Float_t rttheta = padrow2angle(TRDgeometry, rtDet, RT->GetExStartPadrow(plane));
	  h1_11->Fill(rttheta, foundtracks[event][plane][track]-1);
	}
      }
    }
  }
  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  phisto1->cd(1);
    h1_1->SetLineColor(2); h1_1->SetStats(FALSE); h1_1->Draw();
    h1_1_2->SetLineColor(3); h1_1_2->SetStats(FALSE); h1_1_2->Draw("same");
    h1_1_3->SetLineColor(4); h1_1_3->SetStats(FALSE); h1_1_3->Draw("same");
    char hstr[80];
    Float_t max = h1_1->GetMaximum();
    TPaveText *tt1 = new TPaveText(1.2, 0.8*max, 2.8, 0.9*max); tt1->SetTextColor(2); sprintf(hstr, "RMS = %f\n", h1_1->GetRMS()); tt1->AddText(hstr); tt1->Draw();
    TPaveText *tt2 = new TPaveText(1.2, 0.7*max, 2.8, 0.8*max); tt2->SetTextColor(3); sprintf(hstr, "RMS = %f\n", h1_1_2->GetRMS()); tt2->AddText(hstr); tt2->Draw();
    TPaveText *tt3 = new TPaveText(1.2, 0.6*max, 2.8, 0.7*max); tt3->SetTextColor(4); sprintf(hstr, "RMS = %f\n", h1_1_3->GetRMS()); tt3->AddText(hstr); tt3->Draw();

  phisto1->cd(2); h1_2->Draw();
  phisto1->cd(3); h1_3->Draw();
  phisto1->cd(4); h1_4->Draw();
  phisto1->cd(5); h1_5->Divide(h1_5_2); h1_5->Draw();
  phisto1->cd(6); h1_6->Draw();
  phisto1->cd(7); h1_7->Draw();

  phisto1->cd(8);
    h1_8->SetLineColor(2); h1_8->SetStats(FALSE); h1_8->Draw();
    h1_8_2->SetLineColor(3); h1_8_2->SetStats(FALSE); h1_8_2->Draw("same");
    h1_8_3->SetLineColor(4); h1_8_3->SetStats(FALSE); h1_8_3->Draw("same");
    h1_8_4->SetLineColor(6); h1_8_4->SetStats(FALSE); h1_8_4->Draw("same");

  phisto1->cd(9); h1_9->Draw();
    h1_9->SetLineColor(2); h1_9->SetStats(FALSE); h1_9->Draw();
    h1_9_2->SetLineColor(3); h1_9_2->SetStats(FALSE); h1_9_2->Draw("same");
    h1_9_3->SetLineColor(4); h1_9_3->SetStats(FALSE); h1_9_3->Draw("same");

  phisto1->cd(10);h1_10->Draw("colz");
  phisto1->cd(11);h1_11->Draw();

  phisto1->cd(12);
    h1_12->SetLineColor(2); h1_12->SetStats(FALSE); h1_12->Draw();
    h1_12_2->SetLineColor(3); h1_12_2->SetStats(FALSE); h1_12_2->Draw("same");
    h1_12_3->SetLineColor(4); h1_12_3->SetStats(FALSE); h1_12_3->Draw("same");
 
  /////////////////////////////////////////////////////////////////
    HEAD("WRITE HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_res3.root", "CREATE", "Simulation");
    h1_1->Write("h1_1");
    h1_1_2->Write("h1_1_2");
    h1_1_3->Write("h1_1_3");

    h1_2->Write("h1_2");
    h1_3->Write("h1_3");
    h1_4->Write("h1_4");
    h1_5->Write("h1_5");
    h1_6->Write("h1_6");
    h1_7->Write("h1_7");

    h1_8->Write("h1_8");
    h1_8_2->Write("h1_8_2");
    h1_8_3->Write("h1_8_3");
    h1_8_3->Write("h1_8_4");

    h1_9->Write("h1_9");
    h1_9_2->Write("h1_9_2");
    h1_9_3->Write("h1_9_3");

    h1_10->Write("h1_10");
    h1_11->Write("h1_11");

    h1_12->Write("h1_12");
    h1_12_2->Write("h1_12_2");
    h1_12_3->Write("h1_12_3");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
