/*
$Log: AliTRDnh_res4.C,v $
Revision 1.8  2001/04/02 14:51:37  schneide
Use of global header file for fit settings

Revision 1.7  2001/02/18 17:56:43  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.6  2001/02/14 17:42:45  schneide
Update to new root file for full multiplicity

Revision 1.5  2001/02/08 09:30:13  schneide
Remove of static array size for RealTracks

Revision 1.4  2001/01/26 13:17:41  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "res4"

void AliTRDnh_res4()
{
  const Int_t     kChips                  = 8;
  const Int_t     kChannels               = 16;

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  printf("AliRoot file  : %s\n\n", ALIFILE);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt       : %f\n", LPTMIN);
  printf("Threshold     : %d\n", LTH);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 800); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(1,2);

  // init histogramms
  TH1F *h1_1 = new TH1F("h1_1", "fit: residuum^{2} vs. distance to next track", 60.0, 0.0, 60.0);
  h1_1->SetXTitle("distance [mm]"); h1_1->SetYTitle("residuum^{2} [mm^{2}]");
  TH1F *h1_2 = new TH1F("h1_2", "fit: slope error vs. distance to next track", 60.0, 0.0, 60.0);
  h1_2->SetXTitle("distance [mm]"); h1_2->SetYTitle("slope over drift [mm]");

  TH1F *h0_1 = new TH1F("h0_1", "residuum vs. distance to next track", 60.0, 0.0, 60.0);
  TH1F *h0_2 = new TH1F("h0_2", "slope error vs. distance to next track", 60.0, 0.0, 60.0);
  /////////////////////////////////////////////////////////////////
  ////// INITIALIZE ALIROOT ENVIRONMENT
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  printf("Current event number: %d\n", event);
  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  Int_t lParCut = nPrimaryParticles;

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

    for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
      for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
	for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	  printf("working on ev %d, cha %d, sec %2d, pla %d ...\n", event, chamber, sector, plane);
	  Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	  Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector);
	  Int_t lColumnMax  = TRDgeometry->GetColMax(plane);
	  Int_t lTimeMax = TRDgeometry->GetTimeMax();
	  for(Int_t padrow=0; padrow<lPadrowMax; padrow++) {
	    AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	    fitPadrow->SetDigitsManager(DigitsManager);
	    fitPadrow->SetTRDgeometry(TRDgeometry);
	    fitPadrow->SetThreshold(LTH);
	    fitPadrow->SetHitsMin(LSP);
	    fitPadrow->Fit();
	    for(Int_t column=0; column<128; column++) {
	      AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	      Int_t MainTrack = fitTracklet->GetfMainTrack();

	      if(MainTrack != -1) { // found tracklet
		TParticle *Particle = (TParticle *)ParticleArray->At(MainTrack);
                if(fitTracklet->GetFEject() >= 0) { // ==
		  Int_t MainTrackPos = 0;
		  for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
		  AliTRDgtuRealTrack *RT = lReal->GetRealTrack(MainTrack);
                  Float_t fitx1   = offset2mm(TRDgeometry, fitTracklet->GetfRPos(), plane);
                  Float_t fitx2   = fitx1 + (10.0*TRDgeometry->GetColPadSize(plane)*(((Float_t)fitTracklet->GetfAngle()-128)/128));
                  Float_t fitstep = (fitx2-fitx1)/(Float_t)lTimeMax;

		  // for slope error
		  Int_t sumxi = 0;
		  Int_t sumxi2 = 0;
		  Int_t nn = 0;
		  for(Int_t timebin=0; timebin<lTimeMax; timebin++) {
		    Int_t hitpos = fitTracklet->GetfHitPos(timebin);
		    if(hitpos != -1) {
		      nn++;
		      sumxi += timebin;
		      sumxi2 += timebin*timebin;
		    }
		  }

		  Float_t dist = AliTRDgtuGlobal::FindNextTrack(TRDgeometry, lReal, MainTrack, lDet, padrow, nParticles);

		  Float_t db_ave_error_res = 0.0;
		  Float_t db_ave_error_anz = 0.0;
		  for(Int_t timebin=0; timebin<lTimeMax; timebin++) {
		    Int_t hitpos = fitTracklet->GetfHitPos(timebin);
		    Int_t yi = fitTracklet->GetYi(timebin);
		    if(hitpos != -1) {
		      Float_t yif  = column2mm(TRDgeometry, column, yi, plane);
		      Float_t yiff = fitx1 + (timebin*fitstep);
		      Float_t res = yiff-yif;

		      h1_1->Fill(dist, res*res);
		      h0_1->Fill(dist, 1);
		      Float_t db_res = (res * ((nn*timebin) - sumxi)) / ((nn*sumxi2) - (sumxi*sumxi));
		      db_ave_error_res += db_res*db_res;
		      db_ave_error_anz += 1.0;
		    }
		  } // end timebin

		  db_ave_error_res = db_ave_error_res/(db_ave_error_anz-1.0); // sigma**2
		  db_ave_error_res = TMath::Sqrt(db_ave_error_res); //sigma
		  h1_2->Fill(dist, 30*db_ave_error_res);
		  h0_2->Fill(dist, 1);
		}
	      } // end found tracklet

	    } // end column
	    delete fitPadrow;
	  } // end padrow
	} // end plane
      } // end sector
    } // end chamber
  //delete DigitsManager;

  } // end event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  c1->cd();
  phisto1->cd(1); h1_1->Divide(h0_1); h1_1->SetLineWidth(5); h1_1->Draw();
  phisto1->cd(2); h1_2->Divide(h0_2); h1_2->SetLineWidth(5); h1_2->Draw();

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_res4.root", "CREATE", "Simulation");
    h0_1->Write("h0_1");
    h1_1->Write("h1_1");
    h0_2->Write("h0_2");
    h1_2->Write("h1_2");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
