/*
$Log: AliTRDnh_res5.C,v $
Revision 1.5  2001/04/02 14:51:37  schneide
Use of global header file for fit settings

Revision 1.4  2001/03/20 14:07:57  schneide
update for siemens1 installation

Revision 1.3  2001/02/18 17:56:44  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.2  2001/02/14 17:42:45  schneide
Update to new root file for full multiplicity

Revision 1.1  2001/02/12 14:14:10  schneide
Review of error calculations and adding of res5

*/

#include "global.h"

#define MODULE "res5"

void AliTRDnh_res5()
{
  const Int_t     kChips                  = 8;
  const Int_t     kChannels               = 16;

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event !! change foundtracks array !!

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  Float_t lMinDist = 20.0;// min. distance (slope error)

  Bool_t WriteHisto = FALSE; // write histograms into root file in HISTOGRAMS directory

  printf("AliRoot file  : %s\n\n", ALIFILE);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt       : %f\n", LPTMIN);
  printf("Threshold     : %d\n", LTH);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 800); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(2,3);

  // init histogramms
  TH1F *h1_1 = new TH1F("h1_1", "fit: residuae (all, primaries, high pt primaries)", 100.0, -3.0, 3.0);
  h1_1->SetXTitle("distance [mm]");
  TH1F *h1_1_2 = new TH1F("h1_1_2", "fit: residuae, primary", 100.0, -3.0, 3.0);
  TH1F *h1_1_3 = new TH1F("h1_1_3", "fit: residuae, primary, high pt", 100.0, -3.0, 3.0);

  TH1F *h1_2 = new TH1F("h1_2", "fit: residuae to real track (all, primaries, high pt primaries)", 100.0, -10.0, 10.0);
  h1_2->SetXTitle("distance [mm]");
  TH1F *h1_2_2 = new TH1F("h1_2_2", "fit: residuae, primary", 100.0, -10.0, 10.0);
  TH1F *h1_2_3 = new TH1F("h1_2_3", "fit: residuae, primary, high pt", 100.0, -10.0, 10.0);

  TH1F *h1_3 = new TH1F("h1_3", "th: position error by quantisation", 100.0, 0.0, 250.0);
  h1_3->SetXTitle("distance [um]");

  TH1F *h1_4 = new TH1F("h1_4", "fit: slope difference (all, primaries, high pt primaries)", 100.0, -30.0, 30.0);
  h1_4->SetXTitle("slope*3cm [mm]");
  TH1F *h1_4_2 = new TH1F("h1_4_2", "fit: ", 100.0, -30.0, 30.0);
  TH1F *h1_4_3 = new TH1F("h1_4_3", "fit: ", 100.0, -30.0, 30.0);

  TH1F *h1_5 = new TH1F("h1_5", "fit: ave. residuae vs. theta (all, primaries, high pt primaries)", 50, 40.0, 140.0);
  h1_5->SetXTitle("theta"); h1_5->SetXTitle("[#mum]");
  TH1F *h1_5_2 = new TH1F("h1_5_2", "fit: ave. residuae vs. theta (all, primaries, high pt primaries)", 50, 40.0, 140.0);
  TH1F *h1_5_3 = new TH1F("h1_5_3", "fit: ave. residuae vs. theta (all, primaries, high pt primaries)", 50, 40.0, 140.0);
  TH1F *h0_5 = new TH1F("h0_5", "fit: ave. residuae vs. theta (all, primaries, high pt primaries)", 50, 40.0, 140.0);
  TH1F *h0_5_2 = new TH1F("h0_5_2", "fit: ave. residuae vs. theta (all, primaries, high pt primaries)", 50, 40.0, 140.0);
  TH1F *h0_5_3 = new TH1F("h0_5_3", "fit: ave. residuae vs. theta (all, primaries, high pt primaries)", 50, 40.0, 140.0);

  /////////////////////////////////////////////////////////////////
  ////// INITIALIZE ALIROOT ENVIRONMENT
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  printf("Current event number: %d\n", event);
  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  Int_t lParCut = nPrimaryParticles;

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

    for(Int_t chamber=lChamberMin; chamber<=lChamberMax; chamber++) {
      for(Int_t sector=lSectorMin; sector<=lSectorMax; sector++) {
	for(Int_t plane=lPlaneMin; plane<=lPlaneMax; plane++) {
	  printf("working on ev %d, cha %d, sec %2d, pla %d ...\n", event, chamber, sector, plane);
	  Int_t lDet = TRDgeometry->GetDetector(plane, chamber, sector);
	  Int_t lPadrowMax = TRDgeometry->GetRowMax(plane, chamber, sector);
	  Int_t lColumnMax  = TRDgeometry->GetColMax(plane);
	  Int_t lTimeMax = TRDgeometry->GetTimeMax();
	  for(Int_t padrow=0; padrow<lPadrowMax; padrow++) {
	    AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, sector, chamber, padrow);
	    fitPadrow->SetDigitsManager(DigitsManager);
	    fitPadrow->SetTRDgeometry(TRDgeometry);
	    fitPadrow->SetThreshold(LTH);
	    fitPadrow->SetHitsMin(LSP);
	    fitPadrow->Fit();
	    for(Int_t column=0; column<128; column++) {
	      AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(column);
	      Int_t MainTrack = fitTracklet->GetfMainTrack();

	      if(MainTrack != -1) { // found tracklet
		TParticle *Particle = (TParticle *)ParticleArray->At(MainTrack);
                if(fitTracklet->GetFEject() >= 0) { // ==
		  Int_t MainTrackPos = 0;
		  for(Int_t MainTrackPos=0; MainTrack != fitTracklet->GetTrackAt(MainTrackPos); MainTrackPos++);
		  AliTRDgtuRealTrack *RT = lReal->GetRealTrack(MainTrack);
                  Float_t fitx1   = offset2mm(TRDgeometry, fitTracklet->GetfRPos(), plane);
                  Float_t fitx2   = fitx1 + (10.0*TRDgeometry->GetColPadSize(plane)*(((Float_t)fitTracklet->GetfAngle()-128.0)/128.0));
		  Float_t fitdiff = fitx2-fitx1;
                  Float_t fitstep = fitdiff/(Float_t)lTimeMax;
		  Float_t realx1  = RT->GetExStartColumn(plane) * 10 * TRDgeometry->GetColPadSize(plane) - 5;
		  Float_t realx2  = RT->GetExEndColumn(plane) * 10 * TRDgeometry->GetColPadSize(plane) - 5;
		  Float_t realdiff= realx2-realx1;
		  Float_t realstep= realdiff/(Float_t)lTimeMax;
		  Float_t slopediff = realdiff - fitdiff;
		  Float_t fittheta = padrow2angle(TRDgeometry, lDet, padrow);

		  for(Int_t timebin=0; timebin<lTimeMax; timebin++) {
		    Int_t hitpos = fitTracklet->GetfHitPos(timebin);
		    Int_t yi = fitTracklet->GetYi(timebin);
		    if(hitpos != -1) {
		      // residuae
		      Float_t yif  = column2mm(TRDgeometry, column, yi, plane);
		      Float_t yiff = fitx1 + (timebin*fitstep);
		      Float_t realyiff = realx1 + (timebin*realstep);
		      Float_t res = yiff-yif;
		      Float_t realres = realyiff-yif;

		      // amplitudes
		      Int_t ampC, ampL, ampR;
		      AliTRDdigit *DigitC = DigitsManager->GetDigit(padrow, hitpos, timebin, lDet);
		      ampC = DigitC->GetAmp();
		      delete DigitC;

		      if((hitpos-1) < 0)
			ampL = 0;
		      else {
			AliTRDdigit *DigitL = DigitsManager->GetDigit(padrow, hitpos-1, timebin, lDet);
			ampL = DigitL->GetAmp();
			delete DigitL;
		      }

		      if((hitpos+1) >= lColumnMax)
			ampR = 0;
		      else {
			AliTRDdigit *DigitR = DigitsManager->GetDigit(padrow, hitpos+1, timebin, lDet);
			ampR = DigitR->GetAmp();
			delete DigitR;
		      }

		      h1_1->Fill(res, 1);
		      h1_2->Fill(realres, 1);
		      h1_3->Fill(1000.0*amps2error(TRDgeometry, ampL, ampC, ampR, plane), 1);
		      h1_5->Fill(fittheta, TMath::Abs(res*1000));
		      h0_5->Fill(fittheta, 1);

		      if(MainTrack < lParCut) {
			h1_1_2->Fill(res, 1);
			h1_2_2->Fill(realres, 1);
			h1_5_2->Fill(fittheta, TMath::Abs(res*1000));
			h0_5_2->Fill(fittheta, 1);
		      }
		      if((MainTrack < lParCut) && (Particle->Pt() >= LPTMIN)) {
			h1_1_3->Fill(res, 1);
			h1_2_3->Fill(realres, 1);
			h1_5_3->Fill(fittheta, TMath::Abs(res*1000));
			h0_5_3->Fill(fittheta, 1);
		      }
		    }
		  } // end timebin

		  h1_4->Fill(slopediff, 1);
		  if(MainTrack < lParCut) {
		    h1_4_2->Fill(slopediff, 1);
		  }
		  if((MainTrack < lParCut) && (Particle->Pt() >= LPTMIN)) {
		    h1_4_3->Fill(slopediff, 1);
		  }
		} // end eject
	      } // end found tracklet

	    } // end column
	    delete fitPadrow;
	  } // end padrow
	} // end plane
      } // end sector
    } // end chamber
  //delete DigitsManager;

  delete lReal;
  } // end event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  char hstr[80];

  c1->cd();
  phisto1->cd(1);
    h1_1->SetLineColor(2); h1_1->SetStats(FALSE); h1_1->Draw();
    h1_1_2->SetLineColor(3); h1_1_2->SetStats(FALSE); h1_1_2->Draw("same");
    h1_1_3->SetLineColor(4); h1_1_3->SetStats(FALSE); h1_1_3->Draw("same");
    Float_t max = h1_1->GetMaximum();
    TPaveText *tt1_1 = new TPaveText(1.2, 0.8*max, 2.8, 0.9*max); tt1_1->SetTextColor(2); sprintf(hstr, "RMS = %f\n", h1_1->GetRMS()); tt1_1->AddText(hstr); tt1_1->Draw();
    TPaveText *tt1_2 = new TPaveText(1.2, 0.7*max, 2.8, 0.8*max); tt1_2->SetTextColor(3); sprintf(hstr, "RMS = %f\n", h1_1_2->GetRMS()); tt1_2->AddText(hstr); tt1_2->Draw();
    TPaveText *tt1_3 = new TPaveText(1.2, 0.6*max, 2.8, 0.7*max); tt1_3->SetTextColor(4); sprintf(hstr, "RMS = %f\n", h1_1_3->GetRMS()); tt1_3->AddText(hstr); tt1_3->Draw();

  phisto1->cd(2);
    h1_2->SetLineColor(2); h1_2->SetStats(FALSE); h1_2->Draw();
    h1_2_2->SetLineColor(3); h1_2_2->SetStats(FALSE); h1_2_2->Draw("same");
    h1_2_3->SetLineColor(4); h1_2_3->SetStats(FALSE); h1_2_3->Draw("same");
    Float_t max = h1_2->GetMaximum();
    TPaveText *tt2_1 = new TPaveText(4, 0.8*max, 9, 0.9*max); tt2_1->SetTextColor(2); sprintf(hstr, "RMS = %f\n", h1_2->GetRMS()); tt2_1->AddText(hstr); tt2_1->Draw();
    TPaveText *tt2_2 = new TPaveText(4, 0.7*max, 9, 0.8*max); tt2_2->SetTextColor(3); sprintf(hstr, "RMS = %f\n", h1_2_2->GetRMS()); tt2_2->AddText(hstr); tt2_2->Draw();
    TPaveText *tt2_3 = new TPaveText(4, 0.6*max, 9, 0.7*max); tt2_3->SetTextColor(4); sprintf(hstr, "RMS = %f\n", h1_2_3->GetRMS()); tt2_3->AddText(hstr); tt2_3->Draw();

  phisto1->cd(3);
    h1_3->SetLineColor(2); h1_3->SetStats(FALSE); h1_3->Draw();

  phisto1->cd(4);
    h1_4->SetLineColor(2); h1_4->SetStats(FALSE); h1_4->Draw();
    h1_4_2->SetLineColor(3); h1_4_2->SetStats(FALSE); h1_4_2->Draw("same");
    h1_4_3->SetLineColor(4); h1_4_3->SetStats(FALSE); h1_4_3->Draw("same");

  phisto1->cd(5);
    h1_5->Divide(h0_5); h1_5->SetLineColor(2); h1_5->SetStats(FALSE); h1_5->Draw();
    h1_5_2->Divide(h0_5_2); h1_5_2->SetLineColor(3); h1_5_2->SetStats(FALSE); h1_5_2->Draw();
    h1_5_3->Divide(h0_5_3); h1_5_3->SetLineColor(4); h1_5_3->SetStats(FALSE); h1_5_3->Draw();

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_res5.root", "CREATE", "Simulation");
    h1_1->Write("h1_1");
    h1_1_2->Write("h1_1_2");
    h1_1_3->Write("h1_1_3");

    h1_2->Write("h1_2");
    h1_2_2->Write("h1_2_2");
    h1_2_3->Write("h1_2_3");

    h1_3->Write("h1_3");

    h1_4->Write("h1_4");
    h1_4_2->Write("h1_4_2");
    h1_4_3->Write("h1_4_3");

    h1_5->Write("h1_5");
    h1_5_2->Write("h1_5_2");
    h1_5_3->Write("h1_5_3");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
