/*
$Log: AliTRDnh_row.C,v $
Revision 1.8  2001/04/02 14:51:37  schneide
Use of global header file for fit settings

Revision 1.7  2001/02/18 17:56:44  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.6  2001/02/14 17:42:45  schneide
Update to new root file for full multiplicity

Revision 1.5  2001/02/08 09:30:13  schneide
Remove of static array size for RealTracks

Revision 1.4  2001/01/26 13:17:41  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "row"

void AliTRDnh_row()
{
  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT EVENT STATISTIC                           //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Bool_t lOutput = TRUE; // output of root, ps, gif files

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  Bool_t WriteHisto = FALSE; // write histograms into root file in HISTOGRAMS directory

  printf("AliRoot file   : %s\n\n", ALIFILE);
  printf("Event range    : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range    : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range   : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range  : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt        : %f\n", LPTMIN);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 800); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(2,4);

  // init histogramms
  TH1F *h1_1 = new TH1F("h1_1", "real: number of tracks vs. theta", 50, 40.0, 140.0);
  h1_1->SetXTitle("theta"); h1_1->SetYTitle("tracks");

  TH1F *h1_2 = new TH1F("h1_2", "real: number of tracks in more than one padrow vs. theta", 50, 40.0, 140.0);
  h1_2->SetXTitle("theta"); h1_2->SetYTitle("tracks");
  TH1F *h1_2_2 = new TH1F("h1_2_2", "real: number of tracks in more than one padrow vs. theta, 1mm", 50, 40.0, 140.0);
  TH1F *h1_2_3 = new TH1F("h1_2_3", "real: number of tracks in more than one padrow vs. theta, 2mm", 50, 40.0, 140.0);
  TH1F *h1_2_4 = new TH1F("h1_2_4", "real: number of tracks in more than one padrow vs. theta, 3mm", 50, 40.0, 140.0);
  TH1F *h1_2_5 = new TH1F("h1_2_5", "real: number of tracks in more than one padrow vs. theta, 5mm", 50, 40.0, 140.0);

  TH1F *h1_3 = new TH1F("h1_3", "real: rel. number of tracks in more than one padrow vs. theta", 50, 40.0, 140.0);
  h1_3->SetXTitle("theta"); h1_3->SetYTitle("tracks [%]");
  TH1F *h1_3_2 = new TH1F("h1_3_2", "real: rel. number of tracks in more than one padrow vs. theta, 1mm", 50, 40.0, 140.0);
  TH1F *h1_3_3 = new TH1F("h1_3_3", "real: rel. number of tracks in more than one padrow vs. theta, 2mm", 50, 40.0, 140.0);
  TH1F *h1_3_4 = new TH1F("h1_3_4", "real: rel. number of tracks in more than one padrow vs. theta, 3mm", 50, 40.0, 140.0);
  TH1F *h1_3_5 = new TH1F("h1_3_5", "real: rel. number of tracks in more than one padrow vs. theta, 5mm", 50, 40.0, 140.0);

  TH1F *h1_4 = new TH1F("h1_4", "real: rel. energy loss in single padrow vs. theta", 50, 40.0, 140.0);
  h1_4->SetXTitle("theta"); h1_4->SetYTitle("%");
  TH1F *h1_5 = new TH1F("h1_5", "real: rel. energy loss in single padrow vs. theta, th=15", 50, 40.0, 140.0);
  h1_5->SetXTitle("theta"); h1_5->SetYTitle("%");
  TH1F *h1_6 = new TH1F("h1_6", "real: ave. number of hits in single padrow vs. theta, th=15", 50, 40.0, 140.0);
  h1_6->SetXTitle("theta");
  TH1F *h1_7 = new TH1F("h1_7", "real: ave. timebin difference for main padrow vs. theta, th=15", 50, 40.0, 140.0);
  h1_7->SetXTitle("theta");

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

  lReal->Dump();
  printf("  particles in TRD         : %d\n", lReal->GetTRDparticles());
  printf("  primary particles in TRD : %d\n", lReal->GetTRDprimaryParticles());

  Int_t colrange = 2;
  Int_t rowrange = 1;

  for(Int_t parno=0; parno<nParticles; parno++) {
    printf("  %3d\%\r", (100.0*parno)/(Float_t)(nParticles-1));
    TParticle *Particle = (TParticle *)ParticleArray->At(parno);
    Float_t lPt = Particle->Pt();
    if(lPt >= LPTMIN) {
      AliTRDgtuRealTrack *RT = lReal->GetRealTrack(parno);
      if(RT->GetTrackID() != -1) {
	if(parno<nPrimaryParticles) {
	  for(Int_t plane=0; plane<6; plane++) {
	    if(RT->GetExStartColumn(plane) != -1.0) {
	      Float_t z1 = RT->GetExStartPadrow(plane); // padrow within chamber
	      Float_t z2 = RT->GetExEndPadrow(plane); // padrow within chamber
              Int_t chamber = RT->GetChamber();
              Int_t sector = RT->GetSector();
	      Int_t rtDet = TRDgeometry->GetDetector(plane, chamber, sector);
	      Float_t rttheta = padrow2angle(TRDgeometry, rtDet, RT->GetExStartPadrow(plane));
	      h1_1->Fill(rttheta, 1);
	      if((Int_t)z1 != (Int_t)z2) {
		Int_t th = (Int_t)TMath::Max(z1, z2);
		Float_t seg1 = TMath::Abs(z1-th);
		Float_t seg2 = TMath::Abs(z2-th);
		Float_t segy = 10.0 * TRDgeometry->GetRowPadSize(plane, chamber, sector) * TMath::Min(seg1, seg2); // mm
		Float_t slope = (10.0 * TRDgeometry->GetRowPadSize(plane, chamber, sector) * (z2-z1))/30.0; // mm/mm
		Float_t segr = TMath::Abs(segy/slope);
		h1_2->Fill(rttheta, 1);
		h1_3->Fill(rttheta, 1);
		if(segr>=3) { h1_2_2->Fill(rttheta, 1); h1_3_2->Fill(rttheta, 1); }
		if(segr>=6) { h1_2_3->Fill(rttheta, 1); h1_3_3->Fill(rttheta, 1); }
		if(segr>=9) { h1_2_4->Fill(rttheta, 1); h1_3_4->Fill(rttheta, 1); }
		if(segr>=12) { h1_2_5->Fill(rttheta, 1); h1_3_5->Fill(rttheta, 1); }
	      }
              // search for digits
              Int_t colMax   = TRDgeometry->GetColMax(plane);
              Int_t rowMax   = TRDgeometry->GetRowMax(plane, chamber, sector);
              Int_t timeMax  = TRDgeometry->GetTimeMax();
	      Int_t colt = (Int_t)(getstartcol(TRDgeometry, RT, plane));
	      Int_t rowt = (Int_t)(getstartrow(TRDgeometry, RT, plane));
	      TArrayI *rowamp = new TArrayI(2*rowrange+1);
	      TArrayI *rowamp_th = new TArrayI(2*rowrange+1);
	      TArrayI *rowhitsanz_th = new TArrayI(2*rowrange+1);
	      TArrayI *rowhits_th = new TArrayI(timeMax*(2*rowrange+1));
	      for(Int_t searchrow=rowt-rowrange; searchrow<=rowt+rowrange; searchrow++) {
		if((searchrow<0) || (searchrow>=rowMax)) continue;
		Int_t hitsrowsum_th = 0;
		for(Int_t time=0; time<timeMax; time++) {
		  Int_t ampcolsum = 0;
		  Int_t ampcolsum_th = 0;
		  for(Int_t searchcol=colt-colrange; searchcol<=colt+colrange; searchcol++) {
		    if((searchcol<0) || (searchcol>=colMax)) continue;
		    Int_t track = DigitsManager->GetTrack(0, searchrow, searchcol, time, rtDet);
		    if(track == parno) {
		      AliTRDdigit *Digit = DigitsManager->GetDigit(searchrow, searchcol, time, rtDet);
		      Int_t amp = Digit->GetAmp();
		      ampcolsum += amp;
		      delete Digit;
		    }
		  } // end searchcol
		  if(ampcolsum>=LTH) {
		    ampcolsum_th += ampcolsum;
		    hitsrowsum_th++;
		    rowhits_th->AddAt(ampcolsum, (rowt+rowrange-searchrow)*timeMax + time);
		  }
		  Int_t rowampi = rowt+rowrange-searchrow;
		  rowamp->AddAt(rowamp->At(rowampi)+ampcolsum, rowampi);
		  rowamp_th->AddAt(rowamp_th->At(rowampi)+ampcolsum_th, rowampi);
		} // end timebin
		rowhitsanz_th->AddAt(rowhitsanz_th->At(rowampi)+hitsrowsum_th, rowampi);
	      } // end searchrow
	      // rel energy loss
	      Int_t ii = 0, amp = 0;
	      for(Int_t rowampi=0; rowampi<2*rowrange+1; rowampi++) {
		if(rowamp->At(rowampi) > amp) {
		  ii = rowampi;
		  amp = rowamp->At(rowampi);
		}
	      }
	      h1_4->Fill(rttheta, (100.0*rowamp->At(ii))/RT->GetAmplitudeSum(plane));
	      delete rowamp;
	      // rel energy loss with threshold
	      Int_t ii = 0, amp = 0;
	      for(Int_t rowampi=0; rowampi<2*rowrange+1; rowampi++) {
		if(rowamp_th->At(rowampi) > amp) {
		  ii = rowampi;
		  amp = rowamp_th->At(rowampi);
		}
	      }
	      h1_5->Fill(rttheta, (100.0*rowamp_th->At(ii))/RT->GetAmplitudeSum(plane));

	      // number of hits
	      Int_t ii = 0, hits = 0;
	      for(Int_t rowhitsi=0; rowhitsi<2*rowrange+1; rowhitsi++) {
		if(rowhitsanz_th->At(rowhitsi) > hits) {
		  ii = rowhitsi;
		  hits = rowhitsanz_th->At(rowhitsi);
		}
	      }
	      h1_6->Fill(rttheta, rowhitsanz_th->At(ii));

	      delete rowamp_th;
	      // timediff for most energy loss
	      Int_t inner = 100;
	      Int_t outer = -1;
    	      for(Int_t time=0; time<timeMax; time++) {
		if(rowhits_th->At(ii*timeMax+time)) {
		  if(time<inner) inner = time;
		  if(time>outer) outer = time;
		}
	      }
	      if(rowhitsanz_th->At(ii)) h1_7->Fill(rttheta, outer-inner);
	      delete rowhits_th;
	    } // end valid readtrack
	  } // end plane
	} // end primary
      } // end realtrack
    } // end min pt
  } // end particle number
  printf("\n");

  delete lReal;

  } // end event

  HEAD("DRAW HISTOGRAMS");
  c1->cd();
  phisto1->cd(1);  /*gPad->SetLogy()*/; h1_1->Draw();
  phisto1->cd(2);
    h1_2->SetLineColor(1);   h1_2->SetStats(FALSE);   h1_2->Draw();
    h1_2_2->SetLineColor(2); h1_2_2->SetStats(FALSE); h1_2_2->Draw("same");
    h1_2_3->SetLineColor(3); h1_2_3->SetStats(FALSE); h1_2_3->Draw("same");
    h1_2_4->SetLineColor(4); h1_2_4->SetStats(FALSE); h1_2_4->Draw("same");
    h1_2_5->SetLineColor(6); h1_2_5->SetStats(FALSE); h1_2_5->Draw("same");
  phisto1->cd(3);
    h1_3->Divide(h1_1);   h1_3->Scale(100);   h1_3->SetStats(FALSE);   h1_3->SetLineColor(1);   h1_3->Draw();
    h1_3_2->Divide(h1_1); h1_3_2->Scale(100); h1_3_2->SetStats(FALSE); h1_3_2->SetLineColor(2); h1_3_2->Draw("same");
    h1_3_3->Divide(h1_1); h1_3_3->Scale(100); h1_3_3->SetStats(FALSE); h1_3_3->SetLineColor(3); h1_3_3->Draw("same");
    h1_3_4->Divide(h1_1); h1_3_4->Scale(100); h1_3_4->SetStats(FALSE); h1_3_4->SetLineColor(4); h1_3_4->Draw("same");
    h1_3_5->Divide(h1_1); h1_3_5->Scale(100); h1_3_5->SetStats(FALSE); h1_3_5->SetLineColor(6); h1_3_5->Draw("same");
    Float_t max = h1_3->GetMaximum();
    TPaveText *tt0 = new TPaveText(60, 0.9*max, 120, 0.95*max); tt0->SetTextColor(1); tt0->AddText("segment lost in r direction"); tt0->Draw();
    TPaveText *tt1 = new TPaveText(80, 0.85*max, 100, 0.9*max); tt1->SetTextColor(1); tt1->AddText(">0mm"); tt1->Draw();
    TPaveText *tt2 = new TPaveText(80, 0.8*max, 100, 0.85*max); tt2->SetTextColor(2); tt2->AddText(">3mm"); tt2->Draw();
    TPaveText *tt3 = new TPaveText(80, 0.75*max, 100, 0.8*max); tt3->SetTextColor(3); tt3->AddText(">6mm"); tt3->Draw();
    TPaveText *tt4 = new TPaveText(80, 0.7*max, 100, 0.75*max); tt4->SetTextColor(4); tt4->AddText(">9mm"); tt4->Draw();
    TPaveText *tt5 = new TPaveText(80, 0.65*max, 100, 0.7*max); tt5->SetTextColor(6); tt5->AddText(">12mm"); tt5->Draw();

  phisto1->cd(4);  /*gPad->SetLogy()*/; h1_4->Divide(h1_1); h1_4->Draw();
  phisto1->cd(5);  /*gPad->SetLogy()*/; h1_5->Divide(h1_1); h1_5->Draw();
  phisto1->cd(6);  /*gPad->SetLogy()*/; h1_6->Divide(h1_1); h1_6->Draw();
  phisto1->cd(7);  /*gPad->SetLogy()*/; h1_7->Divide(h1_1); h1_7->Draw();

  /////////////////////////////////////////////////////////////////
    HEAD("WRITE HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  if(lOutput) {
    TFile *fp = new TFile("./HISTOGRAMS/histo_row.root", "CREATE", "Simulation");
    h1_1->Write("h1_1");

    h1_2->Write("h1_2");
    h1_2_2->Write("h1_2_2");
    h1_2_3->Write("h1_2_3");
    h1_2_4->Write("h1_2_4");
    h1_2_5->Write("h1_2_5");

    h1_3->Write("h1_3");
    h1_3_2->Write("h1_3_2");
    h1_3_3->Write("h1_3_3");
    h1_3_4->Write("h1_3_4");
    h1_3_5->Write("h1_3_5");

    h1_4->Write("h1_4");
    h1_5->Write("h1_5");
    h1_6->Write("h1_6");
    h1_7->Write("h1_7");
  }

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
