/*
$Log: AliTRDnh_row2.C,v $
Revision 1.5  2001/04/02 14:51:37  schneide
Use of global header file for fit settings

Revision 1.4  2001/02/08 09:30:13  schneide
Remove of static array size for RealTracks

Revision 1.3  2001/01/26 13:17:42  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "row2"

void AliTRDnh_row2()
{
  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT EVENT STATISTIC                           //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 17; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  printf("AliRoot file   : %s\n\n", ALIFILE);
  printf("Event range    : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range    : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range   : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range  : %3d .. %3d\n", lChamberMin, lChamberMax);
  printf("Min. Pt        : %f\n", LPTMIN);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE SIMULATION ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  TCanvas *c1 = new TCanvas("c1", "Config_nh.C", 100, 10, 600, 600); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.95, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, TitleString); pltitle1->Draw();
  c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.94);
  phisto1->Draw(); phisto1->Divide(2,2);

  // init histogramms
  TH1F *h1_1 = new TH1F("h1_1", "real: number of tracks vs. theta", 50, 40.0, 140.0);
  h1_1->SetXTitle("theta"); h1_1->SetYTitle("tracks");
  TH1F *h1_2 = new TH1F("h1_2", "real: number of tracks in more than one padrow vs. theta", 50, 40.0, 140.0);
  h1_2->SetXTitle("theta"); h1_2->SetYTitle("tracks");
  TH1F *h1_3 = new TH1F("h1_3", "real: rel. number of tracks in more than one padrow vs. theta", 50, 40.0, 140.0);
  h1_3->SetXTitle("theta"); h1_3->SetYTitle("tracks");

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", event);
  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal();

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

  lReal->Dump();
  printf("  particles in TRD         : %d\n", lReal->GetTRDparticles());
  printf("  primary particles in TRD : %d\n", lReal->GetTRDprimaryParticles());

  Int_t colrange = 2;
  Int_t rowrange = 1;

  for(Int_t parno=0; parno<nParticles; parno++) {
    TParticle *Particle = (TParticle *)ParticleArray->At(parno);
    Float_t lPt = Particle->Pt();
    if(lPt >= LPTMIN) {
      AliTRDgtuRealTrack *RT = lReal->GetRealTrack(parno);
      if(RT->GetTrackID() != -1) {
	if(parno<nPrimaryParticles) {
	  for(Int_t plane=0; plane<6; plane++) {
	    if(RT->GetExStartColumn(plane) != -1.0) {
	      Float_t z1 = RT->GetExStartPadrow(plane);
	      Float_t z2 = RT->GetExEndPadrow(plane);
              Int_t rtDet = TRDgeometry->GetDetector(plane, RT->GetChamber(), RT->GetSector());
              Float_t rttheta = padrow2angle(TRDgeometry, rtDet, RT->GetExStartPadrow(plane));
	      h1_1->Fill(rttheta, 1);
	      if((Int_t)z1 != (Int_t)z2) {
                h1_2->Fill(rttheta, 1);
		h1_3->Fill(rttheta, 1);
	      }
	      // search for digits
	      Int_t chamber  = RT->GetChamber();
	      Int_t sector   = RT->GetSector();
	      Int_t colMax   = TRDgeometry->GetColMax(plane);
	      Int_t rowMax   = TRDgeometry->GetRowMax(plane, chamber, sector);
	      Int_t timeMax  = TRDgeometry->GetTimeMax();
	      for(Int_t time=0; time<timeMax; time++) {
		Int_t colt = (Int_t)(getstartcol(TRDgeometry, RT, plane)
				     + (time * getanglecol(TRDgeometry, RT, plane)));
		for(Int_t searchcol=colt-colrange; searchcol<=colt+colrange; searchcol++) {
		  if((searchcol<0) || (searchcol>=colMax)) continue;
		  for(Int_t trsel=0; trsel<3; trsel++) {
		    //if(parno != DigitsManager->GetTrack(trsel,row,col,time,iDet);
		  }
		}
	      }
	    }
	  } // end plane
	} // end primary
      } // end realtrack
    } // end min pt
  } // end particle number

  delete lReal;

  } //event

  /////////////////////////////////////////////////////////////////
    HEAD("DRAW HISTOGRAMS");
  /////////////////////////////////////////////////////////////////

  HEAD("DRAW HISTOGRAMS");
  c1->cd();
  phisto1->cd(1);  /*gPad->SetLogy()*/; h1_1->Draw();
  phisto1->cd(2);  /*gPad->SetLogy()*/; h1_2->Draw();
  phisto1->cd(3);  /*gPad->SetLogy()*/; h1_3->Divide(h1_1); h1_3->Draw();

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
