/*
$Log: AliTRDnh_test_new.C,v $
Revision 1.6  2001/04/02 14:51:37  schneide
Use of global header file for fit settings

Revision 1.5  2001/02/18 17:56:44  schneide
changes for new AliTRDsim (AliTRDfit) version

Revision 1.4  2001/02/14 17:42:45  schneide
Update to new root file for full multiplicity

Revision 1.3  2001/01/26 13:17:42  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "test_new"

void AliTRDnh_test_new()
{
  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
  ////// SET CONSTANTS AND WORKING RANGE
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  HEAD("SET CONSTANTS AND WORKING RANGE");

  Int_t lEventMin   =  0; Int_t lEventMax   =  0; // Event

  Int_t lPlaneMin   =  0; Int_t lPlaneMax   =  5; // Plane
  Int_t lSectorMin  =  0; Int_t lSectorMax  = 14; // Sector
  Int_t lChamberMin =  0; Int_t lChamberMax =  4; // Chamber

  printf("AliRoot file  : %s\n\n", ALIFILE);
  printf("Event range   : %3d .. %3d\n", lEventMin,   lEventMax);
  printf("Plane range   : %3d .. %3d\n", lPlaneMin,   lPlaneMax);
  printf("Sector range  : %3d .. %3d\n", lSectorMin,  lSectorMax);
  printf("Chamber range : %3d .. %3d\n", lChamberMin, lChamberMax);

  /////////////////////////////////////////////////////////////////
  ////// INITIALIZE ALIROOT ENVIRONMENT
  /////////////////////////////////////////////////////////////////

  HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  for(Int_t event=lEventMin; event<=lEventMax; event++) {

  /////////////////////////////////////////////////////////////////
  ////// GET NEXT EVENT
  /////////////////////////////////////////////////////////////////

  HEAD("GET NEXT EVENT");
  printf("Current event number: %d\n", event);
  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(event);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  //TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
  ////// READ REAL ROOT FILE
  /////////////////////////////////////////////////////////////////

  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  printf("Read AliTRDgtuReal root file \n");
  Char_t treename[10];
  sprintf(treename, "Real%d", event);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  lReal->Dump();

  /////////////////////////////////////////////////////////////////
    HEAD("TESTING");
  /////////////////////////////////////////////////////////////////

    printf("Timebins            : %d\n", TRDgeometry->GetTimeMax());

    for(Int_t plane=0; plane<TRDgeometry->Nplan(); plane++) {
      printf("ColPadSize(plane %d) : %f (%d pads)\n", plane, TRDgeometry->GetColPadSize(plane), TRDgeometry->GetColMax(plane));
    }

    for(Int_t plane=0; plane<TRDgeometry->Nplan(); plane++) {
      printf("RowPadSize(plane %d) : %f (sector 13, chamber 2)\n", plane, TRDgeometry->GetRowPadSize(plane, 2, 13));
    }

    printf("\nNumber of Padrows (z ->, r ^)\n");
    for(Int_t plane=0; plane<=lPlaneMax; plane++) {
      for(Int_t chamber=0; chamber<=lChamberMax; chamber++) {
	printf("%3d ", TRDgeometry->GetRowMax(plane, chamber, 13));
      }
      printf("\n");
    }

    printf("\nparticles: %d\n", nParticles);
    printf("primary particles: %d\n", nPrimaryParticles);
    printf("particles in TRD: %d\n", lReal->GetTRDparticles());
    printf("primary particles in TRD: %d\n", lReal->GetTRDprimaryParticles());

    Int_t segment[6];
    for(Int_t plane=0; plane<=lPlaneMax; plane++) segment[plane] = 0;
    Int_t segments=0;
    for(Int_t parno=0; parno<nParticles; parno++) {
      AliTRDgtuRealTrack *RT = lReal->GetRealTrack(parno);
      for(Int_t plane=0; plane<=lPlaneMax; plane++) {
	if(RT->GetAmplitudeSum(plane)) {
	  segments++;
	  segment[plane]++;
	}
      }
    }
    for(Int_t plane=0; plane<=lPlaneMax; plane++)
      printf("track segments (plane %d) : %d\n", plane, segment[plane]);
    printf("track segments (all)     : %d\n", segments);

    printf("\n");
    for(Int_t plane=0; plane<=lPlaneMax; plane++)
      printf("radius (plane %d) : %f\n", plane, TRDgeometry->GetTime0(plane));

    TStopwatch timer;
    timer.Start();
    Double_t cputime = 0.0;
    printf("\nloop over all particles ...\n");
    for(Int_t parno=0; parno<nParticles; parno++) {
      TParticle *Particle = (TParticle *)gAlice->Particle(parno);
      if(!(parno%10000)) {
	Double_t dtime = timer.CpuTime();
	printf("%6d: CPU time %7.3f\n", parno, dtime);
	cputime += dtime;
	timer.Reset();
	timer.Start();
      }
    }

    cputime += timer.CpuTime();
    printf("========================\n");
    printf("%6d: CPU time %7.3f\n", nParticles, cputime);

  } // end event

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
