/*
$Log: AliTRDnh_visualfit.C,v $
Revision 1.4  2001/04/02 14:51:37  schneide
Use of global header file for fit settings

Revision 1.3  2001/03/20 14:07:57  schneide
update for siemens1 installation

Revision 1.2  2001/02/08 09:30:13  schneide
Remove of static array size for RealTracks

Revision 1.1  2001/01/26 13:27:56  schneide
Save all histograms and added macros for .ps and .gif generation

*/

#include "global.h"

#define MODULE "visualfit"

void AliTRDnh_visualfit()
{
  cout << endl;
  cout << "//////////////////////////////////////////////////////////" << endl;
  cout << "//                                                      //" << endl;
  cout << "//  ALIROOT FIT DEBUGGER                                //" << endl;
  cout << "//                                                      //" << endl;
  cout << "//////////////////////////////////////////////////////////" << endl << endl;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  Char_t TitleString[120];
  sprintf(TitleString, "AliTRDnh_%s (%s, %s)", MODULE, CONFIGURATION, DATE);

  Int_t lEvent        = 0;
  Int_t lChi2Max      = 500;

  Int_t lPlane    =   4; // set plane in any case
  Int_t lTrackID  =  -1; // set track number or -1 for 

  Int_t lSector   =  12; // given chamber
  Int_t lChamber  =   2;
  Int_t lPadrow   =  11;

  printf("  alifile    : %s\n", ALIFILE);
  printf("  realfile   : %s\n", REALFILE);
  printf("  event      : %d\n", lEvent);
  printf("  plane      : %d\n", lPlane);
  printf("  min. pt    : %4.2f\n", LPTMIN);
  if(lTrackID > -1)
    printf("  track ID   : %d\n", lTrackID);
  else {
    printf("  sector     : %d\n", lSector);
    printf("  chamber    : %d\n", lChamber);
    printf("  padrow     : %d\n", lPadrow);
  }

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load(TRDFITLIB);
  gSystem->Load(TRDGTULIB);
  gROOT->LoadMacro("stat_macros.C");

  AliTRDgtuGlobal::TMUwl = 0;

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(ALIFILE);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << ALIFILE << endl;
    gafl = new TFile(ALIFILE);
  }
  else {
    cout << ALIFILE << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", lEvent);
  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(lEvent);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  //TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  // READ REAL ROOT FILE

  printf("Read AliTRDgtuReal root file\n");
  AliTRDgtuReal *lReal = new AliTRDgtuReal(nParticles, nPrimaryParticles);

  TFile *fp = new TFile(REALFILE);
  Char_t treename[10];
  sprintf(treename, "Real%d", lEvent);
  lReal->Read(treename);
  fp->Close();
  delete fp;

  if((lReal->GetParticles() == nParticles) && (lReal->GetPrimaryParticles() == nPrimaryParticles))
    printf("AliTRDgtuReal root file seems to be ok\n");
  else
    printf("*** WARNING: number of particles of root files do not match\n");

  printf("\n");
  lReal->Dump();
  printf("  particles in TRD         : %d\n", lReal->GetTRDparticles());
  printf("  primary particles in TRD : %d\n", lReal->GetTRDprimaryParticles());

  /////////////////////////////////////////////////////////////////
    HEAD("DEBUGGING");
  /////////////////////////////////////////////////////////////////

  if(lTrackID > -1) {
    AliTRDgtuRealTrack *RT = lReal->GetRealTrack(lTrackID);
    if(!RT->GetDigitsSum(lPlane)) {
      printf("*** ERROR: sorry, there is no track %d in plane %d\n\n", lTrackID, lPlane);
      lTrackID = -1;
    }
    else {
      lSector = RT->GetSector();
      lChamber = RT->GetChamber();
      lPadrow = RT->GetStartPadrow(lPlane);
    }
  }

  printf("  track ID           : %5d\n", lTrackID);
  printf("  plane              : %5d\n", lPlane);
  printf("  sector             : %5d\n", lSector);
  printf("  chamber            : %5d\n", lChamber);
  printf("  padrow             : %5d\n\n", lPadrow);
  printf("  exact lines        : red\n");
  printf("  fit lines          : blue\n");
  printf("  rejected fit lines : green\n\n");

  /////////////////////////////////////////////////////////////////
  ////// HISTOGRAMMS
  /////////////////////////////////////////////////////////////////

  Int_t lRowMax  = TRDgeometry->GetRowMax(lPlane, lChamber, lSector);
  Int_t lColMax  = TRDgeometry->GetColMax(lPlane);
  Int_t lTimeMax = TRDgeometry->GetTimeMax();
  Int_t lDet     = TRDgeometry->GetDetector(lPlane, lChamber, lSector);

  AliTRDgtuVisual *vis = new AliTRDgtuVisual();
  vis->Init3D();
  vis->DrawBlock3D();

  /////////////////////////////////////////////////////////////////
  ////// DATA GENERATION
  /////////////////////////////////////////////////////////////////

  for(Int_t plane=0; plane<6; plane++) {
    Int_t lRowMax = TRDgeometry->GetRowMax(plane, lChamber, lSector);
    for(Int_t padrow=0; padrow<lRowMax; padrow++) {
      printf("working on pla %d, row %2d\n", plane, padrow);
      // Falk's fit
      AliTRDfitPadrow *fitPadrow = new AliTRDfitPadrow(plane, lSector, lChamber, padrow);
      fitPadrow->SetCut_off_chi(lChi2Max);
      fitPadrow->SetDigitsManager(DigitsManager);
      fitPadrow->SetTRDgeometry(TRDgeometry);
      fitPadrow->SetHitsMin(LSP);
      fitPadrow->SetThreshold(LTH);
      fitPadrow->Fit();
      for(Int_t fitcol=0; fitcol<128; fitcol++) {
	AliTRDfitTracklet *fitTracklet = fitPadrow->GetTracklet(fitcol);
	Int_t MainTrack = fitTracklet->GetfMainTrack();
	if(MainTrack == -1) continue;
        if(fitTracklet->GetFEject() != 0) continue;
	if(gAlice->Particle(MainTrack)->Pt() < 0.0) continue;
	vis->DrawTracklet3D(TRDgeometry, fitTracklet, plane, lChamber, lSector, padrow);
      }
    }
  }

  delete fitPadrow;
  delete lReal;

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  cout << "BYE." << endl << endl;
}
