void AliTRDstatistic()
{
  gROOT->LoadMacro("getDigitsManager.C");
  gROOT->LoadMacro("dialogs.C");

  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfit");

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  ////// CONSTANTS //////
  const Char_t *alifile     = "~schneide/data/galice_nh.root";
  const Int_t   iSec        = 0;
  const Int_t   iCha        = 2;
  const Int_t   iDefaultRow = 1;
  const Int_t   iOffMax     = 128;
  const Int_t   iAngMax     = 256;

  const Int_t   iSecMin = 0;
  const Int_t   iSecMax = 17;
  const Int_t   iChaMin = 2;
  const Int_t   iChaMax = 2;
  const Int_t   iPlaMin = 0;
  const Int_t   iPlaMax = 5;

  ////// READ ALIROOT FILE //////
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  GET DIGITS FROM ALIROOT EVENT FILE                --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDdigitsManager *DigitsManager;
  AliTRDv1 *TRD;
  TClonesArray *ParticleArray;
  AliTRDgeometry *TRDgeometry;
  if(!(getDigitsManager(alifile, &DigitsManager, &TRD, &ParticleArray))) {
    cout << "ERROR: cannot get DigitsManager" << endl;
    break;
  }
  TRDgeometry = TRD->GetGeometry();

  ////// INITIALIZE ENVIRONMENT //////
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  INITIALIZE SIMULATION ENVIRONMENT                 --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;

  cout << "Current Block    : Sector " << iSec << "; Chamber " << iCha << endl;
  for(Int_t plane = 0; plane < 6; plane++) {
    Int_t colMax  = TRDgeometry->GetColMax(plane);
    Int_t rowMax  = TRDgeometry->GetRowMax(0,iCha,iSec);
    Int_t timeMax = TRDgeometry->GetTimeMax();
    printf("Geometry plane %d : Columns %3d; Rows %2d; Timebins %2d\n", plane, colMax, rowMax, timeMax);
  }
  TArrayI *StatAr = new TArrayI(ParticleArray->GetLast()+1); // array with all particles
  StatAr->Reset();

  ////// STATISTICS //////
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  STARTING SOME STATISTICS                          --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;

  cout << "Number of all Tracks : " << ParticleArray->GetLast()+1 << endl << endl;
  cout << "*** Create array of tracks out of TRD digits" << endl;
  AliTRDdigit *Digit;
  Int_t lTrack1, lTrack2, lTrack3, dt1, dt2, dt3;
  dt1 = dt2 = dt3 = 0;
  for(Int_t sector = iSecMin; sector <= iSecMax; sector++) {
    for(Int_t chamber = iChaMin; chamber <= iChaMax; chamber++) {
      for(Int_t plane = iPlaMin; plane <= iPlaMax; plane++) {
        printf(".");fflush(stdout);
        Int_t colMax = TRDgeometry->GetColMax(plane);
        Int_t iDet = TRDgeometry->GetDetector(plane,chamber,sector);
        for(Int_t row = 0; row < rowMax; row++) {
          for(Int_t col = 0;  col < colMax ;  col++) {
            for(Int_t time = 0; time < timeMax; time++) {
              lTrack1 = DigitsManager->GetTrack(0,row,col,time,iDet);
              if(lTrack1 > -1) {
                dt1++;
                StatAr->AddAt(1,lTrack1);
                lTrack2 = DigitsManager->GetTrack(1,row,col,time,iDet);
                if(lTrack2 > -1 ) {
                  dt2++; dt1--;
                  StatAr->AddAt(1,lTrack2);
                  lTrack3 = DigitsManager->GetTrack(2,row,col,time,iDet);
                  if(lTrack3 > -1 ) {
                    dt3++; dt2--;
                    StatAr->AddAt(1,lTrack3);
		  }
		}
	      }
	    }
	  }
	}
      }
    }
  }
  printf("\n");
  Int_t tracks = 0;
  Int_t primtracks = 0;
  for(Int_t par = 0; par <= ParticleArray->GetLast(); par++) {
    if(StatAr->At(par)) tracks++;
    if((StatAr->At(par)) && (par < 1500)) primtracks++;
  }
  printf("There are %d tracks within current block\n", tracks);
  printf("There are %d primary tracks within current block\n", primtracks);
  printf("There are %d digits with tracks\n", dt1+dt2+dt3);
  printf("  (digits with 1 track  : %6d)\n", dt1);
  printf("  (digits with 2 tracks : %6d)\n", dt2);
  printf("  (digits with 3 tracks : %6d)\n", dt3);

  // Pt within TRD
  TParticle *Particle;
  char ctitle[120];
  cout << "*** Draw histogram with Pt within current Block of TRD" << endl;
  sprintf(ctitle, "Pt distribution within TRD", iSec, iCha);
  TCanvas *c1 = new TCanvas("c1", ctitle, 100, 10, 800, 600);
  c1->Draw();
  TH1F *h1 = new TH1F("h1", ctitle, 100, 0.0, 5.0);
  h1->SetXTitle("GeV/c"); h1->SetYTitle("particles");
  for(Int_t par = 0; par <= ParticleArray->GetLast(); par++) {
    if(StatAr->At(par)) {
      Particle = (TParticle *) ParticleArray->At(par);
      h1->Fill(Particle->Pt(), 1);
    }
  }
  h1->Draw();
  //c1->SaveAs("sim_res3_3.gif");

  // high momentum Pt
  Int_t highpt = 0;
  TArrayI *HighPtArray = new TArrayI();
  cout << "*** Search for particles with high Pt within current block" << endl << endl;
  Float_t minpt = GetFloatDialog("Give hith Pt limit:", 2.5);
  for(Int_t par = 0; par <= ParticleArray->GetLast(); par++) {
    if(StatAr->At(par)) {
      Particle = (TParticle *) ParticleArray->At(par);
      if(Particle->Pt() >= minpt) {
        highpt++;
        HighPtArray->Set(highpt);
        HighPtArray->AddAt(par, highpt-1);
      }
    }
  }
  cout << endl << "--------------------------------------------------------" << endl << endl;
  printf("There are %d particles within current block and Pt > %4.2f\n", HighPtArray->GetSize(), minpt);
  for(Int_t ipar = 0; ipar < HighPtArray->GetSize(); ipar++) {
    Particle = (TParticle *) ParticleArray->At(HighPtArray->At(ipar));
    printf("particle %5d has a Pt of %4.2f\n", HighPtArray->At(ipar), Particle->Pt());
  }

  // location of high Pt particles
  for(Int_t ipar = 0; ipar < HighPtArray->GetSize(); ipar++) {
    Int_t parid = HighPtArray->At(ipar);
    cout << endl << "--------------------------------------------------------" << endl << endl;
    printf("*** Particle %d\n\n", parid);
    printf("    Plane     Row  Column    Bins\n");
    for(Int_t plane = 0; plane < 6; plane++) {
      Int_t colMax = TRDgeometry->GetColMax(plane);
      Int_t iDet = TRDgeometry->GetDetector(plane,iCha,iSec);
      for(Int_t row = 0; row < rowMax; row++) {
        for(Int_t col = 0;  col < colMax ;  col++) {
          Int_t bins = 0;
          for(Int_t time = 0; time < timeMax; time++) {
            if(parid == DigitsManager->GetTrack(0,row,col,time,iDet)) bins++;
          }
          if(bins) printf("        %d      %2d     %3d      %2d\n", plane, row, col, bins);
        }
      }
    }
  }
  cout << endl << "--------------------------------------------------------" << endl << endl;

  // involved rows of specified particle
  AliTRDdigit *Digit;
  cout << "*** Create Hitogram for involved rows of one particle" << endl;
  Int_t parid = GetIntegerDialog("Give Particle ID", HighPtArray->At(0));
  sprintf(ctitle, "Particle %d", parid);
  TCanvas *c2 = new TCanvas("c2", ctitle, 150, 60, 600, 400);
  c2->Draw();
  TH1F *h2 = new TH1F("h2", ctitle, rowMax, -0.5, rowMax-0.5);
  h2->SetXTitle("row"); h2->SetYTitle("sum of digits");
  Int_t digs = 0;
  for(Int_t plane = 0; plane < 6; plane++) {
    printf(".");fflush(stdout);
    Int_t colMax = TRDgeometry->GetColMax(plane);
    Int_t iDet = TRDgeometry->GetDetector(plane,iCha,iSec);
    for(Int_t row = 0; row < rowMax; row++) {
      for(Int_t col = 0;  col < colMax ;  col++) {
        for(Int_t time = 0; time < timeMax; time++) {
          if(parid == DigitsManager->GetTrack(0,row,col,time,iDet)) {
            Digit = DigitsManager->GetDigit(row,col,time,iDet);
            Int_t iAmp = Digit->GetAmp();
            if(iAmp > 255) iAmp = 255;
            h2->Fill(row, iAmp);
            delete Digit;
	  }
        }
      }
    }
  }
  printf("\r*** Draw histogram for particle %d\n", parid);
  h2->Draw();

  ////// FINISHED //////
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
