void AliTRDtest()
{
  gROOT->LoadMacro("getDigitsManager.C");
  gROOT->LoadMacro("dialogs.C");

  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDgtu");
  gSystem->Load("$(ALICE_ROOT)/lib/tgt_$(ALICE_TARGET)/libTRDfit");

  cout << endl;
  cout << "////////////////////////////////////////////////////////" << endl;
  cout << "//                                                    //" << endl;
  cout << "//  ALIROOT AliTRDstatistic GENERATION                //" << endl;
  cout << "//                                                    //" << endl;
  cout << "////////////////////////////////////////////////////////" << endl << endl;

  ////// CONSTANTS //////
  const Char_t *alifile     = "~schneide/data/galice.root";
  const Int_t   iSec        = 13;
  const Int_t   iCha        = 2;
  const Int_t   iDefaultRow = 1;
  const Int_t   iOffMax     = 128;
  const Int_t   iAngMax     = 256;

  ////// READ ALIROOT FILE //////
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  GET DIGITS FROM ALIROOT EVENT FILE                --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;
  AliTRDdigitsManager *DigitsManager;
  AliTRDv1 *TRD;
  TClonesArray *ParticleArray;
  AliTRDgeometry *TRDgeometry;
  if(!(getDigitsManager(alifile, &DigitsManager, &TRD, &ParticleArray))) {
    cout << "ERROR: cannot get DigitsManager" << endl;
    break;
  }
  TRDgeometry = TRD->GetGeometry();

  ////// INITIALIZE ENVIRONMENT //////
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  INITIALIZE SIMULATION ENVIRONMENT                 --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;

  cout << "Current Block    : Sector " << iSec << "; Chamber " << iCha << endl;
  for(Int_t plane = 0; plane < 6; plane++) {
    Int_t colMax  = TRDgeometry->GetColMax(plane);
    Int_t rowMax  = TRDgeometry->GetRowMax(0,iCha,iSec);
    Int_t timeMax = TRDgeometry->GetTimeMax();
    printf("Geometry plane %d : Columns %3d; Rows %2d; Timebins %2d\n", plane, colMax, rowMax, timeMax);
  }
  TArrayI *StatAr = new TArrayI(ParticleArray->GetLast()+1); // array with all particles
  StatAr->Reset();

  ////// STATISTICS //////
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "--  STARTING SOME STATISTICS                          --" << endl;
  cout << "--------------------------------------------------------" << endl << endl;

  cout << "Number of all Particles : " << ParticleArray->GetLast()+1 << endl << endl;
  cout << "*** Create array of tracks out of TRD digits" << endl;
  AliTRDdigit *Digit;
  for(Int_t plane = 0; plane < 6; plane++) {
    printf(".");fflush(stdout);
    Int_t colMax = TRDgeometry->GetColMax(plane);
    Int_t iDet = TRDgeometry->GetDetector(plane,iCha,iSec);
    for(Int_t row = 0; row < rowMax; row++) {
      for(Int_t col = 0;  col < colMax ;  col++) {
        for(Int_t time = 0; time < timeMax; time++) {
          Int_t lTrack = DigitsManager->GetTrack(0,row,col,time,iDet);
          if(lTrack > -1) StatAr->AddAt(1,lTrack);
        }
      }
    }
  }
  printf("\r");

  ////// FINISHED //////
  cout << endl;
  cout << "--------------------------------------------------------" << endl;
  cout << "BYE." << endl << endl;
}
