Int_t getDigitsManager(Char_t *alifile, AliTRDdigitsManager **DigitsManager, AliTRDv1 **TRD, TClonesArray **ParticleArray) {

/////////////////////////////////////////////////////////////////////////
//
// macro to aliroot event
//
/////////////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }

  // Event number
  Int_t   nEvent  = 0;

  // Define the objects
  AliTRDgeometry *TRDgeometry;

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(alifile);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << alifile << endl;
    gafl = new TFile(alifile);
  }
  else {
    cout << alifile << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nparticles = gAlice->GetEvent(nEvent);
  if (nparticles <= 0) break;

  // Get the array with the MC-particles
  (*ParticleArray) = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *iTRD;
  iTRD = (AliTRDv1*) gAlice->GetDetector("TRD");
  // Get the pointer to the geometry object
  if (iTRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    TRDgeometry = (iTRD)->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *iDigitsManager = new AliTRDdigitsManager();

  // Read the digits from the file
  cout << "Read digits from file ..." << endl;
  iDigitsManager->ReadDigits();

  // return values
  (*DigitsManager) = iDigitsManager;
  (*TRD) = iTRD;

  cout << endl;
  gafl->Close();
  delete gafl;
  return(1);
}
