void testDigits() {

/////////////////////////////////////////////////////////////////////////
//
// Example macro for the analysis of the TRD digits and the use
// of the AliTRDmatrix class.
//
/////////////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }

  // Input file name
  Char_t *alifile = "~schneide/data/galice.root"; 

  // Event number
  Int_t   nEvent  = 0;

  // Define the objects
  AliTRDv1       *TRD;
  AliTRDgeometry *TRDgeometry;
  AliTRDdigit    *Digit;

  Int_t           track;

  TH1F *hAmp = new TH1F("hAmp","Amplitude",1000,0.0,1000.0);
  TH1F *hSec = new TH1F("hSec","Number of digits vs sector number" ,5,10.5,15.5);
  TH1F *hCha = new TH1F("hCha","Number of digits vs chamber number",5,-0.5, 4.5);
  TH1F *hPla = new TH1F("hPla","Number of digits vs plane number"  ,6,-0.5, 5.5);

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(alifile);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << alifile << endl;
    gafl = new TFile(alifile);
  }
  else {
    cout << alifile << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  // Import the Trees for the event nEvent in the file
  Int_t nparticles = gAlice->GetEvent(nEvent);
  if (nparticles <= 0) break;
  
  // Get the pointer to the detector object
  TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();

  // Read the digits from the file
  DigitsManager->ReadDigits();

  for (Int_t iSec = 12; iSec < 15; iSec++) {
    for (Int_t iCha =  0; iCha <  5; iCha++) {
      for (Int_t iPla =  0; iPla <  6; iPla++) {

        Int_t  rowMax = TRDgeometry->GetRowMax(iPla,iCha,iSec);
        Int_t  colMax = TRDgeometry->GetColMax(iPla);
        Int_t timeMax = TRDgeometry->GetTimeMax();

        // Get the detector number
        Int_t iDet = TRDgeometry->GetDetector(iPla,iCha,iSec); 

        // Loop through the detector pixel
        for (Int_t time = 0; time < timeMax; time++) {
          for (Int_t  col = 0;  col <  colMax;  col++) {
            for (Int_t  row = 0;  row <  rowMax;  row++) {

              Digit = DigitsManager->GetDigit(row,col,time,iDet);
              track = DigitsManager->GetTrack(0,row,col,time,iDet);
        
              Int_t amp = Digit->GetAmp();
              if (amp > 0) {
                hAmp->Fill(amp);
                hSec->Fill(iSec);
                hCha->Fill(iCha);
                hPla->Fill(iPla);
	      }

              delete Digit;

            }
          }
        }

      }
    }
  }

  TCanvas *c1 = new TCanvas("c1","Digits",50,50,900,700);
  c1->Divide(2,2);

  c1->cd(1);
  gPad->SetLogy();
  hAmp->Draw();

  c1->cd(2);
  hSec->Draw();

  c1->cd(3);
  hCha->Draw();

  c1->cd(4);
  hPla->Draw();

}
