void testParticles(Int_t evNumber1=0, Int_t evNumber2=0) 
{

  Char_t *alifile = "~schneide/data/galice.root";

  // Dynamically link some shared libs                    
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }

  // Connect the Root Galice file containing Geometry, Kine and Hits
  TFile *file = (TFile*)gROOT->GetListOfFiles()->FindObject(alifile);
    
  if (!file) {
    printf("\n Creating %s \n", alifile);
    file = new TFile(alifile);
  } 
  else {
    printf("\n %s found in file list", alifile);
  }
  file->ls();

  //TDatabasePDG*  DataBase = new TDatabasePDG();
    
  // Get AliRun object from file or create it if not on file
  if (!gAlice) {
    gAlice = (AliRun*)(file->Get("gAlice"));
    if (gAlice) 
      printf("AliRun object found on file\n");
    else        
      printf("Error reading AliRun object from file\n");
    if (!gAlice) {
      printf("\n create new gAlice object");
      gAlice = new AliRun("gAlice","Alice test program");
    }
  }
    
  //  Create some histograms
  TH1F *thetaH   =  new TH1F("thetaH","Theta distribution"         ,180,   0,180);
  TH1F *phiH     =  new TH1F("phiH","Phi distribution"             ,180,-180,180);
  TH1F *etaH     =  new TH1F("etaH","Pseudorapidity"               , 60,  -6,  6);
  TH1F *yH       =  new TH1F("yH","Rapidity distribution"          , 60,  -6,  6);
  TH1F *eH       =  new TH1F("eH","Energy distribution"            ,100,   0,100);
  TH1F *eetaH    =  new TH1F("eetaH","Pseudorapidity"              , 60,  -6,  6);
  TH1F *ptH      =  new TH1F("ptH","Pt distribution"               ,150,   0, 15);

  TH1F *thetaCH  =  new TH1F("thetaCH","Theta distribution charged",180,   0,180);
  TH1F *phiCH    =  new TH1F("phiCH","Phi distribution charged"    ,180,-180,180);
  TH1F *etaCH    =  new TH1F("etaCH","Pseudorapidity charged"      , 60,  -6,  6);
  TH1F *yCH      =  new TH1F("yCH","Rapidity distribution charged" , 60,  -6,  6);
  TH1F *eCH      =  new TH1F("eCH","Energy distribution charged"   ,100,   0,100);
  TH1F *eetaCH   =  new TH1F("eetaCH","Pseudorapidity charged"     , 60,  -6,  6);
  TH1F *ptCH     =  new TH1F("ptCH","Pt distribution charged"      ,150,   0, 15);

  //   Loop over events 
  for (Int_t nev = 0; nev <= evNumber2; nev++) {

    cout << " Event number = " << nev << endl;

    Int_t nparticles = gAlice->GetEvent(nev);
    if (nev < evNumber1) continue;
    if (nparticles <= 0) return;

    TClonesArray *fPartArray = gAlice->Particles();       
    Int_t npart = fPartArray->GetEntriesFast();
    cout << " Number of particles = " << npart << endl;

    // Loop over all particles     
    for (Int_t part = 0; part < npart; part++) {

      TParticle *MPart = (TParticle*) fPartArray->UncheckedAt(part);

      Int_t mpart   = MPart->GetPdgCode();

      // Take out RICH cherenkovs
      if (mpart > 10000000) continue;

      TParticlePDG *PDG = MPart->GetPDG();
      if (!PDG) continue;

      Int_t child1  = MPart->GetFirstDaughter();
      Int_t child2  = MPart->GetLastDaughter();	
      Int_t mother  = MPart->GetFirstMother();	   
	    
      Float_t Pt    = MPart->Pt();
      Float_t E     = MPart->Energy();
      Float_t Pz    = MPart->Pz();
      Float_t Py    = MPart->Py();
      Float_t Px    = MPart->Px();
      Float_t pT    = TMath::Sqrt(Px*Px+Py*Py);
      Float_t theta = MPart->Theta();
      Float_t phi   = MPart->Phi()-TMath::Pi();
      Float_t eta   = -TMath::Log(TMath::Tan(theta/2.));
      Float_t y     = TMath::Log((E+Pz)/(E-Pz+1.e-13));

      thetaH->Fill(theta*180./TMath::Pi(),1.);
      phiH->Fill(phi*180./TMath::Pi(),1.);
      etaH->Fill(eta,1.);    
      eetaH->Fill(eta,E);    
      yH->Fill(y,1.);      
      eH->Fill(E,1.);      
      ptH->Fill(pT,1.);     

      if (PDG->Charge() != 0) {

        thetaCH->Fill(theta*180./TMath::Pi(),1.);
        phiCH->Fill(phi*180./TMath::Pi(),1.);
        etaCH->Fill(eta,1.);    
        eetaCH->Fill(eta,E);    
        yCH->Fill(y,1.);      
        eCH->Fill(E,1.);      
        ptCH->Fill(pT,1.);     

      }

   }

 }

 etaH->Scale(5.0);
 etaCH->Scale(5.0);
 eetaCH->Scale(5.0);
    
 //Create a canvas, set the view range, show histograms
 TCanvas *c1 = new TCanvas("c1","Canvas 1",400,10,600,900);
 c1->Divide(2,3);

 c1->cd(1);
 gPad->SetLogy();
 ptH->SetLineColor(9);
 ptH->SetLineWidth(4);
 ptH->Draw();  
 ptCH->SetLineColor(2);
 ptCH->SetLineWidth(4);
 ptCH->SetLineStyle(2);
 ptCH->Draw("SAME");

 c1->cd(2); 
 etaH->SetLineColor(9);
 etaH->SetLineWidth(4);
 etaH->Draw(); 
 etaCH->SetLineColor(2);
 etaCH->SetLineWidth(4);
 etaCH->SetLineStyle(2);
 etaCH->Draw("SAME");

 c1->cd(3); 
 yH->SetLineColor(9);
 yH->SetLineWidth(4);
 yH->Draw();   
 yCH->SetLineColor(2);
 yCH->SetLineWidth(4);
 yCH->SetLineStyle(2);
 yCH->Draw("SAME");

 c1->cd(4); 
 gPad->SetLogy();
 eH->SetLineColor(9);
 eH->SetLineWidth(4);
 eH->Draw();   
 eCH->SetLineColor(2);
 eCH->SetLineWidth(4);
 eCH->SetLineStyle(2);
 eCH->Draw("SAME");

 c1->cd(5); 
 phiH->SetLineColor(9);
 phiH->SetLineWidth(4);
 phiH->Draw();   
 phiCH->SetLineColor(2);
 phiCH->SetLineWidth(4);
 phiCH->SetLineStyle(2);
 phiCH->Draw("SAME");

 c1->cd(6); 
 thetaH->SetLineColor(9);
 thetaH->SetLineWidth(4);
 thetaH->Draw(); 
 thetaCH->SetLineColor(2);
 thetaCH->SetLineWidth(4);
 thetaCH->SetLineStyle(2);
 thetaCH->Draw("SAME");

}







