/**************************************************************************
 * Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 *                                                                        *
 * Author: The ALICE Off-line Project.                                    *
 * Contributors are mentioned in the code where appropriate.              *
 *                                                                        *
 * Permission to use, copy, modify and distribute this software and its   *
 * documentation strictly for non-commercial purposes is hereby granted   *
 * without fee, provided that the above copyright notice appears in all   *
 * copies and that both the copyright notice and this permission notice   *
 * appear in the supporting documentation. The authors make no claims     *
 * about the suitability of this software for any purpose. It is          *
 * provided "as is" without express or implied warranty.                  *
 **************************************************************************/

/*
$Log:$
*/

///////////////////////////////////////////////////////////////////////////
//                                                                       //
//  TRAP simulation -  class                                             //
//  This class represents one TRAP module with 21 independent input      //
//  channels                                                             //
//                                                                       //
//  module: (TRDtrap) TRAP simulation model      author: Rolf Schneider  //
//                                                                       //
///////////////////////////////////////////////////////////////////////////

#include <iostream>
#include "AliTRDtrapConst.h"
#include "AliTRDgeometry.h"
#include "AliTRDtrap.h"

ClassImp(AliTRDtrap)

Int_t AliTRDtrap::fDebug = WL_NONE;

//_________________________________________________________________________
AliTRDtrap::AliTRDtrap():TObject()
{
  //
  //  AliTRDtrap default constructor
  //

  fChamber   = XXX;
  fMCM       = XXX;
  fPadrow    = XXX;
  fPlane     = XXX;
  fSector    = XXX;

  fChannels  = 18;
  fFilter    = NULL;

}

//_________________________________________________________________________
AliTRDtrap::AliTRDtrap(Int_t iPlane, Int_t iSector, Int_t iChamber, Int_t iPadrow, Int_t iMCM):TObject()
{
  //
  //  AliTRDtrap default constructor with identification
  //

  fChamber   = iChamber;
  fMCM       = iMCM;
  fPadrow    = iPadrow;
  fPlane     = iPlane;
  fSector    = iSector;

  fChannels  = 18;
  fFilter    = NULL;

}

//_________________________________________________________________________
AliTRDtrap::~AliTRDtrap()
{
  //
  //  AliTRDtrap default destructor
  //

  if(fFilter) delete fFilter;

}

//_________________________________________________________________________
void AliTRDtrap::Init()
{
  //
  //  Initialize the trap instances:
  //    Filter ...
  //

  if(!fFilter) fFilter = new TObjArray(fChannels+3);

  for(Int_t i=0; i<fChannels+3; i++) {
    if(!(fFilter->At(i))) {
      TObject *lFilter = new AliTRDtrapFilter(fPlane, fSector, fChamber, fPadrow, fMCM, i);
      fFilter->AddAt(lFilter, i);
    }
  }
  for(Int_t i=0; i<fChannels+3; i++) {
    AliTRDtrapFilter *lFilter = (AliTRDtrapFilter *)fFilter->At(i);
    lFilter->Init();
    if(i>0) lFilter->SetFilterLeft(fFilter->At(i-1));
    if(i<fChannels+3-1) lFilter->SetFilterRight(fFilter->At(i+1));
  }

}

