#ifndef ALITRDTRAPFILTER_H
#define ALITRDTRAPFILTER_H
/* Copyright(c) 1998-1999, ALICE Experiment at CERN, All rights reserved. *
 * See cxx source for full Copyright notice                               */

/* $Id$ */

enum ARRAY_TYPE {ADC, TAIL, CT, NL, PD, GAIN};

#include <TObject.h>
#include <TArrayI.h>

class AliTRDtrapFilter : public TObject {

  public:

    AliTRDtrapFilter();
    AliTRDtrapFilter(Int_t iPlane, Int_t iSector, Int_t iChamber, Int_t iPadrow, Int_t iMCM, Int_t iChannel);
    virtual ~AliTRDtrapFilter();
    void     CrosstalkCancellation();
    void     GainCorrection();
    Int_t    GetAlpha_l() const { return fAlpha_l; }
    Int_t    GetC0() const { return fC0; }
    Int_t    GetC1() const { return fC1; }
    Int_t    GetC2() const { return fC2; }
    Int_t    GetC3() const { return fC3; }
    Int_t    GetC4() const { return fC4; }
    Int_t    GetChamber() const { return fChamber; }
    Int_t    GetChannel() const { return fChannel; }
    Int_t    GetCtPed() const { return fCtPed; }
    TObject *GetFilterLeft() const { return fFilterLeft; }
    TObject *GetFilterRight() const { return fFilterRight; }
    Int_t    GetGainFactor() const { return fGainFactor; }
    Int_t    GetGainPedestal() const { return fGainPedestal; }
    Int_t    GetLambda_l() const { return fLambda_l; }
    Int_t    GetLambda_s() const { return fLambda_s; }
    Int_t    GetMCM() const { return fMCM; }
    Int_t    GetNLped(Int_t iSector) const { return fNLped->At(iSector); }
    Int_t    GetPadrow() const { return fPadrow; }
    Int_t    GetPedestal() const { return fPedestal; }
    Int_t    GetPedestalDyn() const { return fPedestalDyn; }
    Int_t    GetPlane() const { return fPlane; }
    Int_t    GetSector() const { return fSector; }
    Int_t    GetTailPed() const { return fTailPed; }
    Int_t    GetTimeMax() const { return fTimeMax; }
    Int_t    GetValue(ARRAY_TYPE iType, Int_t iTimebin);
    void     Info();
    void     Init();
    void     NonLinearityCorrection();
    void     OutputValues(ARRAY_TYPE iType);
    void     PedestalCorrection();
    Int_t    ReadFilter(Char_t *iFilename);
    void     SetAlpha_l(Int_t iAlpha_l) { fAlpha_l = iAlpha_l; }
    void     SetC0(Int_t iC0) { fC0 = iC0; }
    void     SetC1(Int_t iC1) { fC1 = iC1; }
    void     SetC2(Int_t iC2) { fC2 = iC2; }
    void     SetC3(Int_t iC3) { fC3 = iC3; }
    void     SetC4(Int_t iC4) { fC4 = iC4; }
    void     SetChamber(Int_t iChamber) { fChamber = iChamber; }
    void     SetChannel(Int_t iChannel) { fChannel = iChannel; }
    void     SetFilterLeft(TObject *iFilter) { fFilterLeft = iFilter; }
    void     SetFilterRight(TObject *iFilter) { fFilterRight = iFilter; }
    void     SetGainFactor(Int_t iGainFactor) { fGainFactor = iGainFactor; }
    void     SetGainPedestal(Int_t iGainPedestal) { fGainPedestal = iGainPedestal; }
    void     SetLambda_l(Int_t iLambda_l) { fLambda_l = iLambda_l; }
    void     SetLambda_s(Int_t iLambda_s) { fLambda_s = iLambda_s; }
    void     SetMCM(Int_t iMCM) { fMCM = iMCM; }
    void     SetNLped(Int_t iSector, Int_t iValue) { if(fNLped) fNLped->AddAt(iValue, iSector); }
    void     SetPedestal(Int_t iPedestal) { fPedestal = iPedestal; }
    void     SetPedestalDyn(Int_t iPedestalDyn) { fPedestalDyn = iPedestalDyn; }
    void     SetPlane(Int_t iPlane) { fPlane = iPlane; }
    void     SetSector(Int_t iSector) { fSector = iSector; }
    void     SetTimeMax(Int_t iTimeMax) { fTimeMax = iTimeMax; }
    void     SetValue(ARRAY_TYPE iType, Int_t iTimebin, Int_t value);
    void     TailCancellation();

  private:

    Bool_t   fTRAP1;
    Int_t    fPlane;
    Int_t    fSector;
    Int_t    fChamber;
    Int_t    fPadrow;
    Int_t    fMCM;
    Int_t    fChannel;

    TObject *fFilterLeft; // left neighbour channel
    TObject *fFilterRight; // right neighbour channel
    TArrayI *fADCvalue; // Input ADC values
    TArrayI *fTAILvalue; // values after tail cancellation
    TArrayI *fCTvalue; // values after crosstalk cancellation
    TArrayI *fNLvalue; // values after nonlinearity correction
    TArrayI *fPDvalue; // values after pedestal correction
    TArrayI *fGAINvalue; // values after gain correction
    Int_t    fTimeMax;  // Number of time bins

    TArrayI *fNLped; // pedestal for sectors of input range
    Int_t    fPedestal; // static pedestal value
    Int_t    fPedestalDyn; // dynamic pedestal value (channel)
    Int_t    fGainFactor; // configuration gain factor (channel)
    Int_t    fGainPedestal; // configuration gain pedestal (channel)
    Int_t    fAlpha_l; // tail parameter
    Int_t    fLambda_l; // tail parameter
    Int_t    fLambda_s; // tail parameter
    Int_t    fTailPed; // tail filtered pedestal
    Int_t    fCtPed; // CT filtered pedestal

    Int_t    fC0; // cross talk parameter (signed)
    Int_t    fC1; // cross talk parameter (signed)
    Int_t    fC2; // cross talk parameter (signed)
    Int_t    fC3; // cross talk parameter (signed)
    Int_t    fC4; // cross talk parameter (signed)

  protected:

    ClassDef(AliTRDtrapFilter,1) // Data container for one filter channel

};

#endif
