#define HEAD(title) printf("\n----------------------------------------------------------\n--  %s\n----------------------------------------------------------\n\n", title)
#define STEPLINE() printf("----------------------------------------------------------\n")

void filterAR()
{
  Int_t ADC  = 0; // enum ARRAY_TYPE defined in AliTRDtrapFilter.h
  Int_t TAIL = 1;
  Int_t CT   = 2;
  Int_t NL   = 3;
  Int_t PD   = 4;
  Int_t GAIN = 5;

  /////////////////////////////////////////////////////////////////
    HEAD("SET CONSTANTS AND WORKING RANGE");
  /////////////////////////////////////////////////////////////////

  TStyle *mystyle = new TStyle("Default", "Default Style");
  Int_t ncolors = 1;
  Int_t *colors = NULL;
  mystyle->SetPalette(ncolors, colors);
  mystyle->cd();

  const Char_t *alifile = "~/data/fups.25-01-tlt2.root";
  const Char_t *TitleString = *alifile;

  Int_t lEvent    =   0;

  Int_t lPlane    =   2; // set plane in any case
  Int_t lTrackID  = 7149; // set track number or -1 for 

  Int_t lSector   =   0; // given chamber
  Int_t lChamber  =   0;
  Int_t lPadrow   =   2;
  Int_t lColumn   = 118; // center pad

  printf("  alifile    : %s\n", alifile);
  printf("  event      : %d\n", lEvent);
  printf("  plane      : %d\n", lPlane);
  printf("  sector     : %d\n", lSector);
  printf("  chamber    : %d\n", lChamber);
  printf("  padrow     : %d\n", lPadrow);

  /////////////////////////////////////////////////////////////////
    HEAD("INITIALIZE ALIROOT ENVIRONMENT");
  /////////////////////////////////////////////////////////////////

  // Dynamically link some shared libs
  if (gClassTable->GetID("AliRun") < 0) {
    gROOT->LoadMacro("loadlibs.C");
    loadlibs();
  }
  gSystem->Load("libTRDtrap");

  // Connect the AliRoot file containing Geometry, Kine, Hits, and Digits
  TFile *gafl = (TFile*) gROOT->GetListOfFiles()->FindObject(alifile);
  if (!gafl) {
    cout << "Open the ALIROOT-file " << alifile << endl;
    gafl = new TFile(alifile);
  }
  else {
    cout << alifile << " is already open" << endl;
  }

  // Get AliRun object from file or create it if not on file
  gAlice = (AliRun*) gafl->Get("gAlice");
  if (gAlice)  
    cout << "AliRun object found on file" << endl;
  else
    gAlice = new AliRun("gAlice","Alice test program");

  /////////////////////////////////////////////////////////////////
    HEAD("GET NEXT EVENT");
  /////////////////////////////////////////////////////////////////

  printf("Current event number: %d\n", lEvent);
  // Import the Trees for the event nEvent in the file
  Int_t nParticles = gAlice->GetEvent(lEvent);
  if (nParticles <= 0) break;
  printf("Found %d particles\n", nParticles);

  // Get the array with the MC-particles
  //TClonesArray *ParticleArray = gAlice->Particles();

  // Get the pointer to the detector object
  AliTRDv1 *TRD = (AliTRDv1*) gAlice->GetDetector("TRD");

  // Get the pointer to the geometry object
  if (TRD) {
    cout << "TRD-Detector geometry found in AliRun object" << endl;
    AliTRDgeometry *TRDgeometry = TRD->GetGeometry();
  }
  else {
    cout << "Cannot find the TRD-Detector geometry" << endl;
    break;
  }

  // Create the digits manager
  AliTRDdigitsManager *DigitsManager = new AliTRDdigitsManager();
  DigitsManager->ReadDigits();

  // Get the pointer to the hit tree
  TTree *hitTree = gAlice->TreeH();
  Int_t nPrimaryParticles = (Int_t) hitTree->GetEntries();
  printf("Found %d primary particles\n", nPrimaryParticles);

  /////////////////////////////////////////////////////////////////
    HEAD("DEBUGGING");
  /////////////////////////////////////////////////////////////////

  printf("  track ID           : %5d\n", lTrackID);
  printf("  plane              : %5d\n", lPlane);
  printf("  sector             : %5d\n", lSector);
  printf("  chamber            : %5d\n", lChamber);
  printf("  padrow             : %5d\n\n", lPadrow);
  TParticle *Particle = gAlice->Particle(lTrackID);
  printf("  pt                 : %5.2f\n\n", Particle->Pt());
  printf("  mother             : %d, %d\n", Particle->GetMother(0), Particle->GetMother(1));
  printf("  firstmother        : %d\n", Particle->GetFirstMother());
  printf("  vertex             : (%f, %f, %f)\n", Particle->Vx(), Particle->Vy(), Particle->Vz());
  TParticlePDG *ParticlePDG = Particle->GetPDG();

  /////////////////////////////////////////////////////////////////
    HEAD("SIMULATION");
  /////////////////////////////////////////////////////////////////

  Int_t lRowMax  = TRDgeometry->GetRowMax(lPlane, lChamber, lSector);
  Int_t lColMax  = TRDgeometry->GetColMax(lPlane);
  Int_t lTimeMax = TRDgeometry->GetTimeMax();
  Int_t lDet     = TRDgeometry->GetDetector(lPlane, lChamber, lSector);

  // INITIALIZE ///////////////////////////////////////////////////////////
  AliTRDtrap *trap = new AliTRDtrap(1, 2, 3, 4, 5);
  AliTRDtrap::fDebug = 3;
  trap->Init();
  AliTRDtrapFilter *filter_l = trap->GetFilter(2);
  AliTRDtrapFilter *filter_c = trap->GetFilter(3);
  AliTRDtrapFilter *filter_r = trap->GetFilter(4);

  // GET ADC VALUES ///////////////////////////////////////////////////////////

  for(Int_t coloff=-1; coloff<=+1; coloff++) {
    for(Int_t time=0; time<lTimeMax; time++) {
      Int_t col = lColumn+coloff;
      AliTRDdigit *Digit = DigitsManager->GetDigit(lPadrow, col, time, lDet);
      Int_t lAmp = Digit->GetAmp();
      if(lAmp > 1023) lAmp = 1023;
      if(coloff==-1) filter_l->SetValue(ADC, time, lAmp);
      if(coloff== 0) filter_c->SetValue(ADC, time, lAmp);
      if(coloff==+1) filter_r->SetValue(ADC, time, lAmp);
      delete Digit;
    }
  }

  filter_l->ReadFilter("data/left.kip");
  filter_c->ReadFilter("data/center.kip");
  filter_r->ReadFilter("data/right.kip");
  lTimeMax = filter_c->GetTimeMax();

  // RUN CORRECTION ///////////////////////////////////////////////////////////

  filter_l->NonLinearityCorrection();
  filter_c->NonLinearityCorrection();
  filter_r->NonLinearityCorrection();
  filter_l->PedestalCorrection();
  filter_c->PedestalCorrection();
  filter_r->PedestalCorrection();
  filter_l->GainCorrection();
  filter_c->GainCorrection();
  filter_r->GainCorrection();
  filter_l->TailCancellation();
  filter_c->TailCancellation();
  filter_r->TailCancellation();
  filter_l->CrosstalkCancellation();
  filter_c->CrosstalkCancellation();
  filter_r->CrosstalkCancellation();

  /////////////////////////////////////////////////////////////////
    HEAD("HISTOGRAMS");
  /////////////////////////////////////////////////////////////////
  TCanvas *c1 = new TCanvas("c1", "CT values", 100, 10, 800, 1000);  c1->ToggleEventStatus(); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.97, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, "NonLinearity (black), Tail (blue)"); pltitle1->Draw();
   c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.96);
  phisto1->Draw(); phisto1->Divide(1,3);

  // NonLinearity
  TH1D *h1_l = new TH1D("h1_l", "Left Channel", lTimeMax, -0.5, lTimeMax-0.5);
  TH1D *h1_c = new TH1D("h1_c", "Center Channel", lTimeMax, -0.5, lTimeMax-0.5);
  TH1D *h1_r = new TH1D("h1_r", "Right Channel", lTimeMax, -0.5, lTimeMax-0.5);
  h1_l->SetLineWidth(2); h1_l->SetLineColor(1);
  h1_c->SetLineWidth(2); h1_c->SetLineColor(1);
  h1_r->SetLineWidth(2); h1_r->SetLineColor(1);
  // Tail Cancellation
  TH1D *h2_l = new TH1D("h2_l", "Left Channel", lTimeMax, -0.5, lTimeMax-0.5);
  TH1D *h2_c = new TH1D("h2_c", "Center Channel", lTimeMax, -0.5, lTimeMax-0.5);
  TH1D *h2_r = new TH1D("h2_r", "Right Channel", lTimeMax, -0.5, lTimeMax-0.5);
  h2_l->SetLineWidth(2); h2_l->SetLineColor(4);
  h2_c->SetLineWidth(2); h2_c->SetLineColor(4);
  h2_r->SetLineWidth(2); h2_r->SetLineColor(4);
  // Crosstalk Cancellation
  TH1D *h3_l = new TH1D("h3_l", "Left Channel", lTimeMax, -0.5, lTimeMax-0.5);
  TH1D *h3_c = new TH1D("h3_c", "Center Channel", lTimeMax, -0.5, lTimeMax-0.5);
  TH1D *h3_r = new TH1D("h3_r", "Right Channel", lTimeMax, -0.5, lTimeMax-0.5);
  h3_l->SetLineWidth(2); h3_l->SetLineColor(5);
  h3_c->SetLineWidth(2); h3_c->SetLineColor(5);
  h3_r->SetLineWidth(2); h3_r->SetLineColor(5);

  for(Int_t i=0; i<lTimeMax; i++) {
    h1_l->Fill(i, filter_l->GetValue(ADC, i)<<2);
    h1_c->Fill(i, filter_c->GetValue(ADC, i)<<2);
    h1_r->Fill(i, filter_r->GetValue(ADC, i)<<2);
    h2_l->Fill(i, filter_l->GetValue(TAIL, i));
    h2_c->Fill(i, filter_c->GetValue(TAIL, i));
    h2_r->Fill(i, filter_r->GetValue(TAIL, i));
    h3_l->Fill(i, filter_l->GetValue(CT, i));
    h3_c->Fill(i, filter_c->GetValue(CT, i));
    h3_r->Fill(i, filter_r->GetValue(CT, i));
  }

  phisto1->cd(1); h1_l->Draw("L");
  phisto1->cd(2); h1_c->Draw("L");
  phisto1->cd(3); h1_r->Draw("L");
  phisto1->cd(1); h2_l->Draw("LSAME");
  phisto1->cd(2); h2_c->Draw("LSAME");
  phisto1->cd(3); h2_r->Draw("LSAME");
  phisto1->cd(1); h3_l->Draw("LSAME");
  phisto1->cd(2); h3_c->Draw("LSAME");
  phisto1->cd(3); h3_r->Draw("LSAME");

  /////////////////////////////////////////////////////////////////
  ////// FINISHED
  /////////////////////////////////////////////////////////////////

  cout << endl;
  STEPLINE();
  cout << "BYE." << endl << endl;
}
