void filterTestCT()
{
  Int_t ADC  = 0; // enum ARRAY_TYPE defined in AliTRDtrapFilter.h
  Int_t TAIL = 1;
  Int_t CT   = 2;
  Int_t NL   = 3;
  Int_t PD   = 4;
  Int_t GAIN = 5;

  gROOT->Reset();
  gSystem->Load("libTRDtrap");

  // INITIALIZE ///////////////////////////////////////////////////////////
  AliTRDtrap *trap = new AliTRDtrap(1, 2, 3, 4, 5);
  trap->Init();
  AliTRDtrapFilter *filter_l = trap->GetFilter(2);
  AliTRDtrapFilter *filter_c = trap->GetFilter(3);
  AliTRDtrapFilter *filter_r = trap->GetFilter(4);
  filter_l->SetFilterRight(filter_c);
  filter_c->SetFilterLeft(filter_l);
  filter_c->SetFilterRight(filter_r);
  filter_r->SetFilterLeft(filter_c);

  // READ ADC VALUES ///////////////////////////////////////////////////////////
  filter_l->ReadFilter("data/left.kip");
  filter_c->ReadFilter("data/center.kip");
  filter_r->ReadFilter("data/right.kip");

  // RUN CORRECTION ///////////////////////////////////////////////////////////
  filter_l->NonLinearityCorrection();
  filter_c->NonLinearityCorrection();
  filter_r->NonLinearityCorrection();
  filter_l->PedestalCorrection();
  filter_c->PedestalCorrection();
  filter_r->PedestalCorrection();
  filter_l->GainCorrection();
  filter_c->GainCorrection();
  filter_r->GainCorrection();
  filter_l->TailCancellation();
  filter_c->TailCancellation();
  filter_r->TailCancellation();

  printf("%d\n", filter_c->GetTailPed());

  filter_l->CrosstalkCancellation();
  filter_c->CrosstalkCancellation();
  filter_r->CrosstalkCancellation();

  printf("%d\n", filter_c->GetCtPed());

  // DRAW HISTOGRAMS ///////////////////////////////////////////////////////////
  TCanvas *c1 = new TCanvas("c1", "CT values", 100, 10, 800, 1000);  c1->ToggleEventStatus(); c1->Draw();
  TPad *ptitle1 = new TPad("ptitle1", "ptitle1", 0.01, 0.97, 0.99, 0.99); ptitle1->Draw();
  ptitle1->cd(); TPaveLabel *pltitle1 = new TPaveLabel(0.0, 0.0, 1.0, 1.0, "NonLinearity (black), Tail (blue), CrossTalk (red)"); pltitle1->Draw();
   c1->cd(); TPad *phisto1 = new TPad("phisto1", "phisto1", 0.01, 0.01, 0.99, 0.96);
  phisto1->Draw(); phisto1->Divide(1,3);

  // NonLinearity
  TH1D *h1_l = new TH1D("h1_l", "Left Channel", 30, -0.5, 29.5);
  TH1D *h1_c = new TH1D("h1_c", "Center Channel", 30, -0.5, 29.5);
  TH1D *h1_r = new TH1D("h1_r", "Right Channel", 30, -0.5, 29.5);
  h1_l->SetLineWidth(2); h1_l->SetLineColor(1);
  h1_c->SetLineWidth(2); h1_c->SetLineColor(1);
  h1_r->SetLineWidth(2); h1_r->SetLineColor(1);
  // Tail Cancellation
  TH1D *h2_l = new TH1D("h2_l", "Left Channel", 30, -0.5, 29.5);
  TH1D *h2_c = new TH1D("h2_c", "Center Channel", 30, -0.5, 29.5);
  TH1D *h2_r = new TH1D("h2_r", "Right Channel", 30, -0.5, 29.5);
  h2_l->SetLineWidth(2); h2_l->SetLineColor(4);
  h2_c->SetLineWidth(2); h2_c->SetLineColor(4);
  h2_r->SetLineWidth(2); h2_r->SetLineColor(4);

  for(Int_t i=0; i<30; i++) {
    h1_l->Fill(i, filter_l->GetValue(TAIL, i));
    h1_c->Fill(i, filter_c->GetValue(TAIL, i));
    h1_r->Fill(i, filter_r->GetValue(TAIL, i));
    h2_l->Fill(i, filter_l->GetValue(CT, i));
    h2_c->Fill(i, filter_c->GetValue(CT, i));
    h2_r->Fill(i, filter_r->GetValue(CT, i));
  }

  phisto1->cd(1); h1_l->Draw("L");
  phisto1->cd(2); h1_c->Draw("L");
  phisto1->cd(3); h1_r->Draw("L");
  phisto1->cd(1); h2_l->Draw("LSAME");
  phisto1->cd(2); h2_c->Draw("LSAME");
  phisto1->cd(3); h2_r->Draw("LSAME");

  delete trap;
}
