void filterTestTail()
{
  Int_t ADC  = 0; // enum ARRAY_TYPE defined in AliTRDtrapFilter.h
  Int_t TAIL = 1;
  Int_t CT   = 2;
  Int_t NL   = 3;
  Int_t PD   = 4;
  Int_t GAIN = 5;

  gROOT->Reset();
  gSystem->Load("libTRDtrap");

  // INITIALIZE
  AliTRDtrap *trap = new AliTRDtrap(1, 2, 3, 4, 5);
  trap->Init();
  AliTRDtrapFilter *filter_l = trap->GetFilter(2);
  AliTRDtrapFilter *filter_c = trap->GetFilter(3);
  AliTRDtrapFilter *filter_r = trap->GetFilter(4);
  filter_l->SetFilterRight(filter_c);
  filter_c->SetFilterLeft(filter_l);
  filter_c->SetFilterRight(filter_r);
  filter_r->SetFilterLeft(filter_c);

  // READ ADC VALUES
  filter_l->ReadFilter("data/left.kip");
  filter_c->ReadFilter("data/center.kip");
  filter_r->ReadFilter("data/right.kip");

  // RUN CORRECTION
  filter_c->NonLinearityCorrection();
  filter_c->PedestalCorrection();
  filter_c->GainCorrection();
  filter_c->TailCancellation();
  filter_c->CrosstalkCancellation();

  // OUTPUT VALUES
  filter_c->OutputValues(ADC);
  filter_c->OutputValues(NL);
  filter_c->OutputValues(GAIN);
  filter_c->OutputValues(TAIL);

  // DRAW HISTOGRAMS
  TH1D *h1_1 = new TH1D("h1_1", "NL values", 30.0, -0.5, 29.5);
  h1_1->SetLineWidth(3); h1_1->SetLineColor(1);
  TH1D *h1_2 = new TH1D("h1_2", "TAIL values", 30.0, -0.5, 29.5);
  h1_2->SetLineWidth(3); h1_2->SetLineColor(4);
  for(Int_t i=0; i<30; i++) h1_1->Fill(i, filter_c->GetValue(NL, i));
  for(Int_t i=0; i<30; i++) h1_2->Fill(i, filter_c->GetValue(TAIL, i));
  h1_1->Draw("L");
  h1_2->Draw("LSAME");

  delete trap;
}
