void filterTestCenter()
{
  Int_t ADC  = 0; // enum ARRAY_TYPE defined in AliTRDtrapFilter.h
  Int_t TAIL = 1;
  Int_t CT   = 2;
  Int_t NL   = 3;
  Int_t PD   = 4;
  Int_t GAIN = 5;

  gROOT->Reset();
  gSystem->Load("libTRDtrap");

  gStyle->SetCanvasBorderMode(0);
  gStyle->SetCanvasColor(kWhite);
  gStyle->SetOptStat(0);
  gStyle->SetOptTitle(0);

  TCanvas *c1 = new TCanvas("c1", "Config_bv.C", 100, 10, 600, 400); c1->Draw();

  // INITIALIZE
  AliTRDtrap *trap = new AliTRDtrap(1, 2, 3, 4, 5);
  trap->Init();
  AliTRDtrapFilter *filter_l = trap->GetFilter(2);
  AliTRDtrapFilter *filter_c = trap->GetFilter(3);
  AliTRDtrapFilter *filter_r = trap->GetFilter(4);
  filter_l->SetFilterRight(filter_c);
  filter_c->SetFilterLeft(filter_l);
  filter_c->SetFilterRight(filter_r);
  filter_r->SetFilterLeft(filter_c);

  // READ ADC VALUES
  filter_l->ReadFilter("data_phd/left.kip");
  filter_c->ReadFilter("data_phd/center.kip");
  filter_r->ReadFilter("data_phd/right.kip");

  // RUN CORRECTION
  filter_c->NonLinearityCorrection();
  filter_c->PedestalCorrection();
  filter_c->GainCorrection();
  filter_c->TailCancellation();
  filter_c->CrosstalkCancellation();

  // OUTPUT VALUES
  filter_c->OutputValues(ADC);
  filter_c->OutputValues(NL);
  filter_c->OutputValues(GAIN);
  filter_c->OutputValues(TAIL);

  // DRAW HISTOGRAMS
  TH1D *h1_1 = new TH1D("h1_1", "ADC values", 20.0, -0.5, 19.5);
  h1_1->SetLineWidth(3); h1_1->SetLineColor(1);
  TH1D *h1_2 = new TH1D("h1_2", "NL values", 20.0, -0.5, 19.5);
  h1_2->SetLineWidth(3); h1_2->SetLineColor(2);
  TH1D *h1_3 = new TH1D("h1_3", "TAIL values", 20.0, -0.5, 19.5);
  h1_3->SetLineWidth(3); h1_3->SetLineColor(3);
  TH1D *h1_4 = new TH1D("h1_4", "CT values", 20.0, -0.5, 19.5);
  h1_4->SetLineWidth(3); h1_4->SetLineColor(4);
  for(Int_t i=0; i<30; i++) h1_1->Fill(i, filter_c->GetValue(NL, i));
  for(Int_t i=0; i<30; i++) h1_2->Fill(i, filter_c->GetValue(ADC, i));
  for(Int_t i=0; i<30; i++) h1_3->Fill(i, filter_c->GetValue(TAIL, i));
  for(Int_t i=0; i<30; i++) h1_4->Fill(i, filter_c->GetValue(CT, i));
  h1_1->Draw("L");
  h1_2->Draw("LSAME");
  h1_3->Draw("LSAME");
  h1_4->Draw("LSAME");
  Int_t max=4000;
  TPaveText *tt1 = new TPaveText(12, 0.9*max, 18, 0.95*max); tt1->SetTextColor(2); tt1->AddText("ADC values"); tt1->Draw();
  TPaveText *tt2 = new TPaveText(12, 0.85*max, 18, 0.9*max); tt2->SetTextColor(1); tt2->AddText("Nonlinearity"); tt2->Draw();
  TPaveText *tt3 = new TPaveText(12, 0.8*max, 18, 0.85*max); tt3->SetTextColor(3); tt3->AddText("Tail Cancellation"); tt3->Draw();
  TPaveText *tt4 = new TPaveText(12, 0.75*max, 18, 0.8*max); tt4->SetTextColor(4); tt4->AddText("Crosstalk Cancellation"); tt4->Draw();

  c1->SaveAs("sim_results/filter_c.eps");
  delete trap;
}
