void filterTestLeftRight()
{
  Int_t ADC  = 0; // enum ARRAY_TYPE defined in AliTRDtrapFilter.h
  Int_t TAIL = 1;
  Int_t CT   = 2;
  Int_t NL   = 3;
  Int_t PD   = 4;
  Int_t GAIN = 5;

  gROOT->Reset();
  gSystem->Load("libTRDtrap");

  gStyle->SetCanvasBorderMode(0);
  gStyle->SetCanvasColor(kWhite);
  gStyle->SetOptStat(0);
  gStyle->SetOptTitle(0);

  TCanvas *c1 = new TCanvas("c1", "Config_bv.C", 100, 10, 600, 400); c1->Draw();

  // INITIALIZE ///////////////////////////////////////////////////////////
  AliTRDtrap *trap = new AliTRDtrap(1, 2, 3, 4, 5);
  trap->Init();
  AliTRDtrapFilter *filter_l = trap->GetFilter(2);
  AliTRDtrapFilter *filter_c = trap->GetFilter(3);
  AliTRDtrapFilter *filter_r = trap->GetFilter(4);
  filter_l->SetFilterRight(filter_c);
  filter_c->SetFilterLeft(filter_l);
  filter_c->SetFilterRight(filter_r);
  filter_r->SetFilterLeft(filter_c);

  // READ ADC VALUES ///////////////////////////////////////////////////////////
  filter_l->ReadFilter("data_phd/left.kip");
  filter_c->ReadFilter("data_phd/center.kip");
  filter_r->ReadFilter("data_phd/right.kip");

  // RUN CORRECTION ///////////////////////////////////////////////////////////
  filter_l->NonLinearityCorrection();
  filter_c->NonLinearityCorrection();
  filter_r->NonLinearityCorrection();
  filter_l->PedestalCorrection();
  filter_c->PedestalCorrection();
  filter_r->PedestalCorrection();
  filter_l->GainCorrection();
  filter_c->GainCorrection();
  filter_r->GainCorrection();
  filter_l->TailCancellation();
  filter_c->TailCancellation();
  filter_r->TailCancellation();

  // printf("%d\n", filter_c->GetTailPed());

  filter_l->CrosstalkCancellation();
  filter_c->CrosstalkCancellation();
  filter_r->CrosstalkCancellation();

  // printf("%d\n", filter_c->GetCtPed());

  // NonLinearity
  TH1D *h1_l = new TH1D("h1_l", "Left Channel", 20, -0.5, 19.5);
  TH1D *h1_c = new TH1D("h1_c", "Center Channel", 20, -0.5, 19.5);
  TH1D *h1_r = new TH1D("h1_r", "Right Channel", 20, -0.5, 19.5);
  h1_l->SetLineWidth(2); h1_l->SetLineColor(3);
  h1_c->SetLineWidth(2); h1_c->SetLineColor(3);
  h1_r->SetLineWidth(2); h1_r->SetLineColor(3);
  // Tail Cancellation
  TH1D *h2_l = new TH1D("h2_l", "Left Channel", 20, -0.5, 19.5);
  TH1D *h2_c = new TH1D("h2_c", "Center Channel", 20, -0.5, 19.5);
  TH1D *h2_r = new TH1D("h2_r", "Right Channel", 20, -0.5, 19.5);
  h2_l->SetLineWidth(2); h2_l->SetLineColor(4);
  h2_c->SetLineWidth(2); h2_c->SetLineColor(4);
  h2_r->SetLineWidth(2); h2_r->SetLineColor(4);

  for(Int_t i=0; i<30; i++) {
    h1_l->Fill(i, filter_l->GetValue(TAIL, i));
    h1_c->Fill(i, filter_c->GetValue(TAIL, i));
    h1_r->Fill(i, filter_r->GetValue(TAIL, i));
    h2_l->Fill(i, filter_l->GetValue(CT, i));
    h2_c->Fill(i, filter_c->GetValue(CT, i));
    h2_r->Fill(i, filter_r->GetValue(CT, i));
  }

  h1_l->Draw("L");
  h2_l->Draw("LSAME");

  c1->SaveAs("sim_results/filter_lr.eps");
  delete trap;
}
