library IEEE, TRAP;
use IEEE.std_logic_1164.all;
use std.textio.all;
use IEEE.std_logic_textio.all;
use WORK.ni_global.all;

----------------------------------------------------------------------------------------------------
-- ENTITY
----------------------------------------------------------------------------------------------------
entity ni_tb is
  generic (
    io_stim_file    : string  := "./STIMULI/io_stim_rr.txt";
    io_stim_start   : integer := 5;
    port_stim_file  : string  := "./STIMULI/port_stim_rr.txt";
    port_stim_start : integer := 30;
    sniff_file      : string  := "./RESULTS/ni_sniff.txt";
    ol              : boolean := FALSE);
end ni_tb;

----------------------------------------------------------------------------------------------------
-- ARCHITECTURE
----------------------------------------------------------------------------------------------------
architecture v of ni_tb is

  file     port_stim       : text open read_mode is port_stim_file;

  -- CONSTANTS -------------------------------------------------------------------------------------
  constant period_time : time    := 8 ns;
  constant width       : integer := 32;

  -- SIGNALS ---------------------------------------------------------------------------------------
  signal clk           : STD_LOGIC;
  signal clk_glob      : STD_LOGIC;
  signal clk_alws      : STD_LOGIC;
  signal reset_n       : STD_LOGIC;
  signal clear_n       : STD_LOGIC;
  signal mode_tr       : STD_LOGIC;
  signal mode_rr       : STD_LOGIC;
  signal finished_n    : STD_LOGIC;
  signal we_0          : STD_LOGIC;
  signal address_0     : STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
  signal din_0         : STD_LOGIC_VECTOR(width-1 downto 0);
  signal dout_0        : STD_LOGIC_VECTOR(width-1 downto 0);
  signal intr_0        : STD_LOGIC_VECTOR(2 downto 0);
  signal we_1          : STD_LOGIC;
  signal address_1     : STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
  signal din_1         : STD_LOGIC_VECTOR(width-1 downto 0);
  signal dout_1        : STD_LOGIC_VECTOR(width-1 downto 0);
  signal intr_1        : STD_LOGIC_VECTOR(2 downto 0);
  signal we_2          : STD_LOGIC;
  signal address_2     : STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
  signal din_2         : STD_LOGIC_VECTOR(width-1 downto 0);
  signal dout_2        : STD_LOGIC_VECTOR(width-1 downto 0);
  signal intr_2        : STD_LOGIC_VECTOR(2 downto 0);
  signal we_3          : STD_LOGIC;
  signal address_3     : STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
  signal din_3         : STD_LOGIC_VECTOR(width-1 downto 0);
  signal dout_3        : STD_LOGIC_VECTOR(width-1 downto 0);
  signal intr_3        : STD_LOGIC_VECTOR(2 downto 0);
  signal we_g          : STD_LOGIC;
  signal address_g     : STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
  signal din_g         : STD_LOGIC_VECTOR(width-1 downto 0);
  signal dout_g        : STD_LOGIC_VECTOR(width-1 downto 0);
  signal intr_g        : STD_LOGIC;
  signal p_strobe_in_0 : STD_LOGIC;
  signal p_d_in_0      : STD_LOGIC_VECTOR((width/4)+1 downto 0);
  signal p_ctrl_out_0  : STD_LOGIC;
  signal p_strobe_in_1 : STD_LOGIC;
  signal p_d_in_1      : STD_LOGIC_VECTOR((width/4)+1 downto 0);
  signal p_ctrl_out_1  : STD_LOGIC;
  signal p_strobe_in_2 : STD_LOGIC;
  signal p_d_in_2      : STD_LOGIC_VECTOR((width/4)+1 downto 0);
  signal p_ctrl_out_2  : STD_LOGIC;
  signal p_strobe_in_3 : STD_LOGIC;
  signal p_d_in_3      : STD_LOGIC_VECTOR((width/4)+1 downto 0);
  signal p_ctrl_out_3  : STD_LOGIC;
  signal p_ctrl_in     : STD_LOGIC;
  signal p_strobe_out  : STD_LOGIC;
  signal p_d_out       : STD_LOGIC_VECTOR((width/4)+1 downto 0);
  signal p_ctrl        : STD_LOGIC;
  
  signal enable_strobe_n    : STD_LOGIC;
  signal sniff_p_strobe_out : STD_LOGIC;
  signal sniff_p_d_out      : STD_LOGIC_VECTOR((width/4)+1 downto 0);
  signal sniff_p_ctrl       : STD_LOGIC;

  -- COMPONENTS ------------------------------------------------------------------------------------
  component ni_top
    port (
      clk           : in  STD_LOGIC;
      clk_glob      : in  STD_LOGIC;
      clk_alws      : in  STD_LOGIC;
      reset_n       : in  STD_LOGIC;
      clear_n       : in  STD_LOGIC;
      mode_tr       : in  STD_LOGIC;
      mode_rr       : in  STD_LOGIC;
      finished_n    : out STD_LOGIC;
      we_0          : in  STD_LOGIC;
      address_0     : in  STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
      din_0         : in  STD_LOGIC_VECTOR(width-1 downto 0);
      dout_0        : out STD_LOGIC_VECTOR(width-1 downto 0);
      intr_0        : out STD_LOGIC_VECTOR(2 downto 0);
      we_1          : in  STD_LOGIC;
      address_1     : in  STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
      din_1         : in  STD_LOGIC_VECTOR(width-1 downto 0);
      dout_1        : out STD_LOGIC_VECTOR(width-1 downto 0);
      intr_1        : out STD_LOGIC_VECTOR(2 downto 0);
      we_2          : in  STD_LOGIC;
      address_2     : in  STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
      din_2         : in  STD_LOGIC_VECTOR(width-1 downto 0);
      dout_2        : out STD_LOGIC_VECTOR(width-1 downto 0);
      intr_2        : out STD_LOGIC_VECTOR(2 downto 0);
      we_3          : in  STD_LOGIC;
      address_3     : in  STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
      din_3         : in  STD_LOGIC_VECTOR(width-1 downto 0);
      dout_3        : out STD_LOGIC_VECTOR(width-1 downto 0);
      intr_3        : out STD_LOGIC_VECTOR(2 downto 0);
      we_g          : in  STD_LOGIC;
      address_g     : in  STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
      din_g         : in  STD_LOGIC_VECTOR(width-1 downto 0);
      dout_g        : out STD_LOGIC_VECTOR(width-1 downto 0);
      intr_g        : out STD_LOGIC;
      p_strobe_in_0 : in  STD_LOGIC;
      p_d_in_0      : in  STD_LOGIC_VECTOR((width/4)+1 downto 0);
      p_ctrl_out_0  : out STD_LOGIC;
      p_strobe_in_1 : in  STD_LOGIC;
      p_d_in_1      : in  STD_LOGIC_VECTOR((width/4)+1 downto 0);
      p_ctrl_out_1  : out STD_LOGIC;
      p_strobe_in_2 : in  STD_LOGIC;
      p_d_in_2      : in  STD_LOGIC_VECTOR((width/4)+1 downto 0);
      p_ctrl_out_2  : out STD_LOGIC;
      p_strobe_in_3 : in  STD_LOGIC;
      p_d_in_3      : in  STD_LOGIC_VECTOR((width/4)+1 downto 0);
      p_ctrl_out_3  : out STD_LOGIC;
      p_ctrl_in     : in  STD_LOGIC;
      p_strobe_out  : out STD_LOGIC;
      p_d_out       : out STD_LOGIC_VECTOR((width/4)+1 downto 0);
      p_ctrl        : out STD_LOGIC);
  end component;

  component ni_sniffer
    generic (
      filename : string;
      sel_p    : integer;
      sel_s    : integer;
      ol       : boolean);
    port (
      strobe   : in std_logic;
      data     : in std_logic_vector(9 downto 0);
      ctrl_out : in std_logic;
      ctrl_in  : in std_logic);
  end component;

  component ni_io_stim is
    generic (
      filename : string;
      start    : integer;
      width    : integer);
    port (
      we_0      : out STD_LOGIC;
      address_0 : out STD_LOGIC_VECTOR((width/2)-1 downto 0);
      din_0     : out STD_LOGIC_VECTOR(width-1 downto 0);
      we_1      : out STD_LOGIC;
      address_1 : out STD_LOGIC_VECTOR((width/2)-1 downto 0);
      din_1     : out STD_LOGIC_VECTOR(width-1 downto 0);
      we_2      : out STD_LOGIC;
      address_2 : out STD_LOGIC_VECTOR((width/2)-1 downto 0);
      din_2     : out STD_LOGIC_VECTOR(width-1 downto 0);
      we_3      : out STD_LOGIC;
      address_3 : out STD_LOGIC_VECTOR((width/2)-1 downto 0);
      din_3     : out STD_LOGIC_VECTOR(width-1 downto 0);
      we_g      : out STD_LOGIC;
      address_g : out STD_LOGIC_VECTOR((width/2)-1 downto 0);
      din_g     : out STD_LOGIC_VECTOR(width-1 downto 0));
  end component ni_io_stim;

  component ni_port_stim is
    generic (
      filename : string;
      start    : integer;
      width    : integer);
    port (
      p_strobe_in_0 : out STD_LOGIC;
      p_d_in_0      : out STD_LOGIC_VECTOR(width-1 downto 0);
      p_strobe_in_1 : out STD_LOGIC;
      p_d_in_1      : out STD_LOGIC_VECTOR(width-1 downto 0);
      p_strobe_in_2 : out STD_LOGIC;
      p_d_in_2      : out STD_LOGIC_VECTOR(width-1 downto 0);
      p_strobe_in_3 : out STD_LOGIC;
      p_d_in_3      : out STD_LOGIC_VECTOR(width-1 downto 0);
      p_ctrl_in     : out STD_LOGIC);
  end component ni_port_stim;

  -- STRUCTURE -------------------------------------------------------------------------------------
begin

  U_ni_top: ni_top
    port map (
      clk           => clk,
      clk_glob      => clk_glob,
      clk_alws      => clk_alws,
      reset_n       => reset_n,
      clear_n       => clear_n,
      mode_tr       => mode_tr,
      mode_rr       => mode_rr,
      finished_n    => finished_n,
      we_0          => we_0,
      address_0     => address_0,
      din_0         => din_0,
      dout_0        => dout_0,
      intr_0        => intr_0,
      we_1          => we_1,
      address_1     => address_1,
      din_1         => din_1,
      dout_1        => dout_1,
      intr_1        => intr_1,
      we_2          => we_2,
      address_2     => address_2,
      din_2         => din_2,
      dout_2        => dout_2,
      intr_2        => intr_2,
      we_3          => we_3,
      address_3     => address_3,
      din_3         => din_3,
      dout_3        => dout_3,
      intr_3        => intr_3,
      we_g          => we_g,
      address_g     => address_g,
      din_g         => din_g,
      dout_g        => dout_g,
      intr_g        => intr_g,
      p_strobe_in_0 => p_strobe_in_0,
      p_d_in_0      => p_d_in_0,
      p_ctrl_out_0  => p_ctrl_out_0,
      p_strobe_in_1 => p_strobe_in_1,
      p_d_in_1      => p_d_in_1,
      p_ctrl_out_1  => p_ctrl_out_1,
      p_strobe_in_2 => p_strobe_in_2,
      p_d_in_2      => p_d_in_2,
      p_ctrl_out_2  => p_ctrl_out_2,
      p_strobe_in_3 => p_strobe_in_3,
      p_d_in_3      => p_d_in_3,
      p_ctrl_out_3  => p_ctrl_out_3,
      p_ctrl_in     => p_ctrl_in,
      p_strobe_out  => p_strobe_out,
      p_d_out       => p_d_out,
      p_ctrl        => p_ctrl);


  -- clk/reset stimuli -----------------------------------------------------------------------------
  reset_n <= '1',
             '0' after 2 ns,
             '1' after 15 ns;
  clear_n <= '1',
	     '0' after 2 ns,
	     '1' after 25 ns;
  mode_tr <= '0';
  mode_rr <= '0';

  U_clock: process
  begin
    clk <= '1';
    wait for period_time/2;
    clk <= '0';
    wait for period_time/2;
  end process;
  clk_glob <= clk;
  clk_alws <= clk;

  -- local/global io stimuli -----------------------------------------------------------------------
  U_io_stim: ni_io_stim
    generic map (
      filename => io_stim_file,
      start    => io_stim_start,
      width    => width)
    port map (
      we_0      => we_0,
      address_0 => address_0,
      din_0     => din_0,
      we_1      => we_1,
      address_1 => address_1,
      din_1     => din_1,
      we_2      => we_2,
      address_2 => address_2,
      din_2     => din_2,
      we_3      => we_3,
      address_3 => address_3,
      din_3     => din_3,
      we_g      => we_g,
      address_g => address_g,
      din_g     => din_g);

  -- input/output ports stimuli --------------------------------------------------------------------
  U_port_stim: ni_port_stim
    generic map (
      filename => port_stim_file,
      start    => port_stim_start,
      width    => (width/4)+2)
    port map (
      p_strobe_in_0 => p_strobe_in_0,
      p_d_in_0      => p_d_in_0,
      p_strobe_in_1 => p_strobe_in_1,
      p_d_in_1      => p_d_in_1,
      p_strobe_in_2 => p_strobe_in_2,
      p_d_in_2      => p_d_in_2,
      p_strobe_in_3 => p_strobe_in_3,
      p_d_in_3      => p_d_in_3,
      p_ctrl_in     => p_ctrl_in);

  -- output port protocol --------------------------------------------------------------------------
  enable_strobe_n    <= '1', '0' after 100 ns;
  sniff_p_strobe_out <= enable_strobe_n or p_strobe_out;
  sniff_p_d_out      <= transport p_d_out after 1 ns;
  sniff_p_ctrl       <= transport p_ctrl after 1 ns;
  U_ni_sniffer: ni_sniffer
    generic map (
      filename => sniff_file,
      sel_p    => 8,
      sel_s    => 9,
      ol       => ol)
    port map (
      strobe   => sniff_p_strobe_out,
      data     => sniff_p_d_out,
      ctrl_out => sniff_p_ctrl,
      ctrl_in  => p_ctrl_in);

end v;

----------------------------------------------------------------------------------------------------
-- CONFIGURATION
----------------------------------------------------------------------------------------------------
-- pragma translate_off
configuration ni_tb_CFG of ni_tb is
  for v
  end for; -- v
end ni_tb_CFG;
-- pragma translate_on

