
################################################################################
# define all synchronous clocks into appropriate groups
################################################################################


# Clock Name: CLK120 (12000 sinks)
# 120 MHz master clock
# Note this clock is the master root for ALL 120 MHz clocks. This is relevalt in 
# particular for the default configuration where GCLK is identical to CLK_ADC_d2. 
# In configurations where GCLK is a fraction if this root pin or derived from the
# 480 MHz PLL it will have a balanced tree but run asynchronously. All signals
# crossing from this root clock domain to the GCLK domain are synchronized. The 
# balancing for the default clock is introduced in order to ensure best signal 
# propagation for this default configuration.
ClkGroup
#+ top_CLK_mux/CLK120_buf/Z
+ top_CLK_mux/i2/Z


# Clock Name: CLK10 (8000 sinks)
# this is the root of the 10 MHz domain
ClkGroup
+ Itrap2top/adcc/SLOW_CLK_reg/Q


# Clock Name: SC_SLOW_CLK (100 sinks?)
# This clock is used for the slow control ADC and chip id
# it is very slow, running at 4 MHz.
ClkGroup
+ Itrap2top/adcc/scclk_buf/Z


# Clock Name: GATE (800 sinks)
# this is the root of the gate_latches
ClkGroup
+ Itrap2top/mg/frontend_instance/dl/D1i_reg/Q


# Clock Name: CLK480 (2 sinks)
# This clock is an alternative for generating independent digital clocks not
# identical to the ADC clock. The root is the output of the 480 MHz PLL
ClkGroup
+ PLL480/PLLOUT


# Clock Name: CLK_JTAG (1 sinks)
# 1 MHz JTAG Master Clock
ClkGroup
+ PTCK/DI


################################################################################
# now define the various clock trees
################################################################################
#
# Note: The UMC Clock buffers are huge - 32 um wide - all of them independent of
#       their driving capability. This wastes a lot of space, which we cannot
#	afford here. The good IPO1 results are badly screwed after CTS with CLK
#	buffers. Therefore only the smaller BUFBD buffers are used here.
#
################################################################################


# Clock Name: CLK120 (12087 sinks)
# 120 MHz master clock
#
# Note: this clock has a reconvergence at Itrap2top/rs/U_port_out/U_sync/U20/Z
#       caused by VHDL source ni_synch.vhd
#
#       -- output strobe signal is gated clock signal or clock signal in 
#       -- optical link mode
#       strobe_i <= clk_alws when ol = '1' else clk or we_n_reg;
#
#       We want the clock output in both modi to be balanced and accept this
#       warning
#
AutoCTSRootPin    	top_CLK_mux/i2/Z
RouteType		CLKTree
LeafPin
+ Itrap2top/rs/U_port_out/U_delay/U_delaybit_10/U_delay_2/U_inv_1/A rising
+ Itrap2top/rs/U_port_out/U_delay/U_delaybit_10/U_delay_2/U_select/A0 rising
+ Itrap2top/rs/U_port_out/U_sync/U_byte_sel/A2 rising
ExcludedPin
+ top_CLK_mux/i4/A
+ top_CLK_mux/CLKFanOutRoot/A
NoGating          	NO
MaxDelay          	5000ps
MinDelay          	0ps
MaxSkew           	300ps
MaxDepth          	50
SinkMaxTran       	500ps
BufMaxTran        	500ps
Buffer			BUFBD2 BUFBD4 BUFBD8
RouteClkNet             YES
PostOpt                 YES         # this is the default
DetailReport            YES
End


# Clock Name: CLK10 (8043 sinks)
# this is the root of the 10 MHz domain
AutoCTSRootPin    	Itrap2top/adcc/SLOW_CLK_reg/Q
RouteType		CLKTree
LeafPin
+ IADC/adc_i/PA_SCLK rising
NoGating          	NO
MaxDelay          	5000ps
MinDelay          	0ps
MaxSkew           	300ps
MaxDepth          	50
SinkMaxTran       	500ps
BufMaxTran        	500ps
Buffer			BUFBD2 BUFBD4 BUFBD8
RouteClkNet             YES
PostOpt                 YES         # this is the default
DetailReport            YES
End

# Clock Name: GATE (800 sinks)
# this is the root of the gate_latches
AutoCTSRootPin    	Itrap2top/mg/frontend_instance/dl/D1i_reg/Q
RouteType		CLKTree
NoGating          	rising
MaxDelay          	3000ps
MinDelay          	0ps
MaxSkew           	1000ps
MaxDepth          	100
SinkMaxTran       	500ps
BufMaxTran        	500ps
Buffer			BUFBD2 BUFBD4 BUFBD8 BUFBD12
RouteClkNet             YES
PostOpt                 YES         # this is the default
DetailReport            YES
End


# Clock Name: SC_SLOW_CLK (3 sinks)
AutoCTSRootPin    	Itrap2top/adcc/scclk_buf/Z
RouteType		CLKTree
NoGating          	NO
MaxDelay          	5000ps
MinDelay          	0ps
MaxSkew           	300ps
MaxDepth          	100
SinkMaxTran       	500ps
BufMaxTran        	500ps
Buffer			BUFBD2 BUFBD4 BUFBD8 BUFBD12
RouteClkNet             YES
PostOpt                 YES         # this is the default
DetailReport            YES
End


# Clock Name: CLK480 (2 sinks)
# This clock is an alternative for generating independent digital clocks not
# identical to the ADC clock. The root is the output of the 480 MHz PLL
AutoCTSRootPin    	PLL480/PLLOUT
RouteType		CLKSpline
LeafPin
+ top_CLK_mux/i6/A rising
NoGating          	rising
MaxDelay          	5000ps
MinDelay          	0ps
MaxSkew           	300ps
MaxDepth          	100
SinkMaxTran       	500ps
BufMaxTran        	500ps
Buffer			BUFBD2 BUFBD4 BUFBD8 BUFBD12
RouteClkNet             YES
PostOpt                 YES         # this is the default
DetailReport            YES
End


# JTAG CLOCK ROOT
AutoCTSRootPin    	PTCK/DI
RouteType		CLKTree
# the JTAG clock should be defined as gated clock. However CTS core dumps if
# JTAG clock is defined as gated clock. We have to live with this here. It is
# a very slow clock.
#NoGating          	NO
NoGating          	rising
MaxDelay          	5000ps
MinDelay          	0ps
MaxSkew           	300ps
MaxDepth          	100
SinkMaxTran       	500ps
BufMaxTran        	500ps
Buffer			BUFBD2 BUFBD4 BUFBD8 BUFBD12
RouteClkNet             YES
PostOpt                 YES         # this is the default
DetailReport            YES
End
