exec date -R

encMessage warning 0
encMessage debug 0
encMessage info 0
restoreDesign ./OUTPUT/ENC/IPOpreCTSFinal.enc.dat top_pad 1 1 0
setDrawMode fplan
encMessage warning 1
encMessage debug 0
encMessage info 1


#
# the clock tree synthesis tool moves clock gating gates even if they inside fences
# it seems not to read the placement directives. But if the gates are marked fixed
# it leaves them where they are. We fix the clock gating cells here to avoid this
# problem. It has happened that a glock gate was moved several millimeters away
# from the appropriate enabling flip flop.
#
#setBPFixedBlock "Itrap2top/ck"
#setBPFixedBlock "top_CLK_mux"
setBlockPlacementStatus -name Itrap2top/ck/* -status preplaced
setBlockPlacementStatus -name top_CLK_mux/* -status preplaced
defOut -floorplan -placement -netlist ./OUTPUT/CTS/top_pad_prects.def

#
# the clock tree synthesis modifies the placement and netlist and therefore has
# impact on the timing of the design. Rerunning IPO after CTS does not improve
# the timing - as empirically experienced. The Clock buffers are therefore kept
# small in order to avoid too large distortions of the design. However, in order
# to measure the impact on the timing performance it is calculated before and
# after the clock tree synthesis. The latter uses the results of the placed
# clock tree.
#

source SCRIPTS/setOpCond.tcl
specifyClockTree -clkfile ./CFG/CTS/routeTypes.cts
specifyClockTree -clkfile ./CFG/CTS/top_pad_masterCLK.cts
setAnalysisMode -setup -noAsync -noSkew -noClockTree
setTrialRouteMode -highEffort -maxRouteLayer 6 

# create some extra spacing around flip-flops (GRF area hard to route - this is
# a weak form of a congestion constraint
# Note: this setting is not carried by saveDesign
source ./SCRIPTS/setCellPadding.tcl

trialRoute

extractRC
freeTimingGraph
buildTimingGraph
reportClock

reportSlacks        -outfile ./REPORTS/CTS/top_pad.slk
reportViolation     -outfile ./REPORTS/CTS/top_pad.tarpt  -num 1000 -longForm
reportViolation     -outfile ./REPORTS/CTS/top_pad.tasrpt -num 1000 -shortForm
reportTranViolation -outfile ./REPORTS/CTS/top_pad.tran   -noGlobalNets -excNetFile ./CFG/TranExcl.ntf


#
# Clock tree synthesis
#

checkUnique
ckSynthesis -rguide ./OUTPUT/CTS/top_pad_cts.guide -report 		\
	./REPORTS/CTS/top_pad_cts.ctsrpt -forceReconvergent -fixAddedBuffers


saveClockNets -output ./OUTPUT/CTS/top_pad_cts.ctsntf
saveClockBuffers -output ./OUTPUT/CTS/top_pad.clkbuffers
savePlace ./OUTPUT/CTS/top_pad_cts.place
defOut -floorplan -placement -netlist ./OUTPUT/CTS/top_pad_cts.def

#
# verify timing of clock routed design
#

setAnalysisMode -setup -noAsync -skew -clockTree

trialRoute -maxRouteLayer 6 -highEffort -guide OUTPUT/CTS/top_pad_cts.guide

extractRC
freeTimingGraph
buildTimingGraph
reportClock

reportSlacks        -outfile ./REPORTS/CTS/top_pad_cts.slk
reportViolation     -outfile ./REPORTS/CTS/top_pad_cts.tarpt  -num 1000 -longForm
reportViolation     -outfile ./REPORTS/CTS/top_pad_cts.tasrpt -num 1000 -shortForm
reportTranViolation -outfile ./REPORTS/CTS/top_pad_cts.tran   -noGlobalNets -excNetFile ./CFG/TranExcl.ntf

# now save everything

saveDesign ./OUTPUT/ENC/CTSFinal.enc
saveDesign ./OUTPUT/ENC/RouteIN.enc

# now verify that the clock enable signals are not too slow. This would mean
# the placement fix of the clock enable gates failed

unloadTimingCon
loadTimingCon ./CFG/top_pad_CLKgate.tc

setCteReport
extractRC
freeTimingGraph
buildTimingGraph
reportClock
reportTA -clock_from CLK120 -to Itrap2top/ck/*/S_1/* -summary \
                    -outfile ./REPORTS/CTS/top_pad_clkgate.slk



exec cp ./CFG/CTS/top_pad_masterCLK.cts ./REPORTS/CTS/
exec date -R
exit
