#
# This script is to be run after possibly required manual fixes to check
# and repair all routes and do full timing analyses
#

encMessage warning 0
encMessage debug 0
encMessage info 0
restoreDesign ./OUTPUT/ENC/Route1Final.enc.dat top_pad 1 1 0
setDrawMode fplan
encMessage warning 1
encMessage debug 0
encMessage info 1

#clearDrc

source ./SCRIPTS/setOpCond.tcl
specifyClockTree -clkfile ./CFG/CTS/routeTypes.cts
specifyClockTree -clkfile ./CFG/CTS/top_pad_masterCLK.cts
setAnalysisMode -setup -noAsync -skew -autoDetectClockTree

#
# read default router options
#

source ./SCRIPTS/setRoutingOpt.tcl
setNanoRouteMode -quiet routeInsertAntennaDiode false
setNanoRouteMode -quiet optimizeFixHoldTime true
setNanoRouteMode -quiet optimizeTargetHoldSlack 0.500000
#setNanoRouteMode -quiet optimizeGs true


# now repair all geometries left route first try
globalDetailRoute
saveDesign ./OUTPUT/ENC/RouteFpreSI.enc


#
# check optimization result prior to SI routing
#

extractRC
freeTimingGraph
buildTimingGraph
reportClock

reportSlacks        -outfile ./REPORTS/ROUTING/FINAL/top_pad_route.slk
reportViolation     -outfile ./REPORTS/ROUTING/FINAL/top_pad_route.tarpt  -num 1000 -longForm
reportViolation     -outfile ./REPORTS/ROUTING/FINAL/top_pad_route.tasrpt -num 1000 -shortForm
reportTranViolation -outfile ./REPORTS/ROUTING/FINAL/top_pad_route.tran  -noGlobalNets -excNetFile ./CFG/TranExcl.ntf


#
# the first routing tries operate without noise analysis - this is done now
#
setNanoRouteMode -quiet routeWithSiDriven true
setNanoRouteMode -quiet routeSiEffort normal

globalDetailRoute
saveDesign ./OUTPUT/ENC/RouteFpostSI.enc


#
# now do some more verify and repair passes. Unfortunately sometimes the repair creates other violations
# --> need to be a bit iterative here
#

# this is the first completed route - save it - verify for all remaining violations and route again
checkRoute
clearDrc
verifyGeometry -reportfile ./REPORTS/ROUTING/FINAL/violation_report_step1.rpt	\
        -allowRoutingBlkgPinOverlap -regRoutingOnly                     	\
        -area { 555 555 4400 5933 }  -error 100000 -warning 5000
globalDetailRoute
saveDesign ./OUTPUT/ENC/RouteFStep1.enc

# search and repair run (goes fast if no errors) 1
checkRoute
clearDrc
verifyGeometry -reportfile ./REPORTS/ROUTING/FINAL/violation_report_step2.rpt	\
        -allowRoutingBlkgPinOverlap -regRoutingOnly                     	\
        -area { 555 555 4400 5933 }  -error 100000 -warning 5000
globalDetailRoute

# search and repair run (goes fast if no errors) 2
checkRoute
clearDrc
verifyGeometry -reportfile ./REPORTS/ROUTING/FINAL/violation_report_step3.rpt	\
        -allowRoutingBlkgPinOverlap -regRoutingOnly                     	\
        -area { 555 555 4400 5933 }  -error 100000 -warning 5000
globalDetailRoute

saveDesign ./OUTPUT/ENC/RouteFRouted.enc

checkRoute
verifyGeometry -reportfile ./REPORTS/ROUTING/FINAL/violation_report_final.rpt	\
        -allowRoutingBlkgPinOverlap                                     	\
        -area { 555 555 4400 5933 }  -error 100000 -warning 5000

saveNetlist ./OUTPUT/NETLIST/top_pad_final.v
saveDesign ./OUTPUT/ENC/RouteFinal.enc

# save also for stream-out - this is to allow some manual patching after final route
saveDesign ./OUTPUT/ENC/RouteF2GDSout.enc


#
# some final optimizations
#
#setNanoRouteMode drouteOptimizeUseMultiCutVia true
#setNanoRouteMode drouteStartIteration 20
#setNanoRouteMode drouteEndIteration default
#detailRoute
#setNanoRouteMode drouteOptimizeUseMultiCutVia false
#setNanoRouteMode drouteStartIteration 16
#setNanoRouteMode drouteEndIteration 20
#detailRoute


################################################################################
#
# do timing check after route with the worst case timing
#
################################################################################

extractRC
freeTimingGraph
buildTimingGraph
reportClock

reportSlacks        -outfile ./REPORTS/ROUTING/FINAL/top_pad_route_final.slk
reportViolation     -outfile ./REPORTS/ROUTING/FINAL/top_pad_route_final.tarpt  -num 1000 -longForm
reportViolation     -outfile ./REPORTS/ROUTING/FINAL/top_pad_route_final.tasrpt -num 1000 -shortForm
reportTranViolation -outfile ./REPORTS/ROUTING/FINAL/top_pad_route_final.tran  -noGlobalNets -excNetFile ./CFG/TranExcl.ntf

# now verify the transition times without overconstraining the design
# the same file like top_pad.tc except for max transition

unloadTimingCon
loadTimingCon ./CFG/top_pad_VSTtran.tc

reportTranViolation -outfile ./REPORTS/ROUTING/FINAL/top_pad_route_final.vsttran  -noGlobalNets -excNetFile ./CFG/TranExcl.ntf

# now verify that the clock enable signals are not too slow. This would mean
# the placement fix of the clock enable gates failed

unloadTimingCon
loadTimingCon ./CFG/top_pad_CLKgate.tc
setCteReport
extractRC
freeTimingGraph
buildTimingGraph
reportClock
reportViolation     -outfile ./REPORTS/ROUTING/FINAL/top_pad_route_clkgate.tarpt  -num 1000 -longForm
reportTA -clock_from CLK120 -to Itrap2top/ck/*/S_1/* -summary \
                    -outfile ./REPORTS/ROUTING/FINAL/top_pad_route_clkgate.slk

exit
