#date

# VoLi 20040104:
#
# The design instantiates all IO cells explicitly. The top level instance 
# exports all PADs as pins. One consequence of this is the resulting existence
# of nets with only one pin (the IO cells PAD). The placement of the bonding
# PADs is done automatically during stream-out. As a result the router produces
# the following warning for all toplevel IO pins/pads:
#          ***WARNING***RST_n does not have layer defined ! 
# here for the RESET input RST_n. These warnings may be ignored. Maybe on the 
# long run we find a more elegant way of doing this.

encMessage warning 0
encMessage debug 0
encMessage info 0
restoreDesign ./OUTPUT/ENC/RouteCLK.enc.dat top_pad 1 1 0
setDrawMode fplan
encMessage warning 1
encMessage debug 0
encMessage info 1

#
# prepare the routing - do timing analysis first, allowing a comparison between
# the trial route estimates and the final result
#

source SCRIPTS/setOpCond.tcl
specifyClockTree -clkfile ./CFG/CTS/routeTypes.cts
specifyClockTree -clkfile ./CFG/CTS/top_pad_masterCLK.cts
setAnalysisMode -setup -noAsync -skew -clockTree
setTrialRouteMode -highEffort -maxRouteLayer 6 -guide ./OUTPUT/CTS/top_pad_cts.guide
# design is already trial routed

#
# do first timing analysis
#
extractRC
freeTimingGraph
buildTimingGraph
reportClock

reportSlacks        -outfile ./REPORTS/ROUTING/1st/top_pad.slk
reportViolation     -outfile ./REPORTS/ROUTING/1st/top_pad.tarpt  -num 1000 -longForm
reportViolation     -outfile ./REPORTS/ROUTING/1st/top_pad.tasrpt -num 1000 -shortForm
reportTranViolation -outfile ./REPORTS/ROUTING/1st/top_pad.tran   -noGlobalNets -excNetFile ./CFG/TranExcl.ntf


# read default router options for NanoRoute
source ./SCRIPTS/setRoutingOpt.tcl

deselectAll
setNanoRouteMode routeSelectedNetOnly false
# VoLi 20040401: some of the additional post routing timing prolems may result in antenna fixing w/o ANT cells.
#                the Antenna cell problem existed in trap2 with FE2.3 Iam giving it a ty
# VoLi 20040402: the netlist generated post route with Antenna insertion resulted
#		 in netlist with syntax errors, also verified with synopsis. 
#		 returned to NO antena insertion.

setNanoRouteMode -quiet routeInsertAntennaDiode false

# optimize everything
setNanoRouteMode -quiet optimizeFixSetupTime true
setNanoRouteMode -quiet optimizeFixHoldTime true
setNanoRouteMode -quiet optimizeTargetHoldSlack 0.500000
setNanoRouteMode routeSelectedNetOnly false

globalDetailRoute
saveDesign ./OUTPUT/ENC/Route1pass.enc

#
# timing analysis after first routing
#
extractRC
freeTimingGraph
buildTimingGraph
reportClock

reportSlacks        -outfile ./REPORTS/ROUTING/1st/top_pad_first.slk
reportViolation     -outfile ./REPORTS/ROUTING/1st/top_pad_first.tarpt  -num 1000 -longForm
reportViolation     -outfile ./REPORTS/ROUTING/1st/top_pad_first.tasrpt -num 1000 -shortForm
reportTranViolation -outfile ./REPORTS/ROUTING/1st/top_pad_first.tran   -noGlobalNets -excNetFile ./CFG/TranExcl.ntf


#
# perform post routing cell optimization - just change size
#

resize -postIPO -noFootPrintChange
saveDesign ./OUTPUT/ENC/Route1Opt.enc
globalDetailRoute

# overwrite this file with the manually fixed antenna cells (if required)
saveDesign ./OUTPUT/ENC/Route1Final.enc

#
# the route stops here as nanoroute illegally places the Antenna cells
# over other core cells - move them to their correct place manually here
# then run final route
#
# do not check yet for other problems
# there is a known bug reporting IO cells overlapping, which are not

verifyGeometry -reportfile ./REPORTS/ROUTING/1st/violation_report_first.rpt 	\
	-allowRoutingBlkgPinOverlap -regRoutingOnly				\
	-area { 555 555 4400 5933 }  -error 100000 -warning 5000


#
# do final timing analysis - from here we determine what options in RouteFinal
#
extractRC
freeTimingGraph
buildTimingGraph
reportClock

reportSlacks        -outfile ./REPORTS/ROUTING/1st/top_pad_final.slk
reportViolation     -outfile ./REPORTS/ROUTING/1st/top_pad_final.tarpt  -num 1000 -longForm
reportViolation     -outfile ./REPORTS/ROUTING/1st/top_pad_final.tasrpt -num 1000 -shortForm
reportTranViolation -outfile ./REPORTS/ROUTING/1st/top_pad_final.tran   -noGlobalNets -excNetFile ./CFG/TranExcl.ntf

#
# now perform preliminary hold time analysis for possible fixing
#
setAnalysisMode -hold -noAsync -skew -autoDetectClockTree 
setBufFootPrint BUFBD
setDelayFootPrint DLY1D

freeTimingGraph
buildTimingGraph

reportSlacks        -outfile ./REPORTS/ROUTING/1st/top_pad_route_hold.slk
reportViolation     -outfile ./REPORTS/ROUTING/1st/top_pad_route_hold.tarpt  -num 1000 -longForm
reportViolation     -outfile ./REPORTS/ROUTING/1st/top_pad_route_hold.tasrpt -num 1000 -shortForm
reportTranViolation -outfile ./REPORTS/ROUTING/1st/top_pad_route_hold.tran   -noGlobalNets -excNetFile ./CFG/TranExcl.ntf


exit
