// 
// Copyright (C) 2001 Virtual Silicon Technology Inc.. All Rights Reserved.
// eSi, eSi-Route, eSi-Pad, eSi-RAM, eSi-ROM, eSi-PLL,
// The Heart of Great Silicon(R), Silicon Ready(R), IP Ambassador,
// Design Service Ambassador, and Virtual Silicon are trademarks
// of Virtual Silicon Technology Inc.
// 
// Virtual Silicon Technology Inc.
// 1200 Crossman Ave Suite 200
// Sunnyvale, CA 94089-1116
// Phone : 408-548-2700
// Fax : 408-548-2750
// Web Site : www.virtual-silicon.com
// 
// VST Library Release: UMCL18U420T2_1.3
// 
// Two-Port RAM 128 words by 16 bits
// column mux = 1
// bytewrite  = n
// tristate   = n
// test       = n
// powerbus   = o
// frequency  = 120
// 
`timescale 1 ns / 10 ps
`celldefine
module R128X16M1 (
  RCK,
  WCK,
  RADR,
  WADR,
  DI,
  DOUT,
  REN,
  WEN
  );

  parameter words = 128;
  parameter addMsb = 6;
  parameter bitMsb = 15;

  input RCK;
  input WCK;
  input [addMsb:0] RADR;
  input [addMsb:0] WADR;
  input [bitMsb:0] DI;
  input REN;
  input WEN;
  output [bitMsb:0] DOUT;
  wire TIRADR = 1'b0;
  wire TIREN = 1'b0;
  wire TIWADR = 1'b0;
  wire TIWEN = 1'b0;
  wire TWCK = 1'b0;
  wire TSE = 1'b0;
  wire TCE = 1'b0;
  wire TRCN = 1'b0;
  wire TID = 1'b0;
  wire BYP = 1'b0;     

  reg [addMsb:0] intWADR;
  reg intWEN;
  reg [addMsb:0] intRADR;
  reg intREN;
  reg [bitMsb:0] intDI;
  reg [bitMsb:0] intDOUT;
  reg [bitMsb:0] dly_intDOUT;
  reg [bitMsb:0] memory_array [127:0];
  reg write_error;
  reg read_error;
  reg equal_to_wadr;
  reg equal_to_radr;

  reg shWADR_notifier;
  reg shTIWADR_notifier;
  reg shWEN_notifier;
  reg shTIWEN_notifier;
  reg shDI_notifier;
  reg shTID_notifier;
  reg shRADR_notifier;
  reg shTIRADR_notifier;
  reg shREN_notifier;
  reg shTIREN_notifier;
  reg shTSERCK_notifier;
  reg shTSEWCK_notifier;
  reg shTCE_notifier;
  reg shTRCN_notifier;
  reg rd_notifier;
  reg wt_notifier;
  reg rd_wr_conflict_notifier;
  reg si_rd_wr_conflict_notifier;

  integer i;
  real rckTime;
  real wckTime;
  reg[31:0] tsechangetime;
  reg[31:0] wckhightime;
  reg[31:0] wcklowtime;

  parameter xData = 16'bx;
  parameter xAdr  = 7'bx;

  wire bufRCK;
  wire bufWCK;
  wire bufTIRADR;
  wire bufTIREN;
  wire bufREN;
  wire bufTIWADR;
  wire bufTIWEN;
  wire bufWEN;
  wire bufTCE;
  wire bufTSE;
  wire bufTRCN;
  wire bufTID;
  wire bufBYP;
  wire bufTWCK;

  wire [bitMsb:0]  oeintDOUT = bufBYP ? intDI : intDOUT;

  wire intWCK = bufTCE ? bufTWCK : bufWCK;
  wire [bitMsb:0] intTDI = bufTRCN ? {intDI[bitMsb-1:0],bufTID} : dly_intDOUT[bitMsb:0];

  wire [addMsb:0] bufRADR;
  wire [addMsb:0] bufWADR;
  wire [bitMsb:0] bufDI;
  wire towadr = intWADR[addMsb];
  wire wiretowen = intWEN;
  wire wiretoradr = intRADR[addMsb];
  wire wiretoren = intREN;
  wire wiretod = intDI[bitMsb];

  buf (bufRCK, RCK);
  buf (bufWCK, WCK);
  buf (bufDI[0], DI[0]);
  buf (bufDI[1], DI[1]);
  buf (bufDI[2], DI[2]);
  buf (bufDI[3], DI[3]);
  buf (bufDI[4], DI[4]);
  buf (bufDI[5], DI[5]);
  buf (bufDI[6], DI[6]);
  buf (bufDI[7], DI[7]);
  buf (bufDI[8], DI[8]);
  buf (bufDI[9], DI[9]);
  buf (bufDI[10], DI[10]);
  buf (bufDI[11], DI[11]);
  buf (bufDI[12], DI[12]);
  buf (bufDI[13], DI[13]);
  buf (bufDI[14], DI[14]);
  buf (bufDI[15], DI[15]);
  buf (bufRADR[0], RADR[0]);
  buf (bufWADR[0], WADR[0]);
  buf (bufRADR[1], RADR[1]);
  buf (bufWADR[1], WADR[1]);
  buf (bufRADR[2], RADR[2]);
  buf (bufWADR[2], WADR[2]);
  buf (bufRADR[3], RADR[3]);
  buf (bufWADR[3], WADR[3]);
  buf (bufRADR[4], RADR[4]);
  buf (bufWADR[4], WADR[4]);
  buf (bufRADR[5], RADR[5]);
  buf (bufWADR[5], WADR[5]);
  buf (bufRADR[6], RADR[6]);
  buf (bufWADR[6], WADR[6]);
  buf (bufTIRADR, TIRADR);
  buf (bufTIREN, TIREN);
  buf (bufREN, REN);
  buf (bufTIWADR, TIWADR);
  buf (bufTIWEN, TIWEN);
  buf (bufWEN, WEN);
  buf (bufTCE, TCE);
  buf (bufTSE, TSE);
  buf (bufTRCN, TRCN);
  buf (bufTID, TID);
  buf (bufBYP, BYP);
  buf (bufTWCK, TWCK);
  buf (TOWADR, towadr);
  buf (TOWEN, wiretowen);
  buf (TORADR, wiretoradr);
  buf (TOREN, wiretoren);
  buf (TOD, wiretod);

  wire rflag;
  wire wflag;
  wire wadrflag = (intWADR === bufRADR);
  wire radrflag = (intRADR === bufWADR);
  and(wflag, wadrflag, ~bufREN, ~intWEN);
  and(rflag, radrflag, ~bufWEN, ~intREN);
  nor(TSEnorWEN, TSE, WEN);
  and(TSEandTRCN, TSE, TRCN);

  // Delay intDOUT so that the test input latch
  //   does not get the new value
  always @ (intDOUT) dly_intDOUT = #1 intDOUT;

  initial begin  // READ loop
    read_error = 1'b0;
    equal_to_wadr = 1'b0;
    rd_wr_conflict_notifier = 1'b0;
      // Wait for valid initial transition
    wait (bufRCK === 1'b0);

    forever @(posedge bufRCK) begin
         equal_to_wadr = 1'b0;
        // 0->1 transition
      if (bufRCK === 1'b1) begin
        if (bufTSE === 1'b0) begin
          intREN = bufREN;
          intRADR = bufRADR;
        end else if (bufTSE === 1'b1) begin
          intREN = bufTIREN;
          intRADR[addMsb:0] = {intRADR[addMsb-1:0],bufTIRADR};
        end else begin
          intREN = 1'bx;
          intRADR = xAdr;
        end
          // Read cycle
        if (intREN === 1'b0) begin
          if (^intRADR === 1'bx)  begin
            intDOUT = xData;
          end else if (read_error === 1'b0) begin
            intDOUT = memory_array[intRADR];
       `ifdef no_tchk
            // >>>    code for Eq Rd/WR to same address - start
             if ((intWEN === 1'b0) && (intRADR === intWADR)) begin
                   if (wck_to_rck <= tcymin/2)
                     rd_wr_conflict_notifier = 1'b1;

             end
             //    code for Eq Rd/WR to same address - end  <<<<
       `else
            rckTime = $realtime;
          if (rckTime == wckTime) begin
            if ((bufRADR === bufWADR) && (bufREN === 1'b0) && (bufWEN === 1'b0)) begin
		si_rd_wr_conflict_notifier = 1'b1;
	     end
	   end
      `endif

if ((intWEN === 1'b0) && (intRADR === intWADR)) begin  //Checking valid Read/Write to same addr 
                  equal_to_wadr = 1'b1;    
            end 
         end 
       end else if (intREN !== 1'b1) begin 
         intDOUT = xData; 
       end 
     end 

        // 0->unknown transition, wait until returns to 0
      else begin
        intDOUT = xData;
        wait (bufRCK === 1'b0);
      end

    end
  end  // end READ loop

  initial begin  // WRITE loop
    write_error = 1'b0;
    equal_to_radr = 1'b0;
    wckhightime = 0;
    rd_wr_conflict_notifier = 1'b0;
      // Wait for valid initial transition
    wait (intWCK === 1'b0);

    forever @(posedge intWCK) begin
    wckhightime = $time;
      equal_to_radr = 1'b0;
      // 0->1 transistion
      if (intWCK === 1'b1) begin
        if (bufTSE === 1'b0) begin
          intWEN = bufWEN;
          intWADR = bufWADR;
          if (bufWEN === 1'b0) begin
            intDI = bufDI;
        end
        end else if (bufTSE === 1'b1) begin
          intWEN = bufTIWEN;
          intWADR[addMsb:0] = {intWADR[addMsb-1:0],bufTIWADR};
          if ((tsechangetime === wckhightime) || (tsechangetime === wcklowtime)) begin
            intDI = xData;
          end
           else  begin
           intDI = intTDI;
          end
        end else begin
          intWEN = 1'bx;
          intWADR = xAdr;
          intDI = xData;
        end
        if (intWEN !== 1'b1) begin
          if (^intWADR === 1'bx) begin
            for (i = 0; i < words; i=i+1) begin
              memory_array[i] = xData;
            end
          end else if ((intWEN === 1'b0) && (write_error === 1'b0)) begin
          memory_array[intWADR] = intDI; // Write cycle
          `ifdef no_tchk
          `else 
         wckTime = $realtime;
          if (wckTime == rckTime) begin
            if ((bufWADR === bufRADR) && (bufWEN === 1'b0) && (bufREN === 1'b0)) begin
		si_rd_wr_conflict_notifier = 1'b1;
	     end
	   end
          `endif
          end else begin
            memory_array[intWADR] = xData;
          end 
        end
        // 0->unknown transition, wait until returns to 0
      end else begin
        intDI = xData;
        for (i = 0; i < words; i=i+1) begin
          memory_array[i] = xData;
        end
        wait (intWCK === 1'b0);
      end

    end
  end  // end WRITE loop

    initial begin
       tsechangetime = 0;
    end

   always @(TSE) begin
    tsechangetime = $time;
    if (($time > 0) && 
       ((intWCK === 1'b1) || (wcklowtime === tsechangetime))) begin
     intDI = xData;
   $display ("TSE cannot change at %t", $time);
    end
   end

   initial begin
    wcklowtime = 0;

    forever @(negedge intWCK) begin
       wcklowtime = $time;
     if (wcklowtime === tsechangetime) begin
       intDI = xData;
     end
    end
  end

  buf (DOUT[0], oeintDOUT[0]);
  buf (DOUT[1], oeintDOUT[1]);
  buf (DOUT[2], oeintDOUT[2]);
  buf (DOUT[3], oeintDOUT[3]);
  buf (DOUT[4], oeintDOUT[4]);
  buf (DOUT[5], oeintDOUT[5]);
  buf (DOUT[6], oeintDOUT[6]);
  buf (DOUT[7], oeintDOUT[7]);
  buf (DOUT[8], oeintDOUT[8]);
  buf (DOUT[9], oeintDOUT[9]);
  buf (DOUT[10], oeintDOUT[10]);
  buf (DOUT[11], oeintDOUT[11]);
  buf (DOUT[12], oeintDOUT[12]);
  buf (DOUT[13], oeintDOUT[13]);
  buf (DOUT[14], oeintDOUT[14]);
  buf (DOUT[15], oeintDOUT[15]);
always @(shWADR_notifier) begin
  intWADR = xAdr;
  $display (" WADR timing violation detected %t", $time);
  write_SHerror;
end

always @(shTIWADR_notifier) begin
  intWADR = xAdr;
  $display (" TIWADR timing violation detected %t", $time);
  write_SHerror;
end

always @(shWEN_notifier) begin
  $display (" WEN timing violation detected %t", $time);
  write_SHerror;
end

always @(shTIWEN_notifier) begin
  $display (" TIWEN timing violation detected %t", $time);
  write_SHerror;
end

always @(shDI_notifier) begin
  $display (" DI timing violation detected %t", $time);
  write_SHerror;
end

always @(shTID_notifier) begin
  $display (" TID timing violation detected %t", $time);
  write_SHerror;
end

always @(shTSEWCK_notifier) begin
  $display (" TSE write timing violation detected %t", $time);
  write_SHerror;
end

always @(shTCE_notifier) begin
  $display (" TCE timing violation detected %t", $time);
  write_SHerror;
end

always @(shTRCN_notifier) begin
  $display (" TRCN timing violation detected %t", $time);
  write_SHerror;
end

always @(wt_notifier) begin
  $display (" Write clock min pulse violation detected %t", $time);
  write_SHerror;
end

always @(shRADR_notifier) begin
  intRADR = xAdr;
  $display (" RADR timing violation detected %t", $time);
  read_SHerror;
end

always @(shTIRADR_notifier) begin
  intRADR = xAdr;
  $display (" TIRADR timing violation detected %t", $time);
  read_SHerror;
end

always @(shREN_notifier) begin
  $display (" REN timing violation detected %t", $time);
  read_SHerror;
end

always @(shTIREN_notifier) begin
  $display (" TIREN timing violation detected %t", $time);
  read_SHerror;
end

always @(shTSERCK_notifier) begin
  $display (" TSE read timing violation detected %t", $time);
  read_SHerror;
end

always @(rd_notifier) begin
  $display (" Read clock min pulse violation detected %t", $time);
  read_SHerror;
end

always @(si_rd_wr_conflict_notifier) begin
  $display (" Timing violation ");
  $display (" Read and write to same address at same time %m at %t", $time);
  intDOUT = xData;
  si_rd_wr_conflict_notifier = 1'b0;
end
always @(rd_wr_conflict_notifier) begin 
  intDOUT = xData; 
  rd_wr_conflict_notifier = 1'b0; 
end

task read_SHerror;
  begin
    read_error = 1'b1;
    intDOUT = xData;
    wait (bufRCK === 1'b0);
    read_error = 1'b0;
  end
endtask

task write_SHerror;
  begin
    if (intWEN !== 1'b1) begin 
      write_error = 1'b1;
      if (^intWADR === 1'bx) begin
        for (i = 0; i < words; i=i+1) begin
          memory_array[i] = xData;
        end
      end else begin
        memory_array[intWADR] = xData;
      end
      wait (intWCK === 1'b0);
      write_error = 1'b0;
    end
  end
endtask

specify

    // Path delays
  (RCK *> DOUT[0]) = (1,1);
  (RCK *> DOUT[1]) = (1,1);
  (RCK *> DOUT[2]) = (1,1);
  (RCK *> DOUT[3]) = (1,1);
  (RCK *> DOUT[4]) = (1,1);
  (RCK *> DOUT[5]) = (1,1);
  (RCK *> DOUT[6]) = (1,1);
  (RCK *> DOUT[7]) = (1,1);
  (RCK *> DOUT[8]) = (1,1);
  (RCK *> DOUT[9]) = (1,1);
  (RCK *> DOUT[10]) = (1,1);
  (RCK *> DOUT[11]) = (1,1);
  (RCK *> DOUT[12]) = (1,1);
  (RCK *> DOUT[13]) = (1,1);
  (RCK *> DOUT[14]) = (1,1);
  (RCK *> DOUT[15]) = (1,1);
  (WCK *> DOUT[0]) = (1,1);
  (WCK *> DOUT[1]) = (1,1);
  (WCK *> DOUT[2]) = (1,1);
  (WCK *> DOUT[3]) = (1,1);
  (WCK *> DOUT[4]) = (1,1);
  (WCK *> DOUT[5]) = (1,1);
  (WCK *> DOUT[6]) = (1,1);
  (WCK *> DOUT[7]) = (1,1);
  (WCK *> DOUT[8]) = (1,1);
  (WCK *> DOUT[9]) = (1,1);
  (WCK *> DOUT[10]) = (1,1);
  (WCK *> DOUT[11]) = (1,1);
  (WCK *> DOUT[12]) = (1,1);
  (WCK *> DOUT[13]) = (1,1);
  (WCK *> DOUT[14]) = (1,1);
  (WCK *> DOUT[15]) = (1,1);
          `ifdef no_tchk
          `else 

    // Timing check parameters
  specparam tswadrl = 0;
  specparam thwadrl = 0;
  specparam tswadrh = 0;
  specparam thwadrh = 0;
  specparam tswenl = 0;
  specparam thwenl = 0;
  specparam tswenh = 0;
  specparam thwenh = 0;
  specparam tsdil = 0;
  specparam tsdih = 0;
  specparam thdil = 0;
  specparam thdih = 0;
  specparam tsradrl = 0;
  specparam thradrl = 0;
  specparam tsradrh = 0;
  specparam thradrh = 0;
  specparam tsrenl = 0;
  specparam threnl = 0;
  specparam tsrenh = 0;
  specparam threnh = 0;
  specparam tcyc = 0;
  specparam tlclk = 0;
  specparam thclk = 0;
  specparam tswckrck = 0;
  specparam thwckrck = 0;

    // Timing checks
  $setuphold(posedge WCK , negedge WADR[0]  &&& (WEN===1'b0), tswadrl, thwadrl, shWADR_notifier);
  $setuphold(posedge WCK , posedge WADR[0]  &&& (WEN===1'b0), tswadrh, thwadrh, shWADR_notifier);
  $setuphold(posedge WCK , negedge WADR[1]  &&& (WEN===1'b0), tswadrl, thwadrl, shWADR_notifier);
  $setuphold(posedge WCK , posedge WADR[1]  &&& (WEN===1'b0), tswadrh, thwadrh, shWADR_notifier);
  $setuphold(posedge WCK , negedge WADR[2]  &&& (WEN===1'b0), tswadrl, thwadrl, shWADR_notifier);
  $setuphold(posedge WCK , posedge WADR[2]  &&& (WEN===1'b0), tswadrh, thwadrh, shWADR_notifier);
  $setuphold(posedge WCK , negedge WADR[3]  &&& (WEN===1'b0), tswadrl, thwadrl, shWADR_notifier);
  $setuphold(posedge WCK , posedge WADR[3]  &&& (WEN===1'b0), tswadrh, thwadrh, shWADR_notifier);
  $setuphold(posedge WCK , negedge WADR[4]  &&& (WEN===1'b0), tswadrl, thwadrl, shWADR_notifier);
  $setuphold(posedge WCK , posedge WADR[4]  &&& (WEN===1'b0), tswadrh, thwadrh, shWADR_notifier);
  $setuphold(posedge WCK , negedge WADR[5]  &&& (WEN===1'b0), tswadrl, thwadrl, shWADR_notifier);
  $setuphold(posedge WCK , posedge WADR[5]  &&& (WEN===1'b0), tswadrh, thwadrh, shWADR_notifier);
  $setuphold(posedge WCK , negedge WADR[6]  &&& (WEN===1'b0), tswadrl, thwadrl, shWADR_notifier);
  $setuphold(posedge WCK , posedge WADR[6]  &&& (WEN===1'b0), tswadrh, thwadrh, shWADR_notifier);
  $setuphold(posedge WCK , negedge WEN , tswenl, thwenl, shWEN_notifier);
  $setuphold(posedge WCK , posedge WEN , tswenh, thwenh, shWEN_notifier);
  $setuphold(posedge WCK , negedge DI[0]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[0]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[1]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[1]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[2]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[2]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[3]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[3]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[4]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[4]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[5]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[5]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[6]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[6]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[7]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[7]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[8]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[8]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[9]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[9]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[10]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[10]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[11]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[11]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[12]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[12]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[13]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[13]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[14]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[14]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);
  $setuphold(posedge WCK , negedge DI[15]  &&& (WEN===1'b0), tsdil, thdil, shDI_notifier);
  $setuphold(posedge WCK , posedge DI[15]  &&& (WEN===1'b0), tsdih, thdih, shDI_notifier);

  $setuphold(posedge RCK, negedge RADR[0]  &&& (REN===1'b0), tsradrl, thradrl, shRADR_notifier);
  $setuphold(posedge RCK, posedge RADR[0]  &&& (REN===1'b0), tsradrh, thradrh, shRADR_notifier);
  $setuphold(posedge RCK, negedge RADR[1]  &&& (REN===1'b0), tsradrl, thradrl, shRADR_notifier);
  $setuphold(posedge RCK, posedge RADR[1]  &&& (REN===1'b0), tsradrh, thradrh, shRADR_notifier);
  $setuphold(posedge RCK, negedge RADR[2]  &&& (REN===1'b0), tsradrl, thradrl, shRADR_notifier);
  $setuphold(posedge RCK, posedge RADR[2]  &&& (REN===1'b0), tsradrh, thradrh, shRADR_notifier);
  $setuphold(posedge RCK, negedge RADR[3]  &&& (REN===1'b0), tsradrl, thradrl, shRADR_notifier);
  $setuphold(posedge RCK, posedge RADR[3]  &&& (REN===1'b0), tsradrh, thradrh, shRADR_notifier);
  $setuphold(posedge RCK, negedge RADR[4]  &&& (REN===1'b0), tsradrl, thradrl, shRADR_notifier);
  $setuphold(posedge RCK, posedge RADR[4]  &&& (REN===1'b0), tsradrh, thradrh, shRADR_notifier);
  $setuphold(posedge RCK, negedge RADR[5]  &&& (REN===1'b0), tsradrl, thradrl, shRADR_notifier);
  $setuphold(posedge RCK, posedge RADR[5]  &&& (REN===1'b0), tsradrh, thradrh, shRADR_notifier);
  $setuphold(posedge RCK, negedge RADR[6]  &&& (REN===1'b0), tsradrl, thradrl, shRADR_notifier);
  $setuphold(posedge RCK, posedge RADR[6]  &&& (REN===1'b0), tsradrh, thradrh, shRADR_notifier);
  $setuphold(posedge RCK, negedge REN , tsrenl, threnl, shREN_notifier);
  $setuphold(posedge RCK, posedge REN , tsrenh, threnh, shREN_notifier);

  $period(posedge RCK, tcyc, rd_notifier);
  $width(negedge RCK, tlclk, 0, rd_notifier);
  $width(posedge RCK, thclk, 0, rd_notifier);
  $period(posedge WCK , tcyc, wt_notifier);
  $width(negedge WCK , tlclk, 0, wt_notifier);
  $width(posedge WCK, thclk, 0, wt_notifier);

  $setup(posedge RCK, posedge WCK &&& rflag, tswckrck, rd_wr_conflict_notifier);
  $setup(posedge WCK, posedge RCK &&& wflag, thwckrck, rd_wr_conflict_notifier);


 `endif
endspecify

endmodule
`endcelldefine
