-------------------------------------------------------------------------------
-- Title      : ni_delay_word
-- Project    : Network Interface (NI) for the ALICE TRD TRAP3
-------------------------------------------------------------------------------
-- File       : ni_delay_word.vhd
-- Author     : Rolf Schneider  <rolf.schneider@kip.uni-heidelberg.de>
-- Company    : University Heidelberg - KIP
-- Last update: 2003-12-11
-- Platform   : Synopsys - v2003.03
-------------------------------------------------------------------------------
-- Description: produces a delay matrix for a given depth and bit width
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2003/02/27  1.0      schneide	Created
-------------------------------------------------------------------------------


library IEEE;
use IEEE.std_logic_1164.all;

----------------------------------------------------------------------------------------------------
-- ENTITY
----------------------------------------------------------------------------------------------------
entity ni_delay_word is
  generic (
    width : integer := 12;                                      -- width of word
    depth : integer := 3);                                      -- number of delay stages
  port (
    delay    : in  std_logic_vector((width*depth)-1 downto 0);  -- Bit ...333222111000
    data_in  : in  std_logic_vector(width-1 downto 0);          -- incoming data word
    data_out : out std_logic_vector(width-1 downto 0));         -- delayed data word
end ni_delay_word;

----------------------------------------------------------------------------------------------------
-- ARCHITECTURE
----------------------------------------------------------------------------------------------------
architecture v of ni_delay_word is

  -- COMPONENTS ------------------------------------------------------------------------------------
  component ni_delay_bit
    generic (
      depth : integer);
    port (
      delay    : in  std_logic_vector(depth-1 downto 0);
      data_in  : in  std_logic;
      data_out : out std_logic);
  end component;

  -- STRUCTURE -------------------------------------------------------------------------------------
begin

  -- generate a delay_bit $width times
  U_delayword: for i in width-1 downto 0 generate
    U_delaybit: ni_delay_bit
      generic map (
        depth    => depth)
      port map (
        delay    => delay((i*depth)+(depth-1) downto (i*depth)),
        data_in  => data_in(i),
        data_out => data_out(i));
  end generate;

end v;

----------------------------------------------------------------------------------------------------
-- CONFIGURATION
----------------------------------------------------------------------------------------------------
-- pragma translate_off
configuration ni_delay_word_CFG of ni_delay_word is
  for v
  end for; -- v
end ni_delay_word_CFG;
-- pragma translate_on
