-------------------------------------------------------------------------------
-- Title      : ni_register
-- Project    : Network Interface (NI) for the ALICE TRD TRAP3
-------------------------------------------------------------------------------
-- File       : ni_register.vhd
-- Author     : Rolf Schneider  <rolf.schneider@kip.uni-heidelberg.de>
-- Company    : University Heidelberg - KIP
-- Last update: 2003-12-11
-- Platform   : Synopsys - v2003.03
-------------------------------------------------------------------------------
-- Description: just a simple synchronous register
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2003/03/06  1.0      schneide	Created
-------------------------------------------------------------------------------


library IEEE;
use IEEE.std_logic_1164.all;

----------------------------------------------------------------------------------------------------
-- ENTITY
----------------------------------------------------------------------------------------------------
entity ni_register is
  generic (
    width:      integer := 4);    -- some default value
  port (
    clk:        in  STD_LOGIC;
    reset_n:    in  STD_LOGIC;
    A:          in  STD_LOGIC_VECTOR(width-1 downto 0);  -- input bus A
    O:          out STD_LOGIC_VECTOR(width-1 downto 0)); -- output bus
end ni_register;

----------------------------------------------------------------------------------------------------
-- ARCHITECTURE
----------------------------------------------------------------------------------------------------
architecture v of ni_register is

  -- STRUCTURE -------------------------------------------------------------------------------------
begin

  U_reg: process(clk, reset_n)
  begin
    if reset_n='0' then
      O <= (others => '0');
    elsif rising_edge(clk) then
      O <= A;
    end if;
  end process;

end v;

----------------------------------------------------------------------------------------------------
-- CONFIGURATION
----------------------------------------------------------------------------------------------------
-- pragma translate_off
configuration ni_register_CFG of ni_register is
  for v
  end for; -- v
end ni_register_CFG;
-- pragma translate_on
