-------------------------------------------------------------------------------
-- Title      : ni_register_we
-- Project    : Network Interface (NI) for the ALICE TRD TRAP3
-------------------------------------------------------------------------------
-- File       : ni_register_we.vhd
-- Author     : Rolf Schneider  <rolf.schneider@kip.uni-heidelberg.de>
-- Company    : University Heidelberg - KIP
-- Last update: 2003-12-11
-- Platform   : Synopsys - v2003.03
-------------------------------------------------------------------------------
-- Description: simple synchronous register with write enable and reset value
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2003/03/06  1.0      schneide	Created
-- 2003/12/11  1.1      schneide	Replaced register component by process
-------------------------------------------------------------------------------


library IEEE;
use IEEE.std_logic_1164.all;

----------------------------------------------------------------------------------------------------
-- ENTITY
----------------------------------------------------------------------------------------------------
entity ni_register_we is
  generic (
    width:      integer := 4);    -- some default value
  port (
    clk:        in  STD_LOGIC;
    reset_n:    in  STD_LOGIC;
    reset_A:    in  STD_LOGIC_VECTOR(width-1 downto 0);  -- reset value
    we_n:       in  STD_LOGIC;                           -- write enable for port A
    A:          in  STD_LOGIC_VECTOR(width-1 downto 0);  -- input bus A
    O:          out STD_LOGIC_VECTOR(width-1 downto 0)); -- output bus
end ni_register_we;

----------------------------------------------------------------------------------------------------
-- ARCHITECTURE
----------------------------------------------------------------------------------------------------
architecture v of ni_register_we is

  -- STRUCTURE -------------------------------------------------------------------------------------
begin

  U_we : process(clk, reset_n, reset_A, we_n, A)
  begin
    if(reset_n = '0') then
      O   <= reset_A;                   -- reset (default) value
    elsif rising_edge(clk) then
      if (we_n = '0') then              -- low actice write enable
        O <= A;
      end if;
    end if;
  end process;

end v;

----------------------------------------------------------------------------------------------------
-- CONFIGURATION
----------------------------------------------------------------------------------------------------
-- pragma translate_off
configuration ni_register_we_CFG of ni_register_we is
  for v
  end for; -- v
end ni_register_we_CFG;
-- pragma translate_on
