-------------------------------------------------------------------------------
-- Title      : ni_top
-- Project    : Network Interface (NI) for the ALICE TRD TRAP2
-------------------------------------------------------------------------------
-- File       : ni_top_blkbx.vhd
-- Author     : Rolf Schneider  <rolf.schneider@kip.uni-heidelberg.de>
-- Company    : University Heidelberg - KIP
-- Last update: 2003-04-11
-- Platform   : Synopsys - v2003.03
-------------------------------------------------------------------------------
-- Description: Black box of top level design ni_top
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2003/03/19  1.0      schneide	Created
-------------------------------------------------------------------------------


library IEEE;
use IEEE.std_logic_1164.all;
use WORK.ni_global.all;

----------------------------------------------------------------------------------------------------
-- ENTITY
----------------------------------------------------------------------------------------------------
entity ni_top is
  generic (
    width          :     INTEGER := 32);
  port (
    clk            : in  STD_LOGIC;     -- internal clock
    clk_glob       : in  STD_LOGIC;     -- global bus clock
    clk_alws       : in  STD_LOGIC;     -- clock for optical link
    reset_n        : in  STD_LOGIC;     -- asynchronous reset
    clear_n        : in  STD_LOGIC;     -- synchronous reset
    mode_tr        : in  STD_LOGIC;     -- trigger readout mode
    mode_rr        : in  STD_LOGIC;     -- raw data readout mode
    finished_n     : out STD_LOGIC;     -- tr/rr readout is finished
    -- local bus 0
    we_0           : in  STD_LOGIC;
    address_0      : in  STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
    din_0          : in  STD_LOGIC_VECTOR(width-1 downto 0);
    dout_0         : out STD_LOGIC_VECTOR(width-1 downto 0);
    intr_0         : out STD_LOGIC_VECTOR(2 downto 0);  -- interrupts to CPU0
    -- local bus 1
    we_1           : in  STD_LOGIC;
    address_1      : in  STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
    din_1          : in  STD_LOGIC_VECTOR(width-1 downto 0);
    dout_1         : out STD_LOGIC_VECTOR(width-1 downto 0);
    intr_1         : out STD_LOGIC_VECTOR(2 downto 0);  -- interrupts to CPU1
    -- local bus 2
    we_2           : in  STD_LOGIC;
    address_2      : in  STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
    din_2          : in  STD_LOGIC_VECTOR(width-1 downto 0);
    dout_2         : out STD_LOGIC_VECTOR(width-1 downto 0);
    intr_2         : out STD_LOGIC_VECTOR(2 downto 0);  -- interrupts to CPU2
    -- local bus 3
    we_3           : in  STD_LOGIC;
    address_3      : in  STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
    din_3          : in  STD_LOGIC_VECTOR(width-1 downto 0);
    dout_3         : out STD_LOGIC_VECTOR(width-1 downto 0);
    intr_3         : out STD_LOGIC_VECTOR(2 downto 0);  -- interrupts to CPU3
    -- global
    we_g           : in  STD_LOGIC;
    address_g      : in  STD_LOGIC_VECTOR(io_address_bus_width-1 downto 0);
    din_g          : in  STD_LOGIC_VECTOR(width-1 downto 0);
    dout_g         : out STD_LOGIC_VECTOR(width-1 downto 0);
    intr_g         : out STD_LOGIC;     -- global interrupt
    -- port 0
    p_strobe_in_0  : in  STD_LOGIC;
    p_d_in_0       : in  STD_LOGIC_VECTOR((width/4)+1 downto 0);
    p_ctrl_out_0   : out STD_LOGIC;
    -- port 1
    p_strobe_in_1  : in  STD_LOGIC;
    p_d_in_1       : in  STD_LOGIC_VECTOR((width/4)+1 downto 0);
    p_ctrl_out_1   : out STD_LOGIC;
    -- port 2
    p_strobe_in_2  : in  STD_LOGIC;
    p_d_in_2       : in  STD_LOGIC_VECTOR((width/4)+1 downto 0);
    p_ctrl_out_2   : out STD_LOGIC;
    -- port 3
    p_strobe_in_3  : in  STD_LOGIC;
    p_d_in_3       : in  STD_LOGIC_VECTOR((width/4)+1 downto 0);
    p_ctrl_out_3   : out STD_LOGIC;
    -- port 4 (output)
    p_ctrl_in      : in  STD_LOGIC;
    p_strobe_out   : out STD_LOGIC;     -- optical link mode: clock output
    p_d_out        : out STD_LOGIC_VECTOR((width/4)+1 downto 0);
    p_ctrl         : out STD_LOGIC      -- control/data signal for optical link output
    );
end ni_top;

----------------------------------------------------------------------------------------------------
-- ARCHITECTURE
----------------------------------------------------------------------------------------------------
architecture v of ni_top is

begin

end v;
